// This file consists of testcases taken from the MSVC STL testsuite.

// Copyright (c) Microsoft Corporation.
// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception


// Copyright 2018 Ulf Adams
// Copyright (c) Microsoft Corporation. All rights reserved.

// Boost Software License - Version 1.0 - August 17th, 2003

// Permission is hereby granted, free of charge, to any person or organization
// obtaining a copy of the software and accompanying documentation covered by
// this license (the "Software") to use, reproduce, display, distribute,
// execute, and transmit the Software, and to prepare derivative works of the
// Software, and to permit third-parties to whom the Software is furnished to
// do so, all subject to the following:

// The copyright notices in the Software and this entire statement, including
// the above license grant, this restriction and the following disclaimer,
// must be included in all copies of the Software, in whole or in part, and
// all derivative works of the Software, unless such copies or derivative
// works are solely in the form of machine-executable object code generated by
// a source language processor.

// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE, TITLE AND NON-INFRINGEMENT. IN NO EVENT
// SHALL THE COPYRIGHT HOLDERS OR ANYONE DISTRIBUTING THE SOFTWARE BE LIABLE
// FOR ANY DAMAGES OR OTHER LIABILITY, WHETHER IN CONTRACT, TORT OR OTHERWISE,
// ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
// DEALINGS IN THE SOFTWARE.

// { dg-do run { target c++17 } }
// { dg-require-effective-target ieee-floats }
// { dg-require-effective-target size32plus }

#include <charconv>

#include <cstring>
#include <limits>
#include <optional>

#include <testsuite_hooks.h>

using namespace std;

inline constexpr double double_inf = numeric_limits<double>::infinity();
inline constexpr double double_nan = numeric_limits<double>::quiet_NaN();

struct double_to_chars_testcase {
    double value;
    chars_format fmt;
    optional<int> precision;
    const char* correct;

    constexpr
    double_to_chars_testcase(double value, chars_format fmt, const char* correct)
      : value (value), fmt (fmt), precision (nullopt), correct (correct)
    { }

    constexpr
    double_to_chars_testcase(double value, chars_format fmt, int precision,
			     const char* correct)
      : value (value), fmt (fmt), precision (precision), correct (correct)
    { }
};

inline constexpr double_to_chars_testcase double_to_chars_test_cases[] = {
    // Test special cases (zero, inf, nan) and an ordinary case. Also test negative signs.
    {0.0, chars_format::scientific, "0e+00"},
    {-0.0, chars_format::scientific, "-0e+00"},
    {double_inf, chars_format::scientific, "inf"},
    {-double_inf, chars_format::scientific, "-inf"},
    {double_nan, chars_format::scientific, "nan"},
    {-double_nan, chars_format::scientific, "-nan"},
    {2.018, chars_format::scientific, "2.018e+00"},
    {-2.018, chars_format::scientific, "-2.018e+00"},

    // Ditto for fixed, which doesn't emit exponents.
    {0.0, chars_format::fixed, "0"},
    {-0.0, chars_format::fixed, "-0"},
    {double_inf, chars_format::fixed, "inf"},
    {-double_inf, chars_format::fixed, "-inf"},
    {double_nan, chars_format::fixed, "nan"},
    {-double_nan, chars_format::fixed, "-nan"},
    {2.018, chars_format::fixed, "2.018"},
    {-2.018, chars_format::fixed, "-2.018"},

    // Ditto for general, which selects fixed for the scientific exponent 0.
    {0.0, chars_format::general, "0"},
    {-0.0, chars_format::general, "-0"},
    {double_inf, chars_format::general, "inf"},
    {-double_inf, chars_format::general, "-inf"},
    {double_nan, chars_format::general, "nan"},
    {-double_nan, chars_format::general, "-nan"},
    {2.018, chars_format::general, "2.018"},
    {-2.018, chars_format::general, "-2.018"},

    // Ditto for plain, which selects fixed because it's shorter for these values.
    {0.0, chars_format{}, "0"},
    {-0.0, chars_format{}, "-0"},
    {double_inf, chars_format{}, "inf"},
    {-double_inf, chars_format{}, "-inf"},
    {double_nan, chars_format{}, "nan"},
    {-double_nan, chars_format{}, "-nan"},
    {2.018, chars_format{}, "2.018"},
    {-2.018, chars_format{}, "-2.018"},

    // Ditto for hex.
    {0.0, chars_format::hex, "0p+0"},
    {-0.0, chars_format::hex, "-0p+0"},
    {double_inf, chars_format::hex, "inf"},
    {-double_inf, chars_format::hex, "-inf"},
    {double_nan, chars_format::hex, "nan"},
    {-double_nan, chars_format::hex, "-nan"},
    {0x1.729p+0, chars_format::hex, "1.729p+0"},
    {-0x1.729p+0, chars_format::hex, "-1.729p+0"},

    // Ryu d2s_test.cc SwitchToSubnormal
    {2.2250738585072014e-308, chars_format::scientific, "2.2250738585072014e-308"},

    // Ryu d2s_test.cc MinAndMax
    {0x1.fffffffffffffp+1023, chars_format::scientific, "1.7976931348623157e+308"},
    {0x0.0000000000001p-1022, chars_format::scientific, "5e-324"},

    // Ryu d2s_test.cc LotsOfTrailingZeros
    {2.98023223876953125e-8, chars_format::scientific, "2.9802322387695312e-08"},

    // Ryu d2s_test.cc Regression
    {-2.109808898695963e16, chars_format::scientific, "-2.109808898695963e+16"},
    {4.940656e-318, chars_format::scientific, "4.940656e-318"},
    {1.18575755e-316, chars_format::scientific, "1.18575755e-316"},
    {2.989102097996e-312, chars_format::scientific, "2.989102097996e-312"},
    {9.0608011534336e15, chars_format::scientific, "9.0608011534336e+15"},
    {4.708356024711512e18, chars_format::scientific, "4.708356024711512e+18"},
    {9.409340012568248e18, chars_format::scientific, "9.409340012568248e+18"},

    // Ryu d2s_test.cc LooksLikePow5
    {0x1.0f0cf064dd592p+132, chars_format::scientific, "5.764607523034235e+39"},
    {0x1.0f0cf064dd592p+133, chars_format::scientific, "1.152921504606847e+40"},
    {0x1.0f0cf064dd592p+134, chars_format::scientific, "2.305843009213694e+40"},

    // Ryu d2s_test.cc OutputLength
    {1.0, chars_format::scientific, "1e+00"},
    {1.2, chars_format::scientific, "1.2e+00"},
    {1.23, chars_format::scientific, "1.23e+00"},
    {1.234, chars_format::scientific, "1.234e+00"},
    {1.2345, chars_format::scientific, "1.2345e+00"},
    {1.23456, chars_format::scientific, "1.23456e+00"},
    {1.234567, chars_format::scientific, "1.234567e+00"},
    {1.2345678, chars_format::scientific, "1.2345678e+00"},
    {1.23456789, chars_format::scientific, "1.23456789e+00"},
    {1.234567895, chars_format::scientific, "1.234567895e+00"},
    {1.2345678901, chars_format::scientific, "1.2345678901e+00"},
    {1.23456789012, chars_format::scientific, "1.23456789012e+00"},
    {1.234567890123, chars_format::scientific, "1.234567890123e+00"},
    {1.2345678901234, chars_format::scientific, "1.2345678901234e+00"},
    {1.23456789012345, chars_format::scientific, "1.23456789012345e+00"},
    {1.234567890123456, chars_format::scientific, "1.234567890123456e+00"},
    {1.2345678901234567, chars_format::scientific, "1.2345678901234567e+00"},

    // Ryu d2s_test.cc 32-bit Chunking
    {4.294967294, chars_format::scientific, "4.294967294e+00"},
    {4.294967295, chars_format::scientific, "4.294967295e+00"},
    {4.294967296, chars_format::scientific, "4.294967296e+00"},
    {4.294967297, chars_format::scientific, "4.294967297e+00"},
    {4.294967298, chars_format::scientific, "4.294967298e+00"},

    // Ryu d2s_test.cc MinMaxShift
    {0x1.0000000000000p-1019, chars_format::scientific, "1.7800590868057611e-307"},
    {0x1.fffffffffffffp-1016, chars_format::scientific, "2.8480945388892175e-306"},
    {0x1.0000000000000p-982, chars_format::scientific, "2.446494580089078e-296"},
    {0x1.fffffffffffffp-982, chars_format::scientific, "4.8929891601781557e-296"},
    {0x1.0000000000000p+54, chars_format::scientific, "1.8014398509481984e+16"},
    {0x1.fffffffffffffp+54, chars_format::scientific, "3.6028797018963964e+16"},
    {0x1.0000000000000p-716, chars_format::scientific, "2.900835519859558e-216"},
    {0x1.fffffffffffffp-716, chars_format::scientific, "5.801671039719115e-216"},
    {0x1.fa7161a4d6e0cp-89, chars_format::scientific, "3.196104012172126e-27"},

    // Ryu d2s_test.cc SmallIntegers
    {9007199254740991.0, chars_format::scientific, "9.007199254740991e+15"},
    {9007199254740992.0, chars_format::scientific, "9.007199254740992e+15"},

    {1.0, chars_format::scientific, "1e+00"},
    {12.0, chars_format::scientific, "1.2e+01"},
    {123.0, chars_format::scientific, "1.23e+02"},
    {1234.0, chars_format::scientific, "1.234e+03"},
    {12345.0, chars_format::scientific, "1.2345e+04"},
    {123456.0, chars_format::scientific, "1.23456e+05"},
    {1234567.0, chars_format::scientific, "1.234567e+06"},
    {12345678.0, chars_format::scientific, "1.2345678e+07"},
    {123456789.0, chars_format::scientific, "1.23456789e+08"},
    {1234567890.0, chars_format::scientific, "1.23456789e+09"},
    {1234567895.0, chars_format::scientific, "1.234567895e+09"},
    {12345678901.0, chars_format::scientific, "1.2345678901e+10"},
    {123456789012.0, chars_format::scientific, "1.23456789012e+11"},
    {1234567890123.0, chars_format::scientific, "1.234567890123e+12"},
    {12345678901234.0, chars_format::scientific, "1.2345678901234e+13"},
    {123456789012345.0, chars_format::scientific, "1.23456789012345e+14"},
    {1234567890123456.0, chars_format::scientific, "1.234567890123456e+15"},

    {1.0, chars_format::scientific, "1e+00"},
    {10.0, chars_format::scientific, "1e+01"},
    {100.0, chars_format::scientific, "1e+02"},
    {1000.0, chars_format::scientific, "1e+03"},
    {10000.0, chars_format::scientific, "1e+04"},
    {100000.0, chars_format::scientific, "1e+05"},
    {1000000.0, chars_format::scientific, "1e+06"},
    {10000000.0, chars_format::scientific, "1e+07"},
    {100000000.0, chars_format::scientific, "1e+08"},
    {1000000000.0, chars_format::scientific, "1e+09"},
    {10000000000.0, chars_format::scientific, "1e+10"},
    {100000000000.0, chars_format::scientific, "1e+11"},
    {1000000000000.0, chars_format::scientific, "1e+12"},
    {10000000000000.0, chars_format::scientific, "1e+13"},
    {100000000000000.0, chars_format::scientific, "1e+14"},
    {1000000000000000.0, chars_format::scientific, "1e+15"},

    {1000000000000001.0, chars_format::scientific, "1.000000000000001e+15"},
    {1000000000000010.0, chars_format::scientific, "1.00000000000001e+15"},
    {1000000000000100.0, chars_format::scientific, "1.0000000000001e+15"},
    {1000000000001000.0, chars_format::scientific, "1.000000000001e+15"},
    {1000000000010000.0, chars_format::scientific, "1.00000000001e+15"},
    {1000000000100000.0, chars_format::scientific, "1.0000000001e+15"},
    {1000000001000000.0, chars_format::scientific, "1.000000001e+15"},
    {1000000010000000.0, chars_format::scientific, "1.00000001e+15"},
    {1000000100000000.0, chars_format::scientific, "1.0000001e+15"},
    {1000001000000000.0, chars_format::scientific, "1.000001e+15"},
    {1000010000000000.0, chars_format::scientific, "1.00001e+15"},
    {1000100000000000.0, chars_format::scientific, "1.0001e+15"},
    {1001000000000000.0, chars_format::scientific, "1.001e+15"},
    {1010000000000000.0, chars_format::scientific, "1.01e+15"},
    {1100000000000000.0, chars_format::scientific, "1.1e+15"},

    {8.0, chars_format::scientific, "8e+00"},
    {64.0, chars_format::scientific, "6.4e+01"},
    {512.0, chars_format::scientific, "5.12e+02"},
    {8192.0, chars_format::scientific, "8.192e+03"},
    {65536.0, chars_format::scientific, "6.5536e+04"},
    {524288.0, chars_format::scientific, "5.24288e+05"},
    {8388608.0, chars_format::scientific, "8.388608e+06"},
    {67108864.0, chars_format::scientific, "6.7108864e+07"},
    {536870912.0, chars_format::scientific, "5.36870912e+08"},
    {8589934592.0, chars_format::scientific, "8.589934592e+09"},
    {68719476736.0, chars_format::scientific, "6.8719476736e+10"},
    {549755813888.0, chars_format::scientific, "5.49755813888e+11"},
    {8796093022208.0, chars_format::scientific, "8.796093022208e+12"},
    {70368744177664.0, chars_format::scientific, "7.0368744177664e+13"},
    {562949953421312.0, chars_format::scientific, "5.62949953421312e+14"},
    {9007199254740992.0, chars_format::scientific, "9.007199254740992e+15"},

    {8000.0, chars_format::scientific, "8e+03"},
    {64000.0, chars_format::scientific, "6.4e+04"},
    {512000.0, chars_format::scientific, "5.12e+05"},
    {8192000.0, chars_format::scientific, "8.192e+06"},
    {65536000.0, chars_format::scientific, "6.5536e+07"},
    {524288000.0, chars_format::scientific, "5.24288e+08"},
    {8388608000.0, chars_format::scientific, "8.388608e+09"},
    {67108864000.0, chars_format::scientific, "6.7108864e+10"},
    {536870912000.0, chars_format::scientific, "5.36870912e+11"},
    {8589934592000.0, chars_format::scientific, "8.589934592e+12"},
    {68719476736000.0, chars_format::scientific, "6.8719476736e+13"},
    {549755813888000.0, chars_format::scientific, "5.49755813888e+14"},
    {8796093022208000.0, chars_format::scientific, "8.796093022208e+15"},

    // Test all exponents.
    {7.29e-324, chars_format::scientific, "5e-324"}, // 1.729e-324 would be too small
    {1.729e-323, chars_format::scientific, "1.5e-323"},
    {1.729e-322, chars_format::scientific, "1.73e-322"},
    {1.729e-321, chars_format::scientific, "1.73e-321"},
    {1.729e-320, chars_format::scientific, "1.729e-320"},
    {1.729e-319, chars_format::scientific, "1.729e-319"},
    {1.729e-318, chars_format::scientific, "1.729e-318"},
    {1.729e-317, chars_format::scientific, "1.729e-317"},
    {1.729e-316, chars_format::scientific, "1.729e-316"},
    {1.729e-315, chars_format::scientific, "1.729e-315"},
    {1.729e-314, chars_format::scientific, "1.729e-314"},
    {1.729e-313, chars_format::scientific, "1.729e-313"},
    {1.729e-312, chars_format::scientific, "1.729e-312"},
    {1.729e-311, chars_format::scientific, "1.729e-311"},
    {1.729e-310, chars_format::scientific, "1.729e-310"},
    {1.729e-309, chars_format::scientific, "1.729e-309"},
    {1.729e-308, chars_format::scientific, "1.729e-308"},
    {1.729e-307, chars_format::scientific, "1.729e-307"},
    {1.729e-306, chars_format::scientific, "1.729e-306"},
    {1.729e-305, chars_format::scientific, "1.729e-305"},
    {1.729e-304, chars_format::scientific, "1.729e-304"},
    {1.729e-303, chars_format::scientific, "1.729e-303"},
    {1.729e-302, chars_format::scientific, "1.729e-302"},
    {1.729e-301, chars_format::scientific, "1.729e-301"},
    {1.729e-300, chars_format::scientific, "1.729e-300"},
    {1.729e-299, chars_format::scientific, "1.729e-299"},
    {1.729e-298, chars_format::scientific, "1.729e-298"},
    {1.729e-297, chars_format::scientific, "1.729e-297"},
    {1.729e-296, chars_format::scientific, "1.729e-296"},
    {1.729e-295, chars_format::scientific, "1.729e-295"},
    {1.729e-294, chars_format::scientific, "1.729e-294"},
    {1.729e-293, chars_format::scientific, "1.729e-293"},
    {1.729e-292, chars_format::scientific, "1.729e-292"},
    {1.729e-291, chars_format::scientific, "1.729e-291"},
    {1.729e-290, chars_format::scientific, "1.729e-290"},
    {1.729e-289, chars_format::scientific, "1.729e-289"},
    {1.729e-288, chars_format::scientific, "1.729e-288"},
    {1.729e-287, chars_format::scientific, "1.729e-287"},
    {1.729e-286, chars_format::scientific, "1.729e-286"},
    {1.729e-285, chars_format::scientific, "1.729e-285"},
    {1.729e-284, chars_format::scientific, "1.729e-284"},
    {1.729e-283, chars_format::scientific, "1.729e-283"},
    {1.729e-282, chars_format::scientific, "1.729e-282"},
    {1.729e-281, chars_format::scientific, "1.729e-281"},
    {1.729e-280, chars_format::scientific, "1.729e-280"},
    {1.729e-279, chars_format::scientific, "1.729e-279"},
    {1.729e-278, chars_format::scientific, "1.729e-278"},
    {1.729e-277, chars_format::scientific, "1.729e-277"},
    {1.729e-276, chars_format::scientific, "1.729e-276"},
    {1.729e-275, chars_format::scientific, "1.729e-275"},
    {1.729e-274, chars_format::scientific, "1.729e-274"},
    {1.729e-273, chars_format::scientific, "1.729e-273"},
    {1.729e-272, chars_format::scientific, "1.729e-272"},
    {1.729e-271, chars_format::scientific, "1.729e-271"},
    {1.729e-270, chars_format::scientific, "1.729e-270"},
    {1.729e-269, chars_format::scientific, "1.729e-269"},
    {1.729e-268, chars_format::scientific, "1.729e-268"},
    {1.729e-267, chars_format::scientific, "1.729e-267"},
    {1.729e-266, chars_format::scientific, "1.729e-266"},
    {1.729e-265, chars_format::scientific, "1.729e-265"},
    {1.729e-264, chars_format::scientific, "1.729e-264"},
    {1.729e-263, chars_format::scientific, "1.729e-263"},
    {1.729e-262, chars_format::scientific, "1.729e-262"},
    {1.729e-261, chars_format::scientific, "1.729e-261"},
    {1.729e-260, chars_format::scientific, "1.729e-260"},
    {1.729e-259, chars_format::scientific, "1.729e-259"},
    {1.729e-258, chars_format::scientific, "1.729e-258"},
    {1.729e-257, chars_format::scientific, "1.729e-257"},
    {1.729e-256, chars_format::scientific, "1.729e-256"},
    {1.729e-255, chars_format::scientific, "1.729e-255"},
    {1.729e-254, chars_format::scientific, "1.729e-254"},
    {1.729e-253, chars_format::scientific, "1.729e-253"},
    {1.729e-252, chars_format::scientific, "1.729e-252"},
    {1.729e-251, chars_format::scientific, "1.729e-251"},
    {1.729e-250, chars_format::scientific, "1.729e-250"},
    {1.729e-249, chars_format::scientific, "1.729e-249"},
    {1.729e-248, chars_format::scientific, "1.729e-248"},
    {1.729e-247, chars_format::scientific, "1.729e-247"},
    {1.729e-246, chars_format::scientific, "1.729e-246"},
    {1.729e-245, chars_format::scientific, "1.729e-245"},
    {1.729e-244, chars_format::scientific, "1.729e-244"},
    {1.729e-243, chars_format::scientific, "1.729e-243"},
    {1.729e-242, chars_format::scientific, "1.729e-242"},
    {1.729e-241, chars_format::scientific, "1.729e-241"},
    {1.729e-240, chars_format::scientific, "1.729e-240"},
    {1.729e-239, chars_format::scientific, "1.729e-239"},
    {1.729e-238, chars_format::scientific, "1.729e-238"},
    {1.729e-237, chars_format::scientific, "1.729e-237"},
    {1.729e-236, chars_format::scientific, "1.729e-236"},
    {1.729e-235, chars_format::scientific, "1.729e-235"},
    {1.729e-234, chars_format::scientific, "1.729e-234"},
    {1.729e-233, chars_format::scientific, "1.729e-233"},
    {1.729e-232, chars_format::scientific, "1.729e-232"},
    {1.729e-231, chars_format::scientific, "1.729e-231"},
    {1.729e-230, chars_format::scientific, "1.729e-230"},
    {1.729e-229, chars_format::scientific, "1.729e-229"},
    {1.729e-228, chars_format::scientific, "1.729e-228"},
    {1.729e-227, chars_format::scientific, "1.729e-227"},
    {1.729e-226, chars_format::scientific, "1.729e-226"},
    {1.729e-225, chars_format::scientific, "1.729e-225"},
    {1.729e-224, chars_format::scientific, "1.729e-224"},
    {1.729e-223, chars_format::scientific, "1.729e-223"},
    {1.729e-222, chars_format::scientific, "1.729e-222"},
    {1.729e-221, chars_format::scientific, "1.729e-221"},
    {1.729e-220, chars_format::scientific, "1.729e-220"},
    {1.729e-219, chars_format::scientific, "1.729e-219"},
    {1.729e-218, chars_format::scientific, "1.729e-218"},
    {1.729e-217, chars_format::scientific, "1.729e-217"},
    {1.729e-216, chars_format::scientific, "1.729e-216"},
    {1.729e-215, chars_format::scientific, "1.729e-215"},
    {1.729e-214, chars_format::scientific, "1.729e-214"},
    {1.729e-213, chars_format::scientific, "1.729e-213"},
    {1.729e-212, chars_format::scientific, "1.729e-212"},
    {1.729e-211, chars_format::scientific, "1.729e-211"},
    {1.729e-210, chars_format::scientific, "1.729e-210"},
    {1.729e-209, chars_format::scientific, "1.729e-209"},
    {1.729e-208, chars_format::scientific, "1.729e-208"},
    {1.729e-207, chars_format::scientific, "1.729e-207"},
    {1.729e-206, chars_format::scientific, "1.729e-206"},
    {1.729e-205, chars_format::scientific, "1.729e-205"},
    {1.729e-204, chars_format::scientific, "1.729e-204"},
    {1.729e-203, chars_format::scientific, "1.729e-203"},
    {1.729e-202, chars_format::scientific, "1.729e-202"},
    {1.729e-201, chars_format::scientific, "1.729e-201"},
    {1.729e-200, chars_format::scientific, "1.729e-200"},
    {1.729e-199, chars_format::scientific, "1.729e-199"},
    {1.729e-198, chars_format::scientific, "1.729e-198"},
    {1.729e-197, chars_format::scientific, "1.729e-197"},
    {1.729e-196, chars_format::scientific, "1.729e-196"},
    {1.729e-195, chars_format::scientific, "1.729e-195"},
    {1.729e-194, chars_format::scientific, "1.729e-194"},
    {1.729e-193, chars_format::scientific, "1.729e-193"},
    {1.729e-192, chars_format::scientific, "1.729e-192"},
    {1.729e-191, chars_format::scientific, "1.729e-191"},
    {1.729e-190, chars_format::scientific, "1.729e-190"},
    {1.729e-189, chars_format::scientific, "1.729e-189"},
    {1.729e-188, chars_format::scientific, "1.729e-188"},
    {1.729e-187, chars_format::scientific, "1.729e-187"},
    {1.729e-186, chars_format::scientific, "1.729e-186"},
    {1.729e-185, chars_format::scientific, "1.729e-185"},
    {1.729e-184, chars_format::scientific, "1.729e-184"},
    {1.729e-183, chars_format::scientific, "1.729e-183"},
    {1.729e-182, chars_format::scientific, "1.729e-182"},
    {1.729e-181, chars_format::scientific, "1.729e-181"},
    {1.729e-180, chars_format::scientific, "1.729e-180"},
    {1.729e-179, chars_format::scientific, "1.729e-179"},
    {1.729e-178, chars_format::scientific, "1.729e-178"},
    {1.729e-177, chars_format::scientific, "1.729e-177"},
    {1.729e-176, chars_format::scientific, "1.729e-176"},
    {1.729e-175, chars_format::scientific, "1.729e-175"},
    {1.729e-174, chars_format::scientific, "1.729e-174"},
    {1.729e-173, chars_format::scientific, "1.729e-173"},
    {1.729e-172, chars_format::scientific, "1.729e-172"},
    {1.729e-171, chars_format::scientific, "1.729e-171"},
    {1.729e-170, chars_format::scientific, "1.729e-170"},
    {1.729e-169, chars_format::scientific, "1.729e-169"},
    {1.729e-168, chars_format::scientific, "1.729e-168"},
    {1.729e-167, chars_format::scientific, "1.729e-167"},
    {1.729e-166, chars_format::scientific, "1.729e-166"},
    {1.729e-165, chars_format::scientific, "1.729e-165"},
    {1.729e-164, chars_format::scientific, "1.729e-164"},
    {1.729e-163, chars_format::scientific, "1.729e-163"},
    {1.729e-162, chars_format::scientific, "1.729e-162"},
    {1.729e-161, chars_format::scientific, "1.729e-161"},
    {1.729e-160, chars_format::scientific, "1.729e-160"},
    {1.729e-159, chars_format::scientific, "1.729e-159"},
    {1.729e-158, chars_format::scientific, "1.729e-158"},
    {1.729e-157, chars_format::scientific, "1.729e-157"},
    {1.729e-156, chars_format::scientific, "1.729e-156"},
    {1.729e-155, chars_format::scientific, "1.729e-155"},
    {1.729e-154, chars_format::scientific, "1.729e-154"},
    {1.729e-153, chars_format::scientific, "1.729e-153"},
    {1.729e-152, chars_format::scientific, "1.729e-152"},
    {1.729e-151, chars_format::scientific, "1.729e-151"},
    {1.729e-150, chars_format::scientific, "1.729e-150"},
    {1.729e-149, chars_format::scientific, "1.729e-149"},
    {1.729e-148, chars_format::scientific, "1.729e-148"},
    {1.729e-147, chars_format::scientific, "1.729e-147"},
    {1.729e-146, chars_format::scientific, "1.729e-146"},
    {1.729e-145, chars_format::scientific, "1.729e-145"},
    {1.729e-144, chars_format::scientific, "1.729e-144"},
    {1.729e-143, chars_format::scientific, "1.729e-143"},
    {1.729e-142, chars_format::scientific, "1.729e-142"},
    {1.729e-141, chars_format::scientific, "1.729e-141"},
    {1.729e-140, chars_format::scientific, "1.729e-140"},
    {1.729e-139, chars_format::scientific, "1.729e-139"},
    {1.729e-138, chars_format::scientific, "1.729e-138"},
    {1.729e-137, chars_format::scientific, "1.729e-137"},
    {1.729e-136, chars_format::scientific, "1.729e-136"},
    {1.729e-135, chars_format::scientific, "1.729e-135"},
    {1.729e-134, chars_format::scientific, "1.729e-134"},
    {1.729e-133, chars_format::scientific, "1.729e-133"},
    {1.729e-132, chars_format::scientific, "1.729e-132"},
    {1.729e-131, chars_format::scientific, "1.729e-131"},
    {1.729e-130, chars_format::scientific, "1.729e-130"},
    {1.729e-129, chars_format::scientific, "1.729e-129"},
    {1.729e-128, chars_format::scientific, "1.729e-128"},
    {1.729e-127, chars_format::scientific, "1.729e-127"},
    {1.729e-126, chars_format::scientific, "1.729e-126"},
    {1.729e-125, chars_format::scientific, "1.729e-125"},
    {1.729e-124, chars_format::scientific, "1.729e-124"},
    {1.729e-123, chars_format::scientific, "1.729e-123"},
    {1.729e-122, chars_format::scientific, "1.729e-122"},
    {1.729e-121, chars_format::scientific, "1.729e-121"},
    {1.729e-120, chars_format::scientific, "1.729e-120"},
    {1.729e-119, chars_format::scientific, "1.729e-119"},
    {1.729e-118, chars_format::scientific, "1.729e-118"},
    {1.729e-117, chars_format::scientific, "1.729e-117"},
    {1.729e-116, chars_format::scientific, "1.729e-116"},
    {1.729e-115, chars_format::scientific, "1.729e-115"},
    {1.729e-114, chars_format::scientific, "1.729e-114"},
    {1.729e-113, chars_format::scientific, "1.729e-113"},
    {1.729e-112, chars_format::scientific, "1.729e-112"},
    {1.729e-111, chars_format::scientific, "1.729e-111"},
    {1.729e-110, chars_format::scientific, "1.729e-110"},
    {1.729e-109, chars_format::scientific, "1.729e-109"},
    {1.729e-108, chars_format::scientific, "1.729e-108"},
    {1.729e-107, chars_format::scientific, "1.729e-107"},
    {1.729e-106, chars_format::scientific, "1.729e-106"},
    {1.729e-105, chars_format::scientific, "1.729e-105"},
    {1.729e-104, chars_format::scientific, "1.729e-104"},
    {1.729e-103, chars_format::scientific, "1.729e-103"},
    {1.729e-102, chars_format::scientific, "1.729e-102"},
    {1.729e-101, chars_format::scientific, "1.729e-101"},
    {1.729e-100, chars_format::scientific, "1.729e-100"},
    {1.729e-99, chars_format::scientific, "1.729e-99"},
    {1.729e-98, chars_format::scientific, "1.729e-98"},
    {1.729e-97, chars_format::scientific, "1.729e-97"},
    {1.729e-96, chars_format::scientific, "1.729e-96"},
    {1.729e-95, chars_format::scientific, "1.729e-95"},
    {1.729e-94, chars_format::scientific, "1.729e-94"},
    {1.729e-93, chars_format::scientific, "1.729e-93"},
    {1.729e-92, chars_format::scientific, "1.729e-92"},
    {1.729e-91, chars_format::scientific, "1.729e-91"},
    {1.729e-90, chars_format::scientific, "1.729e-90"},
    {1.729e-89, chars_format::scientific, "1.729e-89"},
    {1.729e-88, chars_format::scientific, "1.729e-88"},
    {1.729e-87, chars_format::scientific, "1.729e-87"},
    {1.729e-86, chars_format::scientific, "1.729e-86"},
    {1.729e-85, chars_format::scientific, "1.729e-85"},
    {1.729e-84, chars_format::scientific, "1.729e-84"},
    {1.729e-83, chars_format::scientific, "1.729e-83"},
    {1.729e-82, chars_format::scientific, "1.729e-82"},
    {1.729e-81, chars_format::scientific, "1.729e-81"},
    {1.729e-80, chars_format::scientific, "1.729e-80"},
    {1.729e-79, chars_format::scientific, "1.729e-79"},
    {1.729e-78, chars_format::scientific, "1.729e-78"},
    {1.729e-77, chars_format::scientific, "1.729e-77"},
    {1.729e-76, chars_format::scientific, "1.729e-76"},
    {1.729e-75, chars_format::scientific, "1.729e-75"},
    {1.729e-74, chars_format::scientific, "1.729e-74"},
    {1.729e-73, chars_format::scientific, "1.729e-73"},
    {1.729e-72, chars_format::scientific, "1.729e-72"},
    {1.729e-71, chars_format::scientific, "1.729e-71"},
    {1.729e-70, chars_format::scientific, "1.729e-70"},
    {1.729e-69, chars_format::scientific, "1.729e-69"},
    {1.729e-68, chars_format::scientific, "1.729e-68"},
    {1.729e-67, chars_format::scientific, "1.729e-67"},
    {1.729e-66, chars_format::scientific, "1.729e-66"},
    {1.729e-65, chars_format::scientific, "1.729e-65"},
    {1.729e-64, chars_format::scientific, "1.729e-64"},
    {1.729e-63, chars_format::scientific, "1.729e-63"},
    {1.729e-62, chars_format::scientific, "1.729e-62"},
    {1.729e-61, chars_format::scientific, "1.729e-61"},
    {1.729e-60, chars_format::scientific, "1.729e-60"},
    {1.729e-59, chars_format::scientific, "1.729e-59"},
    {1.729e-58, chars_format::scientific, "1.729e-58"},
    {1.729e-57, chars_format::scientific, "1.729e-57"},
    {1.729e-56, chars_format::scientific, "1.729e-56"},
    {1.729e-55, chars_format::scientific, "1.729e-55"},
    {1.729e-54, chars_format::scientific, "1.729e-54"},
    {1.729e-53, chars_format::scientific, "1.729e-53"},
    {1.729e-52, chars_format::scientific, "1.729e-52"},
    {1.729e-51, chars_format::scientific, "1.729e-51"},
    {1.729e-50, chars_format::scientific, "1.729e-50"},
    {1.729e-49, chars_format::scientific, "1.729e-49"},
    {1.729e-48, chars_format::scientific, "1.729e-48"},
    {1.729e-47, chars_format::scientific, "1.729e-47"},
    {1.729e-46, chars_format::scientific, "1.729e-46"},
    {1.729e-45, chars_format::scientific, "1.729e-45"},
    {1.729e-44, chars_format::scientific, "1.729e-44"},
    {1.729e-43, chars_format::scientific, "1.729e-43"},
    {1.729e-42, chars_format::scientific, "1.729e-42"},
    {1.729e-41, chars_format::scientific, "1.729e-41"},
    {1.729e-40, chars_format::scientific, "1.729e-40"},
    {1.729e-39, chars_format::scientific, "1.729e-39"},
    {1.729e-38, chars_format::scientific, "1.729e-38"},
    {1.729e-37, chars_format::scientific, "1.729e-37"},
    {1.729e-36, chars_format::scientific, "1.729e-36"},
    {1.729e-35, chars_format::scientific, "1.729e-35"},
    {1.729e-34, chars_format::scientific, "1.729e-34"},
    {1.729e-33, chars_format::scientific, "1.729e-33"},
    {1.729e-32, chars_format::scientific, "1.729e-32"},
    {1.729e-31, chars_format::scientific, "1.729e-31"},
    {1.729e-30, chars_format::scientific, "1.729e-30"},
    {1.729e-29, chars_format::scientific, "1.729e-29"},
    {1.729e-28, chars_format::scientific, "1.729e-28"},
    {1.729e-27, chars_format::scientific, "1.729e-27"},
    {1.729e-26, chars_format::scientific, "1.729e-26"},
    {1.729e-25, chars_format::scientific, "1.729e-25"},
    {1.729e-24, chars_format::scientific, "1.729e-24"},
    {1.729e-23, chars_format::scientific, "1.729e-23"},
    {1.729e-22, chars_format::scientific, "1.729e-22"},
    {1.729e-21, chars_format::scientific, "1.729e-21"},
    {1.729e-20, chars_format::scientific, "1.729e-20"},
    {1.729e-19, chars_format::scientific, "1.729e-19"},
    {1.729e-18, chars_format::scientific, "1.729e-18"},
    {1.729e-17, chars_format::scientific, "1.729e-17"},
    {1.729e-16, chars_format::scientific, "1.729e-16"},
    {1.729e-15, chars_format::scientific, "1.729e-15"},
    {1.729e-14, chars_format::scientific, "1.729e-14"},
    {1.729e-13, chars_format::scientific, "1.729e-13"},
    {1.729e-12, chars_format::scientific, "1.729e-12"},
    {1.729e-11, chars_format::scientific, "1.729e-11"},
    {1.729e-10, chars_format::scientific, "1.729e-10"},
    {1.729e-9, chars_format::scientific, "1.729e-09"},
    {1.729e-8, chars_format::scientific, "1.729e-08"},
    {1.729e-7, chars_format::scientific, "1.729e-07"},
    {1.729e-6, chars_format::scientific, "1.729e-06"},
    {1.729e-5, chars_format::scientific, "1.729e-05"},
    {1.729e-4, chars_format::scientific, "1.729e-04"},
    {1.729e-3, chars_format::scientific, "1.729e-03"},
    {1.729e-2, chars_format::scientific, "1.729e-02"},
    {1.729e-1, chars_format::scientific, "1.729e-01"},
    {1.729e0, chars_format::scientific, "1.729e+00"},
    {1.729e1, chars_format::scientific, "1.729e+01"},
    {1.729e2, chars_format::scientific, "1.729e+02"},
    {1.729e3, chars_format::scientific, "1.729e+03"},
    {1.729e4, chars_format::scientific, "1.729e+04"},
    {1.729e5, chars_format::scientific, "1.729e+05"},
    {1.729e6, chars_format::scientific, "1.729e+06"},
    {1.729e7, chars_format::scientific, "1.729e+07"},
    {1.729e8, chars_format::scientific, "1.729e+08"},
    {1.729e9, chars_format::scientific, "1.729e+09"},
    {1.729e10, chars_format::scientific, "1.729e+10"},
    {1.729e11, chars_format::scientific, "1.729e+11"},
    {1.729e12, chars_format::scientific, "1.729e+12"},
    {1.729e13, chars_format::scientific, "1.729e+13"},
    {1.729e14, chars_format::scientific, "1.729e+14"},
    {1.729e15, chars_format::scientific, "1.729e+15"},
    {1.729e16, chars_format::scientific, "1.729e+16"},
    {1.729e17, chars_format::scientific, "1.729e+17"},
    {1.729e18, chars_format::scientific, "1.729e+18"},
    {1.729e19, chars_format::scientific, "1.729e+19"},
    {1.729e20, chars_format::scientific, "1.729e+20"},
    {1.729e21, chars_format::scientific, "1.729e+21"},
    {1.729e22, chars_format::scientific, "1.729e+22"},
    {1.729e23, chars_format::scientific, "1.729e+23"},
    {1.729e24, chars_format::scientific, "1.729e+24"},
    {1.729e25, chars_format::scientific, "1.729e+25"},
    {1.729e26, chars_format::scientific, "1.729e+26"},
    {1.729e27, chars_format::scientific, "1.729e+27"},
    {1.729e28, chars_format::scientific, "1.729e+28"},
    {1.729e29, chars_format::scientific, "1.729e+29"},
    {1.729e30, chars_format::scientific, "1.729e+30"},
    {1.729e31, chars_format::scientific, "1.729e+31"},
    {1.729e32, chars_format::scientific, "1.729e+32"},
    {1.729e33, chars_format::scientific, "1.729e+33"},
    {1.729e34, chars_format::scientific, "1.729e+34"},
    {1.729e35, chars_format::scientific, "1.729e+35"},
    {1.729e36, chars_format::scientific, "1.729e+36"},
    {1.729e37, chars_format::scientific, "1.729e+37"},
    {1.729e38, chars_format::scientific, "1.729e+38"},
    {1.729e39, chars_format::scientific, "1.729e+39"},
    {1.729e40, chars_format::scientific, "1.729e+40"},
    {1.729e41, chars_format::scientific, "1.729e+41"},
    {1.729e42, chars_format::scientific, "1.729e+42"},
    {1.729e43, chars_format::scientific, "1.729e+43"},
    {1.729e44, chars_format::scientific, "1.729e+44"},
    {1.729e45, chars_format::scientific, "1.729e+45"},
    {1.729e46, chars_format::scientific, "1.729e+46"},
    {1.729e47, chars_format::scientific, "1.729e+47"},
    {1.729e48, chars_format::scientific, "1.729e+48"},
    {1.729e49, chars_format::scientific, "1.729e+49"},
    {1.729e50, chars_format::scientific, "1.729e+50"},
    {1.729e51, chars_format::scientific, "1.729e+51"},
    {1.729e52, chars_format::scientific, "1.729e+52"},
    {1.729e53, chars_format::scientific, "1.729e+53"},
    {1.729e54, chars_format::scientific, "1.729e+54"},
    {1.729e55, chars_format::scientific, "1.729e+55"},
    {1.729e56, chars_format::scientific, "1.729e+56"},
    {1.729e57, chars_format::scientific, "1.729e+57"},
    {1.729e58, chars_format::scientific, "1.729e+58"},
    {1.729e59, chars_format::scientific, "1.729e+59"},
    {1.729e60, chars_format::scientific, "1.729e+60"},
    {1.729e61, chars_format::scientific, "1.729e+61"},
    {1.729e62, chars_format::scientific, "1.729e+62"},
    {1.729e63, chars_format::scientific, "1.729e+63"},
    {1.729e64, chars_format::scientific, "1.729e+64"},
    {1.729e65, chars_format::scientific, "1.729e+65"},
    {1.729e66, chars_format::scientific, "1.729e+66"},
    {1.729e67, chars_format::scientific, "1.729e+67"},
    {1.729e68, chars_format::scientific, "1.729e+68"},
    {1.729e69, chars_format::scientific, "1.729e+69"},
    {1.729e70, chars_format::scientific, "1.729e+70"},
    {1.729e71, chars_format::scientific, "1.729e+71"},
    {1.729e72, chars_format::scientific, "1.729e+72"},
    {1.729e73, chars_format::scientific, "1.729e+73"},
    {1.729e74, chars_format::scientific, "1.729e+74"},
    {1.729e75, chars_format::scientific, "1.729e+75"},
    {1.729e76, chars_format::scientific, "1.729e+76"},
    {1.729e77, chars_format::scientific, "1.729e+77"},
    {1.729e78, chars_format::scientific, "1.729e+78"},
    {1.729e79, chars_format::scientific, "1.729e+79"},
    {1.729e80, chars_format::scientific, "1.729e+80"},
    {1.729e81, chars_format::scientific, "1.729e+81"},
    {1.729e82, chars_format::scientific, "1.729e+82"},
    {1.729e83, chars_format::scientific, "1.729e+83"},
    {1.729e84, chars_format::scientific, "1.729e+84"},
    {1.729e85, chars_format::scientific, "1.729e+85"},
    {1.729e86, chars_format::scientific, "1.729e+86"},
    {1.729e87, chars_format::scientific, "1.729e+87"},
    {1.729e88, chars_format::scientific, "1.729e+88"},
    {1.729e89, chars_format::scientific, "1.729e+89"},
    {1.729e90, chars_format::scientific, "1.729e+90"},
    {1.729e91, chars_format::scientific, "1.729e+91"},
    {1.729e92, chars_format::scientific, "1.729e+92"},
    {1.729e93, chars_format::scientific, "1.729e+93"},
    {1.729e94, chars_format::scientific, "1.729e+94"},
    {1.729e95, chars_format::scientific, "1.729e+95"},
    {1.729e96, chars_format::scientific, "1.729e+96"},
    {1.729e97, chars_format::scientific, "1.729e+97"},
    {1.729e98, chars_format::scientific, "1.729e+98"},
    {1.729e99, chars_format::scientific, "1.729e+99"},
    {1.729e100, chars_format::scientific, "1.729e+100"},
    {1.729e101, chars_format::scientific, "1.729e+101"},
    {1.729e102, chars_format::scientific, "1.729e+102"},
    {1.729e103, chars_format::scientific, "1.729e+103"},
    {1.729e104, chars_format::scientific, "1.729e+104"},
    {1.729e105, chars_format::scientific, "1.729e+105"},
    {1.729e106, chars_format::scientific, "1.729e+106"},
    {1.729e107, chars_format::scientific, "1.729e+107"},
    {1.729e108, chars_format::scientific, "1.729e+108"},
    {1.729e109, chars_format::scientific, "1.729e+109"},
    {1.729e110, chars_format::scientific, "1.729e+110"},
    {1.729e111, chars_format::scientific, "1.729e+111"},
    {1.729e112, chars_format::scientific, "1.729e+112"},
    {1.729e113, chars_format::scientific, "1.729e+113"},
    {1.729e114, chars_format::scientific, "1.729e+114"},
    {1.729e115, chars_format::scientific, "1.729e+115"},
    {1.729e116, chars_format::scientific, "1.729e+116"},
    {1.729e117, chars_format::scientific, "1.729e+117"},
    {1.729e118, chars_format::scientific, "1.729e+118"},
    {1.729e119, chars_format::scientific, "1.729e+119"},
    {1.729e120, chars_format::scientific, "1.729e+120"},
    {1.729e121, chars_format::scientific, "1.729e+121"},
    {1.729e122, chars_format::scientific, "1.729e+122"},
    {1.729e123, chars_format::scientific, "1.729e+123"},
    {1.729e124, chars_format::scientific, "1.729e+124"},
    {1.729e125, chars_format::scientific, "1.729e+125"},
    {1.729e126, chars_format::scientific, "1.729e+126"},
    {1.729e127, chars_format::scientific, "1.729e+127"},
    {1.729e128, chars_format::scientific, "1.729e+128"},
    {1.729e129, chars_format::scientific, "1.729e+129"},
    {1.729e130, chars_format::scientific, "1.729e+130"},
    {1.729e131, chars_format::scientific, "1.729e+131"},
    {1.729e132, chars_format::scientific, "1.729e+132"},
    {1.729e133, chars_format::scientific, "1.729e+133"},
    {1.729e134, chars_format::scientific, "1.729e+134"},
    {1.729e135, chars_format::scientific, "1.729e+135"},
    {1.729e136, chars_format::scientific, "1.729e+136"},
    {1.729e137, chars_format::scientific, "1.729e+137"},
    {1.729e138, chars_format::scientific, "1.729e+138"},
    {1.729e139, chars_format::scientific, "1.729e+139"},
    {1.729e140, chars_format::scientific, "1.729e+140"},
    {1.729e141, chars_format::scientific, "1.729e+141"},
    {1.729e142, chars_format::scientific, "1.729e+142"},
    {1.729e143, chars_format::scientific, "1.729e+143"},
    {1.729e144, chars_format::scientific, "1.729e+144"},
    {1.729e145, chars_format::scientific, "1.729e+145"},
    {1.729e146, chars_format::scientific, "1.729e+146"},
    {1.729e147, chars_format::scientific, "1.729e+147"},
    {1.729e148, chars_format::scientific, "1.729e+148"},
    {1.729e149, chars_format::scientific, "1.729e+149"},
    {1.729e150, chars_format::scientific, "1.729e+150"},
    {1.729e151, chars_format::scientific, "1.729e+151"},
    {1.729e152, chars_format::scientific, "1.729e+152"},
    {1.729e153, chars_format::scientific, "1.729e+153"},
    {1.729e154, chars_format::scientific, "1.729e+154"},
    {1.729e155, chars_format::scientific, "1.729e+155"},
    {1.729e156, chars_format::scientific, "1.729e+156"},
    {1.729e157, chars_format::scientific, "1.729e+157"},
    {1.729e158, chars_format::scientific, "1.729e+158"},
    {1.729e159, chars_format::scientific, "1.729e+159"},
    {1.729e160, chars_format::scientific, "1.729e+160"},
    {1.729e161, chars_format::scientific, "1.729e+161"},
    {1.729e162, chars_format::scientific, "1.729e+162"},
    {1.729e163, chars_format::scientific, "1.729e+163"},
    {1.729e164, chars_format::scientific, "1.729e+164"},
    {1.729e165, chars_format::scientific, "1.729e+165"},
    {1.729e166, chars_format::scientific, "1.729e+166"},
    {1.729e167, chars_format::scientific, "1.729e+167"},
    {1.729e168, chars_format::scientific, "1.729e+168"},
    {1.729e169, chars_format::scientific, "1.729e+169"},
    {1.729e170, chars_format::scientific, "1.729e+170"},
    {1.729e171, chars_format::scientific, "1.729e+171"},
    {1.729e172, chars_format::scientific, "1.729e+172"},
    {1.729e173, chars_format::scientific, "1.729e+173"},
    {1.729e174, chars_format::scientific, "1.729e+174"},
    {1.729e175, chars_format::scientific, "1.729e+175"},
    {1.729e176, chars_format::scientific, "1.729e+176"},
    {1.729e177, chars_format::scientific, "1.729e+177"},
    {1.729e178, chars_format::scientific, "1.729e+178"},
    {1.729e179, chars_format::scientific, "1.729e+179"},
    {1.729e180, chars_format::scientific, "1.729e+180"},
    {1.729e181, chars_format::scientific, "1.729e+181"},
    {1.729e182, chars_format::scientific, "1.729e+182"},
    {1.729e183, chars_format::scientific, "1.729e+183"},
    {1.729e184, chars_format::scientific, "1.729e+184"},
    {1.729e185, chars_format::scientific, "1.729e+185"},
    {1.729e186, chars_format::scientific, "1.729e+186"},
    {1.729e187, chars_format::scientific, "1.729e+187"},
    {1.729e188, chars_format::scientific, "1.729e+188"},
    {1.729e189, chars_format::scientific, "1.729e+189"},
    {1.729e190, chars_format::scientific, "1.729e+190"},
    {1.729e191, chars_format::scientific, "1.729e+191"},
    {1.729e192, chars_format::scientific, "1.729e+192"},
    {1.729e193, chars_format::scientific, "1.729e+193"},
    {1.729e194, chars_format::scientific, "1.729e+194"},
    {1.729e195, chars_format::scientific, "1.729e+195"},
    {1.729e196, chars_format::scientific, "1.729e+196"},
    {1.729e197, chars_format::scientific, "1.729e+197"},
    {1.729e198, chars_format::scientific, "1.729e+198"},
    {1.729e199, chars_format::scientific, "1.729e+199"},
    {1.729e200, chars_format::scientific, "1.729e+200"},
    {1.729e201, chars_format::scientific, "1.729e+201"},
    {1.729e202, chars_format::scientific, "1.729e+202"},
    {1.729e203, chars_format::scientific, "1.729e+203"},
    {1.729e204, chars_format::scientific, "1.729e+204"},
    {1.729e205, chars_format::scientific, "1.729e+205"},
    {1.729e206, chars_format::scientific, "1.729e+206"},
    {1.729e207, chars_format::scientific, "1.729e+207"},
    {1.729e208, chars_format::scientific, "1.729e+208"},
    {1.729e209, chars_format::scientific, "1.729e+209"},
    {1.729e210, chars_format::scientific, "1.729e+210"},
    {1.729e211, chars_format::scientific, "1.729e+211"},
    {1.729e212, chars_format::scientific, "1.729e+212"},
    {1.729e213, chars_format::scientific, "1.729e+213"},
    {1.729e214, chars_format::scientific, "1.729e+214"},
    {1.729e215, chars_format::scientific, "1.729e+215"},
    {1.729e216, chars_format::scientific, "1.729e+216"},
    {1.729e217, chars_format::scientific, "1.729e+217"},
    {1.729e218, chars_format::scientific, "1.729e+218"},
    {1.729e219, chars_format::scientific, "1.729e+219"},
    {1.729e220, chars_format::scientific, "1.729e+220"},
    {1.729e221, chars_format::scientific, "1.729e+221"},
    {1.729e222, chars_format::scientific, "1.729e+222"},
    {1.729e223, chars_format::scientific, "1.729e+223"},
    {1.729e224, chars_format::scientific, "1.729e+224"},
    {1.729e225, chars_format::scientific, "1.729e+225"},
    {1.729e226, chars_format::scientific, "1.729e+226"},
    {1.729e227, chars_format::scientific, "1.729e+227"},
    {1.729e228, chars_format::scientific, "1.729e+228"},
    {1.729e229, chars_format::scientific, "1.729e+229"},
    {1.729e230, chars_format::scientific, "1.729e+230"},
    {1.729e231, chars_format::scientific, "1.729e+231"},
    {1.729e232, chars_format::scientific, "1.729e+232"},
    {1.729e233, chars_format::scientific, "1.729e+233"},
    {1.729e234, chars_format::scientific, "1.729e+234"},
    {1.729e235, chars_format::scientific, "1.729e+235"},
    {1.729e236, chars_format::scientific, "1.729e+236"},
    {1.729e237, chars_format::scientific, "1.729e+237"},
    {1.729e238, chars_format::scientific, "1.729e+238"},
    {1.729e239, chars_format::scientific, "1.729e+239"},
    {1.729e240, chars_format::scientific, "1.729e+240"},
    {1.729e241, chars_format::scientific, "1.729e+241"},
    {1.729e242, chars_format::scientific, "1.729e+242"},
    {1.729e243, chars_format::scientific, "1.729e+243"},
    {1.729e244, chars_format::scientific, "1.729e+244"},
    {1.729e245, chars_format::scientific, "1.729e+245"},
    {1.729e246, chars_format::scientific, "1.729e+246"},
    {1.729e247, chars_format::scientific, "1.729e+247"},
    {1.729e248, chars_format::scientific, "1.729e+248"},
    {1.729e249, chars_format::scientific, "1.729e+249"},
    {1.729e250, chars_format::scientific, "1.729e+250"},
    {1.729e251, chars_format::scientific, "1.729e+251"},
    {1.729e252, chars_format::scientific, "1.729e+252"},
    {1.729e253, chars_format::scientific, "1.729e+253"},
    {1.729e254, chars_format::scientific, "1.729e+254"},
    {1.729e255, chars_format::scientific, "1.729e+255"},
    {1.729e256, chars_format::scientific, "1.729e+256"},
    {1.729e257, chars_format::scientific, "1.729e+257"},
    {1.729e258, chars_format::scientific, "1.729e+258"},
    {1.729e259, chars_format::scientific, "1.729e+259"},
    {1.729e260, chars_format::scientific, "1.729e+260"},
    {1.729e261, chars_format::scientific, "1.729e+261"},
    {1.729e262, chars_format::scientific, "1.729e+262"},
    {1.729e263, chars_format::scientific, "1.729e+263"},
    {1.729e264, chars_format::scientific, "1.729e+264"},
    {1.729e265, chars_format::scientific, "1.729e+265"},
    {1.729e266, chars_format::scientific, "1.729e+266"},
    {1.729e267, chars_format::scientific, "1.729e+267"},
    {1.729e268, chars_format::scientific, "1.729e+268"},
    {1.729e269, chars_format::scientific, "1.729e+269"},
    {1.729e270, chars_format::scientific, "1.729e+270"},
    {1.729e271, chars_format::scientific, "1.729e+271"},
    {1.729e272, chars_format::scientific, "1.729e+272"},
    {1.729e273, chars_format::scientific, "1.729e+273"},
    {1.729e274, chars_format::scientific, "1.729e+274"},
    {1.729e275, chars_format::scientific, "1.729e+275"},
    {1.729e276, chars_format::scientific, "1.729e+276"},
    {1.729e277, chars_format::scientific, "1.729e+277"},
    {1.729e278, chars_format::scientific, "1.729e+278"},
    {1.729e279, chars_format::scientific, "1.729e+279"},
    {1.729e280, chars_format::scientific, "1.729e+280"},
    {1.729e281, chars_format::scientific, "1.729e+281"},
    {1.729e282, chars_format::scientific, "1.729e+282"},
    {1.729e283, chars_format::scientific, "1.729e+283"},
    {1.729e284, chars_format::scientific, "1.729e+284"},
    {1.729e285, chars_format::scientific, "1.729e+285"},
    {1.729e286, chars_format::scientific, "1.729e+286"},
    {1.729e287, chars_format::scientific, "1.729e+287"},
    {1.729e288, chars_format::scientific, "1.729e+288"},
    {1.729e289, chars_format::scientific, "1.729e+289"},
    {1.729e290, chars_format::scientific, "1.729e+290"},
    {1.729e291, chars_format::scientific, "1.729e+291"},
    {1.729e292, chars_format::scientific, "1.729e+292"},
    {1.729e293, chars_format::scientific, "1.729e+293"},
    {1.729e294, chars_format::scientific, "1.729e+294"},
    {1.729e295, chars_format::scientific, "1.729e+295"},
    {1.729e296, chars_format::scientific, "1.729e+296"},
    {1.729e297, chars_format::scientific, "1.729e+297"},
    {1.729e298, chars_format::scientific, "1.729e+298"},
    {1.729e299, chars_format::scientific, "1.729e+299"},
    {1.729e300, chars_format::scientific, "1.729e+300"},
    {1.729e301, chars_format::scientific, "1.729e+301"},
    {1.729e302, chars_format::scientific, "1.729e+302"},
    {1.729e303, chars_format::scientific, "1.729e+303"},
    {1.729e304, chars_format::scientific, "1.729e+304"},
    {1.729e305, chars_format::scientific, "1.729e+305"},
    {1.729e306, chars_format::scientific, "1.729e+306"},
    {1.729e307, chars_format::scientific, "1.729e+307"},
    {1.729e308, chars_format::scientific, "1.729e+308"},

    // Test all of the cases for fixed notation, including the non-Ryu fallback for large integers.
    {1.729e-4, chars_format::fixed, "0.0001729"},
    {1.729e-3, chars_format::fixed, "0.001729"},
    {1.729e-2, chars_format::fixed, "0.01729"},
    {1.729e-1, chars_format::fixed, "0.1729"},
    {1.729e0, chars_format::fixed, "1.729"},
    {1.729e1, chars_format::fixed, "17.29"},
    {1.729e2, chars_format::fixed, "172.9"},
    {1.729e3, chars_format::fixed, "1729"},
    {1.729e4, chars_format::fixed, "17290"},
    {1.729e5, chars_format::fixed, "172900"},
    {1.729e6, chars_format::fixed, "1729000"},
    {1.729e7, chars_format::fixed, "17290000"},
    {1.729e8, chars_format::fixed, "172900000"},
    {1.729e9, chars_format::fixed, "1729000000"},
    {1.729e10, chars_format::fixed, "17290000000"},
    {1.729e11, chars_format::fixed, "172900000000"},
    {1.729e12, chars_format::fixed, "1729000000000"},
    {1.729e13, chars_format::fixed, "17290000000000"},
    {1.729e14, chars_format::fixed, "172900000000000"},
    {1.729e15, chars_format::fixed, "1729000000000000"},
    {1.729e16, chars_format::fixed, "17290000000000000"},
    {1.729e17, chars_format::fixed, "172900000000000000"},
    {1.729e18, chars_format::fixed, "1729000000000000000"},
    {1.729e19, chars_format::fixed, "17290000000000000000"},
    {1.729e20, chars_format::fixed, "172900000000000000000"},
    {1.729e21, chars_format::fixed, "1729000000000000000000"},
    {1.729e22, chars_format::fixed, "17289999999999999475712"},
    {1.729e23, chars_format::fixed, "172900000000000015728640"},
    {1.729e24, chars_format::fixed, "1728999999999999888850944"},
    {1.729e25, chars_format::fixed, "17290000000000000499122176"},
    {1.729e26, chars_format::fixed, "172899999999999987811352576"},
    {1.729e27, chars_format::fixed, "1729000000000000084271955968"},
    {1.729e28, chars_format::fixed, "17290000000000000842719559680"},
    {1.729e29, chars_format::fixed, "172900000000000004029149085696"},
    {1.729e30, chars_format::fixed, "1728999999999999969922746679296"},
    {1.729e31, chars_format::fixed, "17290000000000000825127373635584"},
    {1.729e32, chars_format::fixed, "172899999999999994740474854244352"},
    {1.729e33, chars_format::fixed, "1729000000000000019462342580371456"},
    {1.729e34, chars_format::fixed, "17290000000000000771084178107138048"},
    {1.729e35, chars_format::fixed, "172900000000000003099155762643992576"},
    {1.729e36, chars_format::fixed, "1728999999999999957204581331601719296"},
    {1.729e37, chars_format::fixed, "17289999999999998981750002957311541248"},
    {1.729e38, chars_format::fixed, "172900000000000018151698926790986694656"},
    {1.729e39, chars_format::fixed, "1728999999999999879285534364252573270016"},
    {1.729e40, chars_format::fixed, "17289999999999999397318253449840320053248"},
    {1.729e41, chars_format::fixed, "172899999999999993973182534498403200532480"},
    {1.729e42, chars_format::fixed, "1728999999999999978417451572652165595922432"},
    {1.729e43, chars_format::fixed, "17290000000000001022114555011901930858348544"},
    {1.729e44, chars_format::fixed, "172899999999999995365865078694456009793994752"},
    {1.729e45, chars_format::fixed, "1729000000000000112114975815473235285027848192"},
    {1.729e46, chars_format::fixed, "17289999999999999853499157926502951353575276544"},
    {1.729e47, chars_format::fixed, "172900000000000003605593980177947119522565586944"},
    {1.729e48, chars_format::fixed, "1728999999999999914361482179869448651542148153344"},
    {1.729e49, chars_format::fixed, "17290000000000001090726143749254847214357604990976"},
    {1.729e50, chars_format::fixed, "172900000000000000522667720422893215082583391469568"},
    {1.729e51, chars_format::fixed, "1729000000000000046765052072507553179069804548456448"},
    {1.729e52, chars_format::fixed, "17289999999999999138422524940159658886890985204219904"},
    {1.729e53, chars_format::fixed, "172899999999999991384225249401596588868909852042199040"},
    {1.729e54, chars_format::fixed, "1729000000000000083983435954485197620376402236306096128"},
    {1.729e55, chars_format::fixed, "17289999999999999478704891861098122350265592635988115456"},
    {1.729e56, chars_format::fixed, "172899999999999994787048918610981223502655926359881154560"},
    {1.729e57, chars_format::fixed, "1729000000000000122095061049630305528274358268664135811072"},
    {1.729e58, chars_format::fixed, "17289999999999999130255748134057135763769994625857466925056"},
    {1.729e59, chars_format::fixed, "172900000000000002452930080605882928405559082582755422240768"},
    {1.729e60, chars_format::fixed, "1728999999999999846123339217813844151769844644640662174564352"},
    {1.729e61, chars_format::fixed, "17290000000000000602104931237078263105127400620649326319763456"},
    {1.729e62, chars_format::fixed, "172899999999999994603067770723103582584986250610532172135661568"},
    {1.729e63, chars_format::fixed, "1728999999999999991702603873821752019715013528489166085604507648"},
    {1.729e64, chars_format::fixed, "17289999999999999917026038738217520197150135284891660856045076480"},
    {1.729e65, chars_format::fixed, "172899999999999999170260387382175201971501352848916608560450764800"},
    {1.729e66, chars_format::fixed, "1728999999999999898166499084643965254679184234647052827624824897536"},
    {1.729e67, chars_format::fixed, "17290000000000000478242667473284240787365111047944340403923172982784"},
    {1.729e68, chars_format::fixed, "172899999999999992809805261718085701949064960867652907017832337768448"},
    {1.729e69, chars_format::fixed, "1729000000000000167550480877475991137982372600912339010606311218872320"},
    {1.729e70, chars_format::fixed, "17289999999999998610513727042982194663129671708505022868584867821518848"},
    {1.729e71, chars_format::fixed, "172900000000000010625065924284043680364849151489997166585674633152823296"},
    {1.729e72, chars_format::fixed, "1729000000000000008170944627423549868714281777280183914257442511777693696"},
    {1.729e73, chars_format::fixed, "17290000000000000081709446274235498687142817772801839142574425117776936960"},
    {1.729e74, chars_format::fixed, "172900000000000000817094462742354986871428177728018391425744251177769369600"},
    {1.729e75, chars_format::fixed, "1728999999999999957954130744330103758027966391618852585438598956065417592832"},
    {1.729e76, chars_format::fixed, "17289999999999999981275818508048606465770187001479176484936738006352384753664"},
    {1.729e77, chars_format::fixed, "172899999999999993385006008044524962489853500650141354760555404932352506331136"},
    {1.729e78, chars_format::fixed, "1728999999999999933850060080445249624898535006501413547605554049323525063311360"},
    {1.729e79, chars_format::fixed, "17289999999999998515748322143849475171500758786338882984687607676445318958809088"},
    {1.729e80, chars_format::fixed,
        "172900000000000004903537909292967257574637778551594889639706464367411549771399168"},
    {1.729e81, chars_format::fixed,
        "1728999999999999996379233258651079226787363943680732736949516943399559870558502912"},
    {1.729e82, chars_format::fixed,
        "17289999999999999121293999238053298684529417967443868818334406229602708671097208832"},
    {1.729e83, chars_format::fixed,
        "172900000000000011432899992743512832845555494939161693411202379201456447538679775232"},
    {1.729e84, chars_format::fixed,
        "1728999999999999898649426590230009971119434253234571545014868411689984626557915758592"},
    {1.729e85, chars_format::fixed,
        "17289999999999998555135119227889862996522101140031624671954373356250686567921393598464"},
    {1.729e86, chars_format::fixed,
        "172899999999999992453097539069462417399976873677341699170652705732893420841738159783936"},
    {1.729e87, chars_format::fixed,
        "1729000000000000034958916939343644772955862533205824230924270612055119091017769178628096"},
    {1.729e88, chars_format::fixed,
        "17289999999999999907877403198840365333734250146328613352371731901646451379776141463126016"},
    {1.729e89, chars_format::fixed,
        "172900000000000013213550550215478290003722507406634260143588494021416178770611024972218368"},
    {1.729e90, chars_format::fixed,
        "1729000000000000019057293356338185806706185026519557588476915540174548467923313366994518016"},
    {1.729e91, chars_format::fixed,
        "17289999999999998833634387813582692947089369694634155729261522601270124841839571077213192192"},
    {1.729e92, chars_format::fixed,
        "172900000000000002810355032800351357417266823032330038951363309217771753350593711761273126912"},
    {1.729e93, chars_format::fixed,
        "1728999999999999912311461090687318150601683221635392536243648426537153494048353109699601629184"},
    {1.729e94, chars_format::fixed,
        "17289999999999999586282967856137963200300772251105556775516422927933791098313867128648534851584"},
    {1.729e95, chars_format::fixed,
        "172900000000000003273523389749616139111550763067081670364443247880334009508424047792925645471744"},
    {1.729e96, chars_format::fixed,
        "1729000000000000032735233897496161391115507630670816703644432478803340095084240477929256454717440"},
    {1.729e97, chars_format::fixed,
        "17290000000000001275921134007055886821048585497879508170432039168960901562078932972116922557530112"},
    {1.729e98, chars_format::fixed,
        "172899999999999997582110619557050501652189707920053623560516961594769005841004878635979497409609728"},
    {1.729e99, chars_format::fixed,
        "1729000000000000097237911959678571948988266255670467900755597056706410136648324395041312799421628416"},
    {1.729e100, chars_format::fixed,
        "17290000000000000001044673483921184030151709144945225686352551040994340740577039080960985391612035072"},
    {1.729e101, chars_format::fixed,
        "172900000000000007781122303742128123979364718743527883433152866618501492413020029765226994736954343424"},
    {1.729e102, chars_format::fixed,
        "1729000000000000015645818486197950970370866169082673821774509816516550244072203186007332820802871492608"},
    {1.729e103, chars_format::fixed,
        "17290000000000000653781421271766151859090909837647578318201248962513219881186008753232825220562090459136"},
    {1.729e104, chars_format::fixed,
        "17289999999999999062347064760448896961867715767820889996741566411000524071701282695122434780455288753356"
        "8"},
    {1.729e105, chars_format::fixed,
        "172899999999999990623470647604488969618677157678208899967415664110005240717012826951224347804552887533568"
        "0"},
    {1.729e106, chars_format::fixed,
        "1728999999999999957160605884407041852897913787016543025960866482748458673073639503371775972128946529920614"
        "4"},
    {1.729e107, chars_format::fixed,
        "1729000000000000079382764464476207029004655091579232689048970102704633711242066464634653957929148900924456"
        "96"},
    {1.729e108, chars_format::fixed,
        "1729000000000000079382764464476207029004655091579232689048970102704633711242066464634653957929148900924456"
        "960"},
    {1.729e109, chars_format::fixed,
        "1728999999999999922938401481987675603588026221738989920296197469160729662386479954218170136104889866039538"
        "4832"},
    {1.729e110, chars_format::fixed,
        "1729000000000000006375395072648225697143561618987119396964342873717478488442792759773628174411161351311495"
        "00416"},
    {1.729e111, chars_format::fixed,
        "1729000000000000073124989945176665771987989936785622978298859197362877549287843004217994605056178539529060"
        "220928"},
    {1.729e112, chars_format::fixed,
        "1729000000000000019725314047153913712112447282546820113231246138446558300611802808662501460540164788955008"
        "0475136"},
    {1.729e113, chars_format::fixed,
        "1729000000000000062445054765572115360012881405937862405285336585579613699552634965106895976152975789414249"
        "78624512"},
    {1.729e114, chars_format::fixed,
        "1728999999999999994093469616102992723372186808512194737998791870166725061247303514795864751172478188679463"
        "004274688"},
    {1.729e115, chars_format::fixed,
        "1729000000000000048774737735678290832684742486452728871828027642497035971891568675044689731156876269267292"
        "4298510336"},
    {1.729e116, chars_format::fixed,
        "1729000000000000136264766726998767807584831571157583485954804878225533428922392931442809699131913198207819"
        "51077318656"},
    {1.729e117, chars_format::fixed,
        "1728999999999999996280720340886004647744689035629816103351961301059937497673074121205817750371854111902976"
        "181297741824"},
    {1.729e118, chars_format::fixed,
        "1729000000000000108267957449776215175616803064052030009434236162792414242672529169395411309379901380946850"
        "8448780976128"},
    {1.729e119, chars_format::fixed,
        "1728999999999999884293483231995794119872575007207602197269686439327460752673619073016224191363806842859101"
        "51771738603520"},
    {1.729e120, chars_format::fixed,
        "1729000000000000099308978481064998333387033941778252896947654173853816103072572765540243824659257599423340"
        "871791669149696"},
    {1.729e121, chars_format::fixed,
        "1729000000000000041971513081313210543116511559226079377033529444646788009632851780867171922447137397672877"
        "0440385269858304"},
    {1.729e122, chars_format::fixed,
        "1728999999999999904361596121908919846467257841100862929239630094549920585377521417651799357138048913471763"
        "85743098579255296"},
    {1.729e123, chars_format::fixed,
        "1728999999999999977753551833591208218013526490767645034729709747934916544980364278033331391969562771712357"
        "556955007762300928"},
    {1.729e124, chars_format::fixed,
        "1729000000000000095180680972282869612487556330234496403513837193350910080344912854643782647699984944897307"
        "4761934429138976768"},
    {1.729e125, chars_format::fixed,
        "1729000000000000048209829316806205054697944394447755856000186215184512666199093423999602145407816075623327"
        "50849806885325897728"},
    {1.729e126, chars_format::fixed,
        "1729000000000000048209829316806205054697944394447755856000186215184512666199093423999602145407816075623327"
        "508498068853258977280"},
    {1.729e127, chars_format::fixed,
        "1728999999999999927964449078785943786756537838833700054365239711078535285985795681550500059539863770281938"
        "7911979112580239065088"},
    {1.729e128, chars_format::fixed,
        "1728999999999999927964449078785943786756537838833700054365239711078535285985795681550500059539863770281938"
        "79119791125802390650880"},
    {1.729e129, chars_format::fixed,
        "1729000000000000120357057459618361815462788327816189336981154117648099094327072069469063396928587458828160"
        "738878163410400019742720"},
    {1.729e130, chars_format::fixed,
        "1728999999999999997225788095885614277090788014867396196106968897443578256988655181201182860999804298158578"
        "6923628020328793072730112"},
    {1.729e131, chars_format::fixed,
        "1728999999999999997225788095885614277090788014867396196106968897443578256988655181201182860999804298158578"
        "69236280203287930727301120"},
    {1.729e132, chars_format::fixed,
        "1729000000000000036627794292280093489369828115011010001186708167909024924936948585446904632497014909572844"
        "947247717673685935263318016"},
    {1.729e133, chars_format::fixed,
        "1729000000000000099671004206511260229016292275240792089314291000653739593654218032240059466892551887835670"
        "9550635826989765400478089216"},
    {1.729e134, chars_format::fixed,
        "1728999999999999948367300412356460053864778290689315077808092202066424388732771359936487864343263140004888"
        "53630550663827908856503074816"},
    {1.729e135, chars_format::fixed,
        "1728999999999999988714954757464406767238515353236375614209745215023041776711823805884106958356406806093097"
        "181307660254465075627104927744"},
    {1.729e136, chars_format::fixed,
        "1728999999999999924158707805291692025840536053161078755967100394292453955945339892367916407935376940351963"
        "3493042144685674963277862404096"},
    {1.729e137, chars_format::fixed,
        "1728999999999999975803705367029863818958919493221316242561216250876924212558527023180868848272200832944870"
        "41490697109728555976724119027712"},
    {1.729e138, chars_format::fixed,
        "1729000000000000099751699515201476122443039749365886210387094306679652828430176137131954705080578175167847"
        "372353587006208912021933069959168"},
    {1.729e139, chars_format::fixed,
        "1729000000000000099751699515201476122443039749365886210387094306679652828430176137131954705080578175167847"
        "3723535870062089120219330699591680"},
    {1.729e140, chars_format::fixed,
        "1728999999999999993982744508761700290136590464122519837842345032394657742886368893227028107270762843137573"
        "70199914143059431809792933263048704"},
    {1.729e141, chars_format::fixed,
        "1729000000000000036290326511337610623059170178219866386860244742108655777103891790788998746394688975949683"
        "170140919660840155667530827561959424"},
    {1.729e142, chars_format::fixed,
        "1729000000000000036290326511337610623059170178219866386860244742108655777103891790788998746394688975949683"
        "1701409196608401556675308275619594240"},
    {1.729e143, chars_format::fixed,
        "1729000000000000090444031474634775849200072212264469969603156370542573260902321099668321164473314425949183"
        "28936239579555482775662074107424407552"},
    {1.729e144, chars_format::fixed,
        "1728999999999999873829211621446114944636464076086055638631509856806903325708603864151031492158812625951182"
        "812476491256696139400261087025105469440"},
    {1.729e145, chars_format::fixed,
        "1728999999999999943145953974466486434096818679663148224542436741202317704970593379516564187299453201950542"
        "9650799807091309196742961763208298233856"},
    {1.729e146, chars_format::fixed,
        "1728999999999999943145953974466486434096818679663148224542436741202317704970593379516564187299453201950542"
        "96507998070913091967429617632082982338560"},
    {1.729e147, chars_format::fixed,
        "1729000000000000031871384186332561940606072572241826734508423153228448110425939959184446037079473139229723"
        "960412447208247438425061090619356996435968"},
    {1.729e148, chars_format::fixed,
        "1728999999999999889910695847346841130191266344115941118562844893986639461697385431715835077431441239583034"
        "3678805008096610084238372277417135195553792"},
    {1.729e149, chars_format::fixed,
        "1728999999999999946694971182941129454357188835366295364941076197683362921188807242703279461290653999441710"
        "20489327936909558042432677289277091030761472"},
    {1.729e150, chars_format::fixed,
        "1728999999999999946694971182941129454357188835366295364941076197683362921188807242703279461290653999441710"
        "204893279369095580424326772892770910307614720"},
    {1.729e151, chars_format::fixed,
        "1728999999999999946694971182941129454357188835366295364941076197683362921188807242703279461290653999441710"
        "2048932793690955804243267728927709103076147200"},
    {1.729e152, chars_format::fixed,
        "1729000000000000062989167070238231942248998097447020861523693907654252566227239111605565559434321731632278"
        "31909544985881758388132936136213644656819306496"},
    {1.729e153, chars_format::fixed,
        "1729000000000000156024523780075913932562445507111601258789788075630964282257984606727394437949255917384732"
        "810457186250595186646931432137628875576655740928"},
    {1.729e154, chars_format::fixed,
        "1728999999999999932739667676465477155810171723916608305351162072486856163784195418435005129513413871578842"
        "0311890189103289400094864622764470459563453186048"},
    {1.729e155, chars_format::fixed,
        "1728999999999999932739667676465477155810171723916608305351162072486856163784195418435005129513413871578842"
        "03118901891032894000948646227644704595634531860480"},
    {1.729e156, chars_format::fixed,
        "1728999999999999885105565041028583976769686650168343141950921858482779765176453724932628743713767568473585"
        "331611809877738807393498202039394922304012428509184"},
    {1.729e157, chars_format::fixed,
        "1728999999999999961320129257727613063234462768165567403391306200889302002948840434536430960993201653441996"
        "0509353443298830195790794184186783201477450526621696"},
    {1.729e158, chars_format::fixed,
        "1729000000000000022291780631086836332406283662563346812543613674814519793166749802219472734816748921416724"
        "62639417189159838932754439152210503842273115198455808"},
    {1.729e159, chars_format::fixed,
        "1729000000000000071069101729774214947743740378081570339865459653954694025341077296365906153875586735796507"
        "486761233940970685126316370004846413042720031442468864"},
    {1.729e160, chars_format::fixed,
        "1728999999999999875959817335024700486393913516008676230578075737393997096643767319780172477640235478277376"
        "0452929857434815019312284560738809145627645136108257280"},
    {1.729e161, chars_format::fixed,
        "1729000000000000000829759347664389741657802707735328460522001443992843131010045704795042030430860283089620"
        "16783266458987457917608472098969883358993604502307733504"},
    {1.729e162, chars_format::fixed,
        "1729000000000000050777736152720265443763358384425989352499571726632381544756557058800989851547110205014517"
        "816848536128431810074027226956026001200804657587977977856"},
    {1.729e163, chars_format::fixed,
        "1728999999999999970860973264630864320394469301720931925335459274409120082762138892391473337761110329934681"
        "5784231416667402406373192174099025330234148774841369493504"},
    {1.729e164, chars_format::fixed,
        "1728999999999999970860973264630864320394469301720931925335459274409120082762138892391473337761110329934681"
        "57842314166674024063731921740990253302341487748413694935040"},
    {1.729e165, chars_format::fixed,
        "1728999999999999919714245016253647601438380288789695171950427304986232747085711265889382768938070409883586"
        "385830889211257636197826091300383513389885418217678691106816"},
    {1.729e166, chars_format::fixed,
        "1728999999999999837879479818850100851108637868099716366534376153909613010003427063486037858821206537801834"
        "0776832852824854690946370895251530819762382833913454779170816"},
    {1.729e167, chars_format::fixed,
        "1729000000000000099750728450541450452163813614307648543865739837354796168666736511176741571195170928463441"
        "46375561785455640382484189520589046249990911483561176012423168"},
    {1.729e168, chars_format::fixed,
        "1729000000000000047376478724203180531952778465066062108399467100665759536934074621638600828720378050331119"
        "986541151340142216878800934069742986395174948546758503682801664"},
    {1.729e169, chars_format::fixed,
        "1729000000000000005477078943132564595783950345672792960026448911314530231547945110008088234740543747825262"
        "8047695781286108673219681651608250055113876155156758985296576512"},
    {1.729e170, chars_format::fixed,
        "1729000000000000072516118592845550093654075336702023597423278014276497120165752328616908385108278631834634"
        "29560409526706102661290059541509377492544734836540806677468807168"},
    {1.729e171, chars_format::fixed,
        "1728999999999999911622423433534384898765775358231870067670888167167776587483015003955740024225714910212142"
        "717601254134780644314662762804848728331703989526050862986615062528"},
    {1.729e172, chars_format::fixed,
        "1729000000000000126147350312615938491950175329525408107340741296646070631059998103503964505402466539042131"
        "4882717089778211540456465396185087904566951346451938013707124080640"},
    {1.729e173, chars_format::fixed,
        "1729000000000000057499373711309841342131167338711475934646388295213016537115363511648532671425906017816535"
        "08165716342804819093173173103813757057669796820706806108780125749248"},
    {1.729e174, chars_format::fixed,
        "1728999999999999892744229868175208182565548160758038720179941091773686711648240491195496269882160766875103"
        "705782254108593079458336190445246642864704768755566284408814496120832"},
    {1.729e175, chars_format::fixed,
        "1729000000000000112417754992354719061986373731362621672801870696359459812271071185132878138607154434797012"
        "2069487998678665614228635779024345464806957013575686533141301779496960"},
    {1.729e176, chars_format::fixed,
        "1728999999999999901531170873142388617742381183582222038284818275957117635673153718952991544631160513591980"
        "04582891593896401873691728594353415900934440605964637916502712339398656"},
    {1.729e177, chars_format::fixed,
        "1729000000000000014004015736722298188005843875731768510027246233505033463192043034248931061418357271567997"
        "198426187367712041502755308321614365660731763551871592044548752490364928"},
    {1.729e178, chars_format::fixed,
        "1729000000000000103982291627586225844216614029451405687421188599543366125207154486485682674848114677948810"
        "9205040045107104597154257262240785309818416495456517623481660557674676224"},
    {1.729e179, chars_format::fixed,
        "1729000000000000103982291627586225844216614029451405687421188599543366125207154486485682674848114677948810"
        "92050400451071045971542572622407853098184164954565176234816605576746762240"},
    {1.729e180, chars_format::fixed,
        "1729000000000000103982291627586225844216614029451405687421188599543366125207154486485682674848114677948810"
        "920504004510710459715425726224078530981841649545651762348166055767467622400"},
    {1.729e181, chars_format::fixed,
        "1729000000000000057913414371463894884236699710746951452595490108131739802255417422940465848772078885881834"
        "2948001621334952695905384722580168783374333879168363151527139964895910428672"},
    {1.729e182, chars_format::fixed,
        "1729000000000000131623617981259624420204562620674078228316607694390341918978196724612812770493736153188996"
        "89592630993703957379035807860371552256848660652294103066543729133419357011968"},
    {1.729e183, chars_format::fixed,
        "1728999999999999954719129317749873533881691636848973966585925487369696838843526400599180158361758711651806"
        "653223555208533243710791023374038776413958881868289713434901383707147504713728"},
    {1.729e184, chars_format::fixed,
        "1728999999999999813195538386942072824823394849788890557201379721753180774735790141388274068656176758422054"
        "4590613514257281796471373791902973794903367021445686596504726576055106523889664"},
    {1.729e185, chars_format::fixed,
        "1729000000000000115112532372665381004147761328850401830555077355068415044832294161038207060028084925312192"
        "47327405282904564964959848678227902626073068555517357439058727328900260401512448"},
    {1.729e186, chars_format::fixed,
        "1728999999999999933962335981231396096553141441413495066542858775079274482774391749248247265204940025178109"
        "664746431987055167648121822227090038198494295508810625546518503878907433039429632"},
    {1.729e187, chars_format::fixed,
        "1729000000000000078882493094378584022628837351363020477752633639070586932420713678680215101063455945285375"
        "9115685286606475532493031538712412286482834075459009846217735194069835698199855104"},
    {1.729e188, chars_format::fixed,
        "1729000000000000001591742634033417128721799532723273591774087044941886959276008649649832255272247454561500"
        "57993007710139828092867311032769392707506254779278612644830417779200963020368904192"},
    {1.729e189, chars_format::fixed,
        "1729000000000000001591742634033417128721799532723273591774087044941886959276008649649832255272247454561500"
        "579930077101398280928673110327693927075062547792786126448304177792009630203689041920"},
    {1.729e190, chars_format::fixed,
        "1728999999999999952125662339412510316621295328793835584747817224699518976463397431070387233965874020498220"
        "3676814681034787466434698824598236540682011975507926172172837991584263088492593020928"},
    {1.729e191, chars_format::fixed,
        "1729000000000000070844255046502686665662505418224486801610864793281202135213664355661055285101170262250092"
        "87707812969848562892795762934271230928466843813157703937173270787902628009989067767808"},
    {1.729e192, chars_format::fixed,
        "1728999999999999880894506715158404507196569275135444854629988683550509081213237276315986403284696275447096"
        "862043471146474617272777234330090460938320853202321963924614453926066326098880476741632"},
    {1.729e193, chars_format::fixed,
        "1729000000000000032854305380233830233969318189606678412214689571335063524413578939792041508737875464889493"
        "6740711979880834265969215503401879396153989211457260242823090570884342892996886374907904"},
    {1.729e194, chars_format::fixed,
        "1729000000000000032854305380233830233969318189606678412214689571335063524413578939792041508737875464889493"
        "67407119798808342659692155034018793961539892114572602428230905708843428929968863749079040"},
    {1.729e195, chars_format::fixed,
        "1729000000000000097690486143999345210725691059781071396784161950123140086845724716208491687064565252384916"
        "313869694773836518575223125171162863850952230134911756701592087771044620265366786077097984"},
    {1.729e196, chars_format::fixed,
        "1728999999999999942083652310962109266510396171362528233817428241031756337008574852809011259080509762395901"
        "9783533024880290978272993455768230456856242885608659988953128141327798259477392294699597824"},
    {1.729e197, chars_format::fixed,
        "1728999999999999900588496622152179681386317534450916723692965918607387337052001555902483144951428298398831"
        "48888226454514711896118633768499909417487017080778713014697167449590921412970521437472292864"},
    {1.729e198, chars_format::fixed,
        "1728999999999999900588496622152179681386317534450916723692965918607387337052001555902483144951428298398831"
        "488882264545147118961186337684999094174870170807787130146971674495909214129705214374722928640"},
    {1.729e199, chars_format::fixed,
        "1729000000000000006816095185505599419303958844944642189611589464013771976940829195983195117121876846231331"
        "9419281216789249848584356378880684100424007122556690341427249919662979803838722930185292742656"},
    {1.729e200, chars_format::fixed,
        "1729000000000000049307134610846967314471015369142132375979038882176325832896360252015479905990056265364332"
        "12314646453243613121733535796929613638941292883482179574102631895445348688553912447605181251584"},
    {1.729e201, chars_format::fixed,
        "1729000000000000117292797691393155946738305807858116674166957951236412002425209941667135568179143335977132"
        "413095813098053965391574910099260498544632475361466214298308442135502297288206054808087873716224"},
    {1.729e202, chars_format::fixed,
        "1728999999999999954127206298082303229296808754939754358515952185492205195555970686503161978925334366506411"
        "7172173765405711633733999849873460293721055636975196097608313465009851523218054220112013268353024"},
    {1.729e203, chars_format::fixed,
        "1728999999999999867105557554983181779994676993383294456835415777095294898559043083749042731323302916122027"
        "34608221037658033563037335826099164581342454414341475400751022882924267500639175118619516849881088"},
    {1.729e204, chars_format::fixed,
        "1728999999999999867105557554983181779994676993383294456835415777095294898559043083749042731323302916122027"
        "346082210376580335630373358260991645813424544143414754007510228829242675006391751186195168498810880"},
    {1.729e205, chars_format::fixed,
        "1728999999999999978493267946150057235101405648175563130986502379843340078715110415274315368253903172614039"
        "3411352230664885951414474404707252567685362491726689693717612594490730459701212498422030511695200256"},
    {1.729e206, chars_format::fixed,
        "1729000000000000023048352102616807417144097110092470600646937020942558150777537347884424423026143275210844"
        "13915642814245189894587707335461870115058093118437065551746167169700519435561304930460620423780368384"},
    {1.729e207, chars_format::fixed,
        "1728999999999999951760217452270007125875790771025418649190241595183809235477654255708249935390559111055956"
        "462322500020910612858789660740389190139309439965647957684341012100313756938826170164761159328549830656"},
    {1.729e208, chars_format::fixed,
        "1729000000000000065821232892824887591905080913532701771520954276397807499957467203190129115607493773703776"
        "7452567850153766705981295209231564077573438259156042742173340674550200568056851767885132311833559957504"},
    {1.729e209, chars_format::fixed,
        "1728999999999999974572420540380983219081648799526875273656384131426608888373616845204625771433946043585520"
        "51890935701980382440665763277694263366291631715563922099093962317125501691219797148951157369951106367488"},
    {1.729e210, chars_format::fixed,
        "1729000000000000047571470422336106717340394490731536471948040247403567777640697131593028446772784227680125"
        "49998729941626210135983514329391365293845832416361126357205517859826704882698773572871289968658700933529"
        "6"},
    {1.729e211, chars_format::fixed,
        "1728999999999999930772990611207909120126401384804078554681390461840433554813368673371584166230643133128757"
        "530262591581928858234751126466760022097591112950855995442270289915047797763324112945990778107265496278630"
        "4"},
    {1.729e212, chars_format::fixed,
        "1729000000000000024211774460110467197897595869546044888494710290290940933075231439948739590664356008769851"
        "9060423578493954527348183399284829267702848819210602099460982008616231986142550111721684753707227067239628"
        "8"},
    {1.729e213, chars_format::fixed,
        "1729000000000000098962801539232513660114551457339617955545366153051346835684721653210463930211326309282727"
        "4066661708633687283348721106978612505084398970972235815491605296188835192949997297531106331814884750802288"
        "64"},
    {1.729e214, chars_format::fixed,
        "1729000000000000098962801539232513660114551457339617955545366153051346835684721653210463930211326309282727"
        "4066661708633687283348721106978612505084398970972235815491605296188835192949997297531106331814884750802288"
        "640"},
    {1.729e215, chars_format::fixed,
        "1728999999999999859759514886041964981020293576400184140983267392218047947334352970772946043661021347641525"
        "8046699692186542464147000442358506145463438485335007924193610775956504931166166302940957281870380163401777"
        "1520"},
    {1.729e216, chars_format::fixed,
        "1728999999999999859759514886041964981020293576400184140983267392218047947334352970772946043661021347641525"
        "8046699692186542464147000442358506145463438485335007924193610775956504931166166302940957281870380163401777"
        "15200"},
    {1.729e217, chars_format::fixed,
        "1729000000000000104703680418909086828412813646482164367094856523311346009005130501588964359488533628362116"
        "2451140797028418759009562402929495057715302022627529284882757164674411119232809241401269909013552860899900"
        "915712"},
    {1.729e218, chars_format::fixed,
        "1728999999999999908748347992615389350498797590416580186205585218436707559668508476936149706826523803785643"
        "8927587913154917723119512834472703927913811192793512196331440053700086168779494890633019807299014702901401"
        "9047424"},
    {1.729e219, chars_format::fixed,
        "1728999999999999947939414477874128846081600801629697022383439479411635249535832881866712637358925768700938"
        "3632298489929617930297522748164062153874109358760315614041703475894951158870157760786669827641922334501101"
        "70693632"},
    {1.729e220, chars_format::fixed,
        "1729000000000000073350827230702095231946571077511670898152573114531403857111270977644514015062612056429880"
        "6687372335608658593267154471976408476947063489854086550714546426918519127160278945278349892739226755620141"
        "073956864"},
    {1.729e221, chars_format::fixed,
        "1728999999999999973021697028439722123254594856806091797537266206435588971050920501022272912899663026246726"
        "8243313259065426062891449092926531418488700184979069801376272066099664752528181997685005840661383218724909"
        "5803404288"},
    {1.729e222, chars_format::fixed,
        "1728999999999999852626740785724874392824223391959396876798897916720611107778499929075583590304124190026942"
        "2110442367213547026440602638066678948338664219129049702170342833117039502969665660572992978167970974450631"
        "78800070656"},
    {1.729e223, chars_format::fixed,
        "1729000000000000109469314103516549551075682516965679374374083601445897216092997149228520811841273707295816"
        "0527233603164222304202408408434364217992074279609092580476325196813306702027833846411953751487250428902424"
        "411658780672"},
    {1.729e224, chars_format::fixed,
        "1728999999999999955363770112841544456124807041961909875828972190610725551104298817136758478918983996934491"
        "7477158861593817137545324946213753056200028243321066853492735778595546382592932934908577287495682756231348"
        "8374639362048"},
    {1.729e225, chars_format::fixed,
        "1728999999999999955363770112841544456124807041961909875828972190610725551104298817136758478918983996934491"
        "7477158861593817137545324946213753056200028243321066853492735778595546382592932934908577287495682756231348"
        "83746393620480"},
    {1.729e226, chars_format::fixed,
        "1729000000000000086867167651550882137149554113965126514587467261190072038561321393855062336346004549776155"
        "1546555974400562879759369500642007914262574194286848807185398748808035188510715046058125203435153836910666"
        "660776870150144"},
    {1.729e227, chars_format::fixed,
        "1728999999999999929063090605099676919919857627561266548077273176494856253612894301793097707433579886366159"
        "0663279439032467989102516035328102084587519053127910462754203184553048621409376512678667704307788540095485"
        "2728013494157312"},
    {1.729e228, chars_format::fixed,
        "1729000000000000097387439454647629151631533879725383845688146866836419757557883199992526644940166194003488"
        "2272107743425102539136493064996268302907577870364111363480811786425034292984137614950089036710311523365012"
        "08664190486577152"},
    {1.729e229, chars_format::fixed,
        "1729000000000000097387439454647629151631533879725383845688146866836419757557883199992526644940166194003488"
        "2272107743425102539136493064996268302907577870364111363480811786425034292984137614950089036710311523365012"
        "086641904865771520"},
    {1.729e230, chars_format::fixed,
        "1729000000000000043523647822792284437483797479032866310452667285927119436295486752568709384938058575559542"
        "8957282686019459483125620415502455113045159048848527075248297033825998878080214062223234210341504168718763"
        "5062129271217586176"},
    {1.729e231, chars_format::fixed,
        "1728999999999999828068481295370905580892851876262796169510748962289918151245900962873440344929628101783761"
        "5697982456396887259082129817527202353595483762786189922318238023429857218464519851315814904866274750133769"
        "18449701614570700800"},
    {1.729e232, chars_format::fixed,
        "1728999999999999897014134584145746815001954469149218614612162825853822562461768415575926437732325853392011"
        "5940958529876110370776046808879283236619379854326137811255856906756622549541541998806189082618348164080967"
        "367446107658043523072"},
    {1.729e233, chars_format::fixed,
        "1729000000000000062483702477205365776863800692076632482855556098407193149379850302061893060458800457251811"
        "6524101106226245838841447588124277355876730474022012744706142226740859344126395152783087109223324357554243"
        "0065239272876511592448"},
    {1.729e234, chars_format::fixed,
        "1729000000000000106608920582021264166693626351523942847720460971088091972558005471791484159852527018281091"
        "6679605793252948630325554462589609121012023972607579393626218312069989156015689327176926582984651342480449"
        "84361134585554652889088"},
    {1.729e235, chars_format::fixed,
        "1728999999999999894807873678904951895510463186176853096368917582219777621302860657089446882762639525340547"
        "5933183295524775231201841465156016648362615179396859478809853102490166058947077290086497108930281814834657"
        "025591736729648754589696"},
    {1.729e236, chars_format::fixed,
        "1729000000000000007768432027233651773474816874361967630423074056282878608638937891597200097210579521575504"
        "4331275294313134377401155063787265967108966535775910100045247880932738377383670376534726161759278896245746"
        "5285355282634609008836608"},
    {1.729e237, chars_format::fixed,
        "1728999999999999827031538669907731968731850973265784375936423697781917028901214316384794954093875527599573"
        "4894328096251759743482253305977267057114804365569429106068616235424622667885121438217559677232883565988003"
        "32382546180936146681331712"},
    {1.729e238, chars_format::fixed,
        "1729000000000000043915810698698835734423410054581204281320404127983070924586482606639681125833920320370690"
        "6218664733925409304184935415349265749107798969817206298840574210034361519283380164198159458664557962297295"
        "169477541554280787697729536"},
    {1.729e239, chars_format::fixed,
        "1729000000000000043915810698698835734423410054581204281320404127983070924586482606639681125833920320370690"
        "6218664733925409304184935415349265749107798969817206298840574210034361519283380164198159458664557962297295"
        "1694775415542807876977295360"},
    {1.729e240, chars_format::fixed,
        "1728999999999999905109876600272529324380812242539335541874656652654332431347910900876553975920291652997175"
        "6571089285814273585335218865351186586232282423098628895466521106284128654388494579570575598548286348659348"
        "38826021051753242233170558976"},
    {1.729e241, chars_format::fixed,
        "1729000000000000053169539638593922828426249908717328863950120626338320157469054053690556269161495564862258"
        "2861836430466151685441583185349137693299500072931778125732177750284377043609705869839998382672309403206491"
        "621558696956730678722131132416"},
    {1.729e242, chars_format::fixed,
        "1729000000000000112393404853922480230044424975188526192780306215811915247917511314816157186457977129608291"
        "3378135288326902925484128913348318136126387132865037817838440407884476399298190385947767496321918625025348"
        "9148780915324099812783013494784"},
    {1.729e243, chars_format::fixed,
        "1728999999999999828118851820345404702277184656126779014395415386338658813764916461413272783434865618827332"
        "6899900770595296973279909418952252010557329245185391295728379651403999491993464708630475750803794360294833"
        "90694499756914932900868430757888"},
    {1.729e244, chars_format::fixed,
        "1728999999999999979731946771586511650419712826293044176200690495391062245312967049894811131713858424577177"
        "3021625846718820147788826482630153944194160118614536107520412054860253842555985069866364681746793968151108"
        "577842647682888343552480063258624"},
    {1.729e245, chars_format::fixed,
        "1729000000000000040377184752082954429676724094359550240922800539012023617932187285287426471025455546877115"
        "1470315877168229417592393308101314717648892467986194032237225016242755582780993214360720254123993811293618"
        "4462017077283839493699983655305216"},
    {1.729e246, chars_format::fixed,
        "1729000000000000040377184752082954429676724094359550240922800539012023617932187285287426471025455546877115"
        "1470315877168229417592393308101314717648892467986194032237225016242755582780993214360720254123993811293618"
        "44620170772838394936999836553052160"},
    {1.729e247, chars_format::fixed,
        "1729000000000000079190137059600677808401211305922114122344950966929438896408488235938700288184877705149075"
        "3677477496655851350266676076402857612659921171584055104055985311527556696524998426837107820445401710904824"
        "761951506157501137093210078984536064"},
    {1.729e248, chars_format::fixed,
        "1728999999999999954988689675543962996482852228921909701794069597593710005284325193854624073274726798678802"
        "6614560314295461165708971217837920348624629320070899674235952366616193132544181746912667608216896432148964"
        "5515521511843261363789325959316897792"},
    {1.729e249, chars_format::fixed,
        "1729000000000000054349847582789334846017539490522073238234774693062293118183655627521885045202847523855020"
        "8264894060183773313355135104689870159852862801281424018091978722545283983728835090852219777999700655153652"
        "71987163516286613695035458237396680704"},
    {1.729e250, chars_format::fixed,
        "1728999999999999974860921256993037366389789681241942409082210616687426627864191280588076267660350943714046"
        "2944627063473123595238203995208310310870276016313004543007157637802011302781112415700578042173457276749902"
        "185216047980034136493216993220145184768"},
    {1.729e251, chars_format::fixed,
        "1728999999999999974860921256993037366389789681241942409082210616687426627864191280588076267660350943714046"
        "2944627063473123595238203995208310310870276016313004543007157637802011302781112415700578042173457276749902"
        "1852160479800341364932169932201451847680"},
    {1.729e252, chars_format::fixed,
        "1729000000000000025733834105502667753351549559181226139739851625567341181668648462625713885287548755004269"
        "9949597941367939414833039905276508614219131558692793007061443132037705818587654927797628753102253038928302"
        "52739562377704661678578505027859102302208"},
    {1.729e253, chars_format::fixed,
        "1728999999999999985035503826694963443782141656829799155213738818463409538625082716995603791185790505972091"
        "0345621239052086759157171177221949971540047124788962235818014736649150205942420918119988184359216429185582"
        "253651963139436632551730604631834352418816"},
    {1.729e254, chars_format::fixed,
        "1729000000000000115270160718879617234404246944354365505697299801195990796364493103011956092311416902875063"
        "7078346686462815257319951106996537628113117313281220703796985601892528166407169749088438004336933580362287"
        "1296316771797885821007048307014556983492608"},
    {1.729e255, chars_format::fixed,
        "1729000000000000011082435205131894201906562714334712425310451015009925790172964794198874251410915785352685"
        "5692166328534232458789727163176867502854661162487413929413808909697825798035370684313678148354759859420923"
        "22884790594750702246152544984575862160490496"},
    {1.729e256, chars_format::fixed,
        "1729000000000000052757525410630983414905636406342573657465190529484351792649576117724106987771116232361636"
        "8246638471705665578201816740704735552958043622804936639167079586575706745384090310223582090747629347797468"
        "789161414440419646317197202188037452302647296"},
    {1.729e257, chars_format::fixed,
        "1729000000000000052757525410630983414905636406342573657465190529484351792649576117724106987771116232361636"
        "8246638471705665578201816740704735552958043622804936639167079586575706745384090310223582090747629347797468"
        "7891614144404196463171972021880374523026472960"},
    {1.729e258, chars_format::fixed,
        "1728999999999999999413409947592149222266822080572511280307123950957086509479513623611809085230059660190179"
        "2176914128446231185354342081469064448825714073598507570682893120172019132777729189058905044484756402675490"
        "47196012356949148778193735918992054900953710592"},
    {1.729e259, chars_format::fixed,
        "1728999999999999871387532836298947159933667698724361575127764162491649829871363637742294119131523886978680"
        "9609575704623588642520402899303453798908123155503077806320845600803168862522462498263680133453861334382742"
        "510677025479263907297313735994439981106072649728"},
    {1.729e260, chars_format::fixed,
        "1729000000000000007948468421678362693089032372695721260652414603521448954786723622669776749636628711737612"
        "4348070023367740688209938026946771825486886801471536221640362954796609150794746968445253371886816073895007"
        "0027123301088399931475789340696192535364347363328"},
    {1.729e261, chars_format::fixed,
        "1729000000000000062572842655830128906351178242284265134862274779933368604752867616640769801838670641641185"
        "0243467750865401506485752078004099036118392259858919587768169896393985266103660756517882667259997969699912"
        "79952645196067042748768501329969096250857957097472"},
    {1.729e262, chars_format::fixed,
        "1728999999999999844075345719223064053302594763930089638022834074285690004888291640756797593030502922026894"
        "6661876840874758233382495873774790193592370426309386123256942130004480804868005604227365485767270386480289"
        "612269964553348690127260696379404126620000232407040"},
    {1.729e263, chars_format::fixed,
        "1728999999999999913994544738937324806278141477003425797011455100092947156844955953039668699849116592303467"
        "5807985932071764080775537859128169023200697413045236831900535015249122232463415252960330983844943213110569"
        "0321920405236916460825964777938959141043456207486976"},
    {1.729e264, chars_format::fixed,
        "1728999999999999913994544738937324806278141477003425797011455100092947156844955953039668699849116592303467"
        "5807985932071764080775537859128169023200697413045236831900535015249122232463415252960330983844943213110569"
        "03219204052369164608259647779389591410434562074869760"},
    {1.729e265, chars_format::fixed,
        "1729000000000000048239406856788705451991191166104231222269607469642880888601751432622781224940854839234487"
        "5768515387170015307770178471006656376048685227578070192496233354918833773446601778527624740154075040240705"
        "518442426386750121516841178109720146074288766364680192"},
    {1.729e266, chars_format::fixed,
        "1728999999999999905044887264413899429897271497730038768660911608789618241394502921067461198176334042508066"
        "2477283968398547332309228485002936533010831558743047941194155125937808129731202817922511400091001091301893"
        "2664420147994877477203134977728409653063494110409654272"},
    {1.729e267, chars_format::fixed,
        "1729000000000000076878310775263666656409975099779069712991346641813533418043201134933845230293758998579771"
        "8426761670924308902862368468207400344656255961345074642756649000715038902189681570648647408166689830028467"
        "96884250870420259627614671417709598222787663742942314496"},
    {1.729e268, chars_format::fixed,
        "1728999999999999985233818236143790802269866512019586542681781290867445323830562087538440413164465688674862"
        "1920373562910569398567360477165019645112029613290660401923318934167182490211826235861374870526322502707628"
        "127562245288354677046368998761493306536395450022245695488"},
    {1.729e269, chars_format::fixed,
        "1728999999999999911918224204847890118957779641812000006434129010110574848460450849622116559461031040750934"
        "4715263076499577795131354084331115085476648534847129009256654880928897360629541968031556840414028640850956"
        "2545380345556763416625468264290111659832105000965037359104"},
    {1.729e270, chars_format::fixed,
        "1728999999999999970570699429884610665607449137978069235432250834716071228756539839955175642423778759090076"
        "6479351465628371077880159198598238733184953397601954123389986123519525464295369382295411264503863730336293"
        "75295740314181900996960456429499687842575846003709730357248"},
    {1.729e271, chars_format::fixed,
        "1728999999999999829804758889796481353648242347179503085836758455662879916045926263155833843313184235076135"
        "4245539331719267199283026924357141978685021726990373849469991141302018015497383588062160646688259515571483"
        "756750918535076606032665993416631168563643356179672741183488"},
    {1.729e272, chars_format::fixed,
        "1728999999999999979955095465890485953071396257364640312071950326652950649603914078408465095697818394024339"
        "3961605607888978003119968016880978516818282175642726141651319122334025960881901768577627972358237344653947"
        "7527045021156018368987338023535545924165661336275922743984128"},
    {1.729e273, chars_format::fixed,
        "1728999999999999979955095465890485953071396257364640312071950326652950649603914078408465095697818394024339"
        "3961605607888978003119968016880978516818282175642726141651319122334025960881901768577627972358237344653947"
        "75270450211560183689873380235355459241656613362759227439841280"},
    {1.729e274, chars_format::fixed,
        "1728999999999999931906987761540404481255987006105396399676688927936128014865357977527623094934735463160914"
        "1252464399514670545892146867273350824615638832073973408153294168403783418358855950812678428143844439347559"
        "273999355369833763021592103493739096783630844844258023769636864"},
    {1.729e275, chars_format::fixed,
        "1728999999999999893468501598060339303803659605098001269760479808962669907074513096822949494324269118470173"
        "9085151432815224580109889947587248670853524157218971221354874205259589384340419296600718792772330115102448"
        "4910352379732193039198787444058867002772826138175906232666161152"},
    {1.729e276, chars_format::fixed,
        "1729000000000000077973235182764652155574831129933497893358283580035268824470568524205382777254507572985726"
        "9488253672972565215864723162080539008911674596522981717987290028351720747628915236818125042555598871478980"
        "24926300147696870760810286802757820350775412274559414568111570944"},
    {1.729e277, chars_format::fixed,
        "1728999999999999979570710604255685301296872983354566360772788235463216068526005629601418359691713730577431"
        "9939932478221983543462145447684117495280661028894176119783334922702584020541717402035508376004522201411496"
        "644874860941635692307716668762676068451502651317325600393382592512"},
    {1.729e278, chars_format::fixed,
        "1729000000000000058292730267062858784719239500617711586841184511120858273281655945284589893741948804504067"
        "9578589434022448881384207619201254706185471882997220598346499007221893402211475669861601709245383537465483"
        "5283853733699021045480256281745977764965038284599404366235690860544"},
    {1.729e279, chars_format::fixed,
        "1729000000000000058292730267062858784719239500617711586841184511120858273281655945284589893741948804504067"
        "9578589434022448881384207619201254706185471882997220598346499007221893402211475669861601709245383537465483"
        "52838537336990210454802562817459777649650382845994043662356908605440"},
    {1.729e280, chars_format::fixed,
        "1729000000000000058292730267062858784719239500617711586841184511120858273281655945284589893741948804504067"
        "9578589434022448881384207619201254706185471882997220598346499007221893402211475669861601709245383537465483"
        "528385373369902104548025628174597776496503828459940436623569086054400"},
    {1.729e281, chars_format::fixed,
        "1729000000000000098598404334420131608231491157456441942588203404257571082116548906914373719175669162354505"
        "5713581795392287134400303451018028958168735040297979371370839018495779805626391902988561495864704541525124"
        "8127427557331745076150638153935016910155444311569592327734245707481088"},
    {1.729e282, chars_format::fixed,
        "1729000000000000034109325826648495090611888506514473373392973175238830587980720168306719598481716589793805"
        "3897594017200545929574550120111190154995513988616765334531895000457561560162525929985425837273790935029698"
        "75777094395193866270780271584325542778507946684172915893365579523817472"},
    {1.729e283, chars_format::fixed,
        "1729000000000000034109325826648495090611888506514473373392973175238830587980720168306719598481716589793805"
        "3897594017200545929574550120111190154995513988616765334531895000457561560162525929985425837273790935029698"
        "757770943951938662707802715843255427785079466841729158933655795238174720"},
    {1.729e284, chars_format::fixed,
        "1729000000000000034109325826648495090611888506514473373392973175238830587980720168306719598481716589793805"
        "3897594017200545929574550120111190154995513988616765334531895000457561560162525929985425837273790935029698"
        "7577709439519386627078027158432554277850794668417291589336557952381747200"},
    {1.729e285, chars_format::fixed,
        "1728999999999999968072509434690339296569415391949897558537057420723640321985631539972481778891109155491648"
        "4038022532332202935832978709262587220546135631695202160808816325986426076807527173630214922876695401978382"
        "47747980868795315752276734990380325423708334338293356332173256911600222208"},
    {1.729e286, chars_format::fixed,
        "1729000000000000020901962548256863931803393883601558210421790024335792534781702442639872034563595102933373"
        "9925679720226877330826235837941469568105638317232452699787279265563334463491526178714383654394371828419435"
        "501712716899141561670795642655364993075480242149970039811271150013740220416"},
    {1.729e287, chars_format::fixed,
        "1729000000000000105429087529963303348177759470244215253437362190115236075255415886907696443639572618840134"
        "9345931220858356362815447243827681324200842614092053562152819968886387882185924586849053624822654110725120"
        "3404853700370430083076409110578637752169152801772284021945328794501210177536"},
    {1.729e288, chars_format::fixed,
        "1729000000000000105429087529963303348177759470244215253437362190115236075255415886907696443639572618840134"
        "9345931220858356362815447243827681324200842614092053562152819968886387882185924586849053624822654110725120"
        "34048537003704300830764091105786377521691528017722840219453287945012101775360"},
    {1.729e289, chars_format::fixed,
        "1728999999999999943137007565086939668738977543890313730847463631818704477545886073913473578213695788299153"
        "9259048339645916621396161344526154752498050364121619906410981818506125318292679643230487281600352128698205"
        "450041876012272230764897995725066113505360007164892346418670358932269886865408"},
    {1.729e290, chars_format::fixed,
        "1729000000000000159526447518255424574657353445695515760967328376214079941158592491239104065448198229020461"
        "9374892181262502943288542543594856848101773364082198114066766019013142070150339568055242405896754771400758"
        "6372998680452999341552218828354629957874337045146737541198203862894047280496640"},
    {1.729e291, chars_format::fixed,
        "1729000000000000090281826733241509404763473157117851111328971658007559792802526437694902309533157447989643"
        "3737822151945195320282980559892872177508582004094813087616915074850896709555888392111320766121905925735941"
        "61737731059473106907031823896013599345717012136274370365545237753512157887070208"},
    {1.729e292, chars_format::fixed,
        "1729000000000000034886130105230377268848368926255719391618286283442343674117673594859540904801124823164988"
        "5228166128491349221878530972931284441034028916104905066457034319521100421080327451356183454302026849204088"
        "001439264634275977002395323859874391592959254841199663283957970531695059527532544"},
    {1.729e293, chars_format::fixed,
        "1729000000000000123519244710048188686312535695635130143155382882746689464013438143396119152372377022884436"
        "2843615766017502979325650312069824819393313856888757900312843528048774482641224956564403153213833371655053"
        "7869401381710041243110719880202929545756966412756701278783490217371774904766038016"},
    {1.729e294, chars_format::fixed,
        "1729000000000000052612753026193939552341202280131601541925705603303212832096826504566856554315375263108878"
        "0751256055996579973367954840758992516705885904261675633228196161226635233392506952397827394084388153694281"
        "15853943934162160646413065669195810418950673212809375620283618077279154571734679552"},
    {1.729e295, chars_format::fixed,
        "1728999999999999995887559679110540245164135547728778660941963779748431526563537193503446475869773855288431"
        "5077368287979841568601798463710326674555943542160009819560478267768923833993532549064566786780831979325663"
        "055818880278115592186577591629290223880554804810032658862425908001282789909941190656"},
    {1.729e296, chars_format::fixed,
        "1729000000000000041267714356777259690905788933651036965728957238592256570990168642354174538626254981544788"
        "7616478502393232292414723565349259348275897431841342470494652582535092953512712071731175272623676918820557"
        "5379953275289204036086200436794245281277163466644815367347541262184897945558656745472"},
    {1.729e297, chars_format::fixed,
        "1728999999999999968659466872510508577719143516175423678069767704442136499907558324193009638215885179534617"
        "1553902159331807134314043402726967070323971208351210228999973678909222362282024835464601695275125015628726"
        "36651301192763270533335212039920964133225787969736333213902897707095858712238650032128"},
    {1.729e298, chars_format::fixed,
        "1729000000000000084832662847337310358817776184136404938324470959082328613639734833250873478872476862750891"
        "7254024308230087387275131662922634715047053165935421815391459924710615308251124413491119419032808060735656"
        "240884716889693022573780797647553460204991426844752459492189215707008519015953179082752"},
    {1.729e299, chars_format::fixed,
        "1729000000000000084832662847337310358817776184136404938324470959082328613639734833250873478872476862750891"
        "7254024308230087387275131662922634715047053165935421815391459924710615308251124413491119419032808060735656"
        "2408847168896930225737807976475534602049914268447524594921892157070085190159531790827520"},
    {1.729e300, chars_format::fixed,
        "1729000000000000010481817423448157218914651276641376931761460876112605660851141867453840620852258185492476"
        "0005946132935188025380035176397407422424280713081526400100908727397723822830900683554148075827890911867221"
        "12128682571397441953990644420861341612644195667042341798616666297993656260407050467540992"},
    {1.729e301, chars_format::fixed,
        "1729000000000000010481817423448157218914651276641376931761460876112605660851141867453840620852258185492476"
        "0005946132935188025380035176397407422424280713081526400100908727397723822830900683554148075827890911867221"
        "121286825713974419539906444208613416126441956670423417986166662979936562604070504675409920"},
    {1.729e302, chars_format::fixed,
        "1728999999999999915312735280870041199838651395047741083360807969911360281281742871233638562586378278601703"
        "8728406068557716842154311673645116487867131973428540268529003194837222721493014309234824756525596961315624"
        "1682015250090546076565472718067701597058986348472822448584577954892844583968606814340120576"},
    {1.729e303, chars_format::fixed,
        "1728999999999999991448000994932534015099451300322649762081330294872356584937262068209800209199082204114321"
        "5750438120059693788734890475846949235512850965150929173786527620885623602563323408690283411967432121756901"
        "73066976557299045716323460972824476484233329230579518336062488948180614176262854002713034752"},
    {1.729e304, chars_format::fixed,
        "1729000000000000113264426137432522519516731148762503648034166014809950670786092783371658843779408484934509"
        "8985689402462856903263816559369881631746001351906751422198566702563065012275817967819017260674368378462945"
        "830618950475287816373934350402604133060628744239415884964092239869840835147857113776119611392"},
    {1.729e305, chars_format::fixed,
        "1729000000000000064537856080432527117749819209386562093653031726834913036446560497306915389947277972606434"
        "5691588889501591657452246125960708673252741197204422522833751069892088448390820144167523721191593875780528"
        "1906392765143688726896544541328603857733105634659676043227052997146269577937656842765239058432"},
    {1.729e306, chars_format::fixed,
        "1728999999999999908612831898032541832095701003383549119633402005314792606560057181899736337684460333156593"
        "5150467248025542870855220739051355206074308702156970044866341045344963443958827108482744394846715467196791"
        "74270431983942825289995878606968039445389238499093310627026709121794255026067310987781764808704"},
    {1.729e307, chars_format::fixed,
        "1729000000000000033352851243952530060618995568185959498849105782530888950469259834225479579494714444716466"
        "3583364561206381900132841048578837979817054698194932027240269064982663447504421537030567855922618194063780"
        "901052285179380748731715320520224387509426927770960704712217658015290076287147169396782654291968"},
    {1.729e308, chars_format::fixed,
        "1729000000000000033352851243952530060618995568185959498849105782530888950469259834225479579494714444716466"
        "3583364561206381900132841048578837979817054698194932027240269064982663447504421537030567855922618194063780"
        "9010522851793807487317153205202243875094269277709607047122176580152900762871471693967826542919680"},

    // Also test one-digit cases, where the decimal point can't appear between digits like "17.29".
    {7e-3, chars_format::fixed, "0.007"},
    {7e-2, chars_format::fixed, "0.07"},
    {7e-1, chars_format::fixed, "0.7"},
    {7e0, chars_format::fixed, "7"},
    {7e1, chars_format::fixed, "70"},
    {7e2, chars_format::fixed, "700"},
    {7e3, chars_format::fixed, "7000"},

    // Test the maximum value in fixed notation.
    {0x1.fffffffffffffp+1023, chars_format::fixed,
        "1797693134862315708145274237317043567980705675258449965989174768031572607800285387605895586327668781715404"
        "5895351438246423432132688946418276846754670353751698604991057655128207624549009038932894407586850845513394"
        "2304583236903222948165808559332123348274797826204144723168738177180919299881250404026184124858368"},

    // Test highly-trimmed powers of 2.
    {0x1p959, chars_format::fixed,
        "4872657005699999540176691193937594155438113428797503763433953228606474345383213051232807532941005129612652"
        "4581157043340917295849326015470232889936481563267097656388499782365149353948277450268241763997967396091894"
        "36842798962697437472873181807734482806413869401552138773540914294995957055488"},
    {0x1p959, chars_format::scientific, "4.8726570057e+288"},
    {0x1p960, chars_format::fixed,
        "9745314011399999080353382387875188310876226857595007526867906457212948690766426102465615065882010259225304"
        "9162314086681834591698652030940465779872963126534195312776999564730298707896554900536483527995934792183788"
        "73685597925394874945746363615468965612827738803104277547081828589991914110976"},
    {0x1p960, chars_format::scientific, "9.7453140114e+288"},

    // Test powers of 10 that are exactly representable.
    {1e0, chars_format::fixed, "1"},
    {1e1, chars_format::fixed, "10"},
    {1e2, chars_format::fixed, "100"},
    {1e3, chars_format::fixed, "1000"},
    {1e4, chars_format::fixed, "10000"},
    {1e5, chars_format::fixed, "100000"},
    {1e6, chars_format::fixed, "1000000"},
    {1e7, chars_format::fixed, "10000000"},
    {1e8, chars_format::fixed, "100000000"},
    {1e9, chars_format::fixed, "1000000000"},
    {1e10, chars_format::fixed, "10000000000"},
    {1e11, chars_format::fixed, "100000000000"},
    {1e12, chars_format::fixed, "1000000000000"},
    {1e13, chars_format::fixed, "10000000000000"},
    {1e14, chars_format::fixed, "100000000000000"},
    {1e15, chars_format::fixed, "1000000000000000"},
    {1e16, chars_format::fixed, "10000000000000000"},
    {1e17, chars_format::fixed, "100000000000000000"},
    {1e18, chars_format::fixed, "1000000000000000000"},
    {1e19, chars_format::fixed, "10000000000000000000"},
    {1e20, chars_format::fixed, "100000000000000000000"},
    {1e21, chars_format::fixed, "1000000000000000000000"},
    {1e22, chars_format::fixed, "10000000000000000000000"},

    // Test powers of 10 that aren't exactly representable.
    // This exercises the "adjustment" code.
    {1e23, chars_format::fixed, "99999999999999991611392"},
    {1e24, chars_format::fixed, "999999999999999983222784"},
    {1e25, chars_format::fixed, "10000000000000000905969664"},
    {1e26, chars_format::fixed, "100000000000000004764729344"},
    {1e27, chars_format::fixed, "1000000000000000013287555072"},
    {1e28, chars_format::fixed, "9999999999999999583119736832"},
    {1e29, chars_format::fixed, "99999999999999991433150857216"},
    {1e30, chars_format::fixed, "1000000000000000019884624838656"},
    {1e31, chars_format::fixed, "9999999999999999635896294965248"},
    {1e32, chars_format::fixed, "100000000000000005366162204393472"},
    {1e33, chars_format::fixed, "999999999999999945575230987042816"},
    {1e34, chars_format::fixed, "9999999999999999455752309870428160"},
    {1e35, chars_format::fixed, "99999999999999996863366107917975552"},
    {1e36, chars_format::fixed, "1000000000000000042420637374017961984"},
    {1e37, chars_format::fixed, "9999999999999999538762658202121142272"},
    {1e38, chars_format::fixed, "99999999999999997748809823456034029568"},
    {1e39, chars_format::fixed, "999999999999999939709166371603178586112"},
    {1e40, chars_format::fixed, "10000000000000000303786028427003666890752"},
    {1e41, chars_format::fixed, "100000000000000000620008645040778319495168"},
    {1e42, chars_format::fixed, "1000000000000000044885712678075916785549312"},
    {1e43, chars_format::fixed, "10000000000000000139372116959414099130712064"},
    {1e44, chars_format::fixed, "100000000000000008821361405306422640701865984"},
    {1e45, chars_format::fixed, "999999999999999929757289024535551219930759168"},
    {1e46, chars_format::fixed, "9999999999999999931398190359470212947659194368"},
    {1e47, chars_format::fixed, "100000000000000004384584304507619735463404765184"},
    {1e48, chars_format::fixed, "1000000000000000043845843045076197354634047651840"},
    {1e49, chars_format::fixed, "9999999999999999464902769475481793196872414789632"},
    {1e50, chars_format::fixed, "100000000000000007629769841091887003294964970946560"},
    {1e51, chars_format::fixed, "999999999999999993220948674361627976461708441944064"},
    {1e52, chars_format::fixed, "9999999999999999932209486743616279764617084419440640"},
    {1e53, chars_format::fixed, "99999999999999999322094867436162797646170844194406400"},
    {1e54, chars_format::fixed, "1000000000000000078291540404596243842305360299886116864"},
    {1e55, chars_format::fixed, "10000000000000000102350670204085511496304388135324745728"},
    {1e56, chars_format::fixed, "100000000000000009190283508143378238084034459715684532224"},
    {1e57, chars_format::fixed, "1000000000000000048346692115553659057528394845890514255872"},
    {1e58, chars_format::fixed, "9999999999999999438119489974413630815797154428513196965888"},
    {1e59, chars_format::fixed, "99999999999999997168788049560464200849936328366177157906432"},
    {1e60, chars_format::fixed, "999999999999999949387135297074018866963645011013410073083904"},
    {1e61, chars_format::fixed, "9999999999999999493871352970740188669636450110134100730839040"},
    {1e62, chars_format::fixed, "100000000000000003502199685943161173046080317798311825604870144"},
    {1e63, chars_format::fixed, "1000000000000000057857959942726969827393378689175040438172647424"},
    {1e64, chars_format::fixed, "10000000000000000213204190094543968723012578712679649467743338496"},
    {1e65, chars_format::fixed, "99999999999999999209038626283633850822756121694230455365568299008"},
    {1e66, chars_format::fixed, "999999999999999945322333868247445125709646570021247924665841614848"},
    {1e67, chars_format::fixed, "9999999999999999827367757839185598317239782875580932278577147150336"},
    {1e68, chars_format::fixed, "99999999999999995280522225138166806691251291352861698530421623488512"},
    {1e69, chars_format::fixed, "1000000000000000072531436381529235126158374409646521955518210155479040"},
    {1e70, chars_format::fixed, "10000000000000000725314363815292351261583744096465219555182101554790400"},
    {1e71, chars_format::fixed, "100000000000000004188152556421145795899143386664033828314342771180699648"},
    {1e72, chars_format::fixed, "999999999999999943801810948794571024057224129020550531544123892056457216"},
    {1e73, chars_format::fixed, "9999999999999999830336967949613257980309080240684656321838454199566729216"},
    {1e74, chars_format::fixed, "99999999999999995164818811802792197885196090803013355167206819763650035712"},
    {1e75, chars_format::fixed, "999999999999999926539781176481198923508803215199467887262646419780362305536"},
    {1e76, chars_format::fixed, "10000000000000000470601344959054695891559601407866630764278709534898249531392"},
    {1e77, chars_format::fixed, "99999999999999998278261272554585856747747644714015897553975120217811154108416"},
    {1e78, chars_format::fixed, "1000000000000000008493621433689702976148869924598760615894999102702796905906176"},
    {1e79, chars_format::fixed, "9999999999999999673560075006595519222746403606649979913266024618633003221909504"},
    {1e80, chars_format::fixed, "100000000000000000026609864708367276537402401181200809098131977453489758916313088"},
    {1e81, chars_format::fixed, "999999999999999921281879895665782741935503249059183851809998224123064148429897728"},
    {1e82, chars_format::fixed, "9999999999999999634067965630886574211027143225273567793680363843427086501542887424"},
    {1e83, chars_format::fixed, "100000000000000003080666323096525690777025204007643346346089744069413985291331436544"},
    {1e84, chars_format::fixed,
        "1000000000000000057766609898115896702437267127096064137098041863234712334016924614656"},
    {1e85, chars_format::fixed,
        "10000000000000000146306952306748730309700429878646550592786107871697963642511482159104"},
    {1e86, chars_format::fixed,
        "100000000000000001463069523067487303097004298786465505927861078716979636425114821591040"},
    {1e87, chars_format::fixed,
        "999999999999999959416724456350362731491996089648451439669739009806703922950954425516032"},
    {1e88, chars_format::fixed,
        "9999999999999999594167244563503627314919960896484514396697390098067039229509544255160320"},
    {1e89, chars_format::fixed,
        "99999999999999999475366575191804932315794610450682175621941694731908308538307845136842752"},
    {1e90, chars_format::fixed,
        "999999999999999966484112715463900049825186092620125502979674597309179755437379230686511104"},
    {1e91, chars_format::fixed,
        "10000000000000000795623248612804971431562261401669105159386439973487930752201761134141767680"},
    {1e92, chars_format::fixed,
        "100000000000000004337729697461918607329029332495193931179177378933611681288968111094132375552"},
    {1e93, chars_format::fixed,
        "1000000000000000043377296974619186073290293324951939311791773789336116812889681110941323755520"},
    {1e94, chars_format::fixed,
        "10000000000000000202188791271559469885760963232143577411377768562080040049981643093586978275328"},
    {1e95, chars_format::fixed,
        "100000000000000002021887912715594698857609632321435774113777685620800400499816430935869782753280"},
    {1e96, chars_format::fixed,
        "1000000000000000049861653971908893017010268485438462151574892930611988399099305815384459015356416"},
    {1e97, chars_format::fixed,
        "10000000000000000735758738477112498397576062152177456799245857901351759143802190202050679656153088"},
    {1e98, chars_format::fixed,
        "99999999999999999769037024514370800696612547992403838920556863966097586548129676477911932478685184"},
    {1e99, chars_format::fixed,
        "999999999999999967336168804116691273849533185806555472917961779471295845921727862608739868455469056"},
    {1e100, chars_format::fixed,
        "10000000000000000159028911097599180468360808563945281389781327557747838772170381060813469985856815104"},
    {1e101, chars_format::fixed,
        "99999999999999997704951326524533662844684271992415000612999597473199345218078991130326129448151154688"},
    {1e102, chars_format::fixed,
        "999999999999999977049513265245336628446842719924150006129995974731993452180789911303261294481511546880"},
    {1e103, chars_format::fixed,
        "10000000000000000019156750857346687362159551272651920111528035145993793242039887559612361451081803235328"},
    {1e104, chars_format::fixed,
        "10000000000000000019156750857346687362159551272651920111528035145993793242039887559612361451081803235328"
        "0"},
    {1e105, chars_format::fixed,
        "99999999999999993825830082528197854032702736447212447829441621253887149182459971363682052750390825530163"
        "2"},
    {1e106, chars_format::fixed,
        "1000000000000000091035999050368435010460453995175486557154545737484090289535133415215418009754161219056435"
        "2"},
    {1e107, chars_format::fixed,
        "9999999999999999688138404702992698343537126906127968940664421175279152513667064539525400239539588480525926"
        "4"},
    {1e108, chars_format::fixed,
        "1000000000000000033998991713002824594943974719712898047713430714837875271723200833292741616380733445921308"
        "672"},
    {1e109, chars_format::fixed,
        "9999999999999999818508707188399807864717650964328171247958398369899072554380053298205803424393137676263358"
        "464"},
    {1e110, chars_format::fixed,
        "1000000000000000023569367514170255833249532795056881863129912539268281668466161732598309361592449510262314"
        "10688"},
    {1e111, chars_format::fixed,
        "9999999999999999568197726416418157584051044772583782817953962156228826076211114881539429309474323220447488"
        "90112"},
    {1e112, chars_format::fixed,
        "9999999999999999301199346926304397284673331501389768492615896861647229832830913903761963586894254467577228"
        "034048"},
    {1e113, chars_format::fixed,
        "1000000000000000015559416129466843024268201396921061433369770580430833781164755703264985389915047447676206"
        "28086784"},
    {1e114, chars_format::fixed,
        "1000000000000000015559416129466843024268201396921061433369770580430833781164755703264985389915047447676206"
        "280867840"},
    {1e115, chars_format::fixed,
        "1000000000000000015559416129466843024268201396921061433369770580430833781164755703264985389915047447676206"
        "2808678400"},
    {1e116, chars_format::fixed,
        "1000000000000000015559416129466843024268201396921061433369770580430833781164755703264985389915047447676206"
        "28086784000"},
    {1e117, chars_format::fixed,
        "1000000000000000050555427725995033814228237030803003279020481474722232763977085405824233377105062219252417"
        "113236701184"},
    {1e118, chars_format::fixed,
        "9999999999999999665649998943273759183241515094863428494587753284228752052274941196820382078490267674695111"
        "155514343424"},
    {1e119, chars_format::fixed,
        "9999999999999999441675524725493338127497287038019000682423203560763798562276031100441194960474173136607361"
        "8283536318464"},
    {1e120, chars_format::fixed,
        "9999999999999999800034683473942011816688051928970085181886483118307724146274287254647894349299924397547760"
        "75181077037056"},
    {1e121, chars_format::fixed,
        "1000000000000000037340933747145988971939327575449182038102773041037800508067149710137861337142112641505239"
        "9029342192009216"},
    {1e122, chars_format::fixed,
        "1000000000000000014405947587245273855831118622428312630137123149354989270691261316268632576257264560805054"
        "37183296233537536"},
    {1e123, chars_format::fixed,
        "9999999999999999777099697314041296700579842975949215773920833226624912908898398860778665588415076316847575"
        "22070951350501376"},
    {1e124, chars_format::fixed,
        "9999999999999999483531874467312143214394768377282087351960514613084929070487027419252537449089020883885200"
        "422613425626021888"},
    {1e125, chars_format::fixed,
        "9999999999999999248677616189928820425446708698348384614392259722252941999757930266031634937628176537515300"
        "5841365553228283904"},
    {1e126, chars_format::fixed,
        "9999999999999999248677616189928820425446708698348384614392259722252941999757930266031634937628176537515300"
        "58413655532282839040"},
    {1e127, chars_format::fixed,
        "9999999999999999549291066784979473595300225087383524118479625982517885450291174622154390152298057300868772"
        "377386949310916067328"},
    {1e128, chars_format::fixed,
        "1000000000000000075174486916518208627471429064352408213482909102357765925242415204664541101097758035428265"
        "95503885252632667750400"},
    {1e129, chars_format::fixed,
        "9999999999999999982174435641852414159889288687594125004365433397299404019059046494971157661422685600097771"
        "75966751665376232210432"},
    {1e130, chars_format::fixed,
        "1000000000000000059783078246051615185174929025233809070873635949832200820575113093631056034106660140344568"
        "1992244323541365884452864"},
    {1e131, chars_format::fixed,
        "9999999999999999120255550095723181391285286496952573018246136855867758157690128277095993909921203475410697"
        "4340599870111173348163584"},
    {1e132, chars_format::fixed,
        "9999999999999999908295674023612765636866088499824849119840922265176691516655996362010429339865415703696022"
        "53175829982724989462249472"},
    {1e133, chars_format::fixed,
        "1000000000000000022351172359476859933509840930097375956047883642890026486024234359597620351184310059501015"
        "2570837624953702918544949248"},
    {1e134, chars_format::fixed,
        "9999999999999999214820364967069931500754982737297246150437511104984830160766032447285726161514508942804936"
        "4457837845490532419930947584"},
    {1e135, chars_format::fixed,
        "9999999999999999618296908418149398634492353362767851514454041234551004040556556906761917101645945603687022"
        "89580532071091311261383655424"},
    {1e136, chars_format::fixed,
        "1000000000000000058664061270074011975546204286389730438809371354550982135205381560950477535796139358980403"
        "0375857007499376802103616864256"},
    {1e137, chars_format::fixed,
        "1000000000000000032841562489204926078987012566359611695512313426258747006898787995544001315627727412683949"
        "50478432243557864849063421149184"},
    {1e138, chars_format::fixed,
        "1000000000000000032841562489204926078987012566359611695512313426258747006898787995544001315627727412683949"
        "504784322435578648490634211491840"},
    {1e139, chars_format::fixed,
        "1000000000000000032841562489204926078987012566359611695512313426258747006898787995544001315627727412683949"
        "5047843224355786484906342114918400"},
    {1e140, chars_format::fixed,
        "1000000000000000059283801240814870037063624887670453288648500744829995778284739806520232965080181245691517"
        "92237293382948229697163514582401024"},
    {1e141, chars_format::fixed,
        "1000000000000000016976219238238959704141045173573106739630601035115997744067216908958262325956255112879408"
        "454231155599236459402033650892537856"},
    {1e142, chars_format::fixed,
        "1000000000000000050822284840299687970479108944850983978844920802887196171441235227007838837255396019129096"
        "0287445781834331294577148468377157632"},
    {1e143, chars_format::fixed,
        "1000000000000000023745432358651105357408657927828682187473464988670237429542020572568177628216083294129345"
        "96913384011607579341316989008157343744"},
    {1e144, chars_format::fixed,
        "1000000000000000023745432358651105357408657927828682187473464988670237429542020572568177628216083294129345"
        "969133840116075793413169890081573437440"},
    {1e145, chars_format::fixed,
        "9999999999999999890870611821409196126784806260401358945180015464725302399110258148854112806457630061296658"
        "928320953898584032761523454337112604672"},
    {1e146, chars_format::fixed,
        "9999999999999999336336672997246224211101969431784618257892600389561987365014342025929851245332505453301777"
        "7074930382791057905692427399713177731072"},
    {1e147, chars_format::fixed,
        "9999999999999999779963824056576601743648238894678010807722532449692639392291074924269260494232605139697682"
        "68415537077468838432306731146395363835904"},
    {1e148, chars_format::fixed,
        "1000000000000000048976726575150520579572227003530743888745042374590168263593384756161231529247276463793113"
        "0646815102767620534329186625852171022761984"},
    {1e149, chars_format::fixed,
        "1000000000000000048976726575150520579572227003530743888745042374590168263593384756161231529247276463793113"
        "06468151027676205343291866258521710227619840"},
    {1e150, chars_format::fixed,
        "9999999999999999808355961724373745905731200140303187930911648101541001122036785829762982686162211519627020"
        "60266176005440567032331208403948233373515776"},
    {1e151, chars_format::fixed,
        "1000000000000000017177532387217719118039310408430545510773232844520003126278188542008262674286117318272254"
        "5959543542834786931126445173006249634549465088"},
    {1e152, chars_format::fixed,
        "1000000000000000046251081359041994740012262723950726884918887272012725537537796509233834198822034251319896"
        "62450489690590919397689516441796634752009109504"},
    {1e153, chars_format::fixed,
        "9999999999999999997334030041231537448555390191184366862858401880243696795224237616729197595645671584436693"
        "78824028710020392594094129030220133015859757056"},
    {1e154, chars_format::fixed,
        "1000000000000000036947545688058226540980917982984268845192277855215054365934721959721651310970540832744651"
        "1753687232667314337003349573404171046192448274432"},
    {1e155, chars_format::fixed,
        "1000000000000000007176231540910168304080614811891603118067127721462506616804883401282666069845761893303865"
        "73813296762136260081534229469225952733653677113344"},
    {1e156, chars_format::fixed,
        "9999999999999999833591802231917217145603722750174705363670076144604684175010125545314778769459387417512373"
        "88344363105067534507348164573733465510370326085632"},
    {1e157, chars_format::fixed,
        "9999999999999999833591802231917217145603722750174705363670076144604684175010125545314778769459387417512373"
        "883443631050675345073481645737334655103703260856320"},
    {1e158, chars_format::fixed,
        "9999999999999999528733545365121100799744618278185808317908538774978595223920578706899569900341651077638731"
        "0061494932420984963311567802202010637287727642443776"},
    {1e159, chars_format::fixed,
        "9999999999999999284846939871684207723057334700594690681299308879277724063048941236167402805047462005739816"
        "70431418299523701733729688780649419062882836695482368"},
    {1e160, chars_format::fixed,
        "1000000000000000006528407745068226556845664214888626711844884454552051177783818114251033750998886703581634"
        "2470187175785193750117648543530356184548650438281396224"},
    {1e161, chars_format::fixed,
        "1000000000000000037745893248228148870661636512820289769330865881201762686375387710504751139196542904784695"
        "27765363729011764432297892058199009821165792668120252416"},
    {1e162, chars_format::fixed,
        "9999999999999999378499396381163974664505251594389679853757253159226858588823650024928554969640430609348999"
        "79621894213003182527093908649335762989920701551401238528"},
    {1e163, chars_format::fixed,
        "9999999999999999378499396381163974664505251594389679853757253159226858588823650024928554969640430609348999"
        "796218942130031825270939086493357629899207015514012385280"},
    {1e164, chars_format::fixed,
        "1000000000000000001783349948587918365145636425603013927107015277701295028477899535620468707992842960998768"
        "97036220978235643807646031628623453753183252563447406133248"},
    {1e165, chars_format::fixed,
        "9999999999999998994898934518334849272334583997405404203369513388555203571250442826162875703467631208965785"
        "85177704871391229197474064067196498264773607101557544845312"},
    {1e166, chars_format::fixed,
        "9999999999999999404072760505352583023983296100855298230449769143938302256661863838179600254051950569374547"
        "392515068357773127490685649548117139715971745147241514401792"},
    {1e167, chars_format::fixed,
        "1000000000000000038608994287419514402794020514913504389544238295685773910164927426701973917545431703435557"
        "50902863155030391327289536708508823166797373630632400726786048"},
    {1e168, chars_format::fixed,
        "9999999999999999338604948347429745623719502164303315186116928223077006466996036476256924325958459471709145"
        "54599698521475539380813444812793279458505403728617494385000448"},
    {1e169, chars_format::fixed,
        "9999999999999999338604948347429745623719502164303315186116928223077006466996036476256924325958459471709145"
        "545996985214755393808134448127932794585054037286174943850004480"},
    {1e170, chars_format::fixed,
        "1000000000000000034419054309312452809177137702974177474706936476750650979626314475538922658147448273184971"
        "79085147422915077831721209019419643357959500300321574675254607872"},
    {1e171, chars_format::fixed,
        "9999999999999999539722067296568702117329877137391007098307415531962907132849458132083384777061664123737260"
        "01850053663010587168093173889073910282723323583537144858509574144"},
    {1e172, chars_format::fixed,
        "1000000000000000082687162857105802367643627696515223533632653430883267139431135672937273166412217389671719"
        "2642523265688348930066834399772699475577180106550229078889679814656"},
    {1e173, chars_format::fixed,
        "1000000000000000014039186255799705217824619705701291360938300429450213045486501081081841332435656868446122"
        "85763778101906192989276863139689872767772084421689716760605683089408"},
    {1e174, chars_format::fixed,
        "1000000000000000068957567536844582937679826098352437099093782830596656320642208754566186799616905285426599"
        "982929417458880300383900478261195703581718577367397759832385751351296"},
    {1e175, chars_format::fixed,
        "9999999999999999371534524623368764100273307559896873275206250678451924602685103382037576783819090846734548"
        "822294900033162112051840457868829614121240178061963384891963422539776"},
    {1e176, chars_format::fixed,
        "1000000000000000007448980502074319891441994938583153872359642541312639852467816160263719876373907058408465"
        "60260278464628372543383280977318309056924111623883709653889736043921408"},
    {1e177, chars_format::fixed,
        "1000000000000000007448980502074319891441994938583153872359642541312639852467816160263719876373907058408465"
        "602602784646283725433832809773183090569241116238837096538897360439214080"},
    {1e178, chars_format::fixed,
        "1000000000000000052438118447506283719547380015442972461056613724331806183475371886382095683088785761598872"
        "4636416932177829345401680187244151732297960592357271816907060120777654272"},
    {1e179, chars_format::fixed,
        "9999999999999999804554977348151415945787638924672627191414598315011400538632827245926943923449798364942214"
        "8597943950338419997003168440244384097290815044070304544781216945608327168"},
    {1e180, chars_format::fixed,
        "1000000000000000009248546019891598444566210341657546615907521388633406505708118389308454908642502206536081"
        "877044340989143693798086218131232373875663313958712699944969706504756133888"},
    {1e181, chars_format::fixed,
        "9999999999999999171107915076469365246063817042486381462561244058101538598046442622180212564904306224021286"
        "256366562347133135483117101991090685868467907010818055540655879490029748224"},
    {1e182, chars_format::fixed,
        "1000000000000000064531198727238395596542107524102891697698359578327358093250202865562715099933745157016453"
        "82788895184180192194795092289050635704895322791329123657951217763820802932736"},
    {1e183, chars_format::fixed,
        "9999999999999999465948729515652283389935268682194888565445714403135947064937559828869600251790935293249936"
        "66087115356131035228239552737388526279268078143523691759154905886843985723392"},
    {1e184, chars_format::fixed,
        "1000000000000000017356668416969128693522675261749530561236844323121852738547624112492413070031884505939869"
        "7631682172475335672600663748292592247410791680053842186513692689376624118857728"},
    {1e185, chars_format::fixed,
        "9999999999999999796170441687537151711071294518668416520676321189574484547855611100361714461103959850786025"
        "1139162957211888350975873638026151889477992007905860430885494197722591793250304"},
    {1e186, chars_format::fixed,
        "9999999999999999796170441687537151711071294518668416520676321189574484547855611100361714461103959850786025"
        "11391629572118883509758736380261518894779920079058604308854941977225917932503040"},
    {1e187, chars_format::fixed,
        "9999999999999999071569656121801212080692814968920789464627446869617922299624001453201875281811380250249693"
        "879805812353226907091680705581859236698853640605134247712274342131878495422251008"},
    {1e188, chars_format::fixed,
        "1000000000000000023093091302697871548929838224851699275430564578154842189679457688865761796867950761110782"
        "38543825857419659919011313587350687602971665369018571203143144663564875896666980352"},
    {1e189, chars_format::fixed,
        "1000000000000000023093091302697871548929838224851699275430564578154842189679457688865761796867950761110782"
        "385438258574196599190113135873506876029716653690185712031431446635648758966669803520"},
    {1e190, chars_format::fixed,
        "1000000000000000072559171597318778361030342428781137282456834398397210172492068907445206818174324195174062"
        "5976868675721161334753163637413771490365780039321792212624518252692320803210995433472"},
    {1e191, chars_format::fixed,
        "1000000000000000072559171597318778361030342428781137282456834398397210172492068907445206818174324195174062"
        "59768686757211613347531636374137714903657800393217922126245182526923208032109954334720"},
    {1e192, chars_format::fixed,
        "1000000000000000040900880208761398001286019738266296957960021713442094663491997727554362004538245197373563"
        "261847757813447631532786297905940174312186739777303375354598782943738754654264509857792"},
    {1e193, chars_format::fixed,
        "1000000000000000066227513319607302289081477890678169217557471861406187070692054671467037855447108395613962"
        "7305190456203824330868103505742897540916997511012040520808812168041334151877325366493184"},
    {1e194, chars_format::fixed,
        "9999999999999999446596743875469617076632787591011823714897111511785435161317813406861937710845650440600452"
        "8089686414709538562749489776621177115003729674648080379472553427423904462708600804999168"},
    {1e195, chars_format::fixed,
        "9999999999999999770777647694297191960414651941883788637744473405725817973478542288944188602479099378077566"
        "00796112539971931616645685181699233267813951241073670004367049615544210109925082343145472"},
    {1e196, chars_format::fixed,
        "9999999999999999511432924639235132053389160461186216699466583890573511723749959183278387889172340228095875"
        "448767138256706948253250552493092635735926276453993770366538373425000777236538229086224384"},
    {1e197, chars_format::fixed,
        "9999999999999999511432924639235132053389160461186216699466583890573511723749959183278387889172340228095875"
        "4487671382567069482532505524930926357359262764539937703665383734250007772365382290862243840"},
    {1e198, chars_format::fixed,
        "1000000000000000017535541566019400541537441865177200086145798104936341572305513193378283771523764365204900"
        "328030374534281861011105867876227585990799216050325567033999660761493056632508247061001404416"},
    {1e199, chars_format::fixed,
        "1000000000000000097206240488534465344975672848047494185584765763991130052222133923438817750651600776079275"
        "6678147673846152604340428430285295728914471221362369950308146488642846313231335560438561636352"},
    {1e200, chars_format::fixed,
        "9999999999999999697331222125103616594745032754550236264824175095034684843555407553419633840470625186802751"
        "2415973882408182135734368278484639385041047239877871023591066789981811181813306167128854888448"},
    {1e201, chars_format::fixed,
        "1000000000000000037718785293056550291741793714171007924670336578563554653884390444993619046236149589293075"
        "414109087389699655531583234914810756005630018925423128793192791080866922220799992003324610084864"},
    {1e202, chars_format::fixed,
        "9999999999999999017474591319641730272072128367390393282944984404433823148266910656903077218579754480674748"
        "342103902584639871831041306548820316951909258721342916786285447187693014154661313392524876840960"},
    {1e203, chars_format::fixed,
        "9999999999999999887691078750632944765093445982954992299750348488402926118236186684444269694600068984518592"
        "0534555642245481492613075738123641525387194542623914743194966239051177873087980216425864602058752"},
    {1e204, chars_format::fixed,
        "9999999999999999887691078750632944765093445982954992299750348488402926118236186684444269694600068984518592"
        "05345556422454814926130757381236415253871945426239147431949662390511778730879802164258646020587520"},
    {1e205, chars_format::fixed,
        "1000000000000000016616035472855013340286026761993566398512806499527303906862635501325745128692656962574862"
        "2041088095949318798038992779336698179926498716835527012730124200454693714718121768282606166882648064"},
    {1e206, chars_format::fixed,
        "1000000000000000038893577551088388431307372492952020133343023820076912942893848967630799656078777013873264"
        "60311941213291353170611409437561654018367221268940354434586262616943544566455807655946219322240663552"},
    {1e207, chars_format::fixed,
        "1000000000000000038893577551088388431307372492952020133343023820076912942893848967630799656078777013873264"
        "603119412132913531706114094375616540183672212689403544345862626169435445664558076559462193222406635520"},
    {1e208, chars_format::fixed,
        "9999999999999999818630698308109481982927274216983785721776674794699138106539424938898600659703096825493544"
        "616522696356805028364441642842329313746550197144253860793660984920822957311285732475861572950035529728"},
    {1e209, chars_format::fixed,
        "1000000000000000073111882183254852571116159535704205070042237624441112422237792851875363410143857412667610"
        "68799969763125334902791605243044670546908252847439043930576054277584733562461577854658781477884848504832"},
    {1e210, chars_format::fixed,
        "9999999999999999271137824193446055745986681532948826734589253924871946437036322790985580594661810444784007"
        "25843812838336795121561031396504666917998514458446354143529431921823271795036250068185162804696593727488"},
    {1e211, chars_format::fixed,
        "9999999999999999563134023721266549739021664297767471527755878388779781994104643936539191296017163181162427"
        "18274989796920105902832035603293074628215317261635171175975654092628084560952155763865693199526971991654"
        "4"},
    {1e212, chars_format::fixed,
        "9999999999999999095940104476753759350165691874057639858689279246527245102795330103653414173848598802956955"
        "303851066631868086527984288724316222918684327765330639240616986193403841354867066507768445677983667689881"
        "6"},
    {1e213, chars_format::fixed,
        "9999999999999999843450375267974223972335247751993370529195837874131304128890232236270657569318301808085710"
        "3100891967716008425285219964180994603002344795269643552712402737660070481623142523171900237856413512525414"
        "4"},
    {1e214, chars_format::fixed,
        "9999999999999999544446266951486038123467425400819078260993214423089680518452271383223760211130420606034208"
        "3075939447157077401283069133405861653476144188223108688589909587369657654393353779934213925425782778274775"
        "04"},
    {1e215, chars_format::fixed,
        "9999999999999999066039693645104940765278909638940210631869016901423082741751534018348724438029810682751805"
        "1036015414262787762879627804165648934234223216948652905993920546904997130825691790753915825536773603473752"
        "064"},
    {1e216, chars_format::fixed,
        "1000000000000000021421546958041957442493134746744949294176709095342291740583330369404881029347127449862957"
        "2793183309320908289504788699434215946041483354800734678422429424402018238738808056478663126527039562299620"
        "72064"},
    {1e217, chars_format::fixed,
        "9999999999999999601855055748251769806450047292244542376488118125689672251656359867008764503902493796828096"
        "6920730331104392157891482092914687179785174704776043382501428272225416917221473218635849697412463879250897"
        "79712"},
    {1e218, chars_format::fixed,
        "1000000000000000082657588341258737904341264764265444350704606378115616256001024752108885608304005520043104"
        "8894293585531377363220429189576963174104449239123865018594716021581494785755468791093741283312832736674151"
        "6615680"},
    {1e219, chars_format::fixed,
        "9999999999999999650843888854825194175928551306260938421710435951908331863990515373171968167067996252972214"
        "7801618552072767416863994485028884962235547412234547654639257549968998154834801806327912222841098418750522"
        "5498624"},
    {1e220, chars_format::fixed,
        "9999999999999999964372420736895110140590976995965873111133270039707753382929110612616471611327211972294570"
        "5439303166270369074288073794559750769917932739968974996321364927527918075560104767557112385584359471548120"
        "96741376"},
    {1e221, chars_format::fixed,
        "1000000000000000046601807174820697568405085809949376861420980458018682781323086299572767712214195712321033"
        "9765959854898653172616660068980913606220974926434405874301273673162218994872058950552383264597357715602427"
        "8435495936"},
    {1e222, chars_format::fixed,
        "1000000000000000046601807174820697568405085809949376861420980458018682781323086299572767712214195712321033"
        "9765959854898653172616660068980913606220974926434405874301273673162218994872058950552383264597357715602427"
        "84354959360"},
    {1e223, chars_format::fixed,
        "1000000000000000046601807174820697568405085809949376861420980458018682781323086299572767712214195712321033"
        "9765959854898653172616660068980913606220974926434405874301273673162218994872058950552383264597357715602427"
        "843549593600"},
    {1e224, chars_format::fixed,
        "9999999999999999695490351794831950209296480724474921121484247526010969488287371335268865457530508571403718"
        "2409224841134505892881183378706080253249519082903930108094789640533388351546084948006950326015738792668900"
        "564521713664"},
    {1e225, chars_format::fixed,
        "9999999999999999284542234486365269956094146124464869125363950430450511714984175783024165903071069343773520"
        "0942358863613425448462294146117783821804062986135861502805217858619360833053015850664613088704891665546032"
        "3666687950848"},
    {1e226, chars_format::fixed,
        "9999999999999999613300728333138614158656013804472910722260188106898877933626732224819925546638620725877678"
        "6115851645630289803997405532188420966960427863550316387036875284150582847847471128538482878553569367244326"
        "92495112994816"},
    {1e227, chars_format::fixed,
        "1000000000000000092833470372023199096890348452450507710984513881269234280819695799200296412090882625429431"
        "2680982277369774722613785107647096954758588737320813592396350498627547090702529224003396203794828017403750"
        "5158080469401600"},
    {1e228, chars_format::fixed,
        "9999999999999999245091215224752468651786722002863904133736401909276707768747069010008674745842963177921021"
        "0721539729771401725798080779789307364385299200846126916697418967555614191277681217319748713923050341342237"
        "0196749149011968"},
    {1e229, chars_format::fixed,
        "9999999999999999918388610622944277578633427011520373324179896670642961784527024602806390495869308408470337"
        "7156852947341939925933988898461972237665534469790930519603853375043556877576725626405434043533142274420344"
        "27503713670135808"},
    {1e230, chars_format::fixed,
        "1000000000000000099566444326005117186158815502537072402888948828882896820977495355128273569591146077734924"
        "4345335409545480104615144188833823603491391090010261628425414842702426517565519668094253057090928936734531"
        "5883616691581616128"},
    {1e231, chars_format::fixed,
        "1000000000000000056475411020520841414840626381983058374700565164155456563967578197189219761589459982979768"
        "1693475363620965659806446069238773051601456032797794197839403040623198185642380825912769195995883053017532"
        "72401848696295129088"},
    {1e232, chars_format::fixed,
        "1000000000000000056475411020520841414840626381983058374700565164155456563967578197189219761589459982979768"
        "1693475363620965659806446069238773051601456032797794197839403040623198185642380825912769195995883053017532"
        "724018486962951290880"},
    {1e233, chars_format::fixed,
        "9999999999999999737406270739910319339097032705193514405788685278787712705085372539462364502262226810498681"
        "4019040754458979257737456796162759919727807229498567311142603806310797883499542489243201826933949562808949"
        "044795771481474727936"},
    {1e234, chars_format::fixed,
        "1000000000000000017865845178806930323739528929966661805443773400559670093686692423675827549619949242079148"
        "1557408762472600717257852554081607757108074221535423380034336465960209600239248423318159656454721941207101"
        "74156699571604284243968"},
    {1e235, chars_format::fixed,
        "1000000000000000053166019662659649035603389457524510097335697298704389152229216559459500429134930490902572"
        "1681812512093962950445138053653873169216309020403876699170397334223513449750683762833231235463783529148067"
        "211236930570359138156544"},
    {1e236, chars_format::fixed,
        "1000000000000000053166019662659649035603389457524510097335697298704389152229216559459500429134930490902572"
        "1681812512093962950445138053653873169216309020403876699170397334223513449750683762833231235463783529148067"
        "2112369305703591381565440"},
    {1e237, chars_format::fixed,
        "9999999999999999402054613143309491576390357693393955632815408246412881648931393249517472146869904946676153"
        "2837205133056038042458244550226238504699576640248260779350025557809411313140906763850021826347864477369777"
        "0829313903654699186257920"},
    {1e238, chars_format::fixed,
        "1000000000000000048647597328726501040484815309997105515973531039741865112735773470079190300557012891053173"
        "8945888832142428584597165509708623196466454966148714674320981543085810557013220039375302073350623645891623"
        "631119178909006652304785408"},
    {1e239, chars_format::fixed,
        "9999999999999999908117914543822067029670662216463268745378029250215574072197019260112206547596676129808759"
        "9260657287627887017431169472094235452683230716826407562484594165232135299736843791138087983021771402091458"
        "056119576436948334022754304"},
    {1e240, chars_format::fixed,
        "1000000000000000013946113804119924437974165856986638331112094170909680489426130543638408513078605724209795"
        "1533994970114644654884736372209103405747575829469070323477468267148252340789498643218406108321555742482136"
        "93581484614981956096327942144"},
    {1e241, chars_format::fixed,
        "1000000000000000050961029563700272813985525273531136661630960164330677420956416331841909086388906702176065"
        "8106681756277614179911327452208591182514380241927357631043882428148314438094801465785761804352561506118922"
        "744139467759619125060885807104"},
    {1e242, chars_format::fixed,
        "1000000000000000050961029563700272813985525273531136661630960164330677420956416331841909086388906702176065"
        "8106681756277614179911327452208591182514380241927357631043882428148314438094801465785761804352561506118922"
        "7441394677596191250608858071040"},
    {1e243, chars_format::fixed,
        "1000000000000000074650575649831695774632795300119615593163034400120115457135799236292149453307499328074479"
        "0313201299421914675928345743408263359645135065900661507886387491188354180370195272228869449812405194846465"
        "66146722558989084608335389392896"},
    {1e244, chars_format::fixed,
        "1000000000000000074650575649831695774632795300119615593163034400120115457135799236292149453307499328074479"
        "0313201299421914675928345743408263359645135065900661507886387491188354180370195272228869449812405194846465"
        "661467225589890846083353893928960"},
    {1e245, chars_format::fixed,
        "1000000000000000044327956659583474385004289666086362560801979378309634770826189118595841783651700766924510"
        "1088856284197210041026562330672682972917768891214832545527981010497103310257691199981691663623805273275210"
        "7272876955671430431745947427930112"},
    {1e246, chars_format::fixed,
        "1000000000000000068586051851782051496707094173312964986690823395758019319873877212752887919376339615844485"
        "2468332296376973748947989060861147282299661830963495715414706195050104006347694457779433892574685210532214"
        "67463131958534128550160206370177024"},
    {1e247, chars_format::fixed,
        "9999999999999999521471949292288813605336325386252733424243721120057734844449743607990664678980731410286045"
        "8468474379141079509251407559565185972665757201699124999584253091957006651156788203502711936104615116985957"
        "27381924297989722331966923339726848"},
    {1e248, chars_format::fixed,
        "1000000000000000045298280467271417469472401846375426657837533139007570152788096642362123629080686320881309"
        "1144035324684400589343419399880221545293044608804779072323450017879223338101291330293601352781840470765490"
        "8851814405278709728676750356293615616"},
    {1e249, chars_format::fixed,
        "9999999999999999210968330832147026575540427693752222372866517696718412616639336002780474141705354144110364"
        "0811181423240104047857145413152842812577527572916236425034170729678597741204746503691611405533351920096306"
        "7478208555469597215339755257651527680"},
    {1e250, chars_format::fixed,
        "9999999999999999210968330832147026575540427693752222372866517696718412616639336002780474141705354144110364"
        "0811181423240104047857145413152842812577527572916236425034170729678597741204746503691611405533351920096306"
        "74782085554695972153397552576515276800"},
    {1e251, chars_format::fixed,
        "1000000000000000048279115204488778624958442464223431563930754291871627646175076555372141458238529942636595"
        "6593545337061049953772804316485780039629891613241094802639130808557096063636830930611787917875324597455631"
        "5302310250472271728848176952226298724352"},
    {1e252, chars_format::fixed,
        "1000000000000000099152028052998409011920202342162715294588395300751542199979533737409779075865727753926819"
        "3598516214955865773367640226553978342978747155620883266693416302792790579443373442708838628804120359634031"
        "87241060084423965317738575228107571068928"},
    {1e253, chars_format::fixed,
        "9999999999999999363587069377675917736425707327570073564839440723358156278052707548893386994586947577981035"
        "1826094056924551506641653143357437722624094200055601817197027212385681288624374039982763538319739206631507"
        "77435958293799716241167969694049028276224"},
    {1e254, chars_format::fixed,
        "9999999999999999363587069377675917736425707327570073564839440723358156278052707548893386994586947577981035"
        "1826094056924551506641653143357437722624094200055601817197027212385681288624374039982763538319739206631507"
        "774359582937997162411679696940490282762240"},
    {1e255, chars_format::fixed,
        "9999999999999999884525696946414532898914128477668338966773684654288481309010349092958796199089453165592925"
        "8756995846567465499292772862455788348916374954024635689112910673359193130483369363856562818230607811338327"
        "2782784390994049606075766012189756664840192"},
    {1e256, chars_format::fixed,
        "1000000000000000030127659900140542502890486539774695128832107979903274133377646232821112356269145763568243"
        "8430171727828179669341366863773446884995019955719986278664561744213800260397056562295560224215930269510378"
        "288141352402853119916429412464176397346144256"},
    {1e257, chars_format::fixed,
        "1000000000000000030127659900140542502890486539774695128832107979903274133377646232821112356269145763568243"
        "8430171727828179669341366863773446884995019955719986278664561744213800260397056562295560224215930269510378"
        "2881413524028531199164294124641763973461442560"},
    {1e258, chars_format::fixed,
        "1000000000000000056799717631659959599209893702659726317411141269166906774962677479877261307539674049653972"
        "6465033899457896865765104193391282437061184730323200812906654977415644066700237122877898747347366742071367"
        "44674199783831719918405933396323484899269935104"},
    {1e259, chars_format::fixed,
        "9999999999999999287738405203667575368767393208115766122317814807014700953545274940077463414411382764424743"
        "8976954756352543229311650112256717871435938122277710485446074580467937964449704320826738363164716737786194"
        "85458899748089618699435710767754281089234894848"},
    {1e260, chars_format::fixed,
        "1000000000000000065334776105746173070032103994782936297756431921731269220269887478935228971946243101201405"
        "8636189794379406368620700138868989813722357458196229463864124812040234084717254902264247074749426413290883"
        "9774942043776657045497009088429335535195969814528"},
    {1e261, chars_format::fixed,
        "9999999999999999287738405203667575368767393208115766122317814807014700953545274940077463414411382764424743"
        "8976954756352543229311650112256717871435938122277710485446074580467937964449704320826738363164716737786194"
        "8545889974808961869943571076775428108923489484800"},
    {1e262, chars_format::fixed,
        "1000000000000000016172839295009583478096172712153246810967557762960541535300357884361335224964405364288190"
        "5330331839631511632172467492917395324154002545647584434349098564602595580939232492998880708913562707066468"
        "760361494711018313643605437535869015444666630275072"},
    {1e263, chars_format::fixed,
        "1000000000000000016172839295009583478096172712153246810967557762960541535300357884361335224964405364288190"
        "5330331839631511632172467492917395324154002545647584434349098564602595580939232492998880708913562707066468"
        "7603614947110183136436054375358690154446666302750720"},
    {1e264, chars_format::fixed,
        "1000000000000000044140518902895287779286391397382581274563006173283444396083023609274483667691850832398819"
        "6988775476110313971129684287058746855997333340341924717806535718700452151977396352492066908144631837718580"
        "52833032509915549602573975010166573043840478561173504"},
    {1e265, chars_format::fixed,
        "1000000000000000066514662589203851220238566345566048845439364901541766684709156189205002421873807206887323"
        "0315530385293355842295457722371828081471997976097396944572485441978737408807927440086615867529487142240269"
        "942705389409665241931447200154303102433395309881065472"},
    {1e266, chars_format::fixed,
        "1000000000000000030716032691110149714715086428472500732037190936328451022907344061316172415182677007705717"
        "6992722530600488848430220225870898120712534558888641381746965884733480997879077699935337532513718655005566"
        "8797052865128496484823152800700833072414104710501367808"},
    {1e267, chars_format::fixed,
        "9999999999999999734382248541602273058775185611228237505937125919871459640244446566940444044768686890151491"
        "6762299630919016582458402314694101834973930913546324812261345931410707403929181156932921964884890754300419"
        "7890512187794469896370420793533163493423472892065087488"},
    {1e268, chars_format::fixed,
        "9999999999999999734382248541602273058775185611228237505937125919871459640244446566940444044768686890151491"
        "6762299630919016582458402314694101834973930913546324812261345931410707403929181156932921964884890754300419"
        "78905121877944698963704207935331634934234728920650874880"},
    {1e269, chars_format::fixed,
        "1000000000000000046753818885456127989189605431330410286841364872744016439394555894610368258180303336939076"
        "8881340449502893261681846624303314743132774169798163873892798646379355869975202383523110226600782937286713"
        "8519293326106230343475263802678137754874196788463928344576"},
    {1e270, chars_format::fixed,
        "1000000000000000046753818885456127989189605431330410286841364872744016439394555894610368258180303336939076"
        "8881340449502893261681846624303314743132774169798163873892798646379355869975202383523110226600782937286713"
        "85192933261062303434752638026781377548741967884639283445760"},
    {1e271, chars_format::fixed,
        "9999999999999999529098585253973751145501342374646995204443699533752222309208135100774737254399069875964494"
        "0587990268968240092837584414759169067994863893904436912794686582343509041098785207009431480570467941101738"
        "54458342872794765056233999682236635579342942941443126198272"},
    {1e272, chars_format::fixed,
        "1000000000000000065522610957467878564117499670103552440120763856617775281089304371516947164728382606807602"
        "3845848734024107112161464260868794310399431725879707910415464644008356863148267156087543642309530165922021"
        "8514235305581886882057848563849292034690350260273827761094656"},
    {1e273, chars_format::fixed,
        "9999999999999999454023416965926748845789765419554426591326103598257186942429141193148421628206752796490392"
        "0729957130883384690919113868497250798928233669578260766704022591827505068406526116751697817735479026560506"
        "5466066369376850351293060923539046438669680406904714953752576"},
    {1e274, chars_format::fixed,
        "9999999999999999213782878444176341486712719163258207029349796604673073768736360688744211624391338142173265"
        "7184251089011847404780008120459112337915016951734497099213897822176292355791297027926950096663514500028564"
        "15308090320884466574359759805482716570229159677380024223137792"},
    {1e275, chars_format::fixed,
        "9999999999999999598167740078976993261235993173332158328511887794407654846644809495790947630496001589080667"
        "8857380756006307062602577317320133875536163700284518967198097453618232695975663570046546450378657742479671"
        "982722077174989256760731188933351130765773907040474247261585408"},
    {1e276, chars_format::fixed,
        "1000000000000000052069140800249855752009185079750964144650090664977064943362508663270311404514719386165843"
        "3087289195679301024137674338978658556582691589680457145036017656907888951241814327113357769929500152436233"
        "07738608946937362752018518070418086469181314516804918593340833792"},
    {1e277, chars_format::fixed,
        "1000000000000000002867878510995372324870206006461498378357342992691038565390227215968329195733322464961695"
        "8313128598304010187936385481780447799767184805866054345934040104083320587698215409722049436653961817402491"
        "275192019201707119869992081071729797163687409453914913289541779456"},
    {1e278, chars_format::fixed,
        "9999999999999999635068686795917855831590227478299257653231448548622174630124020581267434287082049279983778"
        "4938001204037775189753543960218791943147793788145321066524580618236658968633362758090027700335311493754978"
        "334367629875739137498376013657689431411868208826074951744485326848"},
    {1e279, chars_format::fixed,
        "1000000000000000057973292274960393763265862568545700036605220385651388108719182436946549269568487016710341"
        "0060188467364335924481829001842443847400552403738185480928254963246837154867046197200314769922564752640282"
        "09364937790149360843820835266007499279518823345374529865067232493568"},
    {1e280, chars_format::fixed,
        "1000000000000000032782245982862098248570705283021493564263333577440942603197374335927934378672411793053817"
        "4975818241508187016346769106956959939911012930425211247788042456200658152732723551495964903285489125103006"
        "290926013924448356521309485648260046220787856768108551057012647002112"},
    {1e281, chars_format::fixed,
        "1000000000000000032782245982862098248570705283021493564263333577440942603197374335927934378672411793053817"
        "4975818241508187016346769106956959939911012930425211247788042456200658152732723551495964903285489125103006"
        "2909260139244483565213094856482600462207878567681085510570126470021120"},
    {1e282, chars_format::fixed,
        "1000000000000000032782245982862098248570705283021493564263333577440942603197374335927934378672411793053817"
        "4975818241508187016346769106956959939911012930425211247788042456200658152732723551495964903285489125103006"
        "29092601392444835652130948564826004622078785676810855105701264700211200"},
    {1e283, chars_format::fixed,
        "9999999999999999553953517735361344274271821018911312812290573026184540102343798495987494338396687059809772"
        "7966329076780975705558651098687533761031476684077544035813096345547962581760843838922021129763927973084950"
        "24959839786965342632596166187964530344229899589832462449290116390191104"},
    {1e284, chars_format::fixed,
        "1000000000000000079214382508457676541256819191699710934083899342334435758975171027725445345572057645297521"
        "6283329441806240683821311505209883878195732087635685354312082149188175289466707052058222577470946921779713"
        "0505057184069381648545374773244373557467226310750742042216461653692645376"},
    {1e285, chars_format::fixed,
        "9999999999999999801591579205204428501931095198528472118000257105616503599825380852240886161861464938442861"
        "4939722145037261932089543889369794765216645522533405937274641374814720644342089175254062058753036222027386"
        "3006901551095990707698442841525909542472844588688081080376132618600579072"},
    {1e286, chars_format::fixed,
        "1000000000000000032988611034086967485427088011504507863684758314173802572778608987891478871858632441286011"
        "7381629402398400588202211517615861824081167237790591132705927077058380451118207922609574937392980048643791"
        "654301923722148311225012721166820834263125344653917287293299907083743789056"},
    {1e287, chars_format::fixed,
        "1000000000000000075252173524940187193614270804825836385192544397063524343015465710025391076396621199239392"
        "2091755152714140104196817220558967702128769386220391563888697428719907160465407126676909922607121189796634"
        "0736882502910990345434353553680702253338428636675464684849307718019341877248"},
    {1e288, chars_format::fixed,
        "1000000000000000007630473539575035660514778335511710750780086664439969510636494954611131549135839186513983"
        "4555553952208956878605448095849998297252605948732710873996264866061464425509888400169173946264495363952086"
        "20267012778077787723395914064607119962069483324573977857832138825282954985472"},
    {1e289, chars_format::fixed,
        "1000000000000000061727833527867156886994372310963011258310052850538813376539671558942539170944464796694310"
        "4584514912613103459078543395617173821153536698722855425910210916188218613474303381375362727338596024627724"
        "499484625789034803081540112423670420191213257583185130503608895092113260150784"},
    {1e290, chars_format::fixed,
        "1000000000000000061727833527867156886994372310963011258310052850538813376539671558942539170944464796694310"
        "4584514912613103459078543395617173821153536698722855425910210916188218613474303381375362727338596024627724"
        "4994846257890348030815401124236704201912132575831851305036088950921132601507840"},
    {1e291, chars_format::fixed,
        "9999999999999999578609023503462841321535518780965142838525177732290331540055724786262365370719036251480826"
        "1289098686371420245702004200641968152637496587417778862354344999448505725826266174594802676763227561304989"
        "6960078961318150545418464661067991669581788285529005480705688196068853638234112"},
    {1e292, chars_format::fixed,
        "1000000000000000013256598978357416268068656108958646003563203147794249272690425321461597941803936249972737"
        "4638565892090988122974650007025784551738302746731685907395315255274646861058187558214617579496201832662352"
        "585538835573636597522107561710941518560028749376834095178551288964115055725510656"},
    {1e293, chars_format::fixed,
        "9999999999999999246234843735396048506044893395792352520261065484899034827946607729250196942326840502532897"
        "0231162545648343655275306678872441733790178059478330735395060467469727994972900530063978805843953102113868"
        "000379620369084502134308975505229555772913629423636305841602377586326247764393984"},
    {1e294, chars_format::fixed,
        "1000000000000000066436467741248103118547156170586292454485461107376856746627884050583544890346687569804406"
        "1207835674606680377442921610508908778753873711201997607708800780391251297994726061339549398843285746132932"
        "05683935969567348590731356020719265634967118123751637393518591968740451429495341056"},
    {1e295, chars_format::fixed,
        "9999999999999999813486777206230041577815560719820581330098483720446847883279500839884297726782854580737362"
        "6970040225815727702936870449359100155289601680494988872072239402046841988962644563396584878879514845800049"
        "02758521100414464490983962613190835886243290260424727924570510530141380583845003264"},
    {1e296, chars_format::fixed,
        "9999999999999999813486777206230041577815560719820581330098483720446847883279500839884297726782854580737362"
        "6970040225815727702936870449359100155289601680494988872072239402046841988962644563396584878879514845800049"
        "027585211004144644909839626131908358862432902604247279245705105301413805838450032640"},
    {1e297, chars_format::fixed,
        "1000000000000000017652801462756379714374878780719864776839443139119744823869255243069012222883470359078822"
        "0728292194112285349344027126247056154504923279794565007954563392017619494511608074472945276562227436175920"
        "48849967890105831362861792425329827928397252374398383022243308510390698430058459037696"},
    {1e298, chars_format::fixed,
        "9999999999999999595662034753429788238255624467393741467120915117996487670031669885400803025551745174706847"
        "8782311196631452228634829961492223321433823010024592147588202691169230215270582854596864146833859136224555"
        "51313826420028155008403585629126369847605750170289266545852965785882018353801250996224"},
    {1e299, chars_format::fixed,
        "1000000000000000052504760255204420248704468581108159154915854115511802457988908195786371375080447864043704"
        "4438328838781769425232353604305756447921847867069828483872009265758037378302337947880900593689532349707999"
        "4508111903896764088007465274278014249457925878882005684283811566947219638686545940054016"},
    {1e300, chars_format::fixed,
        "1000000000000000052504760255204420248704468581108159154915854115511802457988908195786371375080447864043704"
        "4438328838781769425232353604305756447921847867069828483872009265758037378302337947880900593689532349707999"
        "45081119038967640880074652742780142494579258788820056842838115669472196386865459400540160"},
    {1e301, chars_format::fixed,
        "1000000000000000052504760255204420248704468581108159154915854115511802457988908195786371375080447864043704"
        "4438328838781769425232353604305756447921847867069828483872009265758037378302337947880900593689532349707999"
        "450811190389676408800746527427801424945792587888200568428381156694721963868654594005401600"},
    {1e302, chars_format::fixed,
        "1000000000000000076297030790848949253473468551506568117016017342062113802881257944841421889646917840766397"
        "4757713854876137221038784479993829181561135051983075016764985648898162653636809541460731423515105837345898"
        "6890825155659063617715863205282622390509284183439858617103083735673849899204570498157510656"},
    {1e303, chars_format::fixed,
        "1000000000000000000161765076786456438212668646231659438295495017101117499225738747865260243034213915253779"
        "7735681803374160274458205677791996433915416060260686111507461222849761772566500442005272768073270676904621"
        "12661427500197051226489898260678763391449376088547292320814127957486330655468919122263277568"},
    {1e304, chars_format::fixed,
        "9999999999999999392535525055364621860040287220117324953190771571323204563013233902843309257440507748436856"
        "1180561621725787171937426360305302357988408668827749873014416820110410677102531624409058437198025485515990"
        "76639682550821832659549112269607949805346034918662572406407604380845959862074904348138143744"},
    {1e305, chars_format::fixed,
        "9999999999999999392535525055364621860040287220117324953190771571323204563013233902843309257440507748436856"
        "1180561621725787171937426360305302357988408668827749873014416820110410677102531624409058437198025485515990"
        "766396825508218326595491122696079498053460349186625724064076043808459598620749043481381437440"},
    {1e306, chars_format::fixed,
        "1000000000000000017216064596736454828831087825013238982328892017892380671244575047987920451875459594568606"
        "1388616982910603110492255329485206969388057114406501226285146694284603569926249680283295506892241752843467"
        "30060716088829214255439694630119794546505512415617982143262670862918816362862119154749127262208"},
    {1e307, chars_format::fixed,
        "9999999999999999860310597602564577717002641838126363875249660735883565852672743849064846414228960666786379"
        "2803926546153933531728502521033362759523706153970107306916646893751785690398510731463396416232660711267200"
        "11020169553304018596457812688561947201171488461172921822139066929851282122002676667750021070848"},
    {1e308, chars_format::fixed,
        "1000000000000000010979063629440455417404923096773118463368106829031575854049114915371633289784946888990612"
        "4966972117251561159028374314008832830700919814604603127166450293302718569748969958855904333838446616500117"
        "8426897626212945177628091195786707458122783970171784415105291802893207873272974885715430223118336"},

    // These numbers have odd mantissas (unaffected by shifting)
    // that are barely within the "max shifted mantissa" limit.
    // They're exactly-representable multiples of powers of 10, and can use Ryu with zero-filling.
    {1801439850948197e1, chars_format::fixed, "18014398509481970"},
    {360287970189639e2, chars_format::fixed, "36028797018963900"},
    {72057594037927e3, chars_format::fixed, "72057594037927000"},
    {14411518807585e4, chars_format::fixed, "144115188075850000"},
    {2882303761517e5, chars_format::fixed, "288230376151700000"},
    {576460752303e6, chars_format::fixed, "576460752303000000"},
    {115292150459e7, chars_format::fixed, "1152921504590000000"},
    {23058430091e8, chars_format::fixed, "2305843009100000000"},
    {4611686017e9, chars_format::fixed, "4611686017000000000"},
    {922337203e10, chars_format::fixed, "9223372030000000000"},
    {184467439e11, chars_format::fixed, "18446743900000000000"},
    {36893487e12, chars_format::fixed, "36893487000000000000"},
    {7378697e13, chars_format::fixed, "73786970000000000000"},
    {1475739e14, chars_format::fixed, "147573900000000000000"},
    {295147e15, chars_format::fixed, "295147000000000000000"},
    {59029e16, chars_format::fixed, "590290000000000000000"},
    {11805e17, chars_format::fixed, "1180500000000000000000"},
    {2361e18, chars_format::fixed, "2361000000000000000000"},
    {471e19, chars_format::fixed, "4710000000000000000000"},
    {93e20, chars_format::fixed, "9300000000000000000000"},
    {17e21, chars_format::fixed, "17000000000000000000000"},
    {3e22, chars_format::fixed, "30000000000000000000000"},

    // These numbers have odd mantissas (unaffected by shifting)
    // that are barely above the "max shifted mantissa" limit.
    // This activates the non-Ryu fallback for large integers.
    {1801439850948199e1, chars_format::fixed, "18014398509481992"},
    {360287970189641e2, chars_format::fixed, "36028797018964096"},
    {72057594037929e3, chars_format::fixed, "72057594037928992"},
    {14411518807587e4, chars_format::fixed, "144115188075870016"},
    {2882303761519e5, chars_format::fixed, "288230376151900032"},
    {576460752305e6, chars_format::fixed, "576460752304999936"},
    {115292150461e7, chars_format::fixed, "1152921504609999872"},
    {23058430093e8, chars_format::fixed, "2305843009299999744"},
    {4611686019e9, chars_format::fixed, "4611686019000000512"},
    {922337205e10, chars_format::fixed, "9223372049999998976"},
    {184467441e11, chars_format::fixed, "18446744099999997952"},
    {36893489e12, chars_format::fixed, "36893488999999995904"},
    {7378699e13, chars_format::fixed, "73786990000000008192"},
    {1475741e14, chars_format::fixed, "147574099999999983616"},
    {295149e15, chars_format::fixed, "295148999999999967232"},
    {59031e16, chars_format::fixed, "590310000000000065536"},
    {11807e17, chars_format::fixed, "1180700000000000131072"},
    {2363e18, chars_format::fixed, "2363000000000000262144"},
    {473e19, chars_format::fixed, "4729999999999999475712"},
    {95e20, chars_format::fixed, "9500000000000001048576"},
    {19e21, chars_format::fixed, "19000000000000002097152"},
    {5e22, chars_format::fixed, "49999999999999995805696"},

    // Test the mantissa shifting logic.
    // Also test a large shift, because 32-bit platforms need to simulate _BitScanForward64().
    {302230528e15, chars_format::fixed, "302230528000000000000000"}, // 295147 * 2^10
    {302232576e15, chars_format::fixed, "302232575999999966445568"}, // 295149 * 2^10
    {81123342286848e18, chars_format::fixed, "81123342286848000000000000000000"}, // 2361 * 2^35
    {81192061763584e18, chars_format::fixed, "81192061763584009007199254740992"}, // 2363 * 2^35

    // Inspect all of those numbers in scientific notation.
    // For the within-limit numbers, this verifies that Ryu is actually being used with zero-filling above.
    // For the above-limit numbers, this tests Ryu's trimming.
    {1801439850948197e1, chars_format::scientific, "1.801439850948197e+16"},
    {360287970189639e2, chars_format::scientific, "3.60287970189639e+16"},
    {72057594037927e3, chars_format::scientific, "7.2057594037927e+16"},
    {14411518807585e4, chars_format::scientific, "1.4411518807585e+17"},
    {2882303761517e5, chars_format::scientific, "2.882303761517e+17"},
    {576460752303e6, chars_format::scientific, "5.76460752303e+17"},
    {115292150459e7, chars_format::scientific, "1.15292150459e+18"},
    {23058430091e8, chars_format::scientific, "2.3058430091e+18"},
    {4611686017e9, chars_format::scientific, "4.611686017e+18"},
    {922337203e10, chars_format::scientific, "9.22337203e+18"},
    {184467439e11, chars_format::scientific, "1.84467439e+19"},
    {36893487e12, chars_format::scientific, "3.6893487e+19"},
    {7378697e13, chars_format::scientific, "7.378697e+19"},
    {1475739e14, chars_format::scientific, "1.475739e+20"},
    {295147e15, chars_format::scientific, "2.95147e+20"},
    {59029e16, chars_format::scientific, "5.9029e+20"},
    {11805e17, chars_format::scientific, "1.1805e+21"},
    {2361e18, chars_format::scientific, "2.361e+21"},
    {471e19, chars_format::scientific, "4.71e+21"},
    {93e20, chars_format::scientific, "9.3e+21"},
    {17e21, chars_format::scientific, "1.7e+22"},
    {3e22, chars_format::scientific, "3e+22"},
    {1801439850948199e1, chars_format::scientific, "1.801439850948199e+16"},
    {360287970189641e2, chars_format::scientific, "3.60287970189641e+16"},
    {72057594037929e3, chars_format::scientific, "7.2057594037929e+16"},
    {14411518807587e4, chars_format::scientific, "1.4411518807587e+17"},
    {2882303761519e5, chars_format::scientific, "2.882303761519e+17"},
    {576460752305e6, chars_format::scientific, "5.76460752305e+17"},
    {115292150461e7, chars_format::scientific, "1.15292150461e+18"},
    {23058430093e8, chars_format::scientific, "2.3058430093e+18"},
    {4611686019e9, chars_format::scientific, "4.611686019e+18"},
    {922337205e10, chars_format::scientific, "9.22337205e+18"},
    {184467441e11, chars_format::scientific, "1.84467441e+19"},
    {36893489e12, chars_format::scientific, "3.6893489e+19"},
    {7378699e13, chars_format::scientific, "7.378699e+19"},
    {1475741e14, chars_format::scientific, "1.475741e+20"},
    {295149e15, chars_format::scientific, "2.95149e+20"},
    {59031e16, chars_format::scientific, "5.9031e+20"},
    {11807e17, chars_format::scientific, "1.1807e+21"},
    {2363e18, chars_format::scientific, "2.363e+21"},
    {473e19, chars_format::scientific, "4.73e+21"},
    {95e20, chars_format::scientific, "9.5e+21"},
    {19e21, chars_format::scientific, "1.9e+22"},
    {5e22, chars_format::scientific, "5e+22"},
    {302230528e15, chars_format::scientific, "3.02230528e+23"},
    {302232576e15, chars_format::scientific, "3.02232576e+23"},
    {81123342286848e18, chars_format::scientific, "8.1123342286848e+31"},
    {81192061763584e18, chars_format::scientific, "8.1192061763584e+31"},

    // Test the switching logic of chars_format::general.
    // C11 7.21.6.1 "The fprintf function"/8:
    // "Let P equal [...] 6 if the precision is omitted [...].
    // Then, if a conversion with style E would have an exponent of X:
    // - if P > X >= -4, the conversion is with style f [...].
    // - otherwise, the conversion is with style e [...]."
    {1e-6, chars_format::general, "1e-06"},
    {1e-5, chars_format::general, "1e-05"},
    {1e-4, chars_format::general, "0.0001"},
    {1e-3, chars_format::general, "0.001"},
    {1e-2, chars_format::general, "0.01"},
    {1e-1, chars_format::general, "0.1"},
    {1e0, chars_format::general, "1"},
    {1e1, chars_format::general, "10"},
    {1e2, chars_format::general, "100"},
    {1e3, chars_format::general, "1000"},
    {1e4, chars_format::general, "10000"},
    {1e5, chars_format::general, "100000"},
    {1e6, chars_format::general, "1e+06"},
    {1e7, chars_format::general, "1e+07"},
    {1.234e-6, chars_format::general, "1.234e-06"},
    {1.234e-5, chars_format::general, "1.234e-05"},
    {1.234e-4, chars_format::general, "0.0001234"},
    {1.234e-3, chars_format::general, "0.001234"},
    {1.234e-2, chars_format::general, "0.01234"},
    {1.234e-1, chars_format::general, "0.1234"},
    {1.234e0, chars_format::general, "1.234"},
    {1.234e1, chars_format::general, "12.34"},
    {1.234e2, chars_format::general, "123.4"},
    {1.234e3, chars_format::general, "1234"},
    {1.234e4, chars_format::general, "12340"},
    {1.234e5, chars_format::general, "123400"},
    {1.234e6, chars_format::general, "1.234e+06"},
    {1.234e7, chars_format::general, "1.234e+07"},
    {1.234e8, chars_format::general, "1.234e+08"},
    {1.234e9, chars_format::general, "1.234e+09"},
    {1.234e10, chars_format::general, "1.234e+10"},

    // Test the switching logic of the plain overload.
    // N4762 19.19.2 [charconv.to.chars]/8:
    // "The conversion specifier is f or e, chosen according to the requirement
    // for a shortest representation (see above); a tie is resolved in favor of f."
    {1e-6, chars_format{}, "1e-06"},
    {1e-5, chars_format{}, "1e-05"},
    {1e-4, chars_format{}, "1e-04"},
    {1e-3, chars_format{}, "0.001"},
    {1e-2, chars_format{}, "0.01"},
    {1e-1, chars_format{}, "0.1"},
    {1e0, chars_format{}, "1"},
    {1e1, chars_format{}, "10"},
    {1e2, chars_format{}, "100"},
    {1e3, chars_format{}, "1000"},
    {1e4, chars_format{}, "10000"},
    {1e5, chars_format{}, "1e+05"},
    {1e6, chars_format{}, "1e+06"},
    {1e7, chars_format{}, "1e+07"},
    {1.234e-6, chars_format{}, "1.234e-06"},
    {1.234e-5, chars_format{}, "1.234e-05"},
    {1.234e-4, chars_format{}, "0.0001234"},
    {1.234e-3, chars_format{}, "0.001234"},
    {1.234e-2, chars_format{}, "0.01234"},
    {1.234e-1, chars_format{}, "0.1234"},
    {1.234e0, chars_format{}, "1.234"},
    {1.234e1, chars_format{}, "12.34"},
    {1.234e2, chars_format{}, "123.4"},
    {1.234e3, chars_format{}, "1234"},
    {1.234e4, chars_format{}, "12340"},
    {1.234e5, chars_format{}, "123400"},
    {1.234e6, chars_format{}, "1234000"},
    {1.234e7, chars_format{}, "12340000"},
    {1.234e8, chars_format{}, "123400000"},
    {1.234e9, chars_format{}, "1.234e+09"},
    {1.234e10, chars_format{}, "1.234e+10"},

    // GH-331 "<charconv>: Test plain shortest's large integer fallback"
    // The exactly-representable integer 123456789012345683968 is 21 digits, but scientific shortest needs 22
    // characters. Therefore, the plain overload must select fixed notation. Because this 21-digit number exceeds the
    // 17-digit round-trip limit, we can't use Ryu - we need to activate the large integer fallback (Ryu Printf for
    // double).
    {123456789012345683968.0, chars_format::scientific, "1.2345678901234568e+20"},
    {123456789012345683968.0, chars_format{}, "123456789012345683968"},

    // Exact value is 1.9156918820264798304697...e-56, incorrectly rounded by dtoa_milo() (Grisu2).
    {0x1.e0ffed391517ep-186, chars_format::scientific, "1.9156918820264798e-56"},

    // Exact value is 6.6564021122018745286598...e+264, incorrectly rounded by dtoa_milo() (Grisu2).
    {0x1.a6c767640cd71p+879, chars_format::scientific, "6.6564021122018745e+264"},

    // Incorrectly handled by dtoa_milo() (Grisu2), which doesn't achieve shortest round-trip.
    {4.91e-6, chars_format::scientific, "4.91e-06"},
    {5.547e-6, chars_format::scientific, "5.547e-06"},

    // Test hexfloat corner cases.
    {0x1.728p+0, chars_format::hex, "1.728p+0"}, // instead of "2.e5p-1"
    {0x0.0000000000001p-1022, chars_format::hex, "0.0000000000001p-1022"}, // instead of "1p-1074", min subnormal
    {0x0.fffffffffffffp-1022, chars_format::hex, "0.fffffffffffffp-1022"}, // max subnormal
    {0x1p-1022, chars_format::hex, "1p-1022"}, // min normal
    {0x1.fffffffffffffp+1023, chars_format::hex, "1.fffffffffffffp+1023"}, // max normal

    // Test hexfloat exponents.
    {0x1p-1009, chars_format::hex, "1p-1009"},
    {0x1p-999, chars_format::hex, "1p-999"},
    {0x1p-99, chars_format::hex, "1p-99"},
    {0x1p-9, chars_format::hex, "1p-9"},
    {0x1p+0, chars_format::hex, "1p+0"},
    {0x1p+9, chars_format::hex, "1p+9"},
    {0x1p+99, chars_format::hex, "1p+99"},
    {0x1p+999, chars_format::hex, "1p+999"},
    {0x1p+1009, chars_format::hex, "1p+1009"},

    // Test hexfloat hexits.
    {0x1.01234567p+0, chars_format::hex, "1.01234567p+0"},
    {0x1.89abcdefp+0, chars_format::hex, "1.89abcdefp+0"},

    // Test hexfloat trimming.
    {0x1.000000000000ap+0, chars_format::hex, "1.000000000000ap+0"},
    {0x1.00000000000ap+0, chars_format::hex, "1.00000000000ap+0"},
    {0x1.0000000000ap+0, chars_format::hex, "1.0000000000ap+0"},
    {0x1.000000000ap+0, chars_format::hex, "1.000000000ap+0"},
    {0x1.00000000ap+0, chars_format::hex, "1.00000000ap+0"},
    {0x1.0000000ap+0, chars_format::hex, "1.0000000ap+0"},
    {0x1.000000ap+0, chars_format::hex, "1.000000ap+0"},
    {0x1.00000ap+0, chars_format::hex, "1.00000ap+0"},
    {0x1.0000ap+0, chars_format::hex, "1.0000ap+0"},
    {0x1.000ap+0, chars_format::hex, "1.000ap+0"},
    {0x1.00ap+0, chars_format::hex, "1.00ap+0"},
    {0x1.0ap+0, chars_format::hex, "1.0ap+0"},
    {0x1.ap+0, chars_format::hex, "1.ap+0"},
    {0x1p+0, chars_format::hex, "1p+0"},

    // https://www.exploringbinary.com/the-shortest-decimal-string-that-round-trips-may-not-be-the-nearest/
    // This is an exhaustive list of anomalous values.

    // Because math, these values have shortest-round-trip decimal representations containing 16 significant digits,
    // but those decimal digits aren't what would be printed by "%.15e". For ordinary values, shortest-round-trip
    // behaves as if it can magically pick a precision for "%.*e", finding the smallest precision that round-trips.
    // (That is, start with the exact decimal representation, and then round it as much as possible.) These anomalous
    // values demonstrate an exception to that mental model. They aren't being "incorrectly rounded"; instead, having
    // the shortest output that round-trips is being prioritized. (This differs by 1 in the least significant decimal
    // digit printed, so it's a very small difference.)

    // N4835 20.19.2 [charconv.to.chars]/2 demands this behavior:
    // "The functions that take a floating-point value but not a precision parameter ensure that the string
    // representation consists of the smallest number of characters such that there is at least one digit before the
    // radix point (if present) and parsing the representation using the corresponding from_chars function recovers
    // value exactly. [...] If there are several such representations, the representation with the smallest difference
    // from the floating-point argument value is chosen, resolving any remaining ties using rounding according to
    // round_to_nearest (17.3.4.1)."
    {0x1p976, chars_format::scientific, "6.386688990511104e+293"},
    {0x1p896, chars_format::scientific, "5.282945311356653e+269"},
    {0x1p863, chars_format::scientific, "6.150157786156811e+259"},
    {0x1p803, chars_format::scientific, "5.334411546303884e+241"},
    {0x1p710, chars_format::scientific, "5.386379163185535e+213"},
    {0x1p594, chars_format::scientific, "6.483618076376552e+178"},
    {0x1p574, chars_format::scientific, "6.183260036827614e+172"},
    {0x1p554, chars_format::scientific, "5.896816288783659e+166"},
    {0x1p544, chars_format::scientific, "5.758609657015292e+163"},
    {0x1p534, chars_format::scientific, "5.623642243178996e+160"},
    {0x1p481, chars_format::scientific, "6.243497100631985e+144"},
    {0x1p405, chars_format::scientific, "8.263199609878108e+121"},
    {0x1p398, chars_format::scientific, "6.455624695217272e+119"},
    {0x1p378, chars_format::scientific, "6.156563468186638e+113"},
    {0x1p345, chars_format::scientific, "7.167183174968974e+103"},
    {0x1p305, chars_format::scientific, "6.518515124270356e+91"},
    {0x1p275, chars_format::scientific, "6.070840288205404e+82"},
    {0x1p182, chars_format::scientific, "6.129982163463556e+54"},
    {0x1p172, chars_format::scientific, "5.986310706507379e+51"},
    {0x1p132, chars_format::scientific, "5.444517870735016e+39"},
    {0x1p122, chars_format::scientific, "5.316911983139664e+36"},
    {0x1p89, chars_format::scientific, "6.189700196426902e+26"},
    {0x1p-24, chars_format::scientific, "5.960464477539063e-08"},
    {0x1p-44, chars_format::scientific, "5.684341886080802e-14"},
    {0x1p-77, chars_format::scientific, "6.617444900424222e-24"},
    {0x1p-97, chars_format::scientific, "6.310887241768095e-30"},
    {0x1p-140, chars_format::scientific, "7.174648137343064e-43"},
    {0x1p-296, chars_format::scientific, "7.854549544476363e-90"},
    {0x1p-366, chars_format::scientific, "6.653062250012736e-111"},
    {0x1p-383, chars_format::scientific, "5.075883674631299e-116"},
    {0x1p-489, chars_format::scientific, "6.256509672447191e-148"},
    {0x1p-496, chars_format::scientific, "4.887898181599368e-150"},
    {0x1p-509, chars_format::scientific, "5.966672584960166e-154"},
    {0x1p-549, chars_format::scientific, "5.426657103235053e-166"},
    {0x1p-652, chars_format::scientific, "5.351097043477547e-197"},
    {0x1p-662, chars_format::scientific, "5.225680706521042e-200"},
    {0x1p-695, chars_format::scientific, "6.083493012144512e-210"},
    {0x1p-705, chars_format::scientific, "5.940911144672375e-213"},
    {0x1p-778, chars_format::scientific, "6.290184345309701e-235"},
    {0x1p-788, chars_format::scientific, "6.142758149716505e-238"},
    {0x1p-791, chars_format::scientific, "7.678447687145631e-239"},
    {0x1p-808, chars_format::scientific, "5.858190679279809e-244"},
    {0x1p-921, chars_format::scientific, "5.641232424577593e-278"},
    {0x1p-957, chars_format::scientific, "8.209073602596753e-289"},
    {0x1p-1007, chars_format::scientific, "7.291122019556398e-304"},
    {0x1p-1017, chars_format::scientific, "7.120236347223045e-307"},

    // This is an exhaustive list of almost-but-not-quite-anomalous values.
    {0x1p966, chars_format::scientific, "6.237000967296e+290"},
    {0x1p956, chars_format::scientific, "6.090821257125e+287"},
    {0x1p890, chars_format::scientific, "8.25460204899477e+267"},
    {0x1p740, chars_format::scientific, "5.78358058743443e+222"},
    {0x1p149, chars_format::scientific, "7.1362384635298e+44"},
    {0x1p-499, chars_format::scientific, "6.10987272699921e-151"},
    {0x1p-569, chars_format::scientific, "5.17526350329881e-172"},
    {0x1p-645, chars_format::scientific, "6.84940421565126e-195"},
};

inline constexpr double_to_chars_testcase double_scientific_precision_to_chars_test_cases_1[] = {
    // Test special cases (zero, inf, nan) and an ordinary case. Also test negative signs.
    {0.0, chars_format::scientific, 4, "0.0000e+00"},
    {-0.0, chars_format::scientific, 4, "-0.0000e+00"},
    {double_inf, chars_format::scientific, 4, "inf"},
    {-double_inf, chars_format::scientific, 4, "-inf"},
    {double_nan, chars_format::scientific, 4, "nan"},
    {-double_nan, chars_format::scientific, 4, "-nan"},
    {1.729, chars_format::scientific, 4, "1.7290e+00"},
    {-1.729, chars_format::scientific, 4, "-1.7290e+00"},

    // Ryu Printf d2fixed_test.cc D2expTest Basic
    {0x1.000000001869fp+211, chars_format::scientific, 62,
        "3.29100911471548643542566484557342614975886952410844652587974656e+63"},

    // Ryu Printf d2fixed_test.cc D2expTest Zero
    {0.0, chars_format::scientific, 4, "0.0000e+00"},
    {0.0, chars_format::scientific, 3, "0.000e+00"},
    {0.0, chars_format::scientific, 2, "0.00e+00"},
    {0.0, chars_format::scientific, 1, "0.0e+00"},
    {0.0, chars_format::scientific, 0, "0e+00"},

    // Ryu Printf d2fixed_test.cc D2expTest MinMax
    {0x0.0000000000001p-1022, chars_format::scientific, 750,
        "4.9406564584124654417656879286822137236505980261432476442558568250067550727020875186529983"
        "636163599237979656469544571773092665671035593979639877479601078187812630071319031140452784"
        "581716784898210368871863605699873072305000638740915356498438731247339727316961514003171538"
        "539807412623856559117102665855668676818703956031062493194527159149245532930545654440112748"
        "012970999954193198940908041656332452475714786901472678015935523861155013480352649347201937"
        "902681071074917033322268447533357208324319360923828934583680601060115061698097530783422773"
        "183292479049825247307763759272478746560847782037344696995336470179726777175851256605511991"
        "315048911014510378627381672509558373897335989936648099411642057026370902792427675445652290"
        "87538682506419718265533447265625e-324"},

    {0x1.fffffffffffffp+1023, chars_format::scientific, 308,
        "1.7976931348623157081452742373170435679807056752584499659891747680315726078002853876058955"
        "863276687817154045895351438246423432132688946418276846754670353751698604991057655128207624"
        "549009038932894407586850845513394230458323690322294816580855933212334827479782620414472316"
        "8738177180919299881250404026184124858368e+308"},

    // Test more corner cases.
    {0x0.fffffffffffffp-1022, chars_format::scientific, 766,
        "2."
        "2250738585072008890245868760858598876504231122409594654935248025624400092282356951787758888037591552642309"
        "7809504343120858773871583572918219930202943792242235598198275012420417889695713117910822610439719796040004"
        "5489739193807919893608152561311337614984204327175103362739154978273159414382813627511383860409424946494228"
        "6316695429105080201815926642134996606517803095075913058719846423906068637102005108723282784678843631944515"
        "8661350412234790147923695852083215976210663754016137365830441936037147783553066828345356340050740730401356"
        "0296804637591858316312422452159926254649430083685186171942241764645513713542013221703137049658321015465406"
        "8035397417906022589503023501937519773030945763173210852507299305089761582519159720757232455434770912461317"
        "493580281734466552734375e-308"}, // max subnormal
    {0x1p-1022, chars_format::scientific, 714,
        "2."
        "2250738585072013830902327173324040642192159804623318305533274168872044348139181958542831590125110205640673"
        "3973103581100515243416155346010885601238537771882113077799353200233047961014744258363607192156504694250373"
        "4208375250806650616658158948720491179968591639648500635908770118304874799780887753749949451580451605050915"
        "3998565824708186451135379358049921159810857660519924333521143523901487956996095912888916029926415110634663"
        "1339366347758651302937176204732563178148566435087212282863764204484681140761391147706280168985324411002416"
        "1447421618567166150540154285084716752901903161322778896729707373123334086988983175067838846926092773977972"
        "858659654941091369095406136467568702398678315290680984617210924625396728515625e-308"}, // min normal

    // Ryu Printf d2fixed_test.cc D2expTest RoundToEven
    {0.125, chars_format::scientific, 2, "1.25e-01"},
    {0.125, chars_format::scientific, 1, "1.2e-01"},
    {0.375, chars_format::scientific, 2, "3.75e-01"},
    {0.375, chars_format::scientific, 1, "3.8e-01"},

    // Ryu Printf d2fixed_test.cc D2expTest RoundToEvenInteger
    {2.5, chars_format::scientific, 1, "2.5e+00"},
    {2.5, chars_format::scientific, 0, "2e+00"},
    {3.5, chars_format::scientific, 1, "3.5e+00"},
    {3.5, chars_format::scientific, 0, "4e+00"},

    // Ryu Printf d2fixed_test.cc D2expTest NonRoundToEvenScenarios
    {0.748046875, chars_format::scientific, 2, "7.48e-01"},
    {0.748046875, chars_format::scientific, 1, "7.5e-01"},
    {0.748046875, chars_format::scientific, 0, "7e-01"}, // 0.75 would round to "8e-01", but this is smaller

    {0.2509765625, chars_format::scientific, 2, "2.51e-01"},
    {0.2509765625, chars_format::scientific, 1, "2.5e-01"},
    {0.2509765625, chars_format::scientific, 0, "3e-01"}, // 0.25 would round to "2e-01", but this is larger

    {0x1.0000000000001p-2, chars_format::scientific, 53, "2.50000000000000055511151231257827021181583404541015625e-01"},
    {0x1.0000000000001p-2, chars_format::scientific, 2, "2.50e-01"},
    {0x1.0000000000001p-2, chars_format::scientific, 1, "2.5e-01"},
    {0x1.0000000000001p-2, chars_format::scientific, 0,
        "3e-01"}, // 0.25 would round to "2e-01", but this is larger (again)

    // More rounding tests.
    {9.5, chars_format::scientific, 1, "9.5e+00"},
    {9.5, chars_format::scientific, 0, "1e+01"},
    {10.5, chars_format::scientific, 2, "1.05e+01"},
    {10.5, chars_format::scientific, 1, "1.0e+01"},

    {1.241, chars_format::scientific, 3, "1.241e+00"},
    {1.241, chars_format::scientific, 1, "1.2e+00"},
    {1.251, chars_format::scientific, 3, "1.251e+00"},
    {1.251, chars_format::scientific, 1, "1.3e+00"},
    {1.261, chars_format::scientific, 3, "1.261e+00"},
    {1.261, chars_format::scientific, 1, "1.3e+00"},
    {1.341, chars_format::scientific, 3, "1.341e+00"},
    {1.341, chars_format::scientific, 1, "1.3e+00"},
    {1.351, chars_format::scientific, 3, "1.351e+00"},
    {1.351, chars_format::scientific, 1, "1.4e+00"},
    {1.361, chars_format::scientific, 3, "1.361e+00"},
    {1.361, chars_format::scientific, 1, "1.4e+00"},

    {2.41, chars_format::scientific, 2, "2.41e+00"},
    {2.41, chars_format::scientific, 0, "2e+00"},
    {2.51, chars_format::scientific, 2, "2.51e+00"},
    {2.51, chars_format::scientific, 0, "3e+00"},
    {2.61, chars_format::scientific, 2, "2.61e+00"},
    {2.61, chars_format::scientific, 0, "3e+00"},
    {3.41, chars_format::scientific, 2, "3.41e+00"},
    {3.41, chars_format::scientific, 0, "3e+00"},
    {3.51, chars_format::scientific, 2, "3.51e+00"},
    {3.51, chars_format::scientific, 0, "4e+00"},
    {3.61, chars_format::scientific, 2, "3.61e+00"},
    {3.61, chars_format::scientific, 0, "4e+00"},

    // Ryu Printf d2fixed_test.cc D2expTest VaryingPrecision
    {1729.142857142857, chars_format::scientific, 50, "1.72914285714285711037518922239542007446289062500000e+03"},
    {1729.142857142857, chars_format::scientific, 49, "1.7291428571428571103751892223954200744628906250000e+03"},
    {1729.142857142857, chars_format::scientific, 48, "1.729142857142857110375189222395420074462890625000e+03"},
    {1729.142857142857, chars_format::scientific, 47, "1.72914285714285711037518922239542007446289062500e+03"},
    {1729.142857142857, chars_format::scientific, 46, "1.7291428571428571103751892223954200744628906250e+03"},
    {1729.142857142857, chars_format::scientific, 45, "1.729142857142857110375189222395420074462890625e+03"},
    {1729.142857142857, chars_format::scientific, 44, "1.72914285714285711037518922239542007446289062e+03"},
    {1729.142857142857, chars_format::scientific, 43, "1.7291428571428571103751892223954200744628906e+03"},
    {1729.142857142857, chars_format::scientific, 42, "1.729142857142857110375189222395420074462891e+03"},
    {1729.142857142857, chars_format::scientific, 41, "1.72914285714285711037518922239542007446289e+03"},
    {1729.142857142857, chars_format::scientific, 40, "1.7291428571428571103751892223954200744629e+03"},
    {1729.142857142857, chars_format::scientific, 39, "1.729142857142857110375189222395420074463e+03"},
    {1729.142857142857, chars_format::scientific, 38, "1.72914285714285711037518922239542007446e+03"},
    {1729.142857142857, chars_format::scientific, 37, "1.7291428571428571103751892223954200745e+03"},
    {1729.142857142857, chars_format::scientific, 36, "1.729142857142857110375189222395420074e+03"},
    {1729.142857142857, chars_format::scientific, 35, "1.72914285714285711037518922239542007e+03"},
    {1729.142857142857, chars_format::scientific, 34, "1.7291428571428571103751892223954201e+03"},
    {1729.142857142857, chars_format::scientific, 33, "1.729142857142857110375189222395420e+03"},
    {1729.142857142857, chars_format::scientific, 32, "1.72914285714285711037518922239542e+03"},
    {1729.142857142857, chars_format::scientific, 31, "1.7291428571428571103751892223954e+03"},
    {1729.142857142857, chars_format::scientific, 30, "1.729142857142857110375189222395e+03"},
    {1729.142857142857, chars_format::scientific, 29, "1.72914285714285711037518922240e+03"},
    {1729.142857142857, chars_format::scientific, 28, "1.7291428571428571103751892224e+03"},
    {1729.142857142857, chars_format::scientific, 27, "1.729142857142857110375189222e+03"},
    {1729.142857142857, chars_format::scientific, 26, "1.72914285714285711037518922e+03"},
    {1729.142857142857, chars_format::scientific, 25, "1.7291428571428571103751892e+03"},
    {1729.142857142857, chars_format::scientific, 24, "1.729142857142857110375189e+03"},
    {1729.142857142857, chars_format::scientific, 23, "1.72914285714285711037519e+03"},
    {1729.142857142857, chars_format::scientific, 22, "1.7291428571428571103752e+03"},
    {1729.142857142857, chars_format::scientific, 21, "1.729142857142857110375e+03"},
    {1729.142857142857, chars_format::scientific, 20, "1.72914285714285711038e+03"},
    {1729.142857142857, chars_format::scientific, 19, "1.7291428571428571104e+03"},
    {1729.142857142857, chars_format::scientific, 18, "1.729142857142857110e+03"},
    {1729.142857142857, chars_format::scientific, 17, "1.72914285714285711e+03"},
    {1729.142857142857, chars_format::scientific, 16, "1.7291428571428571e+03"},
    {1729.142857142857, chars_format::scientific, 15, "1.729142857142857e+03"},
    {1729.142857142857, chars_format::scientific, 14, "1.72914285714286e+03"},
    {1729.142857142857, chars_format::scientific, 13, "1.7291428571429e+03"},
    {1729.142857142857, chars_format::scientific, 12, "1.729142857143e+03"},
    {1729.142857142857, chars_format::scientific, 11, "1.72914285714e+03"},
    {1729.142857142857, chars_format::scientific, 10, "1.7291428571e+03"},
    {1729.142857142857, chars_format::scientific, 9, "1.729142857e+03"},
    {1729.142857142857, chars_format::scientific, 8, "1.72914286e+03"},
    {1729.142857142857, chars_format::scientific, 7, "1.7291429e+03"},
    {1729.142857142857, chars_format::scientific, 6, "1.729143e+03"},
    {1729.142857142857, chars_format::scientific, 5, "1.72914e+03"},
    {1729.142857142857, chars_format::scientific, 4, "1.7291e+03"},
    {1729.142857142857, chars_format::scientific, 3, "1.729e+03"},
    {1729.142857142857, chars_format::scientific, 2, "1.73e+03"},
    {1729.142857142857, chars_format::scientific, 1, "1.7e+03"},
    {1729.142857142857, chars_format::scientific, 0, "2e+03"},

    // Negative precision requests 6 digits of precision.
    {1729.142857142857, chars_format::scientific, -1, "1.729143e+03"},
    {1729.142857142857, chars_format::scientific, -2, "1.729143e+03"},
    {1729.142857142857, chars_format::scientific, -3, "1.729143e+03"},

    // Ryu Printf d2fixed_test.cc D2expTest Carrying
    {2.0009, chars_format::scientific, 4, "2.0009e+00"},
    {2.0009, chars_format::scientific, 3, "2.001e+00"},
    {2.0029, chars_format::scientific, 4, "2.0029e+00"},
    {2.0029, chars_format::scientific, 3, "2.003e+00"},
    {2.0099, chars_format::scientific, 4, "2.0099e+00"},
    {2.0099, chars_format::scientific, 3, "2.010e+00"},
    {2.0299, chars_format::scientific, 4, "2.0299e+00"},
    {2.0299, chars_format::scientific, 3, "2.030e+00"},
    {2.0999, chars_format::scientific, 4, "2.0999e+00"},
    {2.0999, chars_format::scientific, 3, "2.100e+00"},
    {2.2999, chars_format::scientific, 4, "2.2999e+00"},
    {2.2999, chars_format::scientific, 3, "2.300e+00"},
    {2.9999, chars_format::scientific, 4, "2.9999e+00"},
    {2.9999, chars_format::scientific, 3, "3.000e+00"},
    {9.9999, chars_format::scientific, 4, "9.9999e+00"},
    {9.9999, chars_format::scientific, 3, "1.000e+01"},

    {2.09, chars_format::scientific, 2, "2.09e+00"},
    {2.09, chars_format::scientific, 1, "2.1e+00"},
    {2.29, chars_format::scientific, 2, "2.29e+00"},
    {2.29, chars_format::scientific, 1, "2.3e+00"},
    {2.99, chars_format::scientific, 2, "2.99e+00"},
    {2.99, chars_format::scientific, 1, "3.0e+00"},
    {9.99, chars_format::scientific, 2, "9.99e+00"},
    {9.99, chars_format::scientific, 1, "1.0e+01"},

    {2.9, chars_format::scientific, 1, "2.9e+00"},
    {2.9, chars_format::scientific, 0, "3e+00"},
    {9.9, chars_format::scientific, 1, "9.9e+00"},
    {9.9, chars_format::scientific, 0, "1e+01"},

    // Ryu Printf d2fixed_test.cc D2expTest Exponents
    {9.99e-100, chars_format::scientific, 2, "9.99e-100"},
    {9.99e-99, chars_format::scientific, 2, "9.99e-99"},
    {9.99e-10, chars_format::scientific, 2, "9.99e-10"},
    {9.99e-09, chars_format::scientific, 2, "9.99e-09"},
    {9.99e-01, chars_format::scientific, 2, "9.99e-01"},
    {9.99e+00, chars_format::scientific, 2, "9.99e+00"},
    {9.99e+01, chars_format::scientific, 2, "9.99e+01"},
    {9.99e+09, chars_format::scientific, 2, "9.99e+09"},
    {9.99e+10, chars_format::scientific, 2, "9.99e+10"},
    {9.99e+99, chars_format::scientific, 2, "9.99e+99"},
    {9.99e+100, chars_format::scientific, 2, "9.99e+100"},

    {9.99e-100, chars_format::scientific, 1, "1.0e-99"},
    {9.99e-99, chars_format::scientific, 1, "1.0e-98"},
    {9.99e-10, chars_format::scientific, 1, "1.0e-09"},
    {9.99e-09, chars_format::scientific, 1, "1.0e-08"},
    {9.99e-01, chars_format::scientific, 1, "1.0e+00"},
    {9.99e+00, chars_format::scientific, 1, "1.0e+01"},
    {9.99e+01, chars_format::scientific, 1, "1.0e+02"},
    {9.99e+09, chars_format::scientific, 1, "1.0e+10"},
    {9.99e+10, chars_format::scientific, 1, "1.0e+11"},
    {9.99e+99, chars_format::scientific, 1, "1.0e+100"},
    {9.99e+100, chars_format::scientific, 1, "1.0e+101"},

    // Ryu Printf d2fixed_test.cc D2expTest PrintDecimalPoint
    // These values exercise each codepath.
    {1e+54, chars_format::scientific, 0, "1e+54"},
    {1e+54, chars_format::scientific, 1, "1.0e+54"},
    {1e-63, chars_format::scientific, 0, "1e-63"},
    {1e-63, chars_format::scientific, 1, "1.0e-63"},
    {1e+83, chars_format::scientific, 0, "1e+83"},
    {1e+83, chars_format::scientific, 1, "1.0e+83"},

    // The UCRT had trouble with rounding this value. charconv was never affected, but let's test it anyways.
    {0x1.88e2d605edc3dp+345, chars_format::scientific, 104,
        "1.09995565999999994887854821710219658911365648587951921896774663603198787416706536331386569598149846892544e+"
        "104"},
    {0x1.88e2d605edc3dp+345, chars_format::scientific, 18, "1.099955659999999949e+104"},
    {0x1.88e2d605edc3dp+345, chars_format::scientific, 17, "1.09995565999999995e+104"},
    {0x1.88e2d605edc3dp+345, chars_format::scientific, 16, "1.0999556599999999e+104"},
    {0x1.88e2d605edc3dp+345, chars_format::scientific, 15, "1.099955660000000e+104"},
    {0x1.88e2d605edc3dp+345, chars_format::scientific, 14, "1.09995566000000e+104"},
    {0x1.88e2d605edc3dp+345, chars_format::scientific, 13, "1.0999556600000e+104"},
    {0x1.88e2d605edc3dp+345, chars_format::scientific, 12, "1.099955660000e+104"},
    {0x1.88e2d605edc3dp+345, chars_format::scientific, 11, "1.09995566000e+104"},
    {0x1.88e2d605edc3dp+345, chars_format::scientific, 10, "1.0999556600e+104"},
    {0x1.88e2d605edc3dp+345, chars_format::scientific, 9, "1.099955660e+104"},
    {0x1.88e2d605edc3dp+345, chars_format::scientific, 8, "1.09995566e+104"},
    {0x1.88e2d605edc3dp+345, chars_format::scientific, 7, "1.0999557e+104"},
    {0x1.88e2d605edc3dp+345, chars_format::scientific, 6, "1.099956e+104"},
    {0x1.88e2d605edc3dp+345, chars_format::scientific, 5, "1.09996e+104"},
    {0x1.88e2d605edc3dp+345, chars_format::scientific, 4, "1.1000e+104"},
    {0x1.88e2d605edc3dp+345, chars_format::scientific, 3, "1.100e+104"},
    {0x1.88e2d605edc3dp+345, chars_format::scientific, 2, "1.10e+104"},
    {0x1.88e2d605edc3dp+345, chars_format::scientific, 1, "1.1e+104"},
    {0x1.88e2d605edc3dp+345, chars_format::scientific, 0, "1e+104"},
};

inline constexpr double_to_chars_testcase double_scientific_precision_to_chars_test_cases_2[] = {
    // Ryu Printf d2fixed_test.cc D2expTest AllPowersOfTen
    // These values test every power of ten that's within the range of doubles.
    {1e-323, chars_format::scientific, 749,
        "9."
        "8813129168249308835313758573644274473011960522864952885117136500135101454041750373059967272327198475959312"
        "9390891435461853313420711879592797549592021563756252601426380622809055691634335697964207377437272113997461"
        "4461000127748183071299687746249467945463392302800634307707961482524771311823420533171133735363740791206212"
        "4986389054318298491065861091308880225496025941999908386397881816083312664904951429573802945356031871047722"
        "3100269607052986944038758053621421498340666445368950667144166486387218476578691673612021202301233961950615"
        "6684554636658495809965049461552751854495749312169556407468939399067294035945355435170251321102398263009782"
        "2029020757254763345019116747794671979873296198823284114052741805584855350891304581750773650128394365310668"
        "9453125e-324"},
    {1e-322, chars_format::scientific, 749,
        "9."
        "8813129168249308835313758573644274473011960522864952885117136500135101454041750373059967272327198475959312"
        "9390891435461853313420711879592797549592021563756252601426380622809055691634335697964207377437272113997461"
        "4461000127748183071299687746249467945463392302800634307707961482524771311823420533171133735363740791206212"
        "4986389054318298491065861091308880225496025941999908386397881816083312664904951429573802945356031871047722"
        "3100269607052986944038758053621421498340666445368950667144166486387218476578691673612021202301233961950615"
        "6684554636658495809965049461552751854495749312169556407468939399067294035945355435170251321102398263009782"
        "2029020757254763345019116747794671979873296198823284114052741805584855350891304581750773650128394365310668"
        "9453125e-323"},
    {1e-321, chars_format::scientific, 751,
        "9."
        "9801260459931801923666896159380717217742080128093602413968307865136452468582167876790566945050470460718906"
        "0684800349816471846554918998388725525087941779393815127440644429037146248550679054943849451211644835137436"
        "0605610129025664902012684623711962624918026225828640650785041097350019024941654738502845072717378199118274"
        "6236252944861481475976519702221969027750986201419907470261860634244145791554000943869540974809592189758199"
        "5331272303123516813479145634157635713324073109822640173815608151251090661344478590348141414324246301570121"
        "8251400183025080768064699956168279373040706805291251971543628793057966976304808989521953834313422245639880"
        "0249310964827310978469307915272618699672029160811516955193269223640703904400217627568281386629678308963775"
        "634765625e-322"},
    {1e-320, chars_format::scientific, 750,
        "9."
        "9998886718268300541337523676528005766688104049139332319738542138136722671490251377536686879595124857670824"
        "6943582132687395553181760422147911120187125822521327632643497190282764359933947726339777865966519379365430"
        "9834532129281161268155283999204461560808953010434241919400457020315068567565301579569187340188105680700687"
        "0486225722970118072958651424404586788201978253303907287034656397876312416883810846728688580700304253500294"
        "9777472842337622787367223150264878556320754442713378075149896484223865098297635973695365456728848769494023"
        "0564769292298397759684630055091384876749698303915591084358566671856101564376699700392294336955627042165899"
        "5893369006341820505159346148768208043631775753209163523421374707251873615102000236731782933929935097694396"
        "97265625e-321"},
    {1e-319, chars_format::scientific, 750,
        "9."
        "9998886718268300541337523676528005766688104049139332319738542138136722671490251377536686879595124857670824"
        "6943582132687395553181760422147911120187125822521327632643497190282764359933947726339777865966519379365430"
        "9834532129281161268155283999204461560808953010434241919400457020315068567565301579569187340188105680700687"
        "0486225722970118072958651424404586788201978253303907287034656397876312416883810846728688580700304253500294"
        "9777472842337622787367223150264878556320754442713378075149896484223865098297635973695365456728848769494023"
        "0564769292298397759684630055091384876749698303915591084358566671856101564376699700392294336955627042165899"
        "5893369006341820505159346148768208043631775753209163523421374707251873615102000236731782933929935097694396"
        "97265625e-320"},
    {1e-318, chars_format::scientific, 754,
        "9."
        "9999874849559983034425876814113742209432834168744560969267393309501724022504791795040417479267848129655584"
        "2874876041601750171714894629266707048162621742736965195169511454088992450490864069696757508040293752086570"
        "9580676739282438749985996996081924055488407644357269925743534099929893815278419813774519051525459318108599"
        "1107475586860661255943562083015499877004233213563327286118520376694473250010459896242984318729757813819005"
        "4549703845033693317236663537845414770535737849377831764656567925888728970482401760612101576940871781833642"
        "5626336137844764344642729705586000404268243261408712779922641361250092237317059153946646039468838066148529"
        "6871589296549393052792796339935685990351574486171151756262515234669929463655509149777600441666436381638050"
        "079345703125e-319"},
    {1e-317, chars_format::scientific, 757,
        "1."
        "0000002306925373540838912978475160267584454368668534526669672098520647422515697285766597706921875662045329"
        "8226457012793890336449486476033452643735894613076931082954841359365992666407440152120030445435135990799474"
        "1954259843078263037226060394561354342969032583944572412669499566187211760243538754890531880822606236371978"
        "5920066306644424273339129868180713684032457145760224028598109997351719737497945725367012867943417584786681"
        "2026553849543810389671707959598249520266798536037749981808256864213845855131011662864961199497267523368458"
        "5488557116467671933238644465316019273339602500503268103425725256465919083825811307197979879484581971974592"
        "4201832234008052893493781386861080768235954429611544999118868631378263784093853548673447306782691157422959"
        "804534912109375e-317"},
    {1e-316, chars_format::scientific, 757,
        "9."
        "9999998365971443346061920956311959264775925433695214550458499705922349191381609347228383804226938538653679"
        "2366287780216044499031536405156556539159558732763919890485263237064770961810478612616379963299515548676713"
        "4548944815532598435214836120691606867323339473597648426536418734881746971242559593050185515442628522784588"
        "1185131819846979153816675915341864013104515083595754786004003374046743354151291027432271285983439508858844"
        "2646232720370702133470343586292981797312610775210888475844901856096836954505497483976693591967374658376095"
        "0009031993538060167762492161897827345208061381095352991868150697424341071434604085640940002282989444146358"
        "4493866832825339621246977613831620733691549327791400285367657800597186444724697763908327630133499042131006"
        "717681884765625e-317"},
    {1e-315, chars_format::scientific, 758,
        "9."
        "9999999848168380869801553486018337869440042528874622393432792982679396693408131157854639400126447623561656"
        "3760184721079416030959336106467234733051521976644243346829052258460480303946313987131415432762626210235795"
        "1648564032447600351437582190186923061065358655548532968545933350501169209114129270401493513009634553240699"
        "9866063694642814968591153281329780382737718466036143916002629170014970595400981001006542729590483689199322"
        "3303391066874746239265147746874352601633933250320885156379161863259334250313774632657068696147692692894604"
        "4301624343806379717639929311373569268499339198531592674411496809458432057444014624821271529836759260682332"
        "3945334163260650980068427789118371950611629025890843267716919511388313528497528027277896356395103794056922"
        "1973419189453125e-316"},
    {1e-314, chars_format::scientific, 759,
        "9."
        "9999999996388074622175516738988975729906454238392563177730222310355101443610783338917264959716398532052454"
        "0899574415165753184152116076598302552440718301032275692463431160600051238159897524582918979708937276391703"
        "3358525954139100543059856797136454680439560573743621422746884812063111432901286238136624312766335156286311"
        "1734156882122398550068601017928572019701038804280182829002491749611793319525949998363969873951188107233370"
        "1369106901525150649844628162932489682066065497831884824432587863975583979894602347525106206565724496346455"
        "3730883578833211672627673026321143460828466980275216642665831420661841156044955678739304682592136242335929"
        "7890480896304182115950572806647047072303636995700787565951845682467426236874811053614853229021264269249513"
        "74530792236328125e-315"},
    {1e-313, chars_format::scientific, 761,
        "1."
        "0000000000132873108058798218075466365858866796204316120387346995461095826861753841161935247836939689566881"
        "4013755407163529775592520874226933814642035817851187677065124379067137026930035030916463576460714764526356"
        "6941552468486215054944726595070143906775203397101679103788691652744850950702752480372779533942489184305449"
        "8212975998837171800278451594248186507426648281555498412610248716893168741033011563160921744542987825450117"
        "1730463076268016413019727751013442758474713657274891814670103539733279230421396327135404079024632555646151"
        "7071185888666743940446059781681939593390610457300000410827430924103528812599832038053657245435064880839104"
        "9702198578740563315381331097389800290969337059469445237589300988817006332715405382115941845810880295175593"
        "3463573455810546875e-313"},
    {1e-312, chars_format::scientific, 761,
        "9."
        "9999999999846534143064242548224957279984003844947981796030495661334201221115511889808726222773497386583906"
        "0366160174694434384393280942568027468226466215267996447194900001649974559958214473790120729137684534602007"
        "8598425065645235547531043204631943751558291951834840153344907012832890084789653234050444031427324837024042"
        "1011079056496922166969741465115877157896849612172543736972488543135719183088865941635643173986271210320831"
        "2523973604333660086091482705973846213942815250273808150020501137325629806918154994205360415142145238426998"
        "5617566294317171084910720379669920191982813295182567868591765894923254035012310969997392122823095038574513"
        "7282534320075197842454489523722716158476450514996352932910660626459272200070280990896048889382541347004007"
        "5480937957763671875e-313"},
    {1e-311, chars_format::scientific, 762,
        "9."
        "9999999999994753836816616511477927917844470256657499736814793090661876925865714541989788848333087337492396"
        "8343299564388520721546473722538158536045855411592384479540534380552114130892428057327572232684630845668163"
        "7680135027566927047722665479238893283177666153753035241799107964294452027013440391018179162227081537627087"
        "7122947149684401750551218912852475949533812932510787775885488405715316005812990910633000601130631914738865"
        "3002039320168310490502062186389904351023247382521319149688554563326346056647735821920228452652563270230450"
        "4126995553552197916865708123384867766175142422964311492560020229534457444110911911051310155975850415556167"
        "3256479466808241373590371668740244833598142522966162877208895552630351312778658273922385846255167507479200"
        "13964176177978515625e-312"},
    {1e-310, chars_format::scientific, 763,
        "9."
        "9999999999999694493275028976919693605773152470381150334840936338306132782690721297062490935851740335856013"
        "1942537544044990266118246815203829571639835051469864080618722193182185449923568510112153949469529056037035"
        "6316192026297650097729052888392458267564978627150308411414247996009837425087566629583770333253740094313855"
        "8993342752790651070003934827777029242588378376522062577182588401134635899903795076266245848702110604886133"
        "1017974844029465503982414835737106288925928453596236183010823010859703264972055182844057387236243871290565"
        "4743976528860032144597541048175366018648220060557036280025628707354830891080865275753107423747608928122222"
        "4455610971699342824628234406907495789435532256565156542018836716836053949868937516689930411484255046161706"
        "559360027313232421875e-311"},
    {1e-309, chars_format::scientific, 765,
        "1."
        "0000000000000018855892087022346387017456602069175351539464355066307055836837322197256976114460360563569237"
        "4830246134201063722057542412447039667519923301545761204072654097444519258182668255539061212114801887707392"
        "2817979772617072240272969162930781476600370987449003572837576199918137596489497925344032945035640594998253"
        "2718038231310127600194920641926948457189383492092319005731229840067656788931287549282957037345925847390085"
        "9881956839641558100533045010067182648271619656070372788634304985561303898580448711893644028069461193139657"
        "6980567462639081556737072434065441584389552782431630875877218955513686823577786061222328715052478477937882"
        "7957552412218845296973202068072422088501927122992505590849983083325662421357796544096668486800716380002995"
        "72013318538665771484375e-309"},
    {1e-308, chars_format::scientific, 764,
        "9."
        "9999999999999990932662533724846199547048873403204569370722504933164788134100221702366853061102859515757830"
        "1758491822824378438792553200763769833775473829862512856683413461939989729065436937279228852476622948659167"
        "9434355446221493480729436132941672166628217375554144801591156397912760548972014203897705803515339607715061"
        "9905566488977026029171097782672502440171652303162739065260414400859795093549243326204240563556399326294969"
        "1698930975461134804791235994697938405200089317860731205010159117711704697471514344499487123311264707354172"
        "3780995387378502198261451023662795913796604718812599767273565216024053297899062477635215259813914438876185"
        "7527558861992808911690506171197530846785775640581096161907433186688396108094354271255983085398000298482656"
        "9445431232452392578125e-309"},
    {1e-307, chars_format::scientific, 764,
        "9."
        "9999999999999990932662533724846199547048873403204569370722504933164788134100221702366853061102859515757830"
        "1758491822824378438792553200763769833775473829862512856683413461939989729065436937279228852476622948659167"
        "9434355446221493480729436132941672166628217375554144801591156397912760548972014203897705803515339607715061"
        "9905566488977026029171097782672502440171652303162739065260414400859795093549243326204240563556399326294969"
        "1698930975461134804791235994697938405200089317860731205010159117711704697471514344499487123311264707354172"
        "3780995387378502198261451023662795913796604718812599767273565216024053297899062477635215259813914438876185"
        "7527558861992808911690506171197530846785775640581096161907433186688396108094354271255983085398000298482656"
        "9445431232452392578125e-308"},
    {1e-306, chars_format::scientific, 763,
        "1."
        "0000000000000000279023803391476325978469990224051750613215776767695913434815660171857902754611290428295390"
        "2855112999397555396569952545618616744426089938099821880772600111269030190023111167436591184859690670436405"
        "3235908198301844721604945146272364072259074692549029825719823273398887747392739210687026322232580358825111"
        "0234205543842448102753778430086832136807498326022836612478352744084880146129506125620176035215057087515132"
        "2612616922071840157682358884105637168985105575243131100589013256198578475477149271096570431275426554079671"
        "6654247614171924100040800742268229310960254010514282230676348267637082219417179036571049957325656665930634"
        "4285043677760454755517299704176913224907978537594173374670297704548248979442337094143862519235455010857549"
        "495995044708251953125e-306"},
    {1e-305, chars_format::scientific, 760,
        "9."
        "9999999999999999628217900530785377054659627883900722995775030945280642024408233714255781016776892345034950"
        "1406426481668573825190999521406861414798119234028697220781311072490218654586931744476129716298164369509417"
        "1579154906539259553297447374781782441000739045507324002369679044368579627272624666077581243976346526774830"
        "7025658385238493027973334562682769653967428338344198908910697296851733096562843141535755075192125128789628"
        "3612239021983130437614961415360789480610798036545823058988806310179363406158165146574713062236131985212038"
        "1806081273895043986502259049610427190720957335454762962899504686945017155165729595557090423005192733858302"
        "0097669333441417250244332809616705208468049446512230390757498683137398144735633162723253963832803492550738"
        "155841827392578125e-306"},
    {1e-304, chars_format::scientific, 757,
        "9."
        "9999999999999997098601793823603070870627408398607296486668841559937848165409539310797183793308082794699787"
        "9690663671822989712784178773583416591227895116453079951225559040330152058071587800564304010459170501625708"
        "2955213245355909423095844104428295815728732741520944598506836092672341349948810713443435661296780877593807"
        "0772540742689702628321774772134328282681384400836865136212433181654078404777068649802950853625368531700272"
        "9601094862994913526248059474804323713218591863837432701467745308734226327267503095061920061821625140744295"
        "4016965379635686375377660351152934455615691119704315487808322295404373123960880979434363102804093593499868"
        "1895455378110913006301401423894763575978660702968627706001115993261324824985442939750956981015406199730932"
        "712554931640625e-305"},
    {1e-303, chars_format::scientific, 755,
        "9."
        "9999999999999993051216023092111380976175857222137814072098938543389377991011628265263428235757987514163528"
        "4945443176070055132933265577065904873515536528332092319936355788874045503647037490305382881116780313011774"
        "1156906587462549214773278871862717215293522655142737552326287369958360106230708389228802729009475838904169"
        "2767552514611637988879279107256822088623714100825131099895210597337830897919829463030464099118557976357304"
        "3183264208613766468061016369913978485391061987504008129434047706422007001042443812641451261158414189595906"
        "9554379948820714197578302433620946079447265174503599527662430468939342674033123193637999390482334968926374"
        "0771913049582106215992711206739656963995638713298863410390903689459607513385138582995281808507570531219244"
        "0032958984375e-304"},
    {1e-302, chars_format::scientific, 751,
        "9."
        "9999999999999996289124639677304732891737098163313400003754860956628154130529957101690432681798063738592536"
        "0741619572672402796813996134279914247685423398828882424967718390038930747186677738512519784590692463902921"
        "4595551913777237381431331057915180095641690724245303189270726348129545101205190248600509074839319869855879"
        "5171543097074089700433275639158827043869850340834518328948988664790828903405620812448453502724006420631679"
        "2317528732118684114610650853826254667653085888570747787061005788271782462022491238577826301688982950514617"
        "7124448293472691939817788767646536780382005930664172295779143930111367033975329422275090360339741868585169"
        "3670746912405151648239663380463742253582056305034674846879073532500981362665382068399821946513839066028594"
        "970703125e-303"},
    {1e-301, chars_format::scientific, 751,
        "1."
        "0000000000000000665043221274992345902153306917507527498505381267899223777698860937825684690912630765676536"
        "0328938404179991532123233391736474424502906138441861076106807871376656352651352653277535787570721134675459"
        "2959921695798423951473709805328306131275582854537351322749293107827733708512353219858996938149482076890135"
        "2286431296095393517740606454124524290065748630886455746192107848064042252096015313058601959426144144230967"
        "8954717520733442058356948120234553845089156237198431469146727165019106393715864300157422643138680298545449"
        "2134866699635902071498414503652842702337317635037800515375262700586184498579038935391378146388344394749331"
        "4294701527343889703142991033638081518025859259858927144364121703023337768036216122169435038813389837741851"
        "806640625e-301"},
    {1e-300, chars_format::scientific, 749,
        "1."
        "0000000000000000250590918352087596856961468077037052499253423199004660431840514846763028121819501008949623"
        "0627027825414891031146499880413081224609160619018271942662793458427551041478278701507022263926060379361392"
        "4359775094030143866141479125513590882591017341692222921220404918621822029155619541859418525883262040928316"
        "3178720501540199698661694898041067655794243192165254180873224255430058507393834020333099315764646743363847"
        "9065531661724812599598594906293782493759617177861888792970476530542335134710418229637566637950767497147854"
        "2365897951520448920491760252897567092617670818249247201056323377556165380506436538125830502246596311593005"
        "6323650792902539887815381155401398600958797808116743280493635963114041915328344956037653901148587465286254"
        "8828125e-300"},
    {1e-299, chars_format::scientific, 746,
        "9."
        "9999999999999999190290760137637976208079970046606724998518567438890097551538379739129028665449972035680926"
        "8654993624028106303651130713543666646941642034794006359075819280682667925398195400906114450103317751101389"
        "4796578126155197978756945816618186836433649314161201999972943672570926856702325994597557960702860121588611"
        "8925518658960446433985656531743023483770388411882929286181173813228715116320889861526972008354488226701519"
        "1541829745179090325919123351411654126959859303926546520294760229609181275060613732216818338004372560297782"
        "5507229530280863996864368522933466048419533648184045496011719191321500860483546203133923869331978450679449"
        "9468102053494600355532932528120522673051486467229961893972473711866052331620480231322289910167455673217773"
        "4375e-300"},
    {1e-298, chars_format::scientific, 743,
        "9."
        "9999999999999991232806544017866794540396664309573605012880972516114481311058134790726022538861880706524197"
        "8378310511738176684897847296134517208981728061861094996950742552059845950875175526912254796125831249071305"
        "7673763372204220340378116764175654061689991467534736690618290439817422613053039377005652445191435431121688"
        "8057471403500725107670554654940656105757483988435859232058608834656227218039009041197321250053738130052815"
        "3669461252213404717758741643748844181432709364664927137710748047655173102156049178235583038396446773463958"
        "9943029566464163497536606908432174341802314765843821861088084189145133793489580175635409101810415254077994"
        "6423927952220683901242822865976210665363906593780031707659147505607571959629353841592092067003250122070312"
        "5e-299"},
    {1e-297, chars_format::scientific, 742,
        "1."
        "0000000000000000396478128980950068520868995348882659698990112439255546729582652670817083234140282683317496"
        "4282100349140206407490310076398915630971759041855375317635086531785636111011200732530243024248980965231943"
        "9707026697852578456178424324808370650127984402213708118558573561222302940289189796515270127000971493586876"
        "5744634701223627922977471765782444391057813106595117131865471280037220785529001835372476246333493828469074"
        "1426525084095850169081535237600934009427614926748351814984516753878158617880335246460555951776912803239807"
        "6684574950857088429646102549163424107238986497758817967696590019262732110067992581963303272984491636864032"
        "3129460651425895022810699832540710987766403439129992000576046943562114055481515606516040861606597900390625"
        "e-297"},
    {1e-296, chars_format::scientific, 739,
        "1."
        "0000000000000000056958802426506498103047840970769246579602908389217120436655495553018554972739190786606809"
        "3230295203015836077090169983922791921618802712343571099517749924697729040098218551239838345679274874478660"
        "3989786601684003410274260951904155918405588334090978932026108356624820092560153567498015491672484040126954"
        "5227598018324013146388027419038876716262595851194708809556241840951461301868974920371744480645995157678729"
        "4477304028395980916466692284740654118418456529339856054660932234114787602503073825490689912326974636334897"
        "8633835752400909208341451386944702327756651825445635092606514925836540448542916698123366642903571607142370"
        "2199575889771541254094321820289220342105066697862794979293345025428418892943227547220885753631591796875e-"
        "296"},
    {1e-295, chars_format::scientific, 737,
        "1."
        "0000000000000000600189724913616210771561687975750707570622434869278602505338946941496200190980937821343908"
        "6913183436814828605730394131884589856583532839562457848505488496038380353558990041304485831390804619683914"
        "1137370755553723483720922348550899489161422043087345630478052683980792648926611533925622908198063965662829"
        "8054856710963396788931138373828584995934943459835362125251008943488676475725017984372915305745993030943280"
        "9596057717515771720650441009317101944033109965193449271178667465736181227106692099042475575446875703382753"
        "5515018469930795962428893246494657174928387301146727692750635075318447106983038112267265251033043654697029"
        "56873915084185072840405266398916053751632054838903102133456680944423311530044884420931339263916015625e-"
        "295"},
    {1e-294, chars_format::scientific, 735,
        "1."
        "0000000000000000165604986923928440636750610371765538777806813685229416850392185830714084016387540193554229"
        "1966872849775634582818214813515151508611748737787348449315297638965859302790372849252767842821580823519711"
        "1419303432457947424963593231233504632556755075890252271716497222096014603833445160783536974977600025234129"
        "5793049756851889874896649609996818372197065372922839472695195261458904336640183533171978645665994732331639"
        "7501054766219939077303442029655943683541387216510574697964479280439066327423797480201047044950954849744469"
        "0010072295906886559158939758854693297190998920585853612635338955732921780230940980952146364529466016653302"
        "089713901350093446008356278420969734871669445506829802610380963923120134495547972619533538818359375e-294"},
    {1e-293, chars_format::scientific, 729,
        "1."
        "0000000000000000513272777315678656744599472454953673812059310632468765374349594719339776956062258295785972"
        "7923921319406989801147958268210702186989176019207435968667450324623876143405266602894142233676959860451073"
        "5193757290934568271969456525087420517840488649647926958725741591603837039907978259297205721553971177577089"
        "7602495320141095406124240621062231671187367842452857594739846207082722047908051094132727973729993371220952"
        "7177057127256605191981041213384870291934765415456874356535829828676758247170113175274189869347691532655096"
        "6414029235126014081774902548966664399380909625034552876727575851401342041632618686004241473732328127088284"
        "072934100943499271924913386875522376987390327812590777589729640340010519139468669891357421875e-293"},
    {1e-292, chars_format::scientific, 729,
        "1."
        "0000000000000000513272777315678656744599472454953673812059310632468765374349594719339776956062258295785972"
        "7923921319406989801147958268210702186989176019207435968667450324623876143405266602894142233676959860451073"
        "5193757290934568271969456525087420517840488649647926958725741591603837039907978259297205721553971177577089"
        "7602495320141095406124240621062231671187367842452857594739846207082722047908051094132727973729993371220952"
        "7177057127256605191981041213384870291934765415456874356535829828676758247170113175274189869347691532655096"
        "6414029235126014081774902548966664399380909625034552876727575851401342041632618686004241473732328127088284"
        "072934100943499271924913386875522376987390327812590777589729640340010519139468669891357421875e-292"},
    {1e-291, chars_format::scientific, 727,
        "9."
        "9999999999999996232432339127981035085063855219920481243729184475360331530186279644580030304949799540727091"
        "8738772371507204422238150241900924503429621787720119191259394493393530314311385935722237930871895259067858"
        "3311554132344189036344464928213958515141307008282797599820760056638116035571735271022137303184610275791116"
        "9703146781207292461816076327347736257721935204560112023055397862857487070623101380732096938861568556643115"
        "2064910830027399384063873030388181744477172261543472305931724251882669326195449958869442388920456244038898"
        "8198994707250476238780378062800183777747382216458827606514493984901861724443237610708779941730011243747301"
        "9589038998438035757852718923186761317114486910984268164259702871277113445103168487548828125e-292"},
    {1e-290, chars_format::scientific, 725,
        "1."
        "0000000000000000691278685996254767391818089841545998949596589069455311818615788070316131741175713964128625"
        "5133930135858243672932786917014824134318418787294520778575752499680780765800092204758525921794913927359931"
        "0566277666474598145636458531540625451105760239411856398474474708791842127178139205736204119801073207576685"
        "3728931448545168638112767218727723280270402706852226873226707491242116716077199285344631629698760674332280"
        "9571170336107378242695971995454080715432175053317379781724361309374456510080226811151638995438820714305337"
        "9932855188006207373354275497503993603702143905712286899942801141983573215470277670990914169644193527630994"
        "84834284313532305479419062640425332975063941955314039677915616266545839607715606689453125e-290"},
    {1e-289, chars_format::scientific, 723,
        "1."
        "0000000000000000121659778218411213320718514204450558509477298071098363196963969347191796428812655825432136"
        "8061901923214231283221335240841633902864841929415849386869185539498685974136650278792498119817460913251586"
        "9374212464746502549902052110890369664656891152167282191278528733790225847913624177131409245410346711577979"
        "4124335837652134295749482106198150131204691140774245182068751381932053777935925073466539930598705304376030"
        "5910008067784904480408193492832607360240464212163762421121060571141822068767863176343801791947207333024565"
        "6672612138789588840300282062184540149874194207543538025654080212120433459189768919033561542726224245894320"
        "367034868121486949612503459912314280908242325983381615372991291224025189876556396484375e-289"},
    {1e-288, chars_format::scientific, 721,
        "1."
        "0000000000000000577354904440686056577598174714126910861572730869783922094285424325691264678703102336389327"
        "7719524493329441194990496581780186088027703415718786500234439107644361807467403819565320361399423324538262"
        "2327864626128979026489577247410574293815986421962941557035285513791518871325236200015245144922927908376944"
        "1808012326366561769640110196221808650457260393636630534995116269380104128448944442969013289878749600341030"
        "8838937882442883490238416294929786044393832885086656309603701161727929621817754084190071554740498038049183"
        "5280806578162883666743476810440102912936553966078537125085056956010945264214175920599443644260599671283659"
        "9520812481325558337578531931058655199821600008391886404979231883771717548370361328125e-288"},
    {1e-287, chars_format::scientific, 719,
        "1."
        "0000000000000000212798803462866181972094446306385828979896384630835474976428260342891690078790745127623574"
        "9993426437237273265575167509029344339897414226676436809542236253127821140802800986947062568133853395508921"
        "9964942897022997845219557138194410590488710206126414064429880089790484452595946581708176425312862950937772"
        "3661071135395019790527607724202881835055204991346722252654024359421663848038528947367034602454714163569030"
        "6495794030716500282374238053252043097071137946748341198817588689259043579377841357913055744505865474029489"
        "2394251026664247805588921011835652702486666159250537845540275560898535820194650319346737963033099330972188"
        "28404414412370072644157340655102452872302586095454302039797767065465450286865234375e-287"},
    {1e-286, chars_format::scientific, 717,
        "1."
        "0000000000000000504443684245122081656497429032578694485237461621994232670713991529131349758720630894636177"
        "2174304882111007609107430767230017738401645577910316562095998536741053674134483253041668802746309338732394"
        "1855280280307782790235573225567341553150531178795636058514204428991311987579378276353831401000914916889109"
        "8178624088172253373817609701818023287376849313178648878526897887388416072366861343848617552393942512986630"
        "8370309112097606848665580646594237454929293897418993287446478667234152413329771538934668392693571525245244"
        "6703495467863156494512565650719212870846576404712937269176100676988463375410270800348902508015099603221365"
        "618473827330784812294597235794897321730333172862259516477934084832668304443359375e-286"},
    {1e-285, chars_format::scientific, 714,
        "1."
        "0000000000000000737759588870926801404019815213532986889510323214921238826142576478123077502664539508246258"
        "9919007638009995083933241373790556457205030658897420364139008363631639700799829065917353790436274093311171"
        "9367550186935610746248386095465686323279987956931013653781663900351974015566123632070355381551356489650179"
        "7792666450394040240449611283910136449234164770644190179225196709761817851829527261033883912345325192520710"
        "9869921177202492101698654721267992941215818657955514958349590649614239480491315683751958511243736366217849"
        "0150891020822283445651481361826061005534504601082856808084760769860405419582767185150634144000699821020707"
        "486017573896452080977016299189995556136179022388432713341899216175079345703125e-285"},
    {1e-284, chars_format::scientific, 712,
        "1."
        "0000000000000000364454141469639249807983997324006119042673744666238028977456840559736313112354285726470128"
        "1527483228571615124211944403293694507119614529318054280870192640606702058135275765316257810132330485985127"
        "5347918336331086016627885503628334691072857111914409501353728746174914770787331062923917012670649973232467"
        "8410198670839181253838408752562755390262460038699324098107918593964375004689261793537457736423112905266182"
        "7470541873034675696845736201789984163157379041097080284904611477806100173032845052044294321563472620661682"
        "0635058136087680323829216224055103990033819486890985545830904621265298148906772969467863526423739472541760"
        "4979475793913844510851457977578383810868256631465555983595550060272216796875e-284"},
    {1e-283, chars_format::scientific, 709,
        "9."
        "9999999999999994685210677065491259774980343891416362102659561493983253406110743556080785756096766502074141"
        "3878246459195032208808316741012258269146158183275756810250349053468517157403478438736274574028658284026209"
        "7008018948802266655386840832186907737757430838745595355266843761499725833182288969724649273569543338299591"
        "8922759999075196859715226773290408487303686820316455034264511160505121715526246715460349142098034158553149"
        "7120315430319163251987317550427630958171239606368370686366614654665658351325155359459002663308396313268813"
        "7970592127246328314557798934048071528321752128304945164216498646370406992843868518292140442390346361922877"
        "2657959257922213934465659432066116096837760096605052240192890167236328125e-284"},
    {1e-282, chars_format::scientific, 704,
        "1."
        "0000000000000000185267526717021225041886804737033222476192186962870088250087687318910666205005363911217585"
        "3499551512041192743545721857455200771078614787119958560901161093554731989656290181027731739586437554468626"
        "2218495048040914146410045219546405907613434306306439508188319872169926333293510629733626595607910845351966"
        "1106614136652848940265031537516012481956041767365788379171625098381602438061934369139173171980451007384009"
        "1918839807034123822516335312440539949689328025005031641651021475338193305452779148824615510516946022794721"
        "9267458351415070825354528957925044622593490632078887339949053669939646658982295745940133629986798505271865"
        "94367398202895198873704795707040293706313605071045458316802978515625e-282"},
    {1e-281, chars_format::scientific, 704,
        "1."
        "0000000000000000185267526717021225041886804737033222476192186962870088250087687318910666205005363911217585"
        "3499551512041192743545721857455200771078614787119958560901161093554731989656290181027731739586437554468626"
        "2218495048040914146410045219546405907613434306306439508188319872169926333293510629733626595607910845351966"
        "1106614136652848940265031537516012481956041767365788379171625098381602438061934369139173171980451007384009"
        "1918839807034123822516335312440539949689328025005031641651021475338193305452779148824615510516946022794721"
        "9267458351415070825354528957925044622593490632078887339949053669939646658982295745940133629986798505271865"
        "94367398202895198873704795707040293706313605071045458316802978515625e-281"},
    {1e-280, chars_format::scientific, 700,
        "9."
        "9999999999999995736438816947517005069417207068324021959351366687075172340009775902257914279210441151555725"
        "8308779196173510175383489009931421520586690004171251700735334129506741559146860533228960854564563482256350"
        "7367302240104608293998170498800889934052711298312352648503909155662324666479368844441019720337612888531868"
        "7103789266301679766012373101564633549368007345473197918690766334590720773073234271930285253494983959461901"
        "2356967550855734248053136101277703677183805567441722726787676002477378641128208658347785021448019020754979"
        "9327177530658970705609297562011086483971681409869254638723357560814229067067468229654822501487066703239591"
        "9842010303184918392220732752395662146227550692856311798095703125e-281"},
    {1e-279, chars_format::scientific, 700,
        "1."
        "0000000000000000552241713730382939762853855155153714644346417139367630859739713156121591071255955788854793"
        "0100755667495497779150145631332435942490582259141658595397737701917166689901252657650633132064426278214420"
        "9107553942459186136616182121346196056138332212191562054191077246132142653280854876907341369752400579251233"
        "6544355262666457518463308073931741958167586387056869531553154177335120654514700934306859959959022574246700"
        "6328725638203254061142948333828201698871896505961547263034373800392466570256754118618517715540232495226256"
        "2868302710424575078230688478959406207111284126734064465595084418254580910347625099724924457889653606240609"
        "9908263094272136716259523347982707264236523769795894622802734375e-279"},
    {1e-278, chars_format::scientific, 697,
        "9."
        "9999999999999993779243152876254526557592938171681397062528805745754945088532304770466314992540617804157284"
        "9769023700417216652159895549252833939722863486722184850086925551573756491173727324573486761348623622278779"
        "0625654803207157679565440355868675808586589133591699069822536494530504293213532859514540924900334307735775"
        "1435836594229100682288231574014076342906436040454098439322611246838623618658479257702622384275935602860880"
        "2170909784620372975377866653876841014876773669006972746076463602187921228840342152780306594657157834453463"
        "3456007615941614690269780116494491366543449438374976635277860236467913059785711676135938086005172831406290"
        "3993886175277628638145832606909380047000013291835784912109375e-279"},
    {1e-277, chars_format::scientific, 695,
        "9."
        "9999999999999996910756215390274492176511768406309596897444903251867308690896258581332873851212335159994790"
        "3432632493627286289317645086338574069104985914640691811124379276266532599930740458422245310494127398242893"
        "7412290702243078662657808584560218409332384597144744795712732752341416890438870435396906997599980037009524"
        "8504560869545227216246858018094967873244950128484657606311659387241979065722087280466882975026412973422513"
        "8468602210596951011658297769718221274568024706502572715214403442651053088500928561688272077522535732535889"
        "8849879479489384314813008029321043554428620592765821440790655955422018671436522161766153150776203026339572"
        "93508847799292922446656728396874314057640731334686279296875e-278"},
    {1e-276, chars_format::scientific, 681,
        "1."
        "0000000000000000943680846544635435465218708934482239623710929327631676310035207382479910928589920458334481"
        "1808706766646756483794864323468153458663347562631471965527419417503763703495879299381727950707614250209935"
        "2455883429838676259502728149932638881231556645135692769927351778358506727934022073892637128839856295410452"
        "3677945797080973335208136379441853399459900648060689427426785194885540085397651937152392533802832245566904"
        "8365937191450326315678002223308374231333302885648497259176616280450358052714327419732013400898404732486559"
        "6042536693368046281298591968062725230596930521032920066284183883123844111803976410428701340986032380607270"
        "307788791985359466707450337707996368408203125e-276"},
    {1e-275, chars_format::scientific, 690,
        "9."
        "9999999999999993403461585374572130683322678543526013082338874045021461456248630313162327929500011721456784"
        "3329390645232008295700965604802545124197008795371964014762431104610623358122885748511635735451163169163085"
        "3011258495322847161594356168425690696497093677965333582715712943593194781546492350408656996176376820222925"
        "1787589681191165498213196400724369359265814349890431339283925469990220965010846294970911113385878318393484"
        "1815186693503183611024214919975875383713823544507500749779910821332345405681071783711350736713312486683572"
        "1608742992315882335324592766955305103997228899848075258616324750193420386387614417860312278232649208014296"
        "495104634271942900536345177897601388394832611083984375e-276"},
    {1e-274, chars_format::scientific, 688,
        "9."
        "9999999999999996610130961388928575477095560703785289713292957891280521785069319015489684200779850293834389"
        "8280926049479119604150501130778343016684302161560515142864783718696026093490067197572764489776159035750338"
        "7320773655935630248280941234605830319660788232643652406027273911591569281105238028112199854620814046999244"
        "8785963339114879068986829879463202286332452776033723926280710765763256942803980910281513958314367145848597"
        "0184023737703199520175376382597448769637664606902995118177161217966592429973512266433107391167459454319976"
        "9372067780588798430856858149689694544391644161944300339461427566402424532718044355145652504558184127625977"
        "8116612913882732538439768177340738475322723388671875e-275"},
    {1e-273, chars_format::scientific, 681,
        "1."
        "0000000000000000943680846544635435465218708934482239623710929327631676310035207382479910928589920458334481"
        "1808706766646756483794864323468153458663347562631471965527419417503763703495879299381727950707614250209935"
        "2455883429838676259502728149932638881231556645135692769927351778358506727934022073892637128839856295410452"
        "3677945797080973335208136379441853399459900648060689427426785194885540085397651937152392533802832245566904"
        "8365937191450326315678002223308374231333302885648497259176616280450358052714327419732013400898404732486559"
        "6042536693368046281298591968062725230596930521032920066284183883123844111803976410428701340986032380607270"
        "307788791985359466707450337707996368408203125e-273"},
    {1e-272, chars_format::scientific, 683,
        "9."
        "9999999999999993018661260252849357308069932684294899886624383983470374216790147668883045176946431092771471"
        "6735206396722354938687021341685449377098533591429337879390148790920375029878823974624300284932163665172614"
        "8894116676049313191191965960484073941717450331403935323918325627433389841599442869084231853163044353009766"
        "8147784842240319869720360383275709408017817738753236228844311234497456647675670141133638771994459659098870"
        "6410926248199181701926075544461286577402962617020041425572240773736235762765978925784739938178814850567203"
        "5877144017723132403860720921027178371149899068396528248914912412248339888827962825386071451073585017660894"
        "73711783541798325813942938111722469329833984375e-273"},
    {1e-271, chars_format::scientific, 681,
        "9."
        "9999999999999996302290701291550356776893364016400399156721365842039651993502532900066257998736985790886139"
        "7005578650671396918539345720284666419005521998406414234566957867743827430894817778462896129360959432557962"
        "4027060200516803071959029068252536915837073555394533798989364058663725329147598443052659740210148073228718"
        "1874119467954202566192561065504274325334055487123967837929019377369045488935839987211696085201232218412906"
        "1860615381459997992896864882185777724588975864913027658811025179889704715641437980091818752339861345426882"
        "0786788600914598485685760672947193158113780296783062731700297696046360134670323081166259842830932775343256"
        "405271852305105539926444180309772491455078125e-272"},
    {1e-270, chars_format::scientific, 678,
        "1."
        "0000000000000000418300135978443275550206959921345359740495412230260591865761225745490596877103431706636134"
        "2965447206014909767018492422892278731958229417515139748699129965212011319333320290767552615599006927428279"
        "6434612465923877878579998052689684805372416929297197013915985629361653049926317182057688666912319700175420"
        "1481732256966752103772584270285283012689302608321372369973231892026085870796024761779903363689748636076659"
        "1493986930128595709122675929272455647783540765985619461858410775465803020254253971042880790632637293309011"
        "0456993560057411708206585607755522864682709524491074549038522237716160872469198769503871198304856739378092"
        "440884149283419901621527969837188720703125e-270"},
    {1e-269, chars_format::scientific, 674,
        "9."
        "9999999999999995776909990725358196861881615003263519273505848744668567549228551263076943947250497039187792"
        "8162319090039550201762973819708791692300403853290082017738668415452075046732258769848720794252352109776306"
        "8005789236602004691036298971009582839977933839556038042977997909666871651139893551217711278282611477993685"
        "9677905927839981334757008956347703938563457447384650780475466074509591274334212811839206915088148608922660"
        "4988665120138267386341538588149859141039213745250149861492819674905149683181364531402686142074093906249333"
        "5201245467603963912593754312639990792199559300241217214454636050638676895335545440241429700149757134114078"
        "53836720960316597484052181243896484375e-270"},
    {1e-268, chars_format::scientific, 674,
        "9."
        "9999999999999995776909990725358196861881615003263519273505848744668567549228551263076943947250497039187792"
        "8162319090039550201762973819708791692300403853290082017738668415452075046732258769848720794252352109776306"
        "8005789236602004691036298971009582839977933839556038042977997909666871651139893551217711278282611477993685"
        "9677905927839981334757008956347703938563457447384650780475466074509591274334212811839206915088148608922660"
        "4988665120138267386341538588149859141039213745250149861492819674905149683181364531402686142074093906249333"
        "5201245467603963912593754312639990792199559300241217214454636050638676895335545440241429700149757134114078"
        "53836720960316597484052181243896484375e-269"},
    {1e-267, chars_format::scientific, 667,
        "9."
        "9999999999999998466859228824262055626741769950524344275569296283208519903911337244462231890861319447883328"
        "8639808040474605391657997950657270293030608756285702967899510411185847253644560893953298510008421602418383"
        "4834696571845772401360677068893507708376729184649136313756192592530762482539342597412647403351598845597050"
        "9322519253224794039707035755229344318828919410849954114637658985149996853094543949746351466067136689512718"
        "4173050458105528091904809213613762288813995797924084183762031860426071449376940588691045106634823194838382"
        "1399226310154412926824826877412866905680370802535466262752423675126015080729606961776560030677376417207469"
        "2169189802370965480804443359375e-268"},
    {1e-266, chars_format::scientific, 667,
        "9."
        "9999999999999998466859228824262055626741769950524344275569296283208519903911337244462231890861319447883328"
        "8639808040474605391657997950657270293030608756285702967899510411185847253644560893953298510008421602418383"
        "4834696571845772401360677068893507708376729184649136313756192592530762482539342597412647403351598845597050"
        "9322519253224794039707035755229344318828919410849954114637658985149996853094543949746351466067136689512718"
        "4173050458105528091904809213613762288813995797924084183762031860426071449376940588691045106634823194838382"
        "1399226310154412926824826877412866905680370802535466262752423675126015080729606961776560030677376417207469"
        "2169189802370965480804443359375e-267"},
    {1e-265, chars_format::scientific, 667,
        "9."
        "9999999999999998466859228824262055626741769950524344275569296283208519903911337244462231890861319447883328"
        "8639808040474605391657997950657270293030608756285702967899510411185847253644560893953298510008421602418383"
        "4834696571845772401360677068893507708376729184649136313756192592530762482539342597412647403351598845597050"
        "9322519253224794039707035755229344318828919410849954114637658985149996853094543949746351466067136689512718"
        "4173050458105528091904809213613762288813995797924084183762031860426071449376940588691045106634823194838382"
        "1399226310154412926824826877412866905680370802535466262752423675126015080729606961776560030677376417207469"
        "2169189802370965480804443359375e-266"},
    {1e-264, chars_format::scientific, 661,
        "1."
        "0000000000000000122136724863753960700195856861651942907768226656267343111510651008940076674511880159438755"
        "7776875672572010190611050266074851238017833857695321882086421261481722999352275826903638609094263676288387"
        "0006749768313539053673284024112664677361709561802446894303306394778338669389237842071626199542224191002289"
        "6655860329841884224957586319728414406822075246143842472881974452564577216574512303496326748626962048403693"
        "7725786104418400305440159833408879911213537261986219292976570513839949533796121047135432468634500998635356"
        "7926595869292607271739744518374029204588472178088477728820935820260104938257312595982853348913765856309510"
        "1271755993366241455078125e-264"},
    {1e-263, chars_format::scientific, 661,
        "1."
        "0000000000000000122136724863753960700195856861651942907768226656267343111510651008940076674511880159438755"
        "7776875672572010190611050266074851238017833857695321882086421261481722999352275826903638609094263676288387"
        "0006749768313539053673284024112664677361709561802446894303306394778338669389237842071626199542224191002289"
        "6655860329841884224957586319728414406822075246143842472881974452564577216574512303496326748626962048403693"
        "7725786104418400305440159833408879911213537261986219292976570513839949533796121047135432468634500998635356"
        "7926595869292607271739744518374029204588472178088477728820935820260104938257312595982853348913765856309510"
        "1271755993366241455078125e-263"},
    {1e-262, chars_format::scientific, 661,
        "1."
        "0000000000000000122136724863753960700195856861651942907768226656267343111510651008940076674511880159438755"
        "7776875672572010190611050266074851238017833857695321882086421261481722999352275826903638609094263676288387"
        "0006749768313539053673284024112664677361709561802446894303306394778338669389237842071626199542224191002289"
        "6655860329841884224957586319728414406822075246143842472881974452564577216574512303496326748626962048403693"
        "7725786104418400305440159833408879911213537261986219292976570513839949533796121047135432468634500998635356"
        "7926595869292607271739744518374029204588472178088477728820935820260104938257312595982853348913765856309510"
        "1271755993366241455078125e-262"},
    {1e-261, chars_format::scientific, 658,
        "9."
        "9999999999999998400751036348743394393736566782540462240318584996501362034842653096183707054359139876367227"
        "3700713272028713475311137837615080482939063240589682587428357558298694067887484156951304408066000438567211"
        "8069109345174821566111745152759912370810960390248128330653547680004699501466869737653360653141903412050830"
        "6348853236140136882670183896620029124843515417635830819897288932178098245590930051701145481582277078444137"
        "1539015004039644692804886274722361405054282754197569573857943701754709276050918111507126396721778711842017"
        "6810424732967893091851084038061008702315466379055082798141457246466614257485362505823312667674329645706166"
        "0476028919219970703125e-262"},
    {1e-260, chars_format::scientific, 655,
        "9."
        "9999999999999996144258066517706424307158965315357288770427639743563706770631567501610059301751410501950963"
        "0446278509075602730671645979108334965147642971498853600679673513083865327379264867283239061764691379113885"
        "2470398674806366389614869082066524848566052208027055840749934665781749747526462791203039579317632613673177"
        "8181053186317172589145640456088737170141725782593755692759324457403959109467575665091447877832402353969896"
        "6963938171924158003527516627229211239389410861665870889131734552438880426522684223629367765023193692232777"
        "4845997565001349391413995121517582027460062057591327206087136481559066157415151742619136010503666511795017"
        "8682804107666015625e-261"},
    {1e-259, chars_format::scientific, 650,
        "1."
        "0000000000000000697542432170668388072273145235783652142590417695766445203884477835556356851426851149914903"
        "1806756537125053430494120689994071345054646026313483273707335693011504328181871745768995272401097486448985"
        "2734420989257495123679987422139478495534161148268820379228727713405190856644041613416458073367413244588591"
        "1338649342546740119806344897063893855271031603079571630302155393631982696285967672081799637583180103144625"
        "0892430696607849411205889093519633203458079594581802457581753846915485890425820688544260919717640178635713"
        "0427524797124075915351202192092603006676600280061735404794787615311529703775216340599918396492284955456852"
        "91290283203125e-259"},
    {1e-258, chars_format::scientific, 651,
        "9."
        "9999999999999995422180316171774593879454132845858673260062537262623657086084020111346492020916937102137758"
        "4604859384930607292387008584386176399454388485389788324920094618615120130416634694589458150948272480088820"
        "7478811260288460733135868739444640841447681589716312643980778501230405826265532568338936835693865958192328"
        "9167357170373824015217786555118723744637153099380291652075175825476234585908102261376344644632442442138139"
        "7499913585647202262958758340031403186376651856055727310019347624657815194673649379508485002879646485957820"
        "6217380871252055407274126668223685491506332674722925416629753836788650765392684298393799480209054308943450"
        "450897216796875e-259"},
    {1e-257, chars_format::scientific, 646,
        "9."
        "9999999999999997732829117278756451248109596748254242893230865201631816076636171760189907319587251981540013"
        "1297400582194592694897848247497083809672802840938797207350747080915104760697051247209557065560812956969027"
        "1451890986745758833868669835834669664226467568310690873642078227794706374300509281504065615289919255731045"
        "4011184421392539451786919038222766706251785685663376582264451447644953061298417153264674990872314159999761"
        "9784792261733460632778784859064388956017480674008186763178985793557223936590560880695309841738997546037682"
        "5828954291249796156521705718764154406558266699901811142893378300053980019864580119914876377151813358068466"
        "1865234375e-258"},
    {1e-256, chars_format::scientific, 646,
        "9."
        "9999999999999997732829117278756451248109596748254242893230865201631816076636171760189907319587251981540013"
        "1297400582194592694897848247497083809672802840938797207350747080915104760697051247209557065560812956969027"
        "1451890986745758833868669835834669664226467568310690873642078227794706374300509281504065615289919255731045"
        "4011184421392539451786919038222766706251785685663376582264451447644953061298417153264674990872314159999761"
        "9784792261733460632778784859064388956017480674008186763178985793557223936590560880695309841738997546037682"
        "5828954291249796156521705718764154406558266699901811142893378300053980019864580119914876377151813358068466"
        "1865234375e-257"},
    {1e-255, chars_format::scientific, 643,
        "1."
        "0000000000000000069045958269569322867998859054332057202368632496356225958454292587070947890188525502717489"
        "9106385331469249401011172301627904529475237321604152857686198223265908508745598443456328367626486476737569"
        "1333743303661110040280665523921390655738331362091149500760854187779701107578527947435543045317286747658060"
        "2501128330269649521059540861659594169711851539610572529290672424402091270979802021488173783405934995886263"
        "8430943696712387134614841880342661074115774156098733486322332264974846712624420760221444563547896690293990"
        "5893176826884690431555860690345595461782474225213078487251081761303360146558860677146185480523854494094848"
        "6328125e-255"},
    {1e-254, chars_format::scientific, 639,
        "9."
        "9999999999999991226042093361495540897975810399108318806228853725384840359241312717046849838531645281143263"
        "9811204570699209801427323756176768542497748015712788194426029747078348041827398235031358522011898974074365"
        "9303698477042007382205101948400348499281406252588921778915858197789636031034014857231062971947433169862019"
        "7810966882523836782408241965801781726344980322690209418851451295617841834599290417707136735860835402501433"
        "7830573909874557063365590181467501028708906722654060943081444709936488919352538093353211095511064960852791"
        "3002763540536158206640523112442193941772020484998068937735011811498812839271721486511523835361003875732421"
        "875e-255"},
    {1e-253, chars_format::scientific, 637,
        "1."
        "0000000000000000636911007629621184134919625862984792395416080770646871111972389376290705633989742087479388"
        "0181544256108846453532236257234041134610514833623877280632355372400752731483313615428243876881664424335648"
        "6575767377235255621516758721370204139224445804190503894482415208580143610263603824463005094190812806061175"
        "2133147315480009026750770860707243767958263644015503481733988801306275523491725809318649849297845869267936"
        "1219675480147345991581811597660207656862704246398729921530844941363565405037920930753118635945970806819217"
        "4648917110583335198090945717806421102345637531241041443337630109395447464137873794243205338716506958007812"
        "5e-253"},
    {1e-252, chars_format::scientific, 637,
        "9."
        "9999999999999994254655689948438800988219900045256239835815244521601614511337828926218891138804800399873387"
        "2212052168777060748206331519409497103219228079817985116805534542464183896428545818881574571372848027930790"
        "0594493536104117148797599001460687077874016610452145212097516975391996045354419534710860565939572148011966"
        "2515068136979087479428135294055912916992511546183174498549138639106824514662883952803009087284360060537019"
        "2703810088194337633856095340494416136692533870920708597526845650676321945557872336188806148300793582320667"
        "9700045053595596961494309925566597358108891450480538036863269667989945199693124777695629745721817016601562"
        "5e-253"},
    {1e-251, chars_format::scientific, 635,
        "1."
        "0000000000000000152332832175710262520480571519601125030682258243252187247636946782823179025946037268482568"
        "2997408640416390302047595015116804564895078023367045773051634605139018994747130002012209308983912575718620"
        "7969240167785318058861959192880549966649628146932388145173349804163766007972339076066237479152070569557183"
        "7780491114767168915227587928186582777454658648256629068982358826348038294681550843703310273070081923982242"
        "4439957691616181100303330772215901239585323902676066296819580790845192120845067451899423427499614227384357"
        "197735206849382499731433982770651655573173817676384638747710885235686628647044926765374839305877685546875e"
        "-251"},
    {1e-250, chars_format::scientific, 631,
        "1."
        "0000000000000000539995372538838999812031814994308058922469316265167934339105300857597200312381001123680024"
        "0744717132970355223235308008810593820667427471572510979116211218948405984136076892745036963302114054612243"
        "0854461935345268108985798815672273304709482272738880744620602127696868089805350874783651571183064358760376"
        "9262616075337441004446134274203111569857542644863728599183662806314628077729690816195581934052293080210797"
        "3863731922441113013326115432571346373407228177654197196588592111259890748199350234982379594256699490932245"
        "41146041021654331579356245397864401930228576603456024321655258579877312286043888889253139495849609375e-"
        "250"},
    {1e-249, chars_format::scientific, 631,
        "1."
        "0000000000000000539995372538838999812031814994308058922469316265167934339105300857597200312381001123680024"
        "0744717132970355223235308008810593820667427471572510979116211218948405984136076892745036963302114054612243"
        "0854461935345268108985798815672273304709482272738880744620602127696868089805350874783651571183064358760376"
        "9262616075337441004446134274203111569857542644863728599183662806314628077729690816195581934052293080210797"
        "3863731922441113013326115432571346373407228177654197196588592111259890748199350234982379594256699490932245"
        "41146041021654331579356245397864401930228576603456024321655258579877312286043888889253139495849609375e-"
        "249"},
    {1e-248, chars_format::scientific, 627,
        "9."
        "9999999999999997956832950416318242122534275228707458502381648630896999234860610340310794424258705217009089"
        "8698848272667425745548990609185184495845165310180177834722241204343829645092988625380078670111672151364882"
        "9148361416301640127480267399121644956345623511904149536818776665133120926859682212462165144835562834902460"
        "8169361510425185931465252898513762884440053713780975011971591647787756942772620690104203449664476602519718"
        "9700853992572437403223688846888917164691719696961858690320903760636693836791272914631037540830957849203000"
        "4110801975159454895427578925929868094239082518686308263637652071764705397072248160839080810546875e-249"},
    {1e-247, chars_format::scientific, 625,
        "1."
        "0000000000000000192649736373475651198801900840970646155428112277531424945149655606599677239735273509423103"
        "7003128723642002653851117166460958647495402365980414154482350572975195241643580478648423385033005529523557"
        "5149303231611552864074838513650889193807852976016263375515864045811208624482972303132848544723293923634315"
        "8654632110666477212506316748172301771864558583903767420123294440264563632118557400842506525812231884230012"
        "1580030211621974019257700376892867533502801947273791910395557968168320778089912861340050868842351094793337"
        "57196262799956722460189534377628286140100146030563490161247042209424762404523789882659912109375e-247"},
    {1e-246, chars_format::scientific, 623,
        "9."
        "9999999999999995575034302425255280203243435320108056671241964144246649104879042904899207640402287290675921"
        "5899384894415865269771681975930543308379850300405799608661482489098955982287298928717585561980642265042467"
        "5741558876413307019519396756689296767305879762949059005814858389345741736077657721142372963397136994038042"
        "1143185752681434215306504148588209983916734438626955498414779994873029315724848699111686364589771258651477"
        "4041185118384055729611699893665062262489939831496222442140098208008785470326559495369354852275425989964775"
        "225952548028109435657040565491081726672244441155999912507201798916867119260132312774658203125e-247"},
    {1e-245, chars_format::scientific, 617,
        "9."
        "9999999999999993034449077901454787489333206084268694718026300691819608966232037640460181737622108169253875"
        "4246623957614200762275886100458926041750180956646462834196673192837757408627896585610926246640877052965224"
        "5440969500532418371027801404761458698996819764063629106077345561839203932576831597067927969862816097115995"
        "4981931611088099051403838815334286890025193878462668017287514231763986513540558575386334807176752225192019"
        "7337538319249781944425578343559617033474707974999543777413905618539016546097531848156893317816192006777335"
        "028483055241084311512275416582382971737136376395860271060200830106623470783233642578125e-246"},
    {1e-244, chars_format::scientific, 617,
        "9."
        "9999999999999993034449077901454787489333206084268694718026300691819608966232037640460181737622108169253875"
        "4246623957614200762275886100458926041750180956646462834196673192837757408627896585610926246640877052965224"
        "5440969500532418371027801404761458698996819764063629106077345561839203932576831597067927969862816097115995"
        "4981931611088099051403838815334286890025193878462668017287514231763986513540558575386334807176752225192019"
        "7337538319249781944425578343559617033474707974999543777413905618539016546097531848156893317816192006777335"
        "028483055241084311512275416582382971737136376395860271060200830106623470783233642578125e-245"},
    {1e-243, chars_format::scientific, 616,
        "9."
        "9999999999999999538347252682384048836943392928017461318258399130032831721168371117424088048739366720094313"
        "6077691955826461901465123541666266244322134476670364976826584991266425757195966583963974093910675995882966"
        "7010478302787493311166285505696724153868013361210329649405378400255940709538946474698507153310677593236434"
        "8354742213567037070994662068464330010387537712483243968973314585323136087132341292123234794154080950848231"
        "3698874125033522834502049511829556819753701527631041159112958647581624992123842625020794846031831003737181"
        "93400495677586862932287419778865178437101302218181775316452331026084721088409423828125e-244"},
    {1e-242, chars_format::scientific, 607,
        "9."
        "9999999999999996936787982770012344297899318190517954678165559754747542619193837726638525524292463299758138"
        "3345264756541557445789428565183330163293353068660804119774620271894958417768738584622754955002756418715869"
        "8382674781885463335110891865322617971919535922351649432074165264889245998754100523646275479931532994788259"
        "1005617972575461863158332767212312762242600178875013588298994443899476257695628205428474799363149460585746"
        "7154339802720026478471461044521580905242104106578442206433337435964581613713318314275234234745575404953243"
        "17179619616195490219863468530614425931746236386743476032279431819915771484375e-243"},
    {1e-241, chars_format::scientific, 607,
        "9."
        "9999999999999996936787982770012344297899318190517954678165559754747542619193837726638525524292463299758138"
        "3345264756541557445789428565183330163293353068660804119774620271894958417768738584622754955002756418715869"
        "8382674781885463335110891865322617971919535922351649432074165264889245998754100523646275479931532994788259"
        "1005617972575461863158332767212312762242600178875013588298994443899476257695628205428474799363149460585746"
        "7154339802720026478471461044521580905242104106578442206433337435964581613713318314275234234745575404953243"
        "17179619616195490219863468530614425931746236386743476032279431819915771484375e-242"},
    {1e-240, chars_format::scientific, 607,
        "9."
        "9999999999999996936787982770012344297899318190517954678165559754747542619193837726638525524292463299758138"
        "3345264756541557445789428565183330163293353068660804119774620271894958417768738584622754955002756418715869"
        "8382674781885463335110891865322617971919535922351649432074165264889245998754100523646275479931532994788259"
        "1005617972575461863158332767212312762242600178875013588298994443899476257695628205428474799363149460585746"
        "7154339802720026478471461044521580905242104106578442206433337435964581613713318314275234234745575404953243"
        "17179619616195490219863468530614425931746236386743476032279431819915771484375e-241"},
    {1e-239, chars_format::scientific, 606,
        "1."
        "0000000000000000759277475233108684608982384831531593387598582983591608678088152649529618962442697970945511"
        "2253728656481252609623707518885743635118724171586796539025946776244048864006266446992438854796959500679229"
        "8588215800350017811703378421629495689318049951191680360226281426735122753412882953915621641409250927003198"
        "6910763086367695391445593758514057541064426431653432522754100974317078691906840500853021173802680484470088"
        "3860075238691610755277275140661505025108160714320988751660906591874799129168282589108905049857407833757225"
        "6341803279636545528499519728434495081936805860323147499002516269683837890625e-239"},
    {1e-238, chars_format::scientific, 601,
        "9."
        "9999999999999999067985336682227244656284224215477550517729613770981251451531375480370058344319366581697533"
        "1183669118195751175878957889918151400872130798102236373871589770004064462227523761683081673596124136331155"
        "5882571426208406291495470335517085756171728640264680266111895065381642305829046326748263666763728249837004"
        "6626020550795760273417853730797965291922933006406875916147397503753738389970183566048822187095880537408774"
        "1443622319559242693331719116940274774410004713904731268468483132521263549307219829637997487511275991477045"
        "80579761285687302745881169393181442384133106315857730805873870849609375e-239"},
    {1e-237, chars_format::scientific, 601,
        "9."
        "9999999999999999067985336682227244656284224215477550517729613770981251451531375480370058344319366581697533"
        "1183669118195751175878957889918151400872130798102236373871589770004064462227523761683081673596124136331155"
        "5882571426208406291495470335517085756171728640264680266111895065381642305829046326748263666763728249837004"
        "6626020550795760273417853730797965291922933006406875916147397503753738389970183566048822187095880537408774"
        "1443622319559242693331719116940274774410004713904731268468483132521263549307219829637997487511275991477045"
        "80579761285687302745881169393181442384133106315857730805873870849609375e-238"},
    {1e-236, chars_format::scientific, 599,
        "1."
        "0000000000000000452385056269749738957374958363937411586701359205253954606231547212992278236358823898346238"
        "3764998428403048712490815296123929376907380178547230294435983168516337593604201381495751807319514549342628"
        "7108230683567514025983999121921492328385734199812203920124848335464217685194090758268935342505414810276179"
        "3301425115103972420368222739757723576790458504488844347543930933698064944859304528923691149969167209407572"
        "4362418556266763620337397978233213107947983026866003126727845611570636930442760770896667141459146949297798"
        "054884123959586342812486483601353004502243493334390223026275634765625e-236"},
    {1e-235, chars_format::scientific, 593,
        "9."
        "9999999999999995794466201073065157705805008561139611308159226802046274685060917490638423932758043140638622"
        "7303880018694909606461440847125465979951128205680196431578644620908477577938829729718419833836711322074076"
        "6762730180528365910488757805298383239560360625550264905029942091825321578161929573183609811789476338082131"
        "4793082190649381915259229530730403006333941783317935380572250403817591754796466532135968599538405603408604"
        "0135284373694206587306362717705160991368109381051551269182499342610200096234987102040793131263159890576484"
        "959971436813478787059179808682785051132668741047382354736328125e-236"},
    {1e-234, chars_format::scientific, 593,
        "9."
        "9999999999999995794466201073065157705805008561139611308159226802046274685060917490638423932758043140638622"
        "7303880018694909606461440847125465979951128205680196431578644620908477577938829729718419833836711322074076"
        "6762730180528365910488757805298383239560360625550264905029942091825321578161929573183609811789476338082131"
        "4793082190649381915259229530730403006333941783317935380572250403817591754796466532135968599538405603408604"
        "0135284373694206587306362717705160991368109381051551269182499342610200096234987102040793131263159890576484"
        "959971436813478787059179808682785051132668741047382354736328125e-235"},
    {1e-233, chars_format::scientific, 593,
        "9."
        "9999999999999995794466201073065157705805008561139611308159226802046274685060917490638423932758043140638622"
        "7303880018694909606461440847125465979951128205680196431578644620908477577938829729718419833836711322074076"
        "6762730180528365910488757805298383239560360625550264905029942091825321578161929573183609811789476338082131"
        "4793082190649381915259229530730403006333941783317935380572250403817591754796466532135968599538405603408604"
        "0135284373694206587306362717705160991368109381051551269182499342610200096234987102040793131263159890576484"
        "959971436813478787059179808682785051132668741047382354736328125e-234"},
    {1e-232, chars_format::scientific, 591,
        "1."
        "0000000000000000249863339080062911178038644222122371080935937931442510710279241545360881120763563354792727"
        "1204968809447263314062851575076488572199734151496053423339459628625623951696207510718204728166398876567257"
        "4288016505168108861079050506718628599358044231968538756452578178166866642842418468448402090677674425335611"
        "1758693995222916479276809189246877056722019580820408559743015166448682006363223901758949274685611426824095"
        "2441476048682580053244629262333867401903791102273486390772019414434805804812691972815986765285930166522083"
        "3572223445350350191397625909672797206440009176731109619140625e-232"},
    {1e-231, chars_format::scientific, 587,
        "9."
        "9999999999999998923077556279261669607276344269178857742052631307823063146668949873357937994367585330706658"
        "6851923787391180589072742468823861859572694416677687405759422064737433149483010905868112642822774129086708"
        "8950866453732969837296239860846071191436398749479988812794667280418882508284315291790468322783534698543322"
        "2763549146053280591430031966208307868080860328264805481772604325463231632253160358680946534953336313663699"
        "9465706559822283761704996673667467070947350147170430500500090250087867140451222327563027908008026052077180"
        "979022374130685442417121322478124056942760944366455078125e-232"},
    {1e-230, chars_format::scientific, 587,
        "1."
        "0000000000000000464396689151344957708425250099245062264974342811838633347646649480175933513559646247825963"
        "8716834667872150467156197971992950003945212977393024232997570081916752333744951362797040806496871754762409"
        "3523774421044995987488706419099041487486686846180862681556445048241853678050810632010015245717266998624378"
        "5448097443593469531357092784822504818670379709616765366682468006790097312245968621293462047399778104098730"
        "3938419284302791059489107019314139818789224754807352395205225648090417259273233816851797149977006703310702"
        "512814408808214904078592866198960109613835811614990234375e-230"},
    {1e-229, chars_format::scientific, 584,
        "1."
        "0000000000000000693232262560712474007504296368175932861281974684261164160838551277311989399208801333728083"
        "0729491583525363430455767462037175531140390391683126429966221232093955941263611471681132623382709491503904"
        "7375249531313675588992339392304815234823905634674008201667236376321839848939762273142402611092832410132397"
        "0716794455188726120242728620103174431415297180332879294084551036487606971854229655463609004961555893191674"
        "5535158735631016132816549960093097063467020650843476133267312297323069477364478450489994893647488342551896"
        "278779277366273448013345159779419191181659698486328125e-229"},
    {1e-228, chars_format::scientific, 582,
        "1."
        "0000000000000000327095345105724447928977822337886539907189763688385114859731508401894299982170153196284692"
        "3509240518480222689176456277966414687628106528818962914816379391810430169233755297466585716365369112717512"
        "1212889354883788226586526635175577239084355573084975369489970251393861975517439647330582826491927751719567"
        "4286879236636315578025711283654103051023429227187097010241218188971591516481012000791373872862711430642963"
        "8980375613505856015492641254846765471982547217185678152367973658550825928418487036668878503774717719765986"
        "2532354876733797777177414900506846606731414794921875e-228"},
    {1e-227, chars_format::scientific, 579,
        "9."
        "9999999999999994483667432137531853405142846651919968173684572982825965370746055008918453812773976664205546"
        "1806379623718849101061094361965886631986252579449704784567589751299683163621004793516731395237522036301698"
        "4232249314520585568125760180654060493094354252712965722645315515667150793038653453822153434497565715287762"
        "8550827121105302767048696761763317380829461396372195290172193549331544235852896295780095558254847205260583"
        "2488961204054717339152603622555696524198109764069629982095609254974414109481076434981991680800682250798021"
        "9193039241043496900829268270172178745269775390625e-228"},
    {1e-226, chars_format::scientific, 576,
        "9."
        "9999999999999992140391160425608486502573412858067853267494422609219249843660980606245241543726628584567845"
        "5596772807429948356873502783913017233507635857119058287608601973485118222629925278543631190326543612068785"
        "6793144185369306448728558535026937320361233858543155596710812316128092403135788648626506813051775901445653"
        "1399369722369875296859785808489260546321506496239188673574863325229045321464303305877790712822242644948835"
        "0538349222453692588279587908979174338697479788659722904339841966832055396226731386526846785614950264968197"
        "7558236700698302001910633407533168792724609375e-227"},
    {1e-225, chars_format::scientific, 573,
        "9."
        "9999999999999995889633195164685873546684506928231237117398663206989994686997099650522381174202385511988166"
        "5532143713492189547573649308797608271073422612848092682742982417988422128215652502500591518184109090841446"
        "0695712392011353039764081168030334396734226489214851798206017435390585826980372336939541407365039603593028"
        "6841701560346559249162043333727751481534234336451999260130591683793043584486052089721478465514409941447632"
        "1659328393015332189676413050701609835498487749315574228749069627859829337433683464055078617912121442295916"
        "4173920765250613840180449187755584716796875e-226"},
    {1e-224, chars_format::scientific, 572,
        "1."
        "0000000000000000188842045074720969281726225744049265127724544816342318643633489012136580458296359659586068"
        "0142873716319177545269388374861295393117868142201454771495799112919370837715281606083172804275621385687770"
        "2693982152263862758542091738083576971893101469828956572059834562621057530513170623824039675826626152702882"
        "9554943250110925357284565537410933697787459888079249619861975705749544080532085014387137886982187761584570"
        "7545289506591395555191133327745750663038010048636493634780383388550426764336480678810024954958759532602026"
        "627590152685343127814121544361114501953125e-224"},
    {1e-223, chars_format::scientific, 568,
        "9."
        "9999999999999997089390646281190637400800057030683519949368020198276633036864657744691065855954627728762669"
        "2711462403432106728597696196760677403094474374681383689185984160229479378003085214166818823098530044048697"
        "3944534218136807948895448410591421461173584131029794582684483073554583722610639117199712477545283988280188"
        "8583247748499098113898765741804068580802307245320098647828424758533523028653011700551458546375903476327247"
        "2418041727595056862123397096052789194474810296725446652560022479388716998619908128864112804247216219040786"
        "38909396659073536284267902374267578125e-224"},
    {1e-222, chars_format::scientific, 568,
        "1."
        "0000000000000000476783833342682112606713957768637813007397190494251111847601702954737064781916897791611948"
        "6665910201904757668715159627972431984802920565041444613042119531057224577664265456883067357455082414457510"
        "5873699390533971936733619876298237867358547303864542840334666315780417025464434651086480732669884805027801"
        "3972914335267534684821378915349249801611797386207593472909455643687259147132155320986333106388946209955678"
        "3727380706890529476578409498630033709192327460014863016495012072917359803021174598364193159679182279020795"
        "42079860630110488273203372955322265625e-222"},
    {1e-221, chars_format::scientific, 566,
        "1."
        "0000000000000000169645925856856893060060376942410028602413035104481732430035608082629881503388323784117675"
        "9708004617280138870373003624653886287005531314012122115392711085043513921718682682696513167396990650436454"
        "2482001003045855479995989862202599578862071747559917487508179112410433564183086355339876938703742242547888"
        "3927078511100484735448777978881712624199170721537360029658810376553696409425413660613858205688403865026496"
        "9133150093238119960431981583020131793294388887877935675999408142925964561757501084173080407977398016174108"
        "708042922444292344152927398681640625e-221"},
    {1e-220, chars_format::scientific, 562,
        "9."
        "9999999999999999239355998681967174227375122814278010784257107926662288959827321849441348805654645781222578"
        "1416801495804438316992788219990497287676199131886641172731843282325453969622164633472698153505172392196091"
        "7686422930553623146058858509260889480648913025162172052469893497144467951580077187425939035308281925639579"
        "8904098517668447759506972297076828822690693898011732750582941628468462192600203323158782851279699890831517"
        "4577656023161923475148392505322102605760380301683938036029249989328483687465622728201902066159706058967593"
        "37838375358842313289642333984375e-221"},
    {1e-219, chars_format::scientific, 558,
        "1."
        "0000000000000000317072121450052998442454095738999365116805429691571034550467333621241329477082039307714926"
        "8647799297899955893577238506246788221948278154506196914264427139130095036572562414306059178624874697166561"
        "2910016229040151379230052268968505957340380014586137656864892970028025625598133537298246759807490672538246"
        "6349079706700668711147626428386130469357231520579072082419120104777806523524649657592646158024664190592504"
        "0138380787791276528182266982512884712925399402503660799437298029321834277564064370984814528794254462340518"
        "3301656506955623626708984375e-219"},
    {1e-218, chars_format::scientific, 558,
        "1."
        "0000000000000000317072121450052998442454095738999365116805429691571034550467333621241329477082039307714926"
        "8647799297899955893577238506246788221948278154506196914264427139130095036572562414306059178624874697166561"
        "2910016229040151379230052268968505957340380014586137656864892970028025625598133537298246759807490672538246"
        "6349079706700668711147626428386130469357231520579072082419120104777806523524649657592646158024664190592504"
        "0138380787791276528182266982512884712925399402503660799437298029321834277564064370984814528794254462340518"
        "3301656506955623626708984375e-218"},
    {1e-217, chars_format::scientific, 556,
        "1."
        "0000000000000000820286869074829038147691322564690967085931469882169185788207623459701738560623254961593543"
        "2495631807748931332781026902083893493219520703392638894413217937078958575273805231533309563616052243338659"
        "9970974867100681381948985284062799729213005566035635834935809604029406528561494585049482415841618646905336"
        "1016177121015963348199695802694543380830079047974782555840977310449435712983375193946909035332432768524474"
        "9169568225199384279436574479448148011932581959092802554105295508219736240850467056635533661182457798588529"
        "84034456312656402587890625e-217"},
    {1e-216, chars_format::scientific, 552,
        "1."
        "0000000000000000417715070975008206383501541104137685510630637729690664798015391588933411293790282438490650"
        "1417365799869750981417996185414209276202526664283485310294185298719867744312810977751509255623110206400981"
        "0322207956652257379773838871987364711714905124876037292479076296828301806190805746848493891014316267411664"
        "5282499189563727638558040303247813051651801026058214177103491545912132361416394764863498733486217906178898"
        "1944618275272898078433128481899937372726835913821489150370897525101414670221344908114958355271895129590120"
        "6322014331817626953125e-216"},
    {1e-215, chars_format::scientific, 552,
        "1."
        "0000000000000000417715070975008206383501541104137685510630637729690664798015391588933411293790282438490650"
        "1417365799869750981417996185414209276202526664283485310294185298719867744312810977751509255623110206400981"
        "0322207956652257379773838871987364711714905124876037292479076296828301806190805746848493891014316267411664"
        "5282499189563727638558040303247813051651801026058214177103491545912132361416394764863498733486217906178898"
        "1944618275272898078433128481899937372726835913821489150370897525101414670221344908114958355271895129590120"
        "6322014331817626953125e-215"},
    {1e-214, chars_format::scientific, 548,
        "9."
        "9999999999999991294853170555815447380942404303671844696679748417593976294002496024747640399247703645613921"
        "9669145746563738570562978920712197817481457391341938411132808559707770852376293656497482700456956882004083"
        "4461538432173005728133703533459726557209837131653219566175297137847666946046014646053306115669486530319154"
        "9347298089165733677047427050182759982813113559251953651435370993927616364020573917965857675783303466730526"
        "8247784355081422352221012897456633272684485689532862584208239791227856442081540328491173763580945887952111"
        "661434173583984375e-215"},
    {1e-213, chars_format::scientific, 544,
        "9."
        "9999999999999995417188383097980764646245766459737448027760269658974031233570950381415311611617342282187547"
        "3910589667246545368520413459409764199735476351819671112511702776504860961416874815223117854304683340245916"
        "0464911595164867510407202793112181136390385649127508640932246203586979303121868349231428609901062896334351"
        "8460160107236627343777979364517278553598680503677613849707225222789602684066453511779979166688543657149232"
        "4631271842328641050496299912350310218151325193111111838448475138359469325323751129341864896105107618495821"
        "95281982421875e-214"},
    {1e-212, chars_format::scientific, 544,
        "9."
        "9999999999999995417188383097980764646245766459737448027760269658974031233570950381415311611617342282187547"
        "3910589667246545368520413459409764199735476351819671112511702776504860961416874815223117854304683340245916"
        "0464911595164867510407202793112181136390385649127508640932246203586979303121868349231428609901062896334351"
        "8460160107236627343777979364517278553598680503677613849707225222789602684066453511779979166688543657149232"
        "4631271842328641050496299912350310218151325193111111838448475138359469325323751129341864896105107618495821"
        "95281982421875e-213"},
    {1e-211, chars_format::scientific, 542,
        "1."
        "0000000000000000860866106323290977989521652535914737868721793763139020704019000432275185949120018591922314"
        "8748321021343152712198420398324197662294833702534841575692416427025554931034673452314515034661740800661978"
        "0367570571673882521368240042400003578976814090504523368015448321395277884576460019940142059144210726758298"
        "1962131856506348707731574677038773798011249472583972648417715875514795890821326821198516793758531226648909"
        "0505843180151974088497721836001007644364521160456150945201722824918063055169882569206407652018242515623569"
        "488525390625e-211"},
    {1e-210, chars_format::scientific, 537,
        "1."
        "0000000000000000438738980558973249501554588251133620087619148388021703078207190706152416416973367595537175"
        "6313997163865233296087579101561566864752022160981921747071217659225532903868917941661009994907733611338014"
        "3784825159783515874863433718211592230068725922315156166760336737063572299211892600734702315734897306878342"
        "0324974785855889196258366120050919096362807417474785044114678002479328491648628750791950753089834631150033"
        "5932174061457858893794332445675895125148716795289738221567522725371785895925880183199296880047768354415893"
        "5546875e-210"},
    {1e-209, chars_format::scientific, 537,
        "1."
        "0000000000000000438738980558973249501554588251133620087619148388021703078207190706152416416973367595537175"
        "6313997163865233296087579101561566864752022160981921747071217659225532903868917941661009994907733611338014"
        "3784825159783515874863433718211592230068725922315156166760336737063572299211892600734702315734897306878342"
        "0324974785855889196258366120050919096362807417474785044114678002479328491648628750791950753089834631150033"
        "5932174061457858893794332445675895125148716795289738221567522725371785895925880183199296880047768354415893"
        "5546875e-209"},
    {1e-208, chars_format::scientific, 532,
        "1."
        "0000000000000000979061701537299941966152430535653450847430534468171869639246307155589561418121080870910153"
        "8629931701436970148709455961417734285606820934169659127706352082009561098641084995297496445792862813672687"
        "8610739287003185182389585813172758756671078777597546184366879565008155448478538897317665187298818484324685"
        "9220535836288477370944073072995373114472813248014545177622566479964726762589682280912355285145766273388594"
        "1786470533386326343014670865292039149744946382702746507819298852791020659758203237288398668169975280761718"
        "75e-208"},
    {1e-207, chars_format::scientific, 532,
        "9."
        "9999999999999992500289944066545260794393352251899924160340990116913366439211345173906974144483983897166235"
        "2189411812074122203194500098779985388714648599688995096739219291006708753701504236607398029604493662017327"
        "1678140799002433983058991092970258715435496406938981280259425155854893708252707482521839982942707164963854"
        "7547404749041952119498108235731202565207945902873127503973233520114522955783109845270607825667850182252003"
        "0527218232152305055095879225203782710370117029811199918136152450494694154947694642032729461789131164550781"
        "25e-208"},
    {1e-206, chars_format::scientific, 531,
        "1."
        "0000000000000000287448618685041775611467192411468067474871960285579656441116238100310015816652007878432741"
        "7265535493345146977353453580801839986912678504489355280493380020846005009332711166642793788659897434684305"
        "8033569204162008468756111131622465602620067122836086961830504745239089017417231637691472711696999377193365"
        "7434217691734764507346368173226471971292005784923652206732469228783416975785133762358237484114173771323236"
        "6292971049317888008012637688183374798261772510814095901417025409694400162052829728054348379373550415039062"
        "5e-206"},
    {1e-205, chars_format::scientific, 526,
        "1."
        "0000000000000000010803385544138509069593097161793914125848530612542771161864210478198197576064378681441776"
        "8719777010108417708811052628555482267435021532617233741608191196380582573609361635180912725806711283088952"
        "9802701171025537783302721259002348340999662460931503272815954817331462444992708733840995721456271734340837"
        "6719690433913279361907286213318911514019682799687295018376430328310893061063314354936590363701536770497093"
        "609557125569051267401182441733990905766850296205863565885611603245575196297068032436072826385498046875e-"
        "205"},
    {1e-204, chars_format::scientific, 526,
        "1."
        "0000000000000000010803385544138509069593097161793914125848530612542771161864210478198197576064378681441776"
        "8719777010108417708811052628555482267435021532617233741608191196380582573609361635180912725806711283088952"
        "9802701171025537783302721259002348340999662460931503272815954817331462444992708733840995721456271734340837"
        "6719690433913279361907286213318911514019682799687295018376430328310893061063314354936590363701536770497093"
        "609557125569051267401182441733990905766850296205863565885611603245575196297068032436072826385498046875e-"
        "204"},
    {1e-203, chars_format::scientific, 520,
        "1."
        "0000000000000000364909283964494690243191939081376830412598520594029984319306805834501324924016544053590211"
        "8858347868651431172545325847430820148366422456613549311381232891696323291335249035452120486258789557131004"
        "5938212253440220260683060295956098435873780428169370394754578725053224457696098050769606268964403117192073"
        "6034285323924780348069311122000588899328256220789832219472160120915723671907243196436298677829712131554556"
        "674824299153355310153286540401954520562788798446562476933408003532122165779583156108856201171875e-203"},
    {1e-202, chars_format::scientific, 520,
        "1."
        "0000000000000000364909283964494690243191939081376830412598520594029984319306805834501324924016544053590211"
        "8858347868651431172545325847430820148366422456613549311381232891696323291335249035452120486258789557131004"
        "5938212253440220260683060295956098435873780428169370394754578725053224457696098050769606268964403117192073"
        "6034285323924780348069311122000588899328256220789832219472160120915723671907243196436298677829712131554556"
        "674824299153355310153286540401954520562788798446562476933408003532122165779583156108856201171875e-202"},
    {1e-201, chars_format::scientific, 518,
        "9."
        "9999999999999994583981840083828664387789037672445647185185462414227186362537617223653189132590007008902182"
        "5036064707813167053855864071099551731820360911829814527622461516880270539569772907578286195014691755833524"
        "6313038824586331185893923613544981929960384320404305625917015212855137051754213994323632673435867770929096"
        "1889224054953378234945273557754947929383082627673369846670918518473573081467853621970453936615832072474512"
        "2774033477753696070790004781196766668518623271037326465104921879856192390434443950653076171875e-202"},
    {1e-200, chars_format::scientific, 514,
        "9."
        "9999999999999998210026239908275959605441178928974709961505359824656249094749793672197213175620180419702157"
        "0455030299293624922494821832383011632557906373552085962098408476913455489082859886355453662043973282024133"
        "1540672308512679754268595351951382901471352304920064954568524027925980061836920599672604679919133131325752"
        "1270675728671148333244408622655324354942874459763350785891191594747038536509684958927467073288347769702934"
        "065739205278643004860546448479624082362272590048489495639927326919860206544399261474609375e-201"},
    {1e-199, chars_format::scientific, 514,
        "9."
        "9999999999999998210026239908275959605441178928974709961505359824656249094749793672197213175620180419702157"
        "0455030299293624922494821832383011632557906373552085962098408476913455489082859886355453662043973282024133"
        "1540672308512679754268595351951382901471352304920064954568524027925980061836920599672604679919133131325752"
        "1270675728671148333244408622655324354942874459763350785891191594747038536509684958927467073288347769702934"
        "065739205278643004860546448479624082362272590048489495639927326919860206544399261474609375e-200"},
    {1e-198, chars_format::scientific, 510,
        "9."
        "9999999999999991248020992245337152787549067716438909430971156796632448648902414890992687013002247470966205"
        "9250616363651145814708022930718768623141819087045324807904590313649740386017732887103292125347752751738164"
        "7903616019374090502989225614211093036170293774649807043557627102989961482478123917402578427471263639364172"
        "7258288515133029744510069298046601617868074142150587382588267288301984862829368791970001850877117631024364"
        "23213435887235808111997818538852504458228488519455634531141186016611754894256591796875e-199"},
    {1e-197, chars_format::scientific, 508,
        "9."
        "9999999999999998674159923085805213393300653009810429996874306693191169124472952257610848253128042616284553"
        "7868657895003123529680608425827294499852312192652536705711329687797703162620535019638931097823721317376531"
        "0449809394455252371020553334467402225824756206938082148635917156255047967127507045157273096748991097456524"
        "0871501542907022905826697910962572537414527814270868346111386548510042114755039370057964754782429778948172"
        "054646195039061999776584332685697351547605103705418372328495024703443050384521484375e-198"},
    {1e-196, chars_format::scientific, 507,
        "1."
        "0000000000000000461507106775817966187790192124450764644959682661043814550492938215090537724522867873253923"
        "2076309112008470570165867682191411520122070667713830622395672118711607338390277672566744227580449616988722"
        "4048676409452018186544561551067244957754832615276870223269854919886711715484701354736102883217117306393040"
        "5176207196512621743488000080129534927305169075196709311692988195667648791629557583252833507790667949728721"
        "83126556639724251347018692505234351971198612785141079939421615563333034515380859375e-196"},
    {1e-195, chars_format::scientific, 504,
        "1."
        "0000000000000000936779998349607922066558293583226541961177484254423572660929452606554100043890918762554297"
        "4707863770014997143924113153878357176231542226472692183855303438657076956092857009049025121818911605189577"
        "8451632785457212546098566525163648745892718210943319829994865483295677250502261874912403342050891863710951"
        "0047452830290157305812264311356157066156142110212407293358467828320964455752800500250463133640607927195845"
        "53190632391191156426420971847936254735776662183610596912330947816371917724609375e-195"},
    {1e-194, chars_format::scientific, 503,
        "1."
        "0000000000000000176343371831543992660529331249185298255229001705015959684231029580212400332902037339673698"
        "6497376317204554625910920399179244126456387732458513685519893326744325567768730070677375691037372424068209"
        "1406902583848901570812158566609402684872101257877000459234848581841332394474165042630322607916852572002294"
        "2253459816246100406093441541393561643994585254187290522693700416075659393155611833054255732280703963248447"
        "6108811118884410829937732489961321031245178314605936975567601621150970458984375e-194"},
    {1e-193, chars_format::scientific, 500,
        "1."
        "0000000000000000480518022438769564422940916182801795737608394724779004874910398790749080217297589908825938"
        "1781571298328731633116197501058889346366449530064185084854057371509426123098380846026035463349988096516756"
        "6224794664492225960926721750031101109280348039103528207538855342423070336885403775543154901570468288685756"
        "9371057021863723165980970649378599812859207996597337230959607380973781418194487299932738692824665548827406"
        "7792911966978292755019478367894242808178173476107986061833798885345458984375e-193"},
    {1e-192, chars_format::scientific, 497,
        "1."
        "0000000000000000967197463410330479242799452076588191709415423556399877179997389527607768032330474019469521"
        "4236283268127414844644640864066321698222548406233259323788719843133587011625822086583891099050173172434432"
        "5933421993521544985110022843505818588333542889065972604825266159353851044743385748203686571416253435379297"
        "2759212550851919581801017222154660883042604384453411964185058524810776658256688046938311429695004085753741"
        "4487473323928503835150271772586917651270965734511264599859714508056640625e-192"},
    {1e-191, chars_format::scientific, 493,
        "1."
        "0000000000000000188510357855833015531025794646529958154524177425806481491858204348633867528277859442439788"
        "2308744116449521706199131483254429935252790204362740541493259888534929589981916101691322081929877050966151"
        "0399618267074634546416741093946270621848431129126061569167008852264601912170614591946835899662997200669632"
        "7338163704470805316488942705712963170749170163883692391024336694671584274157166851729395050702462426671605"
        "977617515280816610694100232507863790232249812106601893901824951171875e-191"},
    {1e-190, chars_format::scientific, 493,
        "1."
        "0000000000000000188510357855833015531025794646529958154524177425806481491858204348633867528277859442439788"
        "2308744116449521706199131483254429935252790204362740541493259888534929589981916101691322081929877050966151"
        "0399618267074634546416741093946270621848431129126061569167008852264601912170614591946835899662997200669632"
        "7338163704470805316488942705712963170749170163883692391024336694671584274157166851729395050702462426671605"
        "977617515280816610694100232507863790232249812106601893901824951171875e-190"},
    {1e-189, chars_format::scientific, 491,
        "1."
        "0000000000000000686870105410711392306560935401767227629654574949386254732267282863177163850871532771738817"
        "4742369173523373314804257486974040663553435453559872562162354259478070339834015932022566252886866568705851"
        "2341252652000657227180441413664381320398902655487604631988293528801721357017188131951220329585081190883818"
        "0407634966154718446288670396235649706616968065048312917847198665960667399980860416663101533257689088484172"
        "6791405982325182252994934771483936941649517393670976161956787109375e-189"},
    {1e-188, chars_format::scientific, 487,
        "9."
        "9999999999999994908067112790032880452765975891977808893416208927947989552854944282732526766467167814211472"
        "9016690365461294541519550780469749156318868554867557125565277692145325401889763392275802425900917261305707"
        "6813301281782027933475606463409156438777709922199012812172103051126346893854116359406976977720796143697733"
        "0409039381133269347693239389812020205342531022532236534723299348668678980039958608222059751251451001340125"
        "954851991484343502465496900111219247264671139419078826904296875e-189"},
    {1e-187, chars_format::scientific, 485,
        "1."
        "0000000000000000128707188149247610317961577755901485817508529722976908703009114926888671969566618642923904"
        "7216709109600659513166516362808076647856712774459084699012968564021752699999664122051572781415038308837387"
        "0166622140883511824725097055580097338022374545962676401628454691080147578789025767146309768072347121843930"
        "4969827153068735740912975382850240786445034415743937927805593258116894299058323623937350272795835227254097"
        "9734347453266124169414530431510002017603255808353424072265625e-187"},
    {1e-186, chars_format::scientific, 482,
        "9."
        "9999999999999991080664251568566946816656094891755579324414755946855331066513221291040011008947756645194928"
        "3126449927134114187432183071903138762969913041033583206826632923302004443025636695331847192951237765064810"
        "1901549205550173745210388007974066273910088599742362089704636735321269557432431572173304555919191098852789"
        "8835500091400816510831330726597787609877843141587950888723719409168520573713992029531193965227310238619613"
        "6871547144152751022960767812719495850615203380584716796875e-187"},
    {1e-185, chars_format::scientific, 480,
        "9."
        "9999999999999999245790355507694271907023841025563002404951188973186335837375563673317377958322500472430223"
        "4358962862232098942818567516845240935447684803879394233469075096834422488602440315478951689910554023712058"
        "1713286968178129346842854046235591958961014087649883630968564875705434541798692451605139055762615194522001"
        "9525717242830049229470069208121483813535843954269093600189489946768858507209387397405040975412143865756706"
        "52490890549595435599083970146239153109490871429443359375e-186"},
    {1e-184, chars_format::scientific, 479,
        "1."
        "0000000000000000577789123865899613197931803793260894086938033539425113965406543757913927151782229553421845"
        "9534497321031048674712767507279892267342990221415604305478302883566035692506388321159663528747800703062985"
        "6556267717828049382814882687684481250700175447797590086397970738801276652929170115515060665563735447105737"
        "1607789096397343540438105999334044077646224460441400776936210637684912885400570369170411858356001076746638"
        "0795112258360497758946650037614745087921619415283203125e-184"},
    {1e-183, chars_format::scientific, 477,
        "1."
        "0000000000000000055221053213795464392148268040697219009783701825739929660071353845448175667022245948478787"
        "0655616493184777650368038902803597728304412828593472399773186584459960937589472889470248840942404462509561"
        "7848316501019860224310404861235743606856916216571508707757079337816690093929729419231423257573756304982907"
        "5883615198705872646445226736516527520612112408429807643402401323278491257656865065626485649704171724609864"
        "13789495760688630365820017686928622424602508544921875e-183"},
    {1e-182, chars_format::scientific, 473,
        "1."
        "0000000000000000473275509735478783436775096642748159071507167196688077104339505775420776854830232832433234"
        "1758721155461794469843821786384633359535274742851177924337279623744820741523005234821780591186721454952300"
        "8814677474466411551113987122394733721931523601552373810669792458604359341129281976258333183965739618681171"
        "2462954316859049361639530146770540766239402050039082150229448774803628559851829308461626616625635206319283"
        "2911879721902170814473720383830368518829345703125e-182"},
    {1e-181, chars_format::scientific, 473,
        "1."
        "0000000000000000473275509735478783436775096642748159071507167196688077104339505775420776854830232832433234"
        "1758721155461794469843821786384633359535274742851177924337279623744820741523005234821780591186721454952300"
        "8814677474466411551113987122394733721931523601552373810669792458604359341129281976258333183965739618681171"
        "2462954316859049361639530146770540766239402050039082150229448774803628559851829308461626616625635206319283"
        "2911879721902170814473720383830368518829345703125e-181"},
    {1e-180, chars_format::scientific, 467,
        "1."
        "0000000000000000205720657561601459248213926337435557432004149359281262740007888540238312094633121226702388"
        "0252734171604503705379320740892770555547523117726246388616260078602510467005544533796800271030358579788947"
        "8596206451460618701959694475252980048283774875164620144805656061300251022921568339761110831074870297914282"
        "5052177281241016263915175964207972289037936679409146465860138405827540686447052193047136397795898578025255"
        "0330804428568853836623020470142364501953125e-180"},
    {1e-179, chars_format::scientific, 467,
        "1."
        "0000000000000000205720657561601459248213926337435557432004149359281262740007888540238312094633121226702388"
        "0252734171604503705379320740892770555547523117726246388616260078602510467005544533796800271030358579788947"
        "8596206451460618701959694475252980048283774875164620144805656061300251022921568339761110831074870297914282"
        "5052177281241016263915175964207972289037936679409146465860138405827540686447052193047136397795898578025255"
        "0330804428568853836623020470142364501953125e-179"},
    {1e-178, chars_format::scientific, 462,
        "9."
        "9999999999999995207802359964755093254973303558352972348764236955198179673189484181712023085285155160314218"
        "7974074929298393483501980644336017773388789574064216571704500430381961642408451391728506514300696193707641"
        "2369206325657890081247052985700906437455381356119707601934668842017337283098214303282216076742448367510473"
        "2805880700588515337408292568477969874021853305965111138747038612487557305308227775860414375917728095925426"
        "92325167763556237332522869110107421875e-179"},
    {1e-177, chars_format::scientific, 462,
        "9."
        "9999999999999995207802359964755093254973303558352972348764236955198179673189484181712023085285155160314218"
        "7974074929298393483501980644336017773388789574064216571704500430381961642408451391728506514300696193707641"
        "2369206325657890081247052985700906437455381356119707601934668842017337283098214303282216076742448367510473"
        "2805880700588515337408292568477969874021853305965111138747038612487557305308227775860414375917728095925426"
        "92325167763556237332522869110107421875e-178"},
    {1e-176, chars_format::scientific, 455,
        "9."
        "9999999999999999591421057981561172760359517840594637610381681203271426218398700962941525716354631708608402"
        "1288165672816245368488365773674697953924112200111094852957684657993573180102527517321784079742545540384017"
        "1468635566584800121790983716471398626500096489256663663452679575447847968613394523652707106506451318955178"
        "4144051652154369610524111495583091804490661938365977391453819697791781023172096034811422121224133013894785"
        "9040854382328689098358154296875e-177"},
    {1e-175, chars_format::scientific, 455,
        "9."
        "9999999999999999591421057981561172760359517840594637610381681203271426218398700962941525716354631708608402"
        "1288165672816245368488365773674697953924112200111094852957684657993573180102527517321784079742545540384017"
        "1468635566584800121790983716471398626500096489256663663452679575447847968613394523652707106506451318955178"
        "4144051652154369610524111495583091804490661938365977391453819697791781023172096034811422121224133013894785"
        "9040854382328689098358154296875e-176"},
    {1e-174, chars_format::scientific, 455,
        "9."
        "9999999999999999591421057981561172760359517840594637610381681203271426218398700962941525716354631708608402"
        "1288165672816245368488365773674697953924112200111094852957684657993573180102527517321784079742545540384017"
        "1468635566584800121790983716471398626500096489256663663452679575447847968613394523652707106506451318955178"
        "4144051652154369610524111495583091804490661938365977391453819697791781023172096034811422121224133013894785"
        "9040854382328689098358154296875e-175"},
    {1e-173, chars_format::scientific, 451,
        "1."
        "0000000000000000408024660475077059817387500126561010283827794411329843068069293894692053641056977569406164"
        "5860179459417852569871442414611750645879228256918309821296094530706786339470126146992930030675499927138062"
        "6078645110929395600330796878478038262808188478558890667044712256648069091058093906931208992098479034123455"
        "6471433870655780438619471007693873666129072197794446443422556352914330611026469713197725405241789164989540"
        "950045920908451080322265625e-173"},
    {1e-172, chars_format::scientific, 451,
        "1."
        "0000000000000000408024660475077059817387500126561010283827794411329843068069293894692053641056977569406164"
        "5860179459417852569871442414611750645879228256918309821296094530706786339470126146992930030675499927138062"
        "6078645110929395600330796878478038262808188478558890667044712256648069091058093906931208992098479034123455"
        "6471433870655780438619471007693873666129072197794446443422556352914330611026469713197725405241789164989540"
        "950045920908451080322265625e-172"},
    {1e-171, chars_format::scientific, 446,
        "9."
        "9999999999999998334549904886182533644575182481590307346570727588463864968956314327427402721974391392681493"
        "8840349574834806876025069429390711572561024496770933912156771676252771920014882010591679536179058495704966"
        "6459647214626236474966227897344883106057195766283635621494235537958651944862482050868079918452516392716952"
        "5584371276921407873336343892803511244586645127284001019477731425013353998786167727604989180489880595814611"
        "2971007823944091796875e-172"},
    {1e-170, chars_format::scientific, 446,
        "9."
        "9999999999999998334549904886182533644575182481590307346570727588463864968956314327427402721974391392681493"
        "8840349574834806876025069429390711572561024496770933912156771676252771920014882010591679536179058495704966"
        "6459647214626236474966227897344883106057195766283635621494235537958651944862482050868079918452516392716952"
        "5584371276921407873336343892803511244586645127284001019477731425013353998786167727604989180489880595814611"
        "2971007823944091796875e-171"},
    {1e-169, chars_format::scientific, 445,
        "1."
        "0000000000000000201179579279951889494332706650336297646126334616435798702446775408390300828267543734556479"
        "1148767438721478692254625644809586029974902966311471906467144279997443046381416486456775682934766059213738"
        "8682880170721357697310494206530360280015299673863900909282408323621275688292229454267224632007317171976821"
        "9062755043188870164156569825065005551127725431170669760491634397165652335013242654640323869852380767042632"
        "214725017547607421875e-169"},
    {1e-168, chars_format::scientific, 442,
        "1."
        "0000000000000000495359250313018798398232857372078111175301744102507328466887690588908349273123627410787142"
        "8960553423711877095976320606305997928149943379618974718668317969895175729885359114774861866388254226928332"
        "6312412530128344937161591339967057855542963751652330786988796139481604083337014453611557944136969598140923"
        "2266209375586253665614918173692729092462974165924485487326723400897105883120943360144183831295094933011569"
        "082736968994140625e-168"},
    {1e-167, chars_format::scientific, 440,
        "1."
        "0000000000000000024671776660111744151992616217291209528621088924792880843782226300079471761353893528818080"
        "8461695847727239650021608667911738891069878718326970219146440066058803436279050909465923972862673158584982"
        "6105160755077165353399835926468341734698701227190842982658575634105078651265358454660624644729525716278361"
        "1140682443750440063281560815888371426326576190318380324390580994926780206148622231338007892986752267461270"
        "0939178466796875e-167"},
    {1e-166, chars_format::scientific, 438,
        "1."
        "0000000000000000401221755582437387548984809141120730845965613066964438942266597731142573770769680634393330"
        "4860781908514949606785378218627146120733930447360573818763942389127901271164097473713074287683138013259662"
        "6270962175118109020409240257267314631374111246760033226122752038406298996922683253821371284255480821768410"
        "8041103989219090945148246702131857559235694570803264454739494919703040747726479134382948643633426399901509"
        "28497314453125e-166"},
    {1e-165, chars_format::scientific, 435,
        "1."
        "0000000000000000099981772444576872831391054802057113792089993753227192463479100586292092163237050949933130"
        "7741513059884781641374362578054820337002689064133690939069940530672623003256060222315354035826766129519918"
        "6138321039085354086801716792628136314033783231104681031351410914965322720396823414492773972634716737376371"
        "0520766752844170239654897993137068652908399866415357150460363779882032314464193611946996043116087093949317"
        "93212890625e-165"},
    {1e-164, chars_format::scientific, 432,
        "9."
        "9999999999999996179977994240000492832410478595553265058890028512475980974191051545313215911848434547968112"
        "3506829020765128967167375531390990830327028509706783315595375571441777746032006200790016328565711155363281"
        "9260952214329461930296792492054510062892584060561175197172651174597606779554476715670182740414942023491074"
        "4882271746442971108655400587454064027847283393947054636137539561684188212445367760494718822883442044258117"
        "67578125e-165"},
    {1e-163, chars_format::scientific, 430,
        "9."
        "9999999999999992324106210075385904447210423055538966769282101296639226045711088091227051335430774586877556"
        "0380187758298979009906375332065220798567138804402682455512151783214215916809129382899197104804151043494558"
        "5563145673110198780120492144673027600936385460172667104099484794553110440023470772264137151669161743272965"
        "6621955120843986078340537112320766026857911177781841141364660971975280266688113073314525536261498928070068"
        "359375e-164"},
    {1e-162, chars_format::scientific, 428,
        "9."
        "9999999999999995408803637407077575155370467487550405400968443069308629988495058854495982996564902555750001"
        "0881500768271898975715175491525836823975050568645963143578730813796265380187430837211852483813399132989537"
        "2521390906085609300261532422578213570501344340483473578558017898588707511648275526988973622665785967447452"
        "7230208421323174102592427892427404427649408950714011937182963843742406623293916823058680165559053421020507"
        "8125e-163"},
    {1e-161, chars_format::scientific, 426,
        "1."
        "0000000000000000281207746300313758485495457412437785811701566332371519945117658868634141898328680968104386"
        "9208465199220690689365629587423131528495403880282983679493852048719318409229535432756222539343559454777748"
        "6122117946522659454860002908955065989745724565322940911725849734827414048354780693832858115305768410546622"
        "1669001634247322536079696576468333658954900360575122184714689073598350987914784582244465127587318420410156"
        "25e-161"},
    {1e-160, chars_format::scientific, 421,
        "9."
        "9999999999999998863664756018572246348509717251403216668457145854698362404413106109357186457035125880887139"
        "5442971339441569337421031670121726772431911744598437514213299328048160779171128466042026508303756993223913"
        "3914625567018069082819497533832021856414098286431576829951574975108576231868056852280790470182005098522878"
        "2311452117859864689754545566146839436535886456398043228499463060121588142692417022772133350372314453125e-"
        "161"},
    {1e-159, chars_format::scientific, 421,
        "9."
        "9999999999999998863664756018572246348509717251403216668457145854698362404413106109357186457035125880887139"
        "5442971339441569337421031670121726772431911744598437514213299328048160779171128466042026508303756993223913"
        "3914625567018069082819497533832021856414098286431576829951574975108576231868056852280790470182005098522878"
        "2311452117859864689754545566146839436535886456398043228499463060121588142692417022772133350372314453125e-"
        "160"},
    {1e-158, chars_format::scientific, 419,
        "1."
        "0000000000000000644461715342893769628088384244751452824968949939521068953419899265716691290743835877718806"
        "0499499819275101744539273894201213671647439569640272413320572395360660554036964212016080836775688509796677"
        "3034320905157843797711811812081180689521694123068341482158086593158645959509317701749254858130330879185409"
        "76318295429117517178155992347336913970321071383156146176302524197776477876686840318143367767333984375e-"
        "158"},
    {1e-157, chars_format::scientific, 416,
        "9."
        "9999999999999994315093317572352976389085242133736429719717733730390966126541574180671350586793186143106586"
        "9711755227455900472638007306987480806006421373515865542817844552713093922452020273570757392631880130378197"
        "6057475476281847746240325181644150833132392519880474034974000401221846213932984753153735603509222882524146"
        "59073461311052731967136774974327947162647755003431814598176263775286543022957630455493927001953125e-158"},
    {1e-156, chars_format::scientific, 415,
        "1."
        "0000000000000000401871238625762075230252412238475890854369514626224674485266750896186780044330932425037176"
        "5793834959969199405084179261500720553438080083182535241512814807342790321678611775084279817273188410444905"
        "7948606233651911993094255953297827568280003148852282666425949282551353691886113856462478598574449160998810"
        "7423610556951506838186752937735609011950981220659355323300554463372691316180862486362457275390625e-156"},
    {1e-155, chars_format::scientific, 412,
        "1."
        "0000000000000000143108063460821601205894042098448624752396783625375187052570059302021541381490502075510105"
        "1441125776709570242998744986620194560681429964294282258251206713457062073829702509023692063137188304469682"
        "8523843917378918068168863037262250905622199443021819929645002817903575273088029754823250588381508661599771"
        "7868176971927245633249316887604321134531113575159345409348876643207404413260519504547119140625e-155"},
    {1e-154, chars_format::scientific, 408,
        "9."
        "9999999999999997290869831969168427669206498744049989892404140240160071602553527513571595209458135162667908"
        "4767910834941635836620501468113529722707897740730774850326337632398968772714476833267516565195881349093261"
        "4442242113421277882882343716053282453697135136930795507954884744671298030110951922004857720728038625613094"
        "579483235888427705349419207394260530659325342359329547026192130942945368587970733642578125e-155"},
    {1e-153, chars_format::scientific, 408,
        "1."
        "0000000000000000391520711619164456269278077432874800210290605386190694987958883232420170497817315211056093"
        "7219726592638814238600761890505499513727814078427005122182350483587361191764655404441856307107748406205896"
        "8771615741000992236097240236656404501773691000619064156954711423965442555134190492396909478166731541022849"
        "184139321355053638998925549573035749685418651483935492674248735056607984006404876708984375e-153"},
    {1e-152, chars_format::scientific, 405,
        "1."
        "0000000000000000656494202988063501670221048456262720698710681931060570119040295424845374888565915888971814"
        "8716900796296674500576246587983158130310623800168576177042237171726346917561938492887898167343012514724525"
        "1702572352864538015220842582676835004335281995389457999418400603764767655983428612475478960604302612407465"
        "074615720461537986384519001106479628333213098383136507862900543841533362865447998046875e-152"},
    {1e-151, chars_format::scientific, 401,
        "9."
        "9999999999999993846214444173480837456947875440007023542943145156851694898495169012043938129726326349763533"
        "5304646187389452430939200400903967707131371358090351137147810686592154337349796683468972382137447938351093"
        "6339806159195182754275513217787685920396452204915675555926925407280071719070856360983454449039614697613088"
        "00329004750413118933670433745949010823799753266971634957371861673891544342041015625e-152"},
    {1e-150, chars_format::scientific, 401,
        "1."
        "0000000000000000062953582321729639972108793363873778804649710470552049825417932113812917053289050370440599"
        "4963230580103067513751160865633202829165130023467457014156090990295018891776024374768764400416020911642797"
        "7937229542290195469983973327591070678597318167103775792299736841014279430081135223499483319944143412505925"
        "47994858646301304824078966967156534016215353732892623384032049216330051422119140625e-150"},
    {1e-149, chars_format::scientific, 397,
        "9."
        "9999999999999997916207271599770174815431910359245482245075520886052976911905660287695077571624832762549010"
        "3901241955574186054882645354160804057843328684040882539795670216406975085596064922000175355351104645197224"
        "2159299717419245921614045252661498439742489884588924976169191208997705268115153885390281699280706354080788"
        "0810075377797307651794197530131880842681202370414439428714103996753692626953125e-150"},
    {1e-148, chars_format::scientific, 395,
        "9."
        "9999999999999993574881589011728214966382273112057792962800986774904942764267802927000528833599759255577835"
        "0731539802843803522676304070686845283750574203026982376971286717937832954133378800900225517256537491228018"
        "2618506588646911876452944415462765085773383026270792261244107687165562815801236526022999299023541920515241"
        "33144221481909121761385664308924357650265601904493451002053916454315185546875e-149"},
    {1e-147, chars_format::scientific, 392,
        "9."
        "9999999999999997047942135082161782845621982909807944388620614063823370082378088815556167824019818061154775"
        "3267301525028109548441377097466012303024777787838102507230793516713146659303527697780185387732191214403383"
        "0251141091664779112581825085221751768948668512925298433184174504631276777652370413516825219229273467367678"
        "73109447318760285566630713102839918271502739344214205630123615264892578125e-148"},
    {1e-146, chars_format::scientific, 392,
        "1."
        "0000000000000000260483900879485549145240551858620818666993201772609285379135454623724519020869191215007787"
        "9732452028052299918966549394031267953386350352353589471564600439475364858757576593278812118049323717148396"
        "6646335629649336669038803415683613046202912529157250830828828141257641911661418463350694669155844394233157"
        "85705380865772214765502279117310481526548215924776741303503513336181640625e-146"},
    {1e-145, chars_format::scientific, 388,
        "9."
        "9999999999999991491045261369468074238838447233407702107309210401553886373401631393867145439347723972231670"
        "9210082769533219907217260254619345072186052052140310298815582638672644731031289462772249594971145257322799"
        "4038925886836191534775616013607373075868211734278088558080067596686134438690556193526703746900102992403778"
        "8916508597979842347823863503257502127752331944066099822521209716796875e-146"},
    {1e-144, chars_format::scientific, 382,
        "9."
        "9999999999999995047459260545592047747179910066303857167348508745406355947146564143748119765537864189142457"
        "7406702773049949277600695034041212099922836522986897312201317600618565965125521933177328502338214669854372"
        "9214743617926487584571589819440575439439704072612302878146696017771025535626117294320381489190772096380674"
        "7888947723673401521480956499754455535367014817893505096435546875e-145"},
    {1e-143, chars_format::scientific, 382,
        "9."
        "9999999999999995047459260545592047747179910066303857167348508745406355947146564143748119765537864189142457"
        "7406702773049949277600695034041212099922836522986897312201317600618565965125521933177328502338214669854372"
        "9214743617926487584571589819440575439439704072612302878146696017771025535626117294320381489190772096380674"
        "7888947723673401521480956499754455535367014817893505096435546875e-144"},
    {1e-142, chars_format::scientific, 379,
        "1."
        "0000000000000000415187909843646941992853405491851801412104911250566867805593359198344341404058462314443407"
        "1999004998205277646578228806936119169092900476835416006646879910320012432440675705741433050519791236593520"
        "1126483700951764547204928276237357349018272445874789153751726477574834674378115371235219650945488500256152"
        "8285839188544891300604311457078665625886060297489166259765625e-142"},
    {1e-141, chars_format::scientific, 379,
        "1."
        "0000000000000000415187909843646941992853405491851801412104911250566867805593359198344341404058462314443407"
        "1999004998205277646578228806936119169092900476835416006646879910320012432440675705741433050519791236593520"
        "1126483700951764547204928276237357349018272445874789153751726477574834674378115371235219650945488500256152"
        "8285839188544891300604311457078665625886060297489166259765625e-141"},
    {1e-140, chars_format::scientific, 376,
        "9."
        "9999999999999998325050402186307901732467402213100953670680726099100791906309894166038425704554697413047438"
        "8736707768290967065346068526756404752685057091319111903737610941547926974466766577902649223367705840443471"
        "0752777238899304424063559278896454737707191411621114795520100770642861170561930404811834896485852742605782"
        "0477947621912585655923333405326047795824706554412841796875e-141"},
    {1e-139, chars_format::scientific, 375,
        "1."
        "0000000000000000298651335918643711628932072437743460203097543522435510082600885241996241637337863799815674"
        "5373938153930041458569504416084023430328021523294715043392256147086968485441875896151199424883187106083685"
        "5116242505539397726245213806567814973968761784932253618911783197472724962913730905084412418686107855057037"
        "903823030327416475360191583376945345662534236907958984375e-139"},
    {1e-138, chars_format::scientific, 373,
        "1."
        "0000000000000000671568372478654048793480338210890152071921120252455854796176801902310160890843779046624419"
        "0574152055610797260197422466810729794375634174624958125807052189432709115838035286839947026920320323715156"
        "2349014330858971553316300109510350574127195899948367330399601693799476039599761196766995561916125919694205"
        "6630578736140489704009581828358932398259639739990234375e-138"},
    {1e-137, chars_format::scientific, 370,
        "9."
        "9999999999999997765674847346292395985645003553380915867445361004070274835946019175567546824295824542834322"
        "0936386915769833362904191450666345206613638114323747280115416878029316028872527491869527820312006013996264"
        "9903619500919943683456929824482651337469540239096944228288373026152734555532884967287960181640825645650030"
        "4089424972613098230311834413441829383373260498046875e-138"},
    {1e-136, chars_format::scientific, 368,
        "1."
        "0000000000000000015234388133035855383875390450151974382791625207620048100283188580157663004673368212241028"
        "7021775588652667049332286697531726593651835908283730300757011154904205606340794759227751247334965860683767"
        "7619335918296521617671188216331487917848351857520007198181041140264394144632347883405649229831294125932790"
        "40680454942957577912920896778814494609832763671875e-136"},
    {1e-135, chars_format::scientific, 364,
        "1."
        "0000000000000000397101433570486440640372814601854186856466967779160881086984927240319116320263425424973183"
        "0906794623973760990199274781475873910436591263245899217149762302266244011866461975293028791820990275538393"
        "7825694267423765216591980590544644372410588391296507638744567280502987247158842902088614368498832624121250"
        "1922610289550874540509539656341075897216796875e-135"},
    {1e-134, chars_format::scientific, 364,
        "1."
        "0000000000000000397101433570486440640372814601854186856466967779160881086984927240319116320263425424973183"
        "0906794623973760990199274781475873910436591263245899217149762302266244011866461975293028791820990275538393"
        "7825694267423765216591980590544644372410588391296507638744567280502987247158842902088614368498832624121250"
        "1922610289550874540509539656341075897216796875e-134"},
    {1e-133, chars_format::scientific, 360,
        "1."
        "0000000000000000641496342650454815204531166058943602839619187024947014198474039982822446442241062041121761"
        "8993206806579261112354147155200128193178834690421687323641123036577948591402888993574806420292045901045354"
        "4357763610865201119901287710041064503330419772913467920705224010255686832775799714045712057246057262961864"
        "454953175851414926000870764255523681640625e-133"},
    {1e-132, chars_format::scientific, 354,
        "9."
        "9999999999999998594326335945560165992244413962574716935320854384313882417088792068117900519126248694463097"
        "1166878222416607214585555592825144884036557234591653828687686867804939368863225350731180091846678994230803"
        "4551417118526062293115049276525200843869593517391950184311224750470481588015379157829994532549384186718988"
        "143383057831670157611370086669921875e-133"},
    {1e-131, chars_format::scientific, 354,
        "9."
        "9999999999999998594326335945560165992244413962574716935320854384313882417088792068117900519126248694463097"
        "1166878222416607214585555592825144884036557234591653828687686867804939368863225350731180091846678994230803"
        "4551417118526062293115049276525200843869593517391950184311224750470481588015379157829994532549384186718988"
        "143383057831670157611370086669921875e-132"},
    {1e-130, chars_format::scientific, 352,
        "1."
        "0000000000000000860474181186106478814017048964495719560523575469171389466368285000105430231533024449190888"
        "5118632122193789221804912802057060030515884801171193467057382254521235894667527601955279175402111741499591"
        "1810497742588727689266426889109856940634588690842264333341972440114105661488593017559271586363570539363054"
        "8343253394705243408679962158203125e-130"},
    {1e-129, chars_format::scientific, 347,
        "9."
        "9999999999999992588077050396257392703488768553145229733371914199873875069132357308356059441403851215995624"
        "3155212422703836212507412136177871631363182768319485323556005461360487622175994949438213094542015941771738"
        "4419280934109333533385517507781179706383817482773534294846124960068136571893048547172361733897591462572052"
        "02346085570752620697021484375e-130"},
    {1e-128, chars_format::scientific, 350,
        "1."
        "0000000000000000540140885956810330905283414542659480243086298659334589074477275146251465374054496583672623"
        "2958009946209108101694078484369205457039971496303344480117025912844198468177541980552987602212529712035107"
        "7136783812753168822080851861443509146635347302329282152570500451292647260628735384990864503768808260741884"
        "90792948869056999683380126953125e-128"},
    {1e-127, chars_format::scientific, 346,
        "1."
        "0000000000000000283874249773373412578296507005190488789136477211465148760964467263168293488071674291258011"
        "1229512205421363205605411030218921798259240852409065290564740839502568526985553483431154343660864088463520"
        "9397812668884721728332391839310430911435954191518896407953322860235480539940849278936138837692998437844948"
        "9668128080666065216064453125e-127"},
    {1e-126, chars_format::scientific, 343,
        "9."
        "9999999999999994638210139863752739319384028852897161364970485782829397577234820373021434529266429555312521"
        "6983194349005795381216751769380140901609027919473718839974286048093527151711902926412879162955340930344432"
        "6331050085056910283373197684845805587978962369256620251783545688525470337396137395610167062504070045747539"
        "5523943006992340087890625e-127"},
    {1e-125, chars_format::scientific, 343,
        "1."
        "0000000000000000119863602615973784849024886181210334258608591484828706960316270217995063481042668024112659"
        "3323273651317206472108663859562740256639573240316726609251278392563925364622680845273181058187798089377705"
        "4044871136808915588333377425145260840908342600600249531398329201958893838700602171061114411404480151190909"
        "9644981324672698974609375e-125"},
    {1e-124, chars_format::scientific, 339,
        "9."
        "9999999999999993326124962604555717485211062261055925120747399969737863172049244011635594473034379418149707"
        "3733285916172541513242774404130688568651687022735009389466586472584381852808921821149092879170812937657908"
        "3507517828450461163381082371524445023758069641907445239343596422312776727474160532609971652195923752515227"
        "533876895904541015625e-125"},
    {1e-123, chars_format::scientific, 336,
        "1."
        "0000000000000000592214266429284712709327154154273179306528902377541659346183077708093965901286206073491272"
        "4893240687137177864579295711052543096504215963142662011434050239747217672227754043168144120350228166744854"
        "1461342749187237271530538937940950644027863982445952535876710937795463538272513841741184759115412816754542"
        "291164398193359375e-123"},
    {1e-122, chars_format::scientific, 336,
        "1."
        "0000000000000000592214266429284712709327154154273179306528902377541659346183077708093965901286206073491272"
        "4893240687137177864579295711052543096504215963142662011434050239747217672227754043168144120350228166744854"
        "1461342749187237271530538937940950644027863982445952535876710937795463538272513841741184759115412816754542"
        "291164398193359375e-122"},
    {1e-121, chars_format::scientific, 330,
        "9."
        "9999999999999997860691335212340624944112834802459237580782384539782206076370595916585057707372344692184393"
        "6804969460044266880960840178432795831352257161863989250421196205543988005817624520940738275930141680382536"
        "2705645307282349322073832894363067133705474907626194082336061086343845843364512571138646990220877341926097"
        "869873046875e-122"},
    {1e-120, chars_format::scientific, 330,
        "9."
        "9999999999999997860691335212340624944112834802459237580782384539782206076370595916585057707372344692184393"
        "6804969460044266880960840178432795831352257161863989250421196205543988005817624520940738275930141680382536"
        "2705645307282349322073832894363067133705474907626194082336061086343845843364512571138646990220877341926097"
        "869873046875e-121"},
    {1e-119, chars_format::scientific, 329,
        "1."
        "0000000000000000130024390228669006586108721634497552792083855061365287802750027321337635426438129020374848"
        "1664600942221067190062254340279232015505994888221071175236010018076668185817385530952343819169425474153069"
        "8485296570604075930318596366131621457117669193880841542694664169076444938015837959888187924661906436085700"
        "98876953125e-119"},
    {1e-118, chars_format::scientific, 325,
        "9."
        "9999999999999998548601848627210513127507711110962495648793617754556340466596531375943317018774133794497211"
        "2773177452477547884893180823304700696093795505933333750808977000588526776288870678657278259082964292612168"
        "7135109387034031318296259047753696621199718313862638351258177207227966550723285976687293441500514745712280"
        "2734375e-119"},
    {1e-117, chars_format::scientific, 324,
        "1."
        "0000000000000000295122913448237779750123491948538334728406551032911080056404251831583617661174558404929924"
        "3896970860405054631006016095048489183043964090797713855329077408887357490730484608804313415126102901088181"
        "6348367949744479609411978642945372534116287611377588167235972038088633907781943577219863072969019412994384"
        "765625e-117"},
    {1e-116, chars_format::scientific, 320,
        "9."
        "9999999999999999429127305798243970002253152785846665975847996269467232486085728763921888937368423845457617"
        "8012483682792147569926576848740738922962964586342094711305336418245536402492065760534449437518577236266098"
        "2404823409116184273460964524093702365192349873845287015478485841959641056142515935789560899138450622558593"
        "75e-117"},
    {1e-115, chars_format::scientific, 316,
        "1."
        "0000000000000000506449023169285809400062397950510535606899601876489694141081659204698474921637188017160421"
        "9554404355680558555414031141153138357492564670095816485848203669125039801019251428454834497950650007565124"
        "72130993150441963186515079572669739126745191857734238466488461104242357890825587674044072628021240234375e-"
        "115"},
    {1e-114, chars_format::scientific, 316,
        "1."
        "0000000000000000506449023169285809400062397950510535606899601876489694141081659204698474921637188017160421"
        "9554404355680558555414031141153138357492564670095816485848203669125039801019251428454834497950650007565124"
        "72130993150441963186515079572669739126745191857734238466488461104242357890825587674044072628021240234375e-"
        "114"},
    {1e-113, chars_format::scientific, 314,
        "9."
        "9999999999999997851225686547752015282709321304454232749766549970746913987161087044664288059247456074136569"
        "3103646918068384934346731171159358420413413594249595070095860341804175152335940173810558685761958841238256"
        "528149588154496617780581231049241207195755411835638060919569276852048034243125584907829761505126953125e-"
        "114"},
    {1e-112, chars_format::scientific, 311,
        "9."
        "9999999999999994965919868489709583795543458024193783422074762453086903017698885043736103596397686435149509"
        "2127488262573504686429299075010548358608520351566167154741389802025686009193310529515444168264142347473060"
        "254169697398616737432210540562148125004249902260523746627858543423172932307352311909198760986328125e-113"},
    {1e-111, chars_format::scientific, 310,
        "1."
        "0000000000000000881538779516831325493393960176944394019499534253785495567111745464819138901807658070228739"
        "7681304980894892987643297313652483665527200791644662114844284839296243389627793282213199385225366151754600"
        "23692731730268401631043898549001949195234763482210724552280700638817734215990640223026275634765625e-111"},
    {1e-110, chars_format::scientific, 307,
        "1."
        "0000000000000000512219634805401894263036729677071056505554985451525014163020583608700331290562887556438396"
        "0756356672991548315909866005345435977616174456581183341678912610204596779305536687743424726985645640552655"
        "11385789128593139162584753710767157743183492959649261329346803250928132911212742328643798828125e-110"},
    {1e-109, chars_format::scientific, 304,
        "9."
        "9999999999999999213090032671148042944651608772737164832437073679082439164747246389102391125712547343738461"
        "6764393803461968411363759120541596769585323204796173046143170436579622027899261365917852738020928226295429"
        "16946809659127192130501219695914914199014601235509201726525674303047708235681056976318359375e-110"},
    {1e-108, chars_format::scientific, 303,
        "1."
        "0000000000000000394037508497744476269322415917111588501092729834801660113711411814742312854964560992025486"
        "0940373214462478020955167986687180717484646029360870134265993496895269864002414577513096836348935076968032"
        "6744756749605705517267782736253202447852708639242959309800795608680346049368381500244140625e-108"},
    {1e-107, chars_format::scientific, 300,
        "1."
        "0000000000000000015854704313240738689436611885241290886813511861286927155922062074076653861049915985904174"
        "1529226147169453077100134326980763885063755062255867870544652334305423735032423824776047586311461273497240"
        "8684525827194158640497566304817959803162658537732665475772364516160450875759124755859375e-107"},
    {1e-106, chars_format::scientific, 298,
        "9."
        "9999999999999994107622176180347585616193254342488147039667631036633544234591024890115994707864839761100750"
        "4713908395006131669320804714504969531903295148878642485905064741616699286804386203967687862515031879439739"
        "78815635133568363766522001452157157165857837531619534132687476812861859798431396484375e-107"},
    {1e-105, chars_format::scientific, 295,
        "9."
        "9999999999999996527992122961171506127462400146458051771054626067127835164442863230376212268918567800277146"
        "8945249625681491309993020136626037259396997338350656973721648182191714512212327021484803062754864221652807"
        "34670414167907363879815853064012686426021044028278339510507066734135150909423828125e-106"},
    {1e-104, chars_format::scientific, 293,
        "9."
        "9999999999999992655400208111853233309431766860106204200835434018336969676679921885959864171232602937594912"
        "6175103656600915884917475461232328895407073835195433793215114677271690151559621713457418742371132474111899"
        "253027677129649636985456904850438396097599136336242509059957228600978851318359375e-105"},
    {1e-103, chars_format::scientific, 291,
        "9."
        "9999999999999995753473739991307851563856273489187682257010787657369662066890274961492942649381374827740700"
        "0391220431865376224977911201547295586599012637719612337620341481207709640081785959879326198678117872144625"
        "7279688487691888384356182054821891706276881794934752178960479795932769775390625e-104"},
    {1e-102, chars_format::scientific, 288,
        "9."
        "9999999999999993275014914487744156960316668185922499812070504746143508154721992501066479866862357315624070"
        "1018327011653807952929562609295322233645461595700269502096160038058894049264054562741800233632529553718444"
        "5480159114575574772754891649767885510036169449676890508271753787994384765625e-103"},
    {1e-101, chars_format::scientific, 287,
        "1."
        "0000000000000000517161727690484989105730677364159537554778386272002904693312974831111350122295364137378389"
        "3800821542866933565876163585210479432782250659739311511261223096517320888518916526900192486585135348216411"
        "421179001055338801084410855940271152519915887069146265275776386260986328125e-101"},
    {1e-100, chars_format::scientific, 281,
        "1."
        "0000000000000000199918998026028836196477607885341594201826030059365956992555434676176762886132929895827460"
        "7481091185079852827053974965402226843604196126360835628314127871794272492894246908066589163059300043457860"
        "230145025079449986855914338755579873208034769049845635890960693359375e-100"},
    {1e-99, chars_format::scientific, 281,
        "1."
        "0000000000000000199918998026028836196477607885341594201826030059365956992555434676176762886132929895827460"
        "7481091185079852827053974965402226843604196126360835628314127871794272492894246908066589163059300043457860"
        "230145025079449986855914338755579873208034769049845635890960693359375e-99"},
    {1e-98, chars_format::scientific, 279,
        "9."
        "9999999999999993877776100850210847487897500195676592182679981550153708786161318795442195615570982374570834"
        "5025814691449261356691720986931002153083765209119373679695640965032686000950926838525646548331616632759691"
        "8109804658117462243096325476277019816961910692043602466583251953125e-99"},
    {1e-97, chars_format::scientific, 278,
        "1."
        "0000000000000000362347275614230386486015179458496381198537636440236074215343295235503271551048096227501536"
        "2076793128266838165330935538744052169263360047450615280383040626852473271454077752909394064704527719494238"
        "439954420779105059740904555554141808215717901475727558135986328125e-97"},
    {1e-96, chars_format::scientific, 273,
        "9."
        "9999999999999990629210549086179841697146068732580852248447853932751364330404107608912022317267655741089325"
        "3111775827709554591152509520094495639900486787323780638317385863868670429754309941669548515427063112032127"
        "6147925518186447666098282116564632815425284206867218017578125e-97"},
    {1e-95, chars_format::scientific, 272,
        "9."
        "9999999999999998945538361602099216521469733278105946480082100633301366137142568246429265960924171922801988"
        "8411715318883203910932890875195952313649679547120498824245718922848550292017649197621159479662720125094691"
        "957033611640984498321327311742834353935904800891876220703125e-96"},
    {1e-94, chars_format::scientific, 269,
        "9."
        "9999999999999995619007236595731466591740267459895908787428401953081365414447183991422368503461565450116923"
        "4291739522413744183020738333155369644150002443201811549874385699256598347112313495240515093968457319869666"
        "220137187712048605636727671708285924978554248809814453125e-95"},
    {1e-93, chars_format::scientific, 266,
        "9."
        "9999999999999990296557436585543066704173122150759848479182484064729364258134569183411332571521395093820818"
        "7699778248062608618361294265890437372950519076931911910880252541509475235263776371431484076857636831509625"
        "041102909425751177341368247653008438646793365478515625e-94"},
    {1e-92, chars_format::scientific, 265,
        "9."
        "9999999999999998812477116601844506524280554645377544972375952686092566108234752876228990062625667663894586"
        "2246916287024425521816404773514329006869692462963751333270865593904872214221435769525933704234949612885690"
        "92755775468382706261394332614145241677761077880859375e-93"},
    {1e-91, chars_format::scientific, 264,
        "1."
        "0000000000000000221884498860836508245232352764322462356965334013463784684827482635335605305906737669192409"
        "3206577150260915228319844897656388566043736181737648710222711081486303100580449952876371355518587472543611"
        "7282139692787057416722973357536830008029937744140625e-91"},
    {1e-90, chars_format::scientific, 260,
        "9."
        "9999999999999999493750691003148621709889149244946960691831430175801622256242767571654402661914009469500487"
        "6210687330141370874092813614124240337583226333846298487062114638096503972538048521373489674425134635395776"
        "198474142304473133435749332420527935028076171875e-91"},
    {1e-89, chars_format::scientific, 259,
        "1."
        "0000000000000000385390156717149495889778415468219122129634648610993958160349406162237704329735939702537825"
        "6557882200608982112866183019402767285414984310749460027132610852092294722576437013319784788364231877946032"
        "19323390230766079866953077726066112518310546875e-89"},
    {1e-88, chars_format::scientific, 256,
        "9."
        "9999999999999993389539464367463749646836141632804995845510351868008479170090955900642705772290466891271611"
        "1095298783813540517696190402259434814389962850738675989092523202139483418021198264819388181521076833705412"
        "17106330922348433887236751616001129150390625e-89"},
    {1e-87, chars_format::scientific, 255,
        "1."
        "0000000000000000176102914661068871704759455207231397620617925926155336111681344047803017579234561099855692"
        "7468211736163456500646870223567402524619786705614341541487939145716625446421573575952215594321807039030933"
        "9980083880305983257130719721317291259765625e-87"},
    {1e-86, chars_format::scientific, 252,
        "1."
        "0000000000000000845822089240526869096820128042392116049471438517638926667419142813994015180838972628438518"
        "0555157222389138459748671170240569759164419042046720695550888606118767130117136575528437015257566523559248"
        "2227300337171982391737401485443115234375e-86"},
    {1e-85, chars_format::scientific, 248,
        "9."
        "9999999999999997742714099133940732695230515061349665633058183712651817782386647880884190182719141827059975"
        "6160444444280473251857896555635021838930073037549140490501694694753404362042357762064827417603513483139454"
        "631754006186383776366710662841796875e-86"},
    {1e-84, chars_format::scientific, 244,
        "1."
        "0000000000000000345765105554531564377414825658805446289260815782664512385801586401904736971641012020430008"
        "4916904592673962596952659796724604890704426897510544260517219675685168006291116202511525020958866108444773"
        "60160453827120363712310791015625e-84"},
    {1e-83, chars_format::scientific, 244,
        "1."
        "0000000000000000345765105554531564377414825658805446289260815782664512385801586401904736971641012020430008"
        "4916904592673962596952659796724604890704426897510544260517219675685168006291116202511525020958866108444773"
        "60160453827120363712310791015625e-83"},
    {1e-82, chars_format::scientific, 237,
        "9."
        "9999999999999996142531751338755757593133547433872322400384190960733692081210467362198499913285667881432745"
        "0118036029191910490910660160383934259858098175033375898393954117365887165799092568410709035847672154773135"
        "8441524207592010498046875e-83"},
    {1e-81, chars_format::scientific, 237,
        "9."
        "9999999999999996142531751338755757593133547433872322400384190960733692081210467362198499913285667881432745"
        "0118036029191910490910660160383934259858098175033375898393954117365887165799092568410709035847672154773135"
        "8441524207592010498046875e-82"},
    {1e-80, chars_format::scientific, 237,
        "9."
        "9999999999999996142531751338755757593133547433872322400384190960733692081210467362198499913285667881432745"
        "0118036029191910490910660160383934259858098175033375898393954117365887165799092568410709035847672154773135"
        "8441524207592010498046875e-81"},
    {1e-79, chars_format::scientific, 233,
        "9."
        "9999999999999999887872835092514419317813078520813578332402861996080345150934830450505121252485387470740823"
        "0432153096736340815962020317497336959217417624670274052264414348782613129120472130243434116803058486766531"
        "132161617279052734375e-80"},
    {1e-78, chars_format::scientific, 233,
        "9."
        "9999999999999999887872835092514419317813078520813578332402861996080345150934830450505121252485387470740823"
        "0432153096736340815962020317497336959217417624670274052264414348782613129120472130243434116803058486766531"
        "132161617279052734375e-79"},
    {1e-77, chars_format::scientific, 228,
        "9."
        "9999999999999992696817954285297788806428378833886366942927013608214771257064053320956408281221925859269313"
        "2229048327051034591863408815839603776447524281367429596833130704462499279543423371524601961368716729339212"
        "1791839599609375e-78"},
    {1e-76, chars_format::scientific, 228,
        "9."
        "9999999999999992696817954285297788806428378833886366942927013608214771257064053320956408281221925859269313"
        "2229048327051034591863408815839603776447524281367429596833130704462499279543423371524601961368716729339212"
        "1791839599609375e-77"},
    {1e-75, chars_format::scientific, 223,
        "9."
        "9999999999999995765001370096376884491285850700308643802436708920370749451782251562897192482294336146830490"
        "7462373028783431914145483056546903267762678774509976564483811726039081188696297508577970347687369212508201"
        "59912109375e-76"},
    {1e-74, chars_format::scientific, 223,
        "9."
        "9999999999999995765001370096376884491285850700308643802436708920370749451782251562897192482294336146830490"
        "7462373028783431914145483056546903267762678774509976564483811726039081188696297508577970347687369212508201"
        "59912109375e-75"},
    {1e-73, chars_format::scientific, 221,
        "9."
        "9999999999999999692276142334558126967903414689329158182609118919930401541021545312581396259667021314908797"
        "9761028647000900486666538084652246616646076525732436683076683433657106032411976404006281882175244390964508"
        "056640625e-74"},
    {1e-72, chars_format::scientific, 218,
        "9."
        "9999999999999996550456324544013132986609363498112746678471190920282679869630110312834033237768873180446152"
        "1922104152426925628649694062167971937539358324754468588202386067562686157439433287663632654584944248199462"
        "890625e-73"},
    {1e-71, chars_format::scientific, 215,
        "9."
        "9999999999999991523544616079141142616538881592166488271850506120846325195403814313238252402731836165305918"
        "9379824961108565855822743626193132450968609203189719636403510281811614357483364301515393890440464019775390"
        "625e-72"},
    {1e-70, chars_format::scientific, 214,
        "9."
        "9999999999999999566603349622936327208651652641680501722443601799944492674165887912591501738791095389530292"
        "1447471667217941492345864323752875629481807797693317959281711539013329237413074679352575913071632385253906"
        "25e-71"},
    {1e-69, chars_format::scientific, 210,
        "9."
        "9999999999999996349379856205418253371806544221874896342206363528305225682661058472850202004367391699840542"
        "86204129847741912377366160447289783580765283598918786301304310361326432854411905282177031040191650390625e-"
        "70"},
    {1e-68, chars_format::scientific, 210,
        "1."
        "0000000000000000664449503514147608964971089116525283355896552599755088005547651268002236115452324350684774"
        "05667000768594192052486210537605449626573422560856484483414528645350838331751219811849296092987060546875e-"
        "68"},
    {1e-67, chars_format::scientific, 207,
        "9."
        "9999999999999994290356820418206686116225674833199308898854531034456094808097967631415770174336221338439103"
        "32110954280101910747866971461536841043771495196989574594736115142890042761791846714913845062255859375e-"
        "68"},
    {1e-66, chars_format::scientific, 204,
        "9."
        "9999999999999997584793677677745193725155065855080248808217463024614704207398912977710861102386093916681406"
        "58660035188325913355065673838741549102961556640076313325245227492388266909983940422534942626953125e-67"},
    {1e-65, chars_format::scientific, 202,
        "9."
        "9999999999999992313694706062483581550868040220070744953236771840360929168517400423638715617506297791493721"
        "361815057351675091835477500352140162082574583311375313564306477331911082728765904903411865234375e-66"},
    {1e-64, chars_format::scientific, 200,
        "9."
        "9999999999999996530573883354692871290297660728078348037221324787763949199622610466896432005410134691643869"
        "5416432929769423252076208907803604252402073697828855693148231154054883518256247043609619140625e-65"},
    {1e-63, chars_format::scientific, 199,
        "1."
        "0000000000000000665108390885599516666492874994729659543878425186153119727427511457071495133637934325200422"
        "517323105847758368530076502780808905681852605731451018311606304678207379765808582305908203125e-63"},
    {1e-62, chars_format::scientific, 193,
        "1."
        "0000000000000000395228123538898122123169379282217172946503413797519326445436778014303001284812088763590813"
        "033814098767741265594259325793402808839764107397274361943573239841498434543609619140625e-62"},
    {1e-61, chars_format::scientific, 193,
        "1."
        "0000000000000000395228123538898122123169379282217172946503413797519326445436778014303001284812088763590813"
        "033814098767741265594259325793402808839764107397274361943573239841498434543609619140625e-61"},
    {1e-60, chars_format::scientific, 190,
        "9."
        "9999999999999997043346391313425520922612302581852072572233846426168156435405004008156570318179241258702127"
        "560310406428974820785673527056432009240175516617821216414085938595235347747802734375e-61"},
    {1e-59, chars_format::scientific, 186,
        "1."
        "0000000000000000257049426657387008116987749477410779808647407966538824285057522491605532434213255836046692"
        "97825748714277250889112093117585088725661479625017591388314031064510345458984375e-59"},
    {1e-58, chars_format::scientific, 186,
        "1."
        "0000000000000000257049426657387008116987749477410779808647407966538824285057522491605532434213255836046692"
        "97825748714277250889112093117585088725661479625017591388314031064510345458984375e-58"},
    {1e-57, chars_format::scientific, 184,
        "9."
        "9999999999999995495744986240501044053378048768020469428246581119186532239157342153944919191472312470207982"
        "938076356229324745710523507339850487508903231770318598137237131595611572265625e-58"},
    {1e-56, chars_format::scientific, 182,
        "1."
        "0000000000000000398544412264054388859317738397532526381811957937462858497285880146847740537226460753851871"
        "9151474574467405157551346472642240549577596908648047246970236301422119140625e-56"},
    {1e-55, chars_format::scientific, 179,
        "9."
        "9999999999999999457604583227187704838617738531429373476853980305059490181551356500726746075842050168752993"
        "1709955247404289379029075578142991831409602809799253009259700775146484375e-56"},
    {1e-54, chars_format::scientific, 176,
        "1."
        "0000000000000000307987621475787265184226545488654608574986645956071476601459731247492727351298009606456557"
        "3955378764522009913621658689676652276290269583114422857761383056640625e-54"},
    {1e-53, chars_format::scientific, 176,
        "1."
        "0000000000000000307987621475787265184226545488654608574986645956071476601459731247492727351298009606456557"
        "3955378764522009913621658689676652276290269583114422857761383056640625e-53"},
    {1e-52, chars_format::scientific, 169,
        "1."
        "0000000000000000076162237057823428575993091641927138989513847283709538948144790065143893595321174669124552"
        "225337349106179808916165796528474629667471162974834442138671875e-52"},
    {1e-51, chars_format::scientific, 169,
        "1."
        "0000000000000000076162237057823428575993091641927138989513847283709538948144790065143893595321174669124552"
        "225337349106179808916165796528474629667471162974834442138671875e-51"},
    {1e-50, chars_format::scientific, 169,
        "1."
        "0000000000000000076162237057823428575993091641927138989513847283709538948144790065143893595321174669124552"
        "225337349106179808916165796528474629667471162974834442138671875e-50"},
    {1e-49, chars_format::scientific, 165,
        "9."
        "9999999999999993639946561258385225154999214247803524229414097622136664771612907529682762969603377416406323"
        "42481329099202736442053573995281112729571759700775146484375e-50"},
    {1e-48, chars_format::scientific, 160,
        "9."
        "9999999999999997438173659562304724144296122072586385917800431070114651283524903861286055227527841029653896"
        "133378731029238417615800926796509884297847747802734375e-49"},
    {1e-47, chars_format::scientific, 160,
        "9."
        "9999999999999997438173659562304724144296122072586385917800431070114651283524903861286055227527841029653896"
        "133378731029238417615800926796509884297847747802734375e-48"},
    {1e-46, chars_format::scientific, 159,
        "1."
        "0000000000000000229990434539132168285059616408830844887893493788352647401877225916573826931767115445461078"
        "92003424942768685657057403659564442932605743408203125e-46"},
    {1e-45, chars_format::scientific, 156,
        "9."
        "9999999999999998410519796728108115885556130475730798510027332432797015830574374922176498045556503714645274"
        "74677148367876444723378881462849676609039306640625e-46"},
    {1e-44, chars_format::scientific, 154,
        "9."
        "9999999999999995299012157797537262313524103585668678214901248072213449280016067527327081027864783122672863"
        "183914675200281152456227573566138744354248046875e-45"},
    {1e-43, chars_format::scientific, 152,
        "1."
        "0000000000000000774504271351982067660165221114591715939540558551454771548224929710672474909863166549056250"
        "9435341909114214331566472537815570831298828125e-43"},
    {1e-42, chars_format::scientific, 150,
        "1."
        "0000000000000000376231293568868998402945121672663764541764419753300075029753466364131749531598626313283782"
        "26348851942617557142511941492557525634765625e-42"},
    {1e-41, chars_format::scientific, 148,
        "1."
        "0000000000000000057612911342378542997169042119121403423543508714776317814976295686899169228986994124665807"
        "319451982237978882039897143840789794921875e-41"},
    {1e-40, chars_format::scientific, 142,
        "9."
        "9999999999999992929287939988014500233064511906197367398133222223193004995110860615409765027190768719826674"
        "537642929863068275153636932373046875e-41"},
    {1e-39, chars_format::scientific, 142,
        "9."
        "9999999999999992929287939988014500233064511906197367398133222223193004995110860615409765027190768719826674"
        "537642929863068275153636932373046875e-40"},
    {1e-38, chars_format::scientific, 138,
        "9."
        "9999999999999996191940173987276763588211566534471145248715351257676278874429088350271387325933882331274737"
        "96457707067020237445831298828125e-39"},
    {1e-37, chars_format::scientific, 138,
        "1."
        "0000000000000000663242732278491600632468214134494723437057816416802275528824741710182857868191184588790854"
        "09307663212530314922332763671875e-37"},
    {1e-36, chars_format::scientific, 134,
        "9."
        "9999999999999994103842744227748915040917451572375927424342788675606983591665422599959949054738289619947977"
        "3713392205536365509033203125e-37"},
    {1e-35, chars_format::scientific, 134,
        "1."
        "0000000000000000078575451945823803039225861945108062446233498893822872849650915300095655152256418629619361"
        "1269700340926647186279296875e-35"},
    {1e-34, chars_format::scientific, 130,
        "9."
        "9999999999999992767460389181651091970649217996634988016744348623082634610696676519760628561173110284698850"
        "591666996479034423828125e-35"},
    {1e-33, chars_format::scientific, 127,
        "1."
        "0000000000000000559673099762419019344522426032374800632968937312731638482799663888967410529939883190309046"
        "767652034759521484375e-33"},
    {1e-32, chars_format::scientific, 127,
        "1."
        "0000000000000000559673099762419019344522426032374800632968937312731638482799663888967410529939883190309046"
        "767652034759521484375e-32"},
    {1e-31, chars_format::scientific, 117,
        "1."
        "0000000000000000833364206075859853509313360268686545023645097835488625154102063086192231367022031918168067"
        "93212890625e-31"},
    {1e-30, chars_format::scientific, 117,
        "1."
        "0000000000000000833364206075859853509313360268686545023645097835488625154102063086192231367022031918168067"
        "93212890625e-30"},
    {1e-29, chars_format::scientific, 119,
        "9."
        "9999999999999994320657417510427825855837769787704137433831559589728533970337791964011486811614304315298795"
        "7000732421875e-30"},
    {1e-28, chars_format::scientific, 117,
        "9."
        "9999999999999997123254346160061967703296936367536399994355443342760077484474359743593652183335507288575172"
        "42431640625e-29"},
    {1e-27, chars_format::scientific, 111,
        "1."
        "0000000000000000384948697491918390813719893615913383013961276435003578191840212241459084907546639442443847"
        "65625e-27"},
    {1e-26, chars_format::scientific, 111,
        "1."
        "0000000000000000384948697491918390813719893615913383013961276435003578191840212241459084907546639442443847"
        "65625e-26"},
    {1e-25, chars_format::scientific, 111,
        "1."
        "0000000000000000384948697491918390813719893615913383013961276435003578191840212241459084907546639442443847"
        "65625e-25"},
    {1e-24, chars_format::scientific, 107,
        "9."
        "9999999999999992370049955170282463130006189848140882691706936497618579684498740789422299712896347045898437"
        "5e-25"},
    {1e-23, chars_format::scientific, 105,
        "9."
        "999999999999999604346980148993092553230786866765862587503680141039208439934782290947623550891876220703125e"
        "-24"},
    {1e-22, chars_format::scientific, 103,
        "1."
        "0000000000000000485967743265708723529783189783450120951502847720104849571498561999760568141937255859375e-"
        "22"},
    {1e-21, chars_format::scientific, 100,
        "9.9999999999999990753745222789637139672993451167553075691041795935998237609965144656598567962646484375e-"
        "22"},
    {1e-20, chars_format::scientific, 98,
        "9.99999999999999945153271454209571651729503702787392447107715776066783064379706047475337982177734375e-21"},
    {1e-19, chars_format::scientific, 94,
        "9.9999999999999997524592683526013185572915905567688179926555402943222361500374972820281982421875e-20"},
    {1e-18, chars_format::scientific, 92,
        "1.00000000000000007154242405462192450852805618492324772617063644020163337700068950653076171875e-18"},
    {1e-17, chars_format::scientific, 92,
        "1.00000000000000007154242405462192450852805618492324772617063644020163337700068950653076171875e-17"},
    {1e-16, chars_format::scientific, 87,
        "9.999999999999999790977867240346035618411149408467364363417573258630000054836273193359375e-17"},
    {1e-15, chars_format::scientific, 86,
        "1.00000000000000007770539987666107923830718560119501514549256171449087560176849365234375e-15"},
    {1e-14, chars_format::scientific, 84,
        "9.999999999999999988193093545598986971343290729163921781719182035885751247406005859375e-15"},
    {1e-13, chars_format::scientific, 82,
        "1.0000000000000000303737455634003709136034716842278413651001756079494953155517578125e-13"},
    {1e-12, chars_format::scientific, 79,
        "9.9999999999999997988664762925561536725284350612952266601496376097202301025390625e-13"},
    {1e-11, chars_format::scientific, 77,
        "9.99999999999999939496969281939810930172340963650867706746794283390045166015625e-12"},
    {1e-10, chars_format::scientific, 76,
        "1.0000000000000000364321973154977415791655470655996396089904010295867919921875e-10"},
    {1e-09, chars_format::scientific, 73,
        "1.0000000000000000622815914577798564188970686927859787829220294952392578125e-09"},
    {1e-08, chars_format::scientific, 70,
        "1.0000000000000000209225608301284726753266340892878361046314239501953125e-08"},
    {1e-07, chars_format::scientific, 65, "9.99999999999999954748111825886258685613938723690807819366455078125e-08"},
    {1e-06, chars_format::scientific, 65, "9.99999999999999954748111825886258685613938723690807819366455078125e-07"},
    {1e-05, chars_format::scientific, 64, "1.0000000000000000818030539140313095458623138256371021270751953125e-05"},
    {1e-04, chars_format::scientific, 62, "1.00000000000000004792173602385929598312941379845142364501953125e-04"},
    {1e-03, chars_format::scientific, 57, "1.000000000000000020816681711721685132943093776702880859375e-03"},
    {1e-02, chars_format::scientific, 57, "1.000000000000000020816681711721685132943093776702880859375e-02"},
    {1e-01, chars_format::scientific, 54, "1.000000000000000055511151231257827021181583404541015625e-01"},
    {1e+00, chars_format::scientific, 0, "1e+00"},
    {1e+01, chars_format::scientific, 0, "1e+01"},
    {1e+02, chars_format::scientific, 0, "1e+02"},
    {1e+03, chars_format::scientific, 0, "1e+03"},
    {1e+04, chars_format::scientific, 0, "1e+04"},
    {1e+05, chars_format::scientific, 0, "1e+05"},
    {1e+06, chars_format::scientific, 0, "1e+06"},
    {1e+07, chars_format::scientific, 0, "1e+07"},
    {1e+08, chars_format::scientific, 0, "1e+08"},
    {1e+09, chars_format::scientific, 0, "1e+09"},
    {1e+10, chars_format::scientific, 0, "1e+10"},
    {1e+11, chars_format::scientific, 0, "1e+11"},
    {1e+12, chars_format::scientific, 0, "1e+12"},
    {1e+13, chars_format::scientific, 0, "1e+13"},
    {1e+14, chars_format::scientific, 0, "1e+14"},
    {1e+15, chars_format::scientific, 0, "1e+15"},
    {1e+16, chars_format::scientific, 0, "1e+16"},
    {1e+17, chars_format::scientific, 0, "1e+17"},
    {1e+18, chars_format::scientific, 0, "1e+18"},
    {1e+19, chars_format::scientific, 0, "1e+19"},
    {1e+20, chars_format::scientific, 0, "1e+20"},
    {1e+21, chars_format::scientific, 0, "1e+21"},
    {1e+22, chars_format::scientific, 0, "1e+22"},
    {1e+23, chars_format::scientific, 22, "9.9999999999999991611392e+22"},
    {1e+24, chars_format::scientific, 23, "9.99999999999999983222784e+23"},
    {1e+25, chars_format::scientific, 25, "1.0000000000000000905969664e+25"},
    {1e+26, chars_format::scientific, 26, "1.00000000000000004764729344e+26"},
    {1e+27, chars_format::scientific, 27, "1.000000000000000013287555072e+27"},
    {1e+28, chars_format::scientific, 27, "9.999999999999999583119736832e+27"},
    {1e+29, chars_format::scientific, 28, "9.9999999999999991433150857216e+28"},
    {1e+30, chars_format::scientific, 30, "1.000000000000000019884624838656e+30"},
    {1e+31, chars_format::scientific, 30, "9.999999999999999635896294965248e+30"},
    {1e+32, chars_format::scientific, 32, "1.00000000000000005366162204393472e+32"},
    {1e+33, chars_format::scientific, 32, "9.99999999999999945575230987042816e+32"},
    {1e+34, chars_format::scientific, 32, "9.99999999999999945575230987042816e+33"},
    {1e+35, chars_format::scientific, 34, "9.9999999999999996863366107917975552e+34"},
    {1e+36, chars_format::scientific, 36, "1.000000000000000042420637374017961984e+36"},
    {1e+37, chars_format::scientific, 36, "9.999999999999999538762658202121142272e+36"},
    {1e+38, chars_format::scientific, 37, "9.9999999999999997748809823456034029568e+37"},
    {1e+39, chars_format::scientific, 38, "9.99999999999999939709166371603178586112e+38"},
    {1e+40, chars_format::scientific, 40, "1.0000000000000000303786028427003666890752e+40"},
    {1e+41, chars_format::scientific, 41, "1.00000000000000000620008645040778319495168e+41"},
    {1e+42, chars_format::scientific, 42, "1.000000000000000044885712678075916785549312e+42"},
    {1e+43, chars_format::scientific, 43, "1.0000000000000000139372116959414099130712064e+43"},
    {1e+44, chars_format::scientific, 44, "1.00000000000000008821361405306422640701865984e+44"},
    {1e+45, chars_format::scientific, 44, "9.99999999999999929757289024535551219930759168e+44"},
    {1e+46, chars_format::scientific, 45, "9.999999999999999931398190359470212947659194368e+45"},
    {1e+47, chars_format::scientific, 47, "1.00000000000000004384584304507619735463404765184e+47"},
    {1e+48, chars_format::scientific, 47, "1.00000000000000004384584304507619735463404765184e+48"},
    {1e+49, chars_format::scientific, 48, "9.999999999999999464902769475481793196872414789632e+48"},
    {1e+50, chars_format::scientific, 49, "1.0000000000000000762976984109188700329496497094656e+50"},
    {1e+51, chars_format::scientific, 50, "9.99999999999999993220948674361627976461708441944064e+50"},
    {1e+52, chars_format::scientific, 50, "9.99999999999999993220948674361627976461708441944064e+51"},
    {1e+53, chars_format::scientific, 50, "9.99999999999999993220948674361627976461708441944064e+52"},
    {1e+54, chars_format::scientific, 54, "1.000000000000000078291540404596243842305360299886116864e+54"},
    {1e+55, chars_format::scientific, 55, "1.0000000000000000102350670204085511496304388135324745728e+55"},
    {1e+56, chars_format::scientific, 56, "1.00000000000000009190283508143378238084034459715684532224e+56"},
    {1e+57, chars_format::scientific, 57, "1.000000000000000048346692115553659057528394845890514255872e+57"},
    {1e+58, chars_format::scientific, 57, "9.999999999999999438119489974413630815797154428513196965888e+57"},
    {1e+59, chars_format::scientific, 58, "9.9999999999999997168788049560464200849936328366177157906432e+58"},
    {1e+60, chars_format::scientific, 59, "9.99999999999999949387135297074018866963645011013410073083904e+59"},
    {1e+61, chars_format::scientific, 59, "9.99999999999999949387135297074018866963645011013410073083904e+60"},
    {1e+62, chars_format::scientific, 62, "1.00000000000000003502199685943161173046080317798311825604870144e+62"},
    {1e+63, chars_format::scientific, 63, "1.000000000000000057857959942726969827393378689175040438172647424e+63"},
    {1e+64, chars_format::scientific, 64, "1.0000000000000000213204190094543968723012578712679649467743338496e+64"},
    {1e+65, chars_format::scientific, 64, "9.9999999999999999209038626283633850822756121694230455365568299008e+64"},
    {1e+66, chars_format::scientific, 65, "9.99999999999999945322333868247445125709646570021247924665841614848e+65"},
    {1e+67, chars_format::scientific, 66, "9.999999999999999827367757839185598317239782875580932278577147150336e+66"},
    {1e+68, chars_format::scientific, 67, "9.9999999999999995280522225138166806691251291352861698530421623488512e+67"},
    {1e+69, chars_format::scientific, 68, "1.00000000000000007253143638152923512615837440964652195551821015547904e+69"},
    {1e+70, chars_format::scientific, 68, "1.00000000000000007253143638152923512615837440964652195551821015547904e+70"},
    {1e+71, chars_format::scientific, 71,
        "1.00000000000000004188152556421145795899143386664033828314342771180699648e+71"},
    {1e+72, chars_format::scientific, 71,
        "9.99999999999999943801810948794571024057224129020550531544123892056457216e+71"},
    {1e+73, chars_format::scientific, 72,
        "9.999999999999999830336967949613257980309080240684656321838454199566729216e+72"},
    {1e+74, chars_format::scientific, 73,
        "9.9999999999999995164818811802792197885196090803013355167206819763650035712e+73"},
    {1e+75, chars_format::scientific, 74,
        "9.99999999999999926539781176481198923508803215199467887262646419780362305536e+74"},
    {1e+76, chars_format::scientific, 76,
        "1.0000000000000000470601344959054695891559601407866630764278709534898249531392e+76"},
    {1e+77, chars_format::scientific, 76,
        "9.9999999999999998278261272554585856747747644714015897553975120217811154108416e+76"},
    {1e+78, chars_format::scientific, 78,
        "1.000000000000000008493621433689702976148869924598760615894999102702796905906176e+78"},
    {1e+79, chars_format::scientific, 78,
        "9.999999999999999673560075006595519222746403606649979913266024618633003221909504e+78"},
    {1e+80, chars_format::scientific, 80,
        "1.00000000000000000026609864708367276537402401181200809098131977453489758916313088e+80"},
    {1e+81, chars_format::scientific, 80,
        "9.99999999999999921281879895665782741935503249059183851809998224123064148429897728e+80"},
    {1e+82, chars_format::scientific, 81,
        "9.999999999999999634067965630886574211027143225273567793680363843427086501542887424e+81"},
    {1e+83, chars_format::scientific, 83,
        "1.00000000000000003080666323096525690777025204007643346346089744069413985291331436544e+83"},
    {1e+84, chars_format::scientific, 84,
        "1.000000000000000057766609898115896702437267127096064137098041863234712334016924614656e+84"},
    {1e+85, chars_format::scientific, 85,
        "1.0000000000000000146306952306748730309700429878646550592786107871697963642511482159104e+85"},
    {1e+86, chars_format::scientific, 85,
        "1.0000000000000000146306952306748730309700429878646550592786107871697963642511482159104e+86"},
    {1e+87, chars_format::scientific, 86,
        "9.99999999999999959416724456350362731491996089648451439669739009806703922950954425516032e+86"},
    {1e+88, chars_format::scientific, 86,
        "9.99999999999999959416724456350362731491996089648451439669739009806703922950954425516032e+87"},
    {1e+89, chars_format::scientific, 88,
        "9.9999999999999999475366575191804932315794610450682175621941694731908308538307845136842752e+88"},
    {1e+90, chars_format::scientific, 89,
        "9.99999999999999966484112715463900049825186092620125502979674597309179755437379230686511104e+89"},
    {1e+91, chars_format::scientific, 90,
        "1.000000000000000079562324861280497143156226140166910515938643997348793075220176113414176768e+91"},
    {1e+92, chars_format::scientific, 92,
        "1.00000000000000004337729697461918607329029332495193931179177378933611681288968111094132375552e+92"},
    {1e+93, chars_format::scientific, 92,
        "1.00000000000000004337729697461918607329029332495193931179177378933611681288968111094132375552e+93"},
    {1e+94, chars_format::scientific, 94,
        "1.0000000000000000202188791271559469885760963232143577411377768562080040049981643093586978275328e+94"},
    {1e+95, chars_format::scientific, 94,
        "1.0000000000000000202188791271559469885760963232143577411377768562080040049981643093586978275328e+95"},
    {1e+96, chars_format::scientific, 96,
        "1.000000000000000049861653971908893017010268485438462151574892930611988399099305815384459015356416e+96"},
    {1e+97, chars_format::scientific, 97,
        "1.0000000000000000735758738477112498397576062152177456799245857901351759143802190202050679656153088e+97"},
    {1e+98, chars_format::scientific, 97,
        "9.9999999999999999769037024514370800696612547992403838920556863966097586548129676477911932478685184e+97"},
    {1e+99, chars_format::scientific, 98,
        "9.99999999999999967336168804116691273849533185806555472917961779471295845921727862608739868455469056e+98"},
    {1e+100, chars_format::scientific, 100,
        "1.0000000000000000159028911097599180468360808563945281389781327557747838772170381060813469985856815104e+"
        "100"},
    {1e+101, chars_format::scientific, 100,
        "9.9999999999999997704951326524533662844684271992415000612999597473199345218078991130326129448151154688e+"
        "100"},
    {1e+102, chars_format::scientific, 100,
        "9.9999999999999997704951326524533662844684271992415000612999597473199345218078991130326129448151154688e+"
        "101"},
    {1e+103, chars_format::scientific, 103,
        "1."
        "0000000000000000019156750857346687362159551272651920111528035145993793242039887559612361451081803235328e+"
        "103"},
    {1e+104, chars_format::scientific, 103,
        "1."
        "0000000000000000019156750857346687362159551272651920111528035145993793242039887559612361451081803235328e+"
        "104"},
    {1e+105, chars_format::scientific, 104,
        "9."
        "99999999999999938258300825281978540327027364472124478294416212538871491824599713636820527503908255301632e+"
        "104"},
    {1e+106, chars_format::scientific, 106,
        "1."
        "0000000000000000910359990503684350104604539951754865571545457374840902895351334152154180097541612190564352"
        "e+106"},
    {1e+107, chars_format::scientific, 106,
        "9."
        "9999999999999996881384047029926983435371269061279689406644211752791525136670645395254002395395884805259264"
        "e+106"},
    {1e+108, chars_format::scientific, 108,
        "1."
        "0000000000000000339989917130028245949439747197128980477134307148378752717232008332927416163807334459213086"
        "72e+108"},
    {1e+109, chars_format::scientific, 108,
        "9."
        "9999999999999998185087071883998078647176509643281712479583983698990725543800532982058034243931376762633584"
        "64e+108"},
    {1e+110, chars_format::scientific, 110,
        "1."
        "0000000000000000235693675141702558332495327950568818631299125392682816684661617325983093615924495102623141"
        "0688e+110"},
    {1e+111, chars_format::scientific, 110,
        "9."
        "9999999999999995681977264164181575840510447725837828179539621562288260762111148815394293094743232204474889"
        "0112e+110"},
    {1e+112, chars_format::scientific, 111,
        "9."
        "9999999999999993011993469263043972846733315013897684926158968616472298328309139037619635868942544675772280"
        "34048e+111"},
    {1e+113, chars_format::scientific, 113,
        "1."
        "0000000000000000155594161294668430242682013969210614333697705804308337811647557032649853899150474476762062"
        "8086784e+113"},
    {1e+114, chars_format::scientific, 113,
        "1."
        "0000000000000000155594161294668430242682013969210614333697705804308337811647557032649853899150474476762062"
        "8086784e+114"},
    {1e+115, chars_format::scientific, 113,
        "1."
        "0000000000000000155594161294668430242682013969210614333697705804308337811647557032649853899150474476762062"
        "8086784e+115"},
    {1e+116, chars_format::scientific, 113,
        "1."
        "0000000000000000155594161294668430242682013969210614333697705804308337811647557032649853899150474476762062"
        "8086784e+116"},
    {1e+117, chars_format::scientific, 117,
        "1."
        "0000000000000000505554277259950338142282370308030032790204814747222327639770854058242333771050622192524171"
        "13236701184e+117"},
    {1e+118, chars_format::scientific, 117,
        "9."
        "9999999999999996656499989432737591832415150948634284945877532842287520522749411968203820784902676746951111"
        "55514343424e+117"},
    {1e+119, chars_format::scientific, 118,
        "9."
        "9999999999999994416755247254933381274972870380190006824232035607637985622760311004411949604741731366073618"
        "283536318464e+118"},
    {1e+120, chars_format::scientific, 119,
        "9."
        "9999999999999998000346834739420118166880519289700851818864831183077241462742872546478943492999243975477607"
        "5181077037056e+119"},
    {1e+121, chars_format::scientific, 121,
        "1."
        "0000000000000000373409337471459889719393275754491820381027730410378005080671497101378613371421126415052399"
        "029342192009216e+121"},
    {1e+122, chars_format::scientific, 122,
        "1."
        "0000000000000000144059475872452738558311186224283126301371231493549892706912613162686325762572645608050543"
        "7183296233537536e+122"},
    {1e+123, chars_format::scientific, 122,
        "9."
        "9999999999999997770996973140412967005798429759492157739208332266249129088983988607786655884150763168475752"
        "2070951350501376e+122"},
    {1e+124, chars_format::scientific, 123,
        "9."
        "9999999999999994835318744673121432143947683772820873519605146130849290704870274192525374490890208838852004"
        "22613425626021888e+123"},
    {1e+125, chars_format::scientific, 124,
        "9."
        "9999999999999992486776161899288204254467086983483846143922597222529419997579302660316349376281765375153005"
        "841365553228283904e+124"},
    {1e+126, chars_format::scientific, 124,
        "9."
        "9999999999999992486776161899288204254467086983483846143922597222529419997579302660316349376281765375153005"
        "841365553228283904e+125"},
    {1e+127, chars_format::scientific, 126,
        "9."
        "9999999999999995492910667849794735953002250873835241184796259825178854502911746221543901522980573008687723"
        "77386949310916067328e+126"},
    {1e+128, chars_format::scientific, 126,
        "1."
        "0000000000000000751744869165182086274714290643524082134829091023577659252424152046645411010977580354282659"
        "55038852526326677504e+128"},
    {1e+129, chars_format::scientific, 128,
        "9."
        "9999999999999999821744356418524141598892886875941250043654333972994040190590464949711576614226856000977717"
        "5966751665376232210432e+128"},
    {1e+130, chars_format::scientific, 130,
        "1."
        "0000000000000000597830782460516151851749290252338090708736359498322008205751130936310560341066601403445681"
        "992244323541365884452864e+130"},
    {1e+131, chars_format::scientific, 130,
        "9."
        "9999999999999991202555500957231813912852864969525730182461368558677581576901282770959939099212034754106974"
        "340599870111173348163584e+130"},
    {1e+132, chars_format::scientific, 131,
        "9."
        "9999999999999999082956740236127656368660884998248491198409222651766915166559963620104293398654157036960225"
        "3175829982724989462249472e+131"},
    {1e+133, chars_format::scientific, 133,
        "1."
        "0000000000000000223511723594768599335098409300973759560478836428900264860242343595976203511843100595010152"
        "570837624953702918544949248e+133"},
    {1e+134, chars_format::scientific, 133,
        "9."
        "9999999999999992148203649670699315007549827372972461504375111049848301607660324472857261615145089428049364"
        "457837845490532419930947584e+133"},
    {1e+135, chars_format::scientific, 134,
        "9."
        "9999999999999996182969084181493986344923533627678515144540412345510040405565569067619171016459456036870228"
        "9580532071091311261383655424e+134"},
    {1e+136, chars_format::scientific, 136,
        "1."
        "0000000000000000586640612700740119755462042863897304388093713545509821352053815609504775357961393589804030"
        "375857007499376802103616864256e+136"},
    {1e+137, chars_format::scientific, 137,
        "1."
        "0000000000000000328415624892049260789870125663596116955123134262587470068987879955440013156277274126839495"
        "0478432243557864849063421149184e+137"},
    {1e+138, chars_format::scientific, 137,
        "1."
        "0000000000000000328415624892049260789870125663596116955123134262587470068987879955440013156277274126839495"
        "0478432243557864849063421149184e+138"},
    {1e+139, chars_format::scientific, 137,
        "1."
        "0000000000000000328415624892049260789870125663596116955123134262587470068987879955440013156277274126839495"
        "0478432243557864849063421149184e+139"},
    {1e+140, chars_format::scientific, 140,
        "1."
        "0000000000000000592838012408148700370636248876704532886485007448299957782847398065202329650801812456915179"
        "2237293382948229697163514582401024e+140"},
    {1e+141, chars_format::scientific, 141,
        "1."
        "0000000000000000169762192382389597041410451735731067396306010351159977440672169089582623259562551128794084"
        "54231155599236459402033650892537856e+141"},
    {1e+142, chars_format::scientific, 142,
        "1."
        "0000000000000000508222848402996879704791089448509839788449208028871961714412352270078388372553960191290960"
        "287445781834331294577148468377157632e+142"},
    {1e+143, chars_format::scientific, 143,
        "1."
        "0000000000000000237454323586511053574086579278286821874734649886702374295420205725681776282160832941293459"
        "6913384011607579341316989008157343744e+143"},
    {1e+144, chars_format::scientific, 143,
        "1."
        "0000000000000000237454323586511053574086579278286821874734649886702374295420205725681776282160832941293459"
        "6913384011607579341316989008157343744e+144"},
    {1e+145, chars_format::scientific, 144,
        "9."
        "9999999999999998908706118214091961267848062604013589451800154647253023991102581488541128064576300612966589"
        "28320953898584032761523454337112604672e+144"},
    {1e+146, chars_format::scientific, 145,
        "9."
        "9999999999999993363366729972462242111019694317846182578926003895619873650143420259298512453325054533017777"
        "074930382791057905692427399713177731072e+145"},
    {1e+147, chars_format::scientific, 146,
        "9."
        "9999999999999997799638240565766017436482388946780108077225324496926393922910749242692604942326051396976826"
        "8415537077468838432306731146395363835904e+146"},
    {1e+148, chars_format::scientific, 148,
        "1."
        "0000000000000000489767265751505205795722270035307438887450423745901682635933847561612315292472764637931130"
        "646815102767620534329186625852171022761984e+148"},
    {1e+149, chars_format::scientific, 148,
        "1."
        "0000000000000000489767265751505205795722270035307438887450423745901682635933847561612315292472764637931130"
        "646815102767620534329186625852171022761984e+149"},
    {1e+150, chars_format::scientific, 149,
        "9."
        "9999999999999998083559617243737459057312001403031879309116481015410011220367858297629826861622115196270206"
        "0266176005440567032331208403948233373515776e+149"},
    {1e+151, chars_format::scientific, 151,
        "1."
        "0000000000000000171775323872177191180393104084305455107732328445200031262781885420082626742861173182722545"
        "959543542834786931126445173006249634549465088e+151"},
    {1e+152, chars_format::scientific, 152,
        "1."
        "0000000000000000462510813590419947400122627239507268849188872720127255375377965092338341988220342513198966"
        "2450489690590919397689516441796634752009109504e+152"},
    {1e+153, chars_format::scientific, 152,
        "9."
        "9999999999999999973340300412315374485553901911843668628584018802436967952242376167291975956456715844366937"
        "8824028710020392594094129030220133015859757056e+152"},
    {1e+154, chars_format::scientific, 154,
        "1."
        "0000000000000000369475456880582265409809179829842688451922778552150543659347219597216513109705408327446511"
        "753687232667314337003349573404171046192448274432e+154"},
    {1e+155, chars_format::scientific, 155,
        "1."
        "0000000000000000071762315409101683040806148118916031180671277214625066168048834012826660698457618933038657"
        "3813296762136260081534229469225952733653677113344e+155"},
    {1e+156, chars_format::scientific, 155,
        "9."
        "9999999999999998335918022319172171456037227501747053636700761446046841750101255453147787694593874175123738"
        "8344363105067534507348164573733465510370326085632e+155"},
    {1e+157, chars_format::scientific, 155,
        "9."
        "9999999999999998335918022319172171456037227501747053636700761446046841750101255453147787694593874175123738"
        "8344363105067534507348164573733465510370326085632e+156"},
    {1e+158, chars_format::scientific, 157,
        "9."
        "9999999999999995287335453651211007997446182781858083179085387749785952239205787068995699003416510776387310"
        "061494932420984963311567802202010637287727642443776e+157"},
    {1e+159, chars_format::scientific, 158,
        "9."
        "9999999999999992848469398716842077230573347005946906812993088792777240630489412361674028050474620057398167"
        "0431418299523701733729688780649419062882836695482368e+158"},
    {1e+160, chars_format::scientific, 160,
        "1."
        "0000000000000000065284077450682265568456642148886267118448844545520511777838181142510337509988867035816342"
        "470187175785193750117648543530356184548650438281396224e+160"},
    {1e+161, chars_format::scientific, 161,
        "1."
        "0000000000000000377458932482281488706616365128202897693308658812017626863753877105047511391965429047846952"
        "7765363729011764432297892058199009821165792668120252416e+161"},
    {1e+162, chars_format::scientific, 161,
        "9."
        "9999999999999993784993963811639746645052515943896798537572531592268585888236500249285549696404306093489997"
        "9621894213003182527093908649335762989920701551401238528e+161"},
    {1e+163, chars_format::scientific, 161,
        "9."
        "9999999999999993784993963811639746645052515943896798537572531592268585888236500249285549696404306093489997"
        "9621894213003182527093908649335762989920701551401238528e+162"},
    {1e+164, chars_format::scientific, 164,
        "1."
        "0000000000000000017833499485879183651456364256030139271070152777012950284778995356204687079928429609987689"
        "7036220978235643807646031628623453753183252563447406133248e+164"},
    {1e+165, chars_format::scientific, 164,
        "9."
        "9999999999999989948989345183348492723345839974054042033695133885552035712504428261628757034676312089657858"
        "5177704871391229197474064067196498264773607101557544845312e+164"},
    {1e+166, chars_format::scientific, 165,
        "9."
        "9999999999999994040727605053525830239832961008552982304497691439383022566618638381796002540519505693745473"
        "92515068357773127490685649548117139715971745147241514401792e+165"},
    {1e+167, chars_format::scientific, 167,
        "1."
        "0000000000000000386089942874195144027940205149135043895442382956857739101649274267019739175454317034355575"
        "0902863155030391327289536708508823166797373630632400726786048e+167"},
    {1e+168, chars_format::scientific, 167,
        "9."
        "9999999999999993386049483474297456237195021643033151861169282230770064669960364762569243259584594717091455"
        "4599698521475539380813444812793279458505403728617494385000448e+167"},
    {1e+169, chars_format::scientific, 167,
        "9."
        "9999999999999993386049483474297456237195021643033151861169282230770064669960364762569243259584594717091455"
        "4599698521475539380813444812793279458505403728617494385000448e+168"},
    {1e+170, chars_format::scientific, 170,
        "1."
        "0000000000000000344190543093124528091771377029741774747069364767506509796263144755389226581474482731849717"
        "9085147422915077831721209019419643357959500300321574675254607872e+170"},
    {1e+171, chars_format::scientific, 170,
        "9."
        "9999999999999995397220672965687021173298771373910070983074155319629071328494581320833847770616641237372600"
        "1850053663010587168093173889073910282723323583537144858509574144e+170"},
    {1e+172, chars_format::scientific, 172,
        "1."
        "0000000000000000826871628571058023676436276965152235336326534308832671394311356729372731664122173896717192"
        "642523265688348930066834399772699475577180106550229078889679814656e+172"},
    {1e+173, chars_format::scientific, 173,
        "1."
        "0000000000000000140391862557997052178246197057012913609383004294502130454865010810818413324356568684461228"
        "5763778101906192989276863139689872767772084421689716760605683089408e+173"},
    {1e+174, chars_format::scientific, 174,
        "1."
        "0000000000000000689575675368445829376798260983524370990937828305966563206422087545661867996169052854265999"
        "82929417458880300383900478261195703581718577367397759832385751351296e+174"},
    {1e+175, chars_format::scientific, 174,
        "9."
        "9999999999999993715345246233687641002733075598968732752062506784519246026851033820375767838190908467345488"
        "22294900033162112051840457868829614121240178061963384891963422539776e+174"},
    {1e+176, chars_format::scientific, 176,
        "1."
        "0000000000000000074489805020743198914419949385831538723596425413126398524678161602637198763739070584084656"
        "0260278464628372543383280977318309056924111623883709653889736043921408e+176"},
    {1e+177, chars_format::scientific, 176,
        "1."
        "0000000000000000074489805020743198914419949385831538723596425413126398524678161602637198763739070584084656"
        "0260278464628372543383280977318309056924111623883709653889736043921408e+177"},
    {1e+178, chars_format::scientific, 178,
        "1."
        "0000000000000000524381184475062837195473800154429724610566137243318061834753718863820956830887857615988724"
        "636416932177829345401680187244151732297960592357271816907060120777654272e+178"},
    {1e+179, chars_format::scientific, 178,
        "9."
        "9999999999999998045549773481514159457876389246726271914145983150114005386328272459269439234497983649422148"
        "597943950338419997003168440244384097290815044070304544781216945608327168e+178"},
    {1e+180, chars_format::scientific, 180,
        "1."
        "0000000000000000092485460198915984445662103416575466159075213886334065057081183893084549086425022065360818"
        "77044340989143693798086218131232373875663313958712699944969706504756133888e+180"},
    {1e+181, chars_format::scientific, 180,
        "9."
        "9999999999999991711079150764693652460638170424863814625612440581015385980464426221802125649043062240212862"
        "56366562347133135483117101991090685868467907010818055540655879490029748224e+180"},
    {1e+182, chars_format::scientific, 182,
        "1."
        "0000000000000000645311987272383955965421075241028916976983595783273580932502028655627150999337451570164538"
        "2788895184180192194795092289050635704895322791329123657951217763820802932736e+182"},
    {1e+183, chars_format::scientific, 182,
        "9."
        "9999999999999994659487295156522833899352686821948885654457144031359470649375598288696002517909352932499366"
        "6087115356131035228239552737388526279268078143523691759154905886843985723392e+182"},
    {1e+184, chars_format::scientific, 184,
        "1."
        "0000000000000000173566684169691286935226752617495305612368443231218527385476241124924130700318845059398697"
        "631682172475335672600663748292592247410791680053842186513692689376624118857728e+184"},
    {1e+185, chars_format::scientific, 184,
        "9."
        "9999999999999997961704416875371517110712945186684165206763211895744845478556111003617144611039598507860251"
        "139162957211888350975873638026151889477992007905860430885494197722591793250304e+184"},
    {1e+186, chars_format::scientific, 184,
        "9."
        "9999999999999997961704416875371517110712945186684165206763211895744845478556111003617144611039598507860251"
        "139162957211888350975873638026151889477992007905860430885494197722591793250304e+185"},
    {1e+187, chars_format::scientific, 186,
        "9."
        "9999999999999990715696561218012120806928149689207894646274468696179222996240014532018752818113802502496938"
        "79805812353226907091680705581859236698853640605134247712274342131878495422251008e+186"},
    {1e+188, chars_format::scientific, 188,
        "1."
        "0000000000000000230930913026978715489298382248516992754305645781548421896794576888657617968679507611107823"
        "8543825857419659919011313587350687602971665369018571203143144663564875896666980352e+188"},
    {1e+189, chars_format::scientific, 188,
        "1."
        "0000000000000000230930913026978715489298382248516992754305645781548421896794576888657617968679507611107823"
        "8543825857419659919011313587350687602971665369018571203143144663564875896666980352e+189"},
    {1e+190, chars_format::scientific, 190,
        "1."
        "0000000000000000725591715973187783610303424287811372824568343983972101724920689074452068181743241951740625"
        "976868675721161334753163637413771490365780039321792212624518252692320803210995433472e+190"},
    {1e+191, chars_format::scientific, 190,
        "1."
        "0000000000000000725591715973187783610303424287811372824568343983972101724920689074452068181743241951740625"
        "976868675721161334753163637413771490365780039321792212624518252692320803210995433472e+191"},
    {1e+192, chars_format::scientific, 192,
        "1."
        "0000000000000000409008802087613980012860197382662969579600217134420946634919977275543620045382451973735632"
        "61847757813447631532786297905940174312186739777303375354598782943738754654264509857792e+192"},
    {1e+193, chars_format::scientific, 193,
        "1."
        "0000000000000000662275133196073022890814778906781692175574718614061870706920546714670378554471083956139627"
        "305190456203824330868103505742897540916997511012040520808812168041334151877325366493184e+193"},
    {1e+194, chars_format::scientific, 193,
        "9."
        "9999999999999994465967438754696170766327875910118237148971115117854351613178134068619377108456504406004528"
        "089686414709538562749489776621177115003729674648080379472553427423904462708600804999168e+193"},
    {1e+195, chars_format::scientific, 194,
        "9."
        "9999999999999997707776476942971919604146519418837886377444734057258179734785422889441886024790993780775660"
        "0796112539971931616645685181699233267813951241073670004367049615544210109925082343145472e+194"},
    {1e+196, chars_format::scientific, 195,
        "9."
        "9999999999999995114329246392351320533891604611862166994665838905735117237499591832783878891723402280958754"
        "48767138256706948253250552493092635735926276453993770366538373425000777236538229086224384e+195"},
    {1e+197, chars_format::scientific, 195,
        "9."
        "9999999999999995114329246392351320533891604611862166994665838905735117237499591832783878891723402280958754"
        "48767138256706948253250552493092635735926276453993770366538373425000777236538229086224384e+196"},
    {1e+198, chars_format::scientific, 198,
        "1."
        "0000000000000000175355415660194005415374418651772000861457981049363415723055131933782837715237643652049003"
        "28030374534281861011105867876227585990799216050325567033999660761493056632508247061001404416e+198"},
    {1e+199, chars_format::scientific, 199,
        "1."
        "0000000000000000972062404885344653449756728480474941855847657639911300522221339234388177506516007760792756"
        "678147673846152604340428430285295728914471221362369950308146488642846313231335560438561636352e+199"},
    {1e+200, chars_format::scientific, 199,
        "9."
        "9999999999999996973312221251036165947450327545502362648241750950346848435554075534196338404706251868027512"
        "415973882408182135734368278484639385041047239877871023591066789981811181813306167128854888448e+199"},
    {1e+201, chars_format::scientific, 201,
        "1."
        "0000000000000000377187852930565502917417937141710079246703365785635546538843904449936190462361495892930754"
        "14109087389699655531583234914810756005630018925423128793192791080866922220799992003324610084864e+201"},
    {1e+202, chars_format::scientific, 200,
        "9."
        "9999999999999990174745913196417302720721283673903932829449844044338231482669106569030772185797544806747483"
        "4210390258463987183104130654882031695190925872134291678628544718769301415466131339252487684096e+201"},
    {1e+203, chars_format::scientific, 202,
        "9."
        "9999999999999998876910787506329447650934459829549922997503484884029261182361866844442696946000689845185920"
        "534555642245481492613075738123641525387194542623914743194966239051177873087980216425864602058752e+202"},
    {1e+204, chars_format::scientific, 202,
        "9."
        "9999999999999998876910787506329447650934459829549922997503484884029261182361866844442696946000689845185920"
        "534555642245481492613075738123641525387194542623914743194966239051177873087980216425864602058752e+203"},
    {1e+205, chars_format::scientific, 205,
        "1."
        "0000000000000000166160354728550133402860267619935663985128064995273039068626355013257451286926569625748622"
        "041088095949318798038992779336698179926498716835527012730124200454693714718121768282606166882648064e+205"},
    {1e+206, chars_format::scientific, 206,
        "1."
        "0000000000000000388935775510883884313073724929520201333430238200769129428938489676307996560787770138732646"
        "0311941213291353170611409437561654018367221268940354434586262616943544566455807655946219322240663552e+"
        "206"},
    {1e+207, chars_format::scientific, 206,
        "1."
        "0000000000000000388935775510883884313073724929520201333430238200769129428938489676307996560787770138732646"
        "0311941213291353170611409437561654018367221268940354434586262616943544566455807655946219322240663552e+"
        "207"},
    {1e+208, chars_format::scientific, 207,
        "9."
        "9999999999999998186306983081094819829272742169837857217766747946991381065394249388986006597030968254935446"
        "16522696356805028364441642842329313746550197144253860793660984920822957311285732475861572950035529728e+"
        "207"},
    {1e+209, chars_format::scientific, 209,
        "1."
        "0000000000000000731118821832548525711161595357042050700422376244411124222377928518753634101438574126676106"
        "8799969763125334902791605243044670546908252847439043930576054277584733562461577854658781477884848504832e+"
        "209"},
    {1e+210, chars_format::scientific, 209,
        "9."
        "9999999999999992711378241934460557459866815329488267345892539248719464370363227909855805946618104447840072"
        "5843812838336795121561031396504666917998514458446354143529431921823271795036250068185162804696593727488e+"
        "209"},
    {1e+211, chars_format::scientific, 210,
        "9."
        "9999999999999995631340237212665497390216642977674715277558783887797819941046439365391912960171631811624271"
        "82749897969201059028320356032930746282153172616351711759756540926280845609521557638656931995269719916544e+"
        "210"},
    {1e+212, chars_format::scientific, 211,
        "9."
        "9999999999999990959401044767537593501656918740576398586892792465272451027953301036534141738485988029569553"
        "038510666318680865279842887243162229186843277653306392406169861934038413548670665077684456779836676898816e"
        "+211"},
    {1e+213, chars_format::scientific, 212,
        "9."
        "9999999999999998434503752679742239723352477519933705291958378741313041288902322362706575693183018080857103"
        "1008919677160084252852199641809946030023447952696435527124027376600704816231425231719002378564135125254144"
        "e+212"},
    {1e+214, chars_format::scientific, 213,
        "9."
        "9999999999999995444462669514860381234674254008190782609932144230896805184522713832237602111304206060342083"
        "0759394471570774012830691334058616534761441882231086885899095873696576543933537799342139254257827782747750"
        "4e+213"},
    {1e+215, chars_format::scientific, 214,
        "9."
        "9999999999999990660396936451049407652789096389402106318690169014230827417515340183487244380298106827518051"
        "0360154142627877628796278041656489342342232169486529059939205469049971308256917907539158255367736034737520"
        "64e+214"},
    {1e+216, chars_format::scientific, 216,
        "1."
        "0000000000000000214215469580419574424931347467449492941767090953422917405833303694048810293471274498629572"
        "7931833093209082895047886994342159460414833548007346784224294244020182387388080564786631265270395622996207"
        "2064e+216"},
    {1e+217, chars_format::scientific, 216,
        "9."
        "9999999999999996018550557482517698064500472922445423764881181256896722516563598670087645039024937968280966"
        "9207303311043921578914820929146871797851747047760433825014282722254169172214732186358496974124638792508977"
        "9712e+216"},
    {1e+218, chars_format::scientific, 217,
        "1."
        "0000000000000000826575883412587379043412647642654443507046063781156162560010247521088856083040055200431048"
        "8942935855313773632204291895769631741044492391238650185947160215814947857554687910937412833128327366741516"
        "61568e+218"},
    {1e+219, chars_format::scientific, 218,
        "9."
        "9999999999999996508438888548251941759285513062609384217104359519083318639905153731719681670679962529722147"
        "8016185520727674168639944850288849622355474122345476546392575499689981548348018063279122228410984187505225"
        "498624e+218"},
    {1e+220, chars_format::scientific, 219,
        "9."
        "9999999999999999643724207368951101405909769959658731111332700397077533829291106126164716113272119722945705"
        "4393031662703690742880737945597507699179327399689749963213649275279180755601047675571123855843594715481209"
        "6741376e+219"},
    {1e+221, chars_format::scientific, 221,
        "1."
        "0000000000000000466018071748206975684050858099493768614209804580186827813230862995727677122141957123210339"
        "7659598548986531726166600689809136062209749264344058743012736731622189948720589505523832645973577156024278"
        "435495936e+221"},
    {1e+222, chars_format::scientific, 221,
        "1."
        "0000000000000000466018071748206975684050858099493768614209804580186827813230862995727677122141957123210339"
        "7659598548986531726166600689809136062209749264344058743012736731622189948720589505523832645973577156024278"
        "435495936e+222"},
    {1e+223, chars_format::scientific, 221,
        "1."
        "0000000000000000466018071748206975684050858099493768614209804580186827813230862995727677122141957123210339"
        "7659598548986531726166600689809136062209749264344058743012736731622189948720589505523832645973577156024278"
        "435495936e+223"},
    {1e+224, chars_format::scientific, 223,
        "9."
        "9999999999999996954903517948319502092964807244749211214842475260109694882873713352688654575305085714037182"
        "4092248411345058928811833787060802532495190829039301080947896405333883515460849480069503260157387926689005"
        "64521713664e+223"},
    {1e+225, chars_format::scientific, 224,
        "9."
        "9999999999999992845422344863652699560941461244648691253639504304505117149841757830241659030710693437735200"
        "9423588636134254484622941461177838218040629861358615028052178586193608330530158506646130887048916655460323"
        "666687950848e+224"},
    {1e+226, chars_format::scientific, 225,
        "9."
        "9999999999999996133007283331386141586560138044729107222601881068988779336267322248199255466386207258776786"
        "1158516456302898039974055321884209669604278635503163870368752841505828478474711285384828785535693672443269"
        "2495112994816e+225"},
    {1e+227, chars_format::scientific, 225,
        "1."
        "0000000000000000928334703720231990968903484524505077109845138812692342808196957992002964120908826254294312"
        "6809822773697747226137851076470969547585887373208135923963504986275470907025292240033962037948280174037505"
        "1580804694016e+227"},
    {1e+228, chars_format::scientific, 227,
        "9."
        "9999999999999992450912152247524686517867220028639041337364019092767077687470690100086747458429631779210210"
        "7215397297714017257980807797893073643852992008461269166974189675556141912776812173197487139230503413422370"
        "196749149011968e+227"},
    {1e+229, chars_format::scientific, 228,
        "9."
        "9999999999999999183886106229442775786334270115203733241798966706429617845270246028063904958693084084703377"
        "1568529473419399259339888984619722376655344697909305196038533750435568775767256264054340435331422744203442"
        "7503713670135808e+228"},
    {1e+230, chars_format::scientific, 230,
        "1."
        "0000000000000000995664443260051171861588155025370724028889488288828968209774953551282735695911460777349244"
        "3453354095454801046151441888338236034913910900102616284254148427024265175655196680942530570909289367345315"
        "883616691581616128e+230"},
    {1e+231, chars_format::scientific, 231,
        "1."
        "0000000000000000564754110205208414148406263819830583747005651641554565639675781971892197615894599829797681"
        "6934753636209656598064460692387730516014560327977941978394030406231981856423808259127691959958830530175327"
        "2401848696295129088e+231"},
    {1e+232, chars_format::scientific, 231,
        "1."
        "0000000000000000564754110205208414148406263819830583747005651641554565639675781971892197615894599829797681"
        "6934753636209656598064460692387730516014560327977941978394030406231981856423808259127691959958830530175327"
        "2401848696295129088e+232"},
    {1e+233, chars_format::scientific, 232,
        "9."
        "9999999999999997374062707399103193390970327051935144057886852787877127050853725394623645022622268104986814"
        "0190407544589792577374567961627599197278072294985673111426038063107978834995424892432018269339495628089490"
        "44795771481474727936e+232"},
    {1e+234, chars_format::scientific, 234,
        "1."
        "0000000000000000178658451788069303237395289299666618054437734005596700936866924236758275496199492420791481"
        "5574087624726007172578525540816077571080742215354233800343364659602096002392484233181596564547219412071017"
        "4156699571604284243968e+234"},
    {1e+235, chars_format::scientific, 235,
        "1."
        "0000000000000000531660196626596490356033894575245100973356972987043891522292165594595004291349304909025721"
        "6818125120939629504451380536538731692163090204038766991703973342235134497506837628332312354637835291480672"
        "11236930570359138156544e+235"},
    {1e+236, chars_format::scientific, 235,
        "1."
        "0000000000000000531660196626596490356033894575245100973356972987043891522292165594595004291349304909025721"
        "6818125120939629504451380536538731692163090204038766991703973342235134497506837628332312354637835291480672"
        "11236930570359138156544e+236"},
    {1e+237, chars_format::scientific, 235,
        "9."
        "9999999999999994020546131433094915763903576933939556328154082464128816489313932495174721468699049466761532"
        "8372051330560380424582445502262385046995766402482607793500255578094113131409067638500218263478644773697770"
        "82931390365469918625792e+236"},
    {1e+238, chars_format::scientific, 238,
        "1."
        "0000000000000000486475973287265010404848153099971055159735310397418651127357734700791903005570128910531738"
        "9458888321424285845971655097086231964664549661487146743209815430858105570132200393753020733506236458916236"
        "31119178909006652304785408e+238"},
    {1e+239, chars_format::scientific, 238,
        "9."
        "9999999999999999081179145438220670296706622164632687453780292502155740721970192601122065475966761298087599"
        "2606572876278870174311694720942354526832307168264075624845941652321352997368437911380879830217714020914580"
        "56119576436948334022754304e+238"},
    {1e+240, chars_format::scientific, 240,
        "1."
        "0000000000000000139461138041199244379741658569866383311120941709096804894261305436384085130786057242097951"
        "5339949701146446548847363722091034057475758294690703234774682671482523407894986432184061083215557424821369"
        "3581484614981956096327942144e+240"},
    {1e+241, chars_format::scientific, 241,
        "1."
        "0000000000000000509610295637002728139855252735311366616309601643306774209564163318419090863889067021760658"
        "1066817562776141799113274522085911825143802419273576310438824281483144380948014657857618043525615061189227"
        "44139467759619125060885807104e+241"},
    {1e+242, chars_format::scientific, 241,
        "1."
        "0000000000000000509610295637002728139855252735311366616309601643306774209564163318419090863889067021760658"
        "1066817562776141799113274522085911825143802419273576310438824281483144380948014657857618043525615061189227"
        "44139467759619125060885807104e+242"},
    {1e+243, chars_format::scientific, 243,
        "1."
        "0000000000000000746505756498316957746327953001196155931630344001201154571357992362921494533074993280744790"
        "3132012994219146759283457434082633596451350659006615078863874911883541803701952722288694498124051948464656"
        "6146722558989084608335389392896e+243"},
    {1e+244, chars_format::scientific, 243,
        "1."
        "0000000000000000746505756498316957746327953001196155931630344001201154571357992362921494533074993280744790"
        "3132012994219146759283457434082633596451350659006615078863874911883541803701952722288694498124051948464656"
        "6146722558989084608335389392896e+244"},
    {1e+245, chars_format::scientific, 245,
        "1."
        "0000000000000000443279566595834743850042896660863625608019793783096347708261891185958417836517007669245101"
        "0888562841972100410265623306726829729177688912148325455279810104971033102576911999816916636238052732752107"
        "272876955671430431745947427930112e+245"},
    {1e+246, chars_format::scientific, 246,
        "1."
        "0000000000000000685860518517820514967070941733129649866908233957580193198738772127528879193763396158444852"
        "4683322963769737489479890608611472822996618309634957154147061950501040063476944577794338925746852105322146"
        "7463131958534128550160206370177024e+246"},
    {1e+247, chars_format::scientific, 246,
        "9."
        "9999999999999995214719492922888136053363253862527334242437211200577348444497436079906646789807314102860458"
        "4684743791410795092514075595651859726657572016991249995842530919570066511567882035027119361046151169859572"
        "7381924297989722331966923339726848e+246"},
    {1e+248, chars_format::scientific, 248,
        "1."
        "0000000000000000452982804672714174694724018463754266578375331390075701527880966423621236290806863208813091"
        "1440353246844005893434193998802215452930446088047790723234500178792233381012913302936013527818404707654908"
        "851814405278709728676750356293615616e+248"},
    {1e+249, chars_format::scientific, 247,
        "9."
        "9999999999999992109683308321470265755404276937522223728665176967184126166393360027804741417053541441103640"
        "8111814232401040478571454131528428125775275729162364250341707296785977412047465036916114055333519200963067"
        "47820855546959721533975525765152768e+248"},
    {1e+250, chars_format::scientific, 247,
        "9."
        "9999999999999992109683308321470265755404276937522223728665176967184126166393360027804741417053541441103640"
        "8111814232401040478571454131528428125775275729162364250341707296785977412047465036916114055333519200963067"
        "47820855546959721533975525765152768e+249"},
    {1e+251, chars_format::scientific, 251,
        "1."
        "0000000000000000482791152044887786249584424642234315639307542918716276461750765553721414582385299426365956"
        "5935453370610499537728043164857800396298916132410948026391308085570960636368309306117879178753245974556315"
        "302310250472271728848176952226298724352e+251"},
    {1e+252, chars_format::scientific, 252,
        "1."
        "0000000000000000991520280529984090119202023421627152945883953007515421999795337374097790758657277539268193"
        "5985162149558657733676402265539783429787471556208832666934163027927905794433734427088386288041203596340318"
        "7241060084423965317738575228107571068928e+252"},
    {1e+253, chars_format::scientific, 252,
        "9."
        "9999999999999993635870693776759177364257073275700735648394407233581562780527075488933869945869475779810351"
        "8260940569245515066416531433574377226240942000556018171970272123856812886243740399827635383197392066315077"
        "7435958293799716241167969694049028276224e+252"},
    {1e+254, chars_format::scientific, 252,
        "9."
        "9999999999999993635870693776759177364257073275700735648394407233581562780527075488933869945869475779810351"
        "8260940569245515066416531433574377226240942000556018171970272123856812886243740399827635383197392066315077"
        "7435958293799716241167969694049028276224e+253"},
    {1e+255, chars_format::scientific, 254,
        "9."
        "9999999999999998845256969464145328989141284776683389667736846542884813090103490929587961990894531655929258"
        "7569958465674654992927728624557883489163749540246356891129106733591931304833693638565628182306078113383272"
        "782784390994049606075766012189756664840192e+254"},
    {1e+256, chars_format::scientific, 256,
        "1."
        "0000000000000000301276599001405425028904865397746951288321079799032741333776462328211123562691457635682438"
        "4301717278281796693413668637734468849950199557199862786645617442138002603970565622955602242159302695103782"
        "88141352402853119916429412464176397346144256e+256"},
    {1e+257, chars_format::scientific, 256,
        "1."
        "0000000000000000301276599001405425028904865397746951288321079799032741333776462328211123562691457635682438"
        "4301717278281796693413668637734468849950199557199862786645617442138002603970565622955602242159302695103782"
        "88141352402853119916429412464176397346144256e+257"},
    {1e+258, chars_format::scientific, 258,
        "1."
        "0000000000000000567997176316599595992098937026597263174111412691669067749626774798772613075396740496539726"
        "4650338994578968657651041933912824370611847303232008129066549774156440667002371228778987473473667420713674"
        "4674199783831719918405933396323484899269935104e+258"},
    {1e+259, chars_format::scientific, 258,
        "9."
        "9999999999999992877384052036675753687673932081157661223178148070147009535452749400774634144113827644247438"
        "9769547563525432293116501122567178714359381222777104854460745804679379644497043208267383631647167377861948"
        "5458899748089618699435710767754281089234894848e+258"},
    {1e+260, chars_format::scientific, 260,
        "1."
        "0000000000000000653347761057461730700321039947829362977564319217312692202698874789352289719462431012014058"
        "6361897943794063686207001388689898137223574581962294638641248120402340847172549022642470747494264132908839"
        "774942043776657045497009088429335535195969814528e+260"},
    {1e+261, chars_format::scientific, 258,
        "9."
        "9999999999999992877384052036675753687673932081157661223178148070147009535452749400774634144113827644247438"
        "9769547563525432293116501122567178714359381222777104854460745804679379644497043208267383631647167377861948"
        "5458899748089618699435710767754281089234894848e+260"},
    {1e+262, chars_format::scientific, 262,
        "1."
        "0000000000000000161728392950095834780961727121532468109675577629605415353003578843613352249644053642881905"
        "3303318396315116321724674929173953241540025456475844343490985646025955809392324929988807089135627070664687"
        "60361494711018313643605437535869015444666630275072e+262"},
    {1e+263, chars_format::scientific, 262,
        "1."
        "0000000000000000161728392950095834780961727121532468109675577629605415353003578843613352249644053642881905"
        "3303318396315116321724674929173953241540025456475844343490985646025955809392324929988807089135627070664687"
        "60361494711018313643605437535869015444666630275072e+263"},
    {1e+264, chars_format::scientific, 264,
        "1."
        "0000000000000000441405189028952877792863913973825812745630061732834443960830236092744836676918508323988196"
        "9887754761103139711296842870587468559973333403419247178065357187004521519773963524920669081446318377185805"
        "2833032509915549602573975010166573043840478561173504e+264"},
    {1e+265, chars_format::scientific, 265,
        "1."
        "0000000000000000665146625892038512202385663455660488454393649015417666847091561892050024218738072068873230"
        "3155303852933558422954577223718280814719979760973969445724854419787374088079274400866158675294871422402699"
        "42705389409665241931447200154303102433395309881065472e+265"},
    {1e+266, chars_format::scientific, 266,
        "1."
        "0000000000000000307160326911101497147150864284725007320371909363284510229073440613161724151826770077057176"
        "9927225306004888484302202258708981207125345588886413817469658847334809978790776999353375325137186550055668"
        "797052865128496484823152800700833072414104710501367808e+266"},
    {1e+267, chars_format::scientific, 266,
        "9."
        "9999999999999997343822485416022730587751856112282375059371259198714596402444465669404440447686868901514916"
        "7622996309190165824584023146941018349739309135463248122613459314107074039291811569329219648848907543004197"
        "890512187794469896370420793533163493423472892065087488e+266"},
    {1e+268, chars_format::scientific, 266,
        "9."
        "9999999999999997343822485416022730587751856112282375059371259198714596402444465669404440447686868901514916"
        "7622996309190165824584023146941018349739309135463248122613459314107074039291811569329219648848907543004197"
        "890512187794469896370420793533163493423472892065087488e+267"},
    {1e+269, chars_format::scientific, 269,
        "1."
        "0000000000000000467538188854561279891896054313304102868413648727440164393945558946103682581803033369390768"
        "8813404495028932616818466243033147431327741697981638738927986463793558699752023835231102266007829372867138"
        "519293326106230343475263802678137754874196788463928344576e+269"},
    {1e+270, chars_format::scientific, 269,
        "1."
        "0000000000000000467538188854561279891896054313304102868413648727440164393945558946103682581803033369390768"
        "8813404495028932616818466243033147431327741697981638738927986463793558699752023835231102266007829372867138"
        "519293326106230343475263802678137754874196788463928344576e+270"},
    {1e+271, chars_format::scientific, 270,
        "9."
        "9999999999999995290985852539737511455013423746469952044436995337522223092081351007747372543990698759644940"
        "5879902689682400928375844147591690679948638939044369127946865823435090410987852070094314805704679411017385"
        "4458342872794765056233999682236635579342942941443126198272e+270"},
    {1e+272, chars_format::scientific, 272,
        "1."
        "0000000000000000655226109574678785641174996701035524401207638566177752810893043715169471647283826068076023"
        "8458487340241071121614642608687943103994317258797079104154646440083568631482671560875436423095301659220218"
        "514235305581886882057848563849292034690350260273827761094656e+272"},
    {1e+273, chars_format::scientific, 272,
        "9."
        "9999999999999994540234169659267488457897654195544265913261035982571869424291411931484216282067527964903920"
        "7299571308833846909191138684972507989282336695782607667040225918275050684065261167516978177354790265605065"
        "466066369376850351293060923539046438669680406904714953752576e+272"},
    {1e+274, chars_format::scientific, 273,
        "9."
        "9999999999999992137828784441763414867127191632582070293497966046730737687363606887442116243913381421732657"
        "1842510890118474047800081204591123379150169517344970992138978221762923557912970279269500966635145000285641"
        "5308090320884466574359759805482716570229159677380024223137792e+273"},
    {1e+275, chars_format::scientific, 274,
        "9."
        "9999999999999995981677400789769932612359931733321583285118877944076548466448094957909476304960015890806678"
        "8573807560063070626025773173201338755361637002845189671980974536182326959756635700465464503786577424796719"
        "82722077174989256760731188933351130765773907040474247261585408e+274"},
    {1e+276, chars_format::scientific, 276,
        "1."
        "0000000000000000520691408002498557520091850797509641446500906649770649433625086632703114045147193861658433"
        "0872891956793010241376743389786585565826915896804571450360176569078889512418143271133577699295001524362330"
        "7738608946937362752018518070418086469181314516804918593340833792e+276"},
    {1e+277, chars_format::scientific, 277,
        "1."
        "0000000000000000028678785109953723248702060064614983783573429926910385653902272159683291957333224649616958"
        "3131285983040101879363854817804477997671848058660543459340401040833205876982154097220494366539618174024912"
        "75192019201707119869992081071729797163687409453914913289541779456e+277"},
    {1e+278, chars_format::scientific, 277,
        "9."
        "9999999999999996350686867959178558315902274782992576532314485486221746301240205812674342870820492799837784"
        "9380012040377751897535439602187919431477937881453210665245806182366589686333627580900277003353114937549783"
        "34367629875739137498376013657689431411868208826074951744485326848e+277"},
    {1e+279, chars_format::scientific, 279,
        "1."
        "0000000000000000579732922749603937632658625685457000366052203856513881087191824369465492695684870167103410"
        "0601884673643359244818290018424438474005524037381854809282549632468371548670461972003147699225647526402820"
        "9364937790149360843820835266007499279518823345374529865067232493568e+279"},
    {1e+280, chars_format::scientific, 280,
        "1."
        "0000000000000000327822459828620982485707052830214935642633335774409426031973743359279343786724117930538174"
        "9758182415081870163467691069569599399110129304252112477880424562006581527327235514959649032854891251030062"
        "90926013924448356521309485648260046220787856768108551057012647002112e+280"},
    {1e+281, chars_format::scientific, 280,
        "1."
        "0000000000000000327822459828620982485707052830214935642633335774409426031973743359279343786724117930538174"
        "9758182415081870163467691069569599399110129304252112477880424562006581527327235514959649032854891251030062"
        "90926013924448356521309485648260046220787856768108551057012647002112e+281"},
    {1e+282, chars_format::scientific, 280,
        "1."
        "0000000000000000327822459828620982485707052830214935642633335774409426031973743359279343786724117930538174"
        "9758182415081870163467691069569599399110129304252112477880424562006581527327235514959649032854891251030062"
        "90926013924448356521309485648260046220787856768108551057012647002112e+282"},
    {1e+283, chars_format::scientific, 282,
        "9."
        "9999999999999995539535177353613442742718210189113128122905730261845401023437984959874943383966870598097727"
        "9663290767809757055586510986875337610314766840775440358130963455479625817608438389220211297639279730849502"
        "4959839786965342632596166187964530344229899589832462449290116390191104e+282"},
    {1e+284, chars_format::scientific, 284,
        "1."
        "0000000000000000792143825084576765412568191916997109340838993423344357589751710277254453455720576452975216"
        "2833294418062406838213115052098838781957320876356853543120821491881752894667070520582225774709469217797130"
        "505057184069381648545374773244373557467226310750742042216461653692645376e+284"},
    {1e+285, chars_format::scientific, 284,
        "9."
        "9999999999999998015915792052044285019310951985284721180002571056165035998253808522408861618614649384428614"
        "9397221450372619320895438893697947652166455225334059372746413748147206443420891752540620587530362220273863"
        "006901551095990707698442841525909542472844588688081080376132618600579072e+284"},
    {1e+286, chars_format::scientific, 286,
        "1."
        "0000000000000000329886110340869674854270880115045078636847583141738025727786089878914788718586324412860117"
        "3816294023984005882022115176158618240811672377905911327059270770583804511182079226095749373929800486437916"
        "54301923722148311225012721166820834263125344653917287293299907083743789056e+286"},
    {1e+287, chars_format::scientific, 287,
        "1."
        "0000000000000000752521735249401871936142708048258363851925443970635243430154657100253910763966211992393922"
        "0917551527141401041968172205589677021287693862203915638886974287199071604654071266769099226071211897966340"
        "736882502910990345434353553680702253338428636675464684849307718019341877248e+287"},
    {1e+288, chars_format::scientific, 288,
        "1."
        "0000000000000000076304735395750356605147783355117107507800866644399695106364949546111315491358391865139834"
        "5555539522089568786054480958499982972526059487327108739962648660614644255098884001691739462644953639520862"
        "0267012778077787723395914064607119962069483324573977857832138825282954985472e+288"},
    {1e+289, chars_format::scientific, 289,
        "1."
        "0000000000000000617278335278671568869943723109630112583100528505388133765396715589425391709444647966943104"
        "5845149126131034590785433956171738211535366987228554259102109161882186134743033813753627273385960246277244"
        "99484625789034803081540112423670420191213257583185130503608895092113260150784e+289"},
    {1e+290, chars_format::scientific, 289,
        "1."
        "0000000000000000617278335278671568869943723109630112583100528505388133765396715589425391709444647966943104"
        "5845149126131034590785433956171738211535366987228554259102109161882186134743033813753627273385960246277244"
        "99484625789034803081540112423670420191213257583185130503608895092113260150784e+290"},
    {1e+291, chars_format::scientific, 290,
        "9."
        "9999999999999995786090235034628413215355187809651428385251777322903315400557247862623653707190362514808261"
        "2890986863714202457020042006419681526374965874177788623543449994485057258262661745948026767632275613049896"
        "960078961318150545418464661067991669581788285529005480705688196068853638234112e+290"},
    {1e+292, chars_format::scientific, 292,
        "1."
        "0000000000000000132565989783574162680686561089586460035632031477942492726904253214615979418039362499727374"
        "6385658920909881229746500070257845517383027467316859073953152552746468610581875582146175794962018326623525"
        "85538835573636597522107561710941518560028749376834095178551288964115055725510656e+292"},
    {1e+293, chars_format::scientific, 292,
        "9."
        "9999999999999992462348437353960485060448933957923525202610654848990348279466077292501969423268405025328970"
        "2311625456483436552753066788724417337901780594783307353950604674697279949729005300639788058439531021138680"
        "00379620369084502134308975505229555772913629423636305841602377586326247764393984e+292"},
    {1e+294, chars_format::scientific, 294,
        "1."
        "0000000000000000664364677412481031185471561705862924544854611073768567466278840505835448903466875698044061"
        "2078356746066803774429216105089087787538737112019976077088007803912512979947260613395493988432857461329320"
        "5683935969567348590731356020719265634967118123751637393518591968740451429495341056e+294"},
    {1e+295, chars_format::scientific, 294,
        "9."
        "9999999999999998134867772062300415778155607198205813300984837204468478832795008398842977267828545807373626"
        "9700402258157277029368704493591001552896016804949888720722394020468419889626445633965848788795148458000490"
        "2758521100414464490983962613190835886243290260424727924570510530141380583845003264e+294"},
    {1e+296, chars_format::scientific, 294,
        "9."
        "9999999999999998134867772062300415778155607198205813300984837204468478832795008398842977267828545807373626"
        "9700402258157277029368704493591001552896016804949888720722394020468419889626445633965848788795148458000490"
        "2758521100414464490983962613190835886243290260424727924570510530141380583845003264e+295"},
    {1e+297, chars_format::scientific, 297,
        "1."
        "0000000000000000176528014627563797143748787807198647768394431391197448238692552430690122228834703590788220"
        "7282921941122853493440271262470561545049232797945650079545633920176194945116080744729452765622274361759204"
        "8849967890105831362861792425329827928397252374398383022243308510390698430058459037696e+297"},
    {1e+298, chars_format::scientific, 297,
        "9."
        "9999999999999995956620347534297882382556244673937414671209151179964876700316698854008030255517451747068478"
        "7823111966314522286348299614922233214338230100245921475882026911692302152705828545968641468338591362245555"
        "1313826420028155008403585629126369847605750170289266545852965785882018353801250996224e+297"},
    {1e+299, chars_format::scientific, 299,
        "1."
        "0000000000000000525047602552044202487044685811081591549158541155118024579889081957863713750804478640437044"
        "4383288387817694252323536043057564479218478670698284838720092657580373783023379478809005936895323497079994"
        "508111903896764088007465274278014249457925878882005684283811566947219638686545940054016e+299"},
    {1e+300, chars_format::scientific, 299,
        "1."
        "0000000000000000525047602552044202487044685811081591549158541155118024579889081957863713750804478640437044"
        "4383288387817694252323536043057564479218478670698284838720092657580373783023379478809005936895323497079994"
        "508111903896764088007465274278014249457925878882005684283811566947219638686545940054016e+300"},
    {1e+301, chars_format::scientific, 299,
        "1."
        "0000000000000000525047602552044202487044685811081591549158541155118024579889081957863713750804478640437044"
        "4383288387817694252323536043057564479218478670698284838720092657580373783023379478809005936895323497079994"
        "508111903896764088007465274278014249457925878882005684283811566947219638686545940054016e+301"},
    {1e+302, chars_format::scientific, 302,
        "1."
        "0000000000000000762970307908489492534734685515065681170160173420621138028812579448414218896469178407663974"
        "7577138548761372210387844799938291815611350519830750167649856488981626536368095414607314235151058373458986"
        "890825155659063617715863205282622390509284183439858617103083735673849899204570498157510656e+302"},
    {1e+303, chars_format::scientific, 303,
        "1."
        "0000000000000000001617650767864564382126686462316594382954950171011174992257387478652602430342139152537797"
        "7356818033741602744582056777919964339154160602606861115074612228497617725665004420052727680732706769046211"
        "2661427500197051226489898260678763391449376088547292320814127957486330655468919122263277568e+303"},
    {1e+304, chars_format::scientific, 303,
        "9."
        "9999999999999993925355250553646218600402872201173249531907715713232045630132339028433092574405077484368561"
        "1805616217257871719374263603053023579884086688277498730144168201104106771025316244090584371980254855159907"
        "6639682550821832659549112269607949805346034918662572406407604380845959862074904348138143744e+303"},
    {1e+305, chars_format::scientific, 303,
        "9."
        "9999999999999993925355250553646218600402872201173249531907715713232045630132339028433092574405077484368561"
        "1805616217257871719374263603053023579884086688277498730144168201104106771025316244090584371980254855159907"
        "6639682550821832659549112269607949805346034918662572406407604380845959862074904348138143744e+304"},
    {1e+306, chars_format::scientific, 306,
        "1."
        "0000000000000000172160645967364548288310878250132389823288920178923806712445750479879204518754595945686061"
        "3886169829106031104922553294852069693880571144065012262851466942846035699262496802832955068922417528434673"
        "0060716088829214255439694630119794546505512415617982143262670862918816362862119154749127262208e+306"},
    {1e+307, chars_format::scientific, 306,
        "9."
        "9999999999999998603105976025645777170026418381263638752496607358835658526727438490648464142289606667863792"
        "8039265461539335317285025210333627595237061539701073069166468937517856903985107314633964162326607112672001"
        "1020169553304018596457812688561947201171488461172921822139066929851282122002676667750021070848e+306"},
    {1e+308, chars_format::scientific, 308,
        "1."
        "0000000000000000109790636294404554174049230967731184633681068290315758540491149153716332897849468889906124"
        "9669721172515611590283743140088328307009198146046031271664502933027185697489699588559043338384466165001178"
        "426897626212945177628091195786707458122783970171784415105291802893207873272974885715430223118336e+308"},
};

inline constexpr double_to_chars_testcase double_scientific_precision_to_chars_test_cases_3[] = {
    // Ryu Printf d2fixed_test.cc D2expTest AllBinaryExponents
    // These values test every binary exponent.
    // The mantissas were randomly generated.
    {0x0.63b831e8bd9d7p-1022, chars_format::scientific, 765,
        "8."
        "6673155601518373204745615934992065170006880827787289636461039456117181014435225731420739682086431846196084"
        "0559717761976781401452617612090003075542930260777812518669659241729724010681746641686623499848468215594968"
        "2021079153402945471922988971873909012440740220527800911244244822910902773084448896950002963160859062629660"
        "9882885374947604962348974323036144310657614326754120115556509383797380330234783520222245524583876671362471"
        "8494080431858617260899963028423305531253945552260335123939000593240656910669298632181747412649714974019858"
        "8356285761402581880926947783051518340651609793980053160313425027619711896255545853478748493923212623215309"
        "2624291889535798750202922731324119623206905408779063259071595105183391812893811664489504206776437911230459"
        "57647264003753662109375e-309"},
    {0x1.8777195166b0cp-1022, chars_format::scientific, 764,
        "3."
        "4024962888548891870780380223721963415936057267215768489022880931036340709664117046765987977180526441192766"
        "7980233377849338161398396361988635343561859686478002041658296279167269633549887180398681467085048366045915"
        "6676370951509663121515851044197786647785688189698831775149285429703757400159268959324595109001459740108998"
        "7064349011889817819942001416735892399032878298656443356501797788246594163297203747575928614864543561706962"
        "7150190560661004463760153276800654567748203691908193307868018274961903878508519765463087823925880361092267"
        "9880731846129559561006152326978128322135743176002677808113397223361200222360522182681889723507749332427973"
        "2240457324020870731250050608330505053074385990942209557473057293561320028309889744618215584592846312261826"
        "8243968486785888671875e-308"},
    {0x1.4668b84fe57a0p-1021, chars_format::scientific, 760,
        "5."
        "6740958740641631511384384536776561146340227260577357930980504423887626489617571637837441488031383754955785"
        "4086594144651757106826827082053224819137614951757164822186954713633389739294124192094600295957101411513892"
        "2292227756567557970015697918331549646091513808709325026828267412677470869412642816923726953169932993282696"
        "1970700281786004455171108499583392239457705199245309170122601944018148603634684132173289075939231416021795"
        "6773831481083699810908312929539145137356475139290129992626736771448814573026906644585538148884867233811394"
        "2395343914793125973137539097252903908512233824086968776157212299338375466427657302566612718734454791559738"
        "4296829871117558203187275819525974756928809649794138442664770396059164903717939140888326665645990942721255"
        "123615264892578125e-308"},
    {0x1.befe59a615135p-1020, chars_format::scientific, 765,
        "1."
        "5540526173622352375993445245662683293464994107818202403773732113997242921188175334393284236610673877760032"
        "1140045136930880932847198094667333515588636758849652193589488647628623014759199260062387648516658758902202"
        "4414313323949909142159529537456605070198347779192598243095403947592025125119457352938379814319820278343589"
        "7747302961203036640889656009214261792160762451937044526624584298357832777585944388632200805521152515342330"
        "8561170623085034646351360745189671642589380586080254484943279473962393703949926697788378603146358212695781"
        "2370158648390166491038532530966495890940486561351377873613480311323741789526145720019072115667475187757369"
        "0752588227109741861829975787681759234538817712508305395458670019301186211951459779169503264140139719984290"
        "42287170886993408203125e-307"},
    {0x1.1e3d1ff2f0c7dp-1019, chars_format::scientific, 764,
        "1."
        "9903200051351428805615989243193127044770722692702459361378399559534652305451954151277557670839014475339478"
        "2867837696288408273532724825127341865493665067774242606965035835847639336549731232556074151242689053806547"
        "2696077887804553644884150043878406627507745699995507099147377175105877153481526330603572499358626260756240"
        "8161745031548857838580407488540228220931314580542710929232921821435828527112974792024775296802861545460264"
        "3826566011906669643593108259028344252667022294947897471948646741545397199053445447059963324528762468428056"
        "1552964343633309851882307590384491177630806444328543647075668536514853052975155234251635207407297067719395"
        "3884058314203115240012536217140219386138413382468962035052024511938122187739312695493269084190401940759329"
        "5909464359283447265625e-307"},
    {0x1.6f434a1f8b19bp-1018, chars_format::scientific, 763,
        "5."
        "1074185390468469270473736828301327180750062564436661993518732867820414412582796763617494622074841605120794"
        "6280001513512476415260093780274458550261745884171770589710369360980007788208880420310179065543732589777800"
        "1026322540349851343686142888941809812697130982668148593939074359425039990092398040350897342987033684062247"
        "8891910045787038724069756928395277953670595630959968898874335051527496681463133794176157145807591872109216"
        "6144382506150797267436509897049656206429012398091894503972795298016547064662347920285527872288390895517604"
        "4191810941642460040564082188712438936906291867000270523960550332664002210898302673308442754015967789648657"
        "7199640058529357006968235192644651239960321968186374102417320609944271040560945042782563241257065556055749"
        "766528606414794921875e-307"},
    {0x1.587345c18153ep-1017, chars_format::scientific, 761,
        "9."
        "5803415071347647865082718369266434040574270026977809712667208404792036119580302875847883246591206937429220"
        "0765720124757014325334439209209434046539893719315938780007431549634993916215217605362262858269407426842334"
        "2012580732514751221293610595763003495795061946838666946253209134456556726989193259291618902375718355472162"
        "4042439056845036040587911004852089800421901874454407994337108163738052947210061561024263715054967969591411"
        "0270363560682828986102429968210287319178363269091390190666341835673642784686119809160641359798630514658952"
        "9621994975436450348729144771801748911075356977674248196373371459254492612305520113008095746852968491757589"
        "4312232673600164454503147125519469744188854742689367713126583601172208920773079707158131901323372403567191"
        "2133693695068359375e-307"},
    {0x1.f1b6b87277fdep-1016, chars_format::scientific, 761,
        "2."
        "7686246461533842708986290401534510677245449052480438452772935563477911887903937433332521175778793903095384"
        "0412239557231923283555660292437990927601776574893980601557250737329754310915661825472040213756951830291482"
        "6971556169842700521540676609741125857389706633023242364855348478771230295850829291438723530923932923590702"
        "4151611338319751130631733719608246390666274473865694983392385750305737090058291815147877218349104719543513"
        "7063089136683774947602824936693432977762482651171413713941775960038695919756102724251419600380177635071493"
        "6245861443988258956704733318591666199586331239518529031729048520377213164363192327716960117074516227535950"
        "9369132897727641328747183370449707056957130139385301002356826323260325258247061322707666120024327938153874"
        "1290569305419921875e-306"},
    {0x1.72a498409980ap-1015, chars_format::scientific, 760,
        "4."
        "1235396742477088973208679969440262899254505285796142223814175822702981218018251380021070120502969772416262"
        "0356011168621659532952906006748436531426296108744371485218418489239052308056360753777114430810169989395269"
        "5946140077164320660032095927443769046869340226546265147500705839457828617891438915581029354085740892509908"
        "6126202065003470601897807688053820010379771148507245760602767529755342564783534772481563133530608872155816"
        "3170273217810752940595356441071317848377916852111771962558733789348917288503698641911641096452799678633118"
        "3241428470038337938910339876846473513908343996450852057201827354601830122948746860487681564435359569830201"
        "2244034576878689343471222581935495027065359114155162611459186679259780987690986908851542569465209453483112"
        "156391143798828125e-306"},
    {0x1.ce91e910d066ap-1014, chars_format::scientific, 760,
        "1."
        "0292523314007669232638574122959890467082535280831773462781705248559642874893726342757936877737789465732731"
        "2479354581078416852016211748037289062294153412444887077225201260286873016177402040776581672627422105268655"
        "7419196324208471582119260101560948486357037365510139379540004408308132593738795998437771752956709763675038"
        "3014741316553229608555779896363377365729952793542626535019308363767322768135329791753783704045210472287174"
        "3258998969100598727128250967239986818240346849429624604806528929509814942265446828862812886192478721784982"
        "9763922746869649849450345544760606574327399799533824584266016235963525049495453939501167672500218822286450"
        "3213932415104343443746664957043752138584117730581730514644229269575090721314998575865173879861913519562222"
        "063541412353515625e-305"},
    {0x1.a41cd0fb8478fp-1013, chars_format::scientific, 760,
        "1."
        "8695629667714589591675011459069349152361779084993905567488662819408615881583054005738477193311059902345076"
        "1887740398618582452621943937695612634176016332254849337060923845633060080657730525723232050132901795302428"
        "7747627232037457266368651155516174545033578105816636548996204160600146117412245796293507856944957146706304"
        "0254113362718627037659792095227781184269228376974078923485650054103229807045611097285162062152946597899434"
        "3606420788243552352751894800076450567507229035568346316425077269088928498850264418366552561657569635100768"
        "6952407174842753490576669187086405946186033731473973426151694416850707500076337061041599563960687925311368"
        "5553781567772169884961236205927091959675967933403932478188107975984517174399812395983733193105535974609665"
        "572643280029296875e-305"},
    {0x1.3e41d54eded4ap-1012, chars_format::scientific, 758,
        "2."
        "8325827575460101051539146153659554542949953849899101704093223118334282451264669960468445814674273734277278"
        "4980027834494082685766178127629247208184380986441039452161190285373582999883474215846885769779038605962665"
        "7678189248144526566294279581606276306288020536846141644176497881789932815661474116675442020743817107419678"
        "6033403238981156288307360202517295738237238234044693827210253447256461636044859195631301675170218334495437"
        "1143800460586565184398113067165957481092210378398497900972951098730107411912334069394868562044554181578968"
        "9681881384571986389866669746565242803754572930194362570076270849264642814287648059465115948199864438616530"
        "2340702226649342072166051234769942192131532561249089789855476072421163114219198973092739279877605440560728"
        "3115386962890625e-305"},
    {0x1.59221b87422dcp-1011, chars_format::scientific, 756,
        "6."
        "1435754675809883764607389644039122653481643689751494279548380407226734715556912511959558049135199048091303"
        "4570147895374919927596970561282274649091727304992573536378826177765491606914330790712251813627403807741060"
        "3228952574550189497787908659493137234313533520312295234438706051770280882165612147632789337287128790236358"
        "3684228396504255283710239792217487466451145359639305211018532224666776225360631707573627254298962575843632"
        "6997585642760239301816630363203045431540296803267094601248551668127076407345103299971987320334913146074020"
        "6557039826594483610259885518699987425238236440286961754514953182564652960551764735240281677725263789812661"
        "3360122856215329758437263182035107129113790998892977867473178270734270283430110068390028743579023284837603"
        "56903076171875e-305"},
    {0x1.922a6e54c4bcbp-1010, chars_format::scientific, 758,
        "1."
        "4317575812076783279096962507607344781067968670789399357106075957085731026073398561781473029430115436014229"
        "5042738269957197194482263497390666912499621452236468720067330567331779529652769510718792075605208255229780"
        "4453598386016350631514998361352765835015287841808273033244090798155636616618100736973069441228252750043602"
        "0203687243042317304969036116006867635224978070867606390602657909489556516702811707764895990014055554819168"
        "2970313452199620495617335159702746235323083593453065072144972997529670760566203914519278435423331980290138"
        "3227718965593270032595543344712007425459523297691036565265412105198702522141620817697556902837198527180570"
        "9506606910343882865250484528903431183126572403711830756908976441373889806932772055664271348973670683335512"
        "8765106201171875e-304"},
    {0x1.072696ae9ff91p-1009, chars_format::scientific, 757,
        "1."
        "8736954404407842914371682565703603275065764259885958103791820006438214075779341036606769350112633220313924"
        "4013286873373278194295713473289353980269648254008823511740795625917107257638613508520649307128393978192620"
        "0705468314546127800658230827802488328422886555037223958144179314615586216250084158766674880816820412018646"
        "3506557142633404052761483488369917577746023162650582898107046603525443910985220071389009387344317203213496"
        "8788006389079497093133715393761312169804834914967830608316141061423753171621552752239867268985731345293183"
        "6000009671729651430504379359358929467240989725060006847711032116813580555184077897939000848084702416809622"
        "5624812892285306182628743961866717634410103283855733573331697661905063280118823205999678549460440990515053"
        "272247314453125e-304"},
    {0x1.0f9b544278c4bp-1008, chars_format::scientific, 756,
        "3."
        "8678085703767115679707960176797382475896222472846518711203204581057046445044323572045619149527021471033513"
        "1037742529492665225855291158606504096304763954369359355075134749682657763340277193897585554908876427528122"
        "3404237262544370036021050362028274509177214367131685009066980529198965345188509320693984189852122869096724"
        "0307762668804484986822336109648123529928998213973332360935499253090321992465599641371421976527675643722147"
        "4818553028447896343622184778775789582470210526709724599576515721933721910757383142738726001358720616381592"
        "4229271802232530916741889867942756272048490315195062592530929515848282749067855559474139733793821353946484"
        "8445188615771182360486800621802327201033747158405727472729308966998705733027858963413159187894052593037486"
        "07635498046875e-304"},
    {0x1.0c159c101694ep-1007, chars_format::scientific, 754,
        "7."
        "6352975143049522614438211587901154588102399522679308870720966934866278134299233303209132483254882406877024"
        "3032314978411326683785882828449889576731085199036357093879916119191477548962018450810436368437123537879171"
        "5398901706373669321385471295753589758753964662654457905715120673904659565201490447825557005135025380834617"
        "0283527824311975829475393389338044032315549305419642372717127492349123269421393795189501093425583277951613"
        "7482472996690706456618658477990379299062555451161914006646917062753813072403148854358191467247380141960317"
        "4369718591349917430634535930397154004116848462943127209818005654101392783570316361193216938245623206104415"
        "4092104891133848306373809820626535624355866825082456994424052303706479922855952791049816141821793280541896"
        "820068359375e-304"},
    {0x1.5dea4ce8e9d1cp-1006, chars_format::scientific, 753,
        "1."
        "9931833457401843380206268213719062063350814301599018679933261580130337290316898735876549592164313534803701"
        "0367716961871843460238736763173540738894631496044341513014086769607675313389734660544429847137223449237368"
        "1854732828188990763143676913549798050111000449048160356662711177445920457729101143615093098470889673928997"
        "8721590778489898585846173250830089770352087321756188087231770443888379781496362819885950130996391895508049"
        "5967945265553649325413439043352821440085193375901604390558169700922107887759422298045475048448298435182127"
        "1529249898671025481762571674803699881589864389977475085144039107611461508367830308205819849065857072705384"
        "2544909780275364598179935132913048405234257751121414962140712577875960000639218860918333575682481750845909"
        "11865234375e-303"},
    {0x1.f54052ccfbd85p-1005, chars_format::scientific, 754,
        "5."
        "7104439440441903852943648577406503088003161021002627368323935629069966209695533414405887372311247087423593"
        "9781943349661969952724399972643565145643565596680341154191365245563840621127630622979641166875699011127504"
        "8568462104925391744823983638657336393276468809438060554239207107070390674319071138242241936104300064142641"
        "4253161862928768191727964756739054251002351820210559683067678277426478312879053806872980671807735494036931"
        "5976069688037470882986462600191569302988629020903776604825882710768551646760758983546554323851915180357433"
        "1464966657766198572115325587926099638392334145329333710974022615959231083135651027696907010536501610597578"
        "0684355323209040588603358187555694328693197982659012778489710933784939697285300275186870067045674659311771"
        "392822265625e-303"},
    {0x1.0090aa3ec4669p-1004, chars_format::scientific, 753,
        "5."
        "8457732298371823574823131482226670449533326157358746716791953135062569212292668611641801097780408195948596"
        "5888373447402064062727322207217975101640660738989340741657280509189289276615212047497934355406431806641278"
        "8478834023123098163293513531622437049966284424578880391547670271754853142196587321184864022163506030620064"
        "2833463853585974609101781931276219629563822287439933439020777086511705876102130660051067922171320065746506"
        "2465994749375713082577376195362056859759924579898568161899707504166498745404902069366067260964218815046333"
        "9524113776506291985183641972212962838327237136002597053343023166906014203406467918165849951752439662675714"
        "8515684537136969992272393011690298548643680023668422526561162499435912606954648951251840571785578504204750"
        "06103515625e-303"},
    {0x1.68e98ac55ee26p-1003, chars_format::scientific, 752,
        "1."
        "6446596413123795549652277705330359127501949597887884484643611330088026618345889007411448311200165299004153"
        "2139330705876914793120460121891845777978753428196824338319708537694880490448415548357571084171954782371013"
        "9827936080983236731056925429888897928508247060002591227377665559607280147694385759161472019199431022048753"
        "9252764806264502002388852086321464182435389525557563807453640035300562682385718848951290103132751234367433"
        "2673547866665016504944648849864967346476782260339605421755639569644367437952386484883839418341180039062684"
        "1460528189649358085660200495553016137618232436443335627143917562089955116648923161635472084978246578377486"
        "6022112969364460310239797566964913160076166500253272495540657636319430742310315762821915086533408612012863"
        "1591796875e-302"},
    {0x1.87db0e29f0009p-1002, chars_format::scientific, 752,
        "3."
        "5713345155797761761079287822950557022675635846989691191937710506813782658682864940472796826062016923286770"
        "8166475001047504811177502998554808270085595314612727547047624036293060053880752125848194352774957680860559"
        "0290184599616254184674980579084610532650542277059343477381901087349157002708882523813589860191819919463864"
        "5572473742585546004235957997477845885941869654346021359209516817462476983259862602002508582493398382630013"
        "1126260391727473707770159740877054653682600781506186186387821934514680593847124459886451259056737591228212"
        "7533791281642861022630716480368525884787242037112467446408232606412304327122490841829569553119141625758702"
        "4691172442399017515655247762428343915640594942453182541456052819062032841011117278995357082749251276254653"
        "9306640625e-302"},
    {0x1.1ebac54ed6e41p-1001, chars_format::scientific, 751,
        "5."
        "2264507616884437569805809040739207336366694095277810554730657091293085596388058781521598800524476996130637"
        "4980627154903920257708024997792739202136400792180949605152479609662491266228594913712258572249852752399855"
        "1285095014756776289555458879942755967386577111803668209714736832027600164037534380000658070281110020332651"
        "9987841007167969298905049974104357743571558147007766635477857992855064039069143805060571043111052222533607"
        "6906939348214560580910775118826868200509986914895110839876152537097330539855968230909381107897375007290398"
        "8378385138191514671010111525187054811597159710392200991099127775914461518114073763353708106827024513399075"
        "6049414344541691511157350304779944771415413564368359181745069897590897094359629893034480119240470230579376"
        "220703125e-302"},
    {0x1.26d300e06c7a2p-1000, chars_format::scientific, 750,
        "1."
        "0747997253788843490025917088317140149354267531941831543005317538947117106260486277259597702417316344843162"
        "7823155594400408640689601791632312318793792452277700217881375008551777955008479104306751684583798640011117"
        "7331237195678228062266622507530803180421764933136874457770345473896308774311676909174769953465658733136531"
        "1730646743826073699550122831792121293574779463809583658915629548187457141074175132979644912781434112119879"
        "6449732242461849927674893802726574013367315709379237708819341288775841440380509951443158447860262711021202"
        "4512841842169839736663696096780505831114559890703110871001542936248745358663880699070477580187175555004706"
        "0426293407222477239023776188348421566739034336984800207756080926084740452888799389086216251598671078681945"
        "80078125e-301"},
    {0x1.05d0c9256bd0dp-999, chars_format::scientific, 750,
        "1."
        "9089292620000501462461091846419476055370811043243200914242752398813586917946117117276706450408017538758722"
        "5660390310015790741172721365183864329136645491654476508380946870544854973961644577246381082657250286554378"
        "6724684318613551976033658170744074959929074525489851922078469090207322060182315897761166701384940345796648"
        "2390692682550639168953244522694274039612474765568989798173496674976754209790799304541250614878586316185908"
        "1832434850661741938378087947299281921587249685730116526155067127702638040935609007598196903511226053833394"
        "6368989549925329930627669708876781138383078123518967695199641472080864590952079516774516291036652778177765"
        "9754149721554139538144541534629568996232451758594381806119602658917928450846290822084938554326072335243225"
        "09765625e-301"},
    {0x1.d161118863a28p-998, chars_format::scientific, 746,
        "6."
        "7862726827637822308383819837405744625386270069383303690107600052832104729374686176902718298036439556876536"
        "7007835766438473158503573341233420991356741827641046279183540631203113336246661546736423349686499782037093"
        "0641229855313759587426623336318947131414886263684536725151767642125347109002448147389830994122526274370789"
        "7617018358553974800233291485285224355118796255276967020647450176078219330437486876008901717954573383579099"
        "1047714288626185265103482007250812237430446740002717533482314627054425459382273947022327354496010149857916"
        "6998179831269447169218862728847291808670566291805820903410461158893419653332870539994687457679135320191821"
        "8210212370421266288662389144108768187401712413790015232870218865309040051636557677738892380148172378540039"
        "0625e-301"},
    {0x1.a15ea25a19660p-997, chars_format::scientific, 744,
        "1."
        "2172372613102280993179252931186926982692345919033968631102111765103315033304380176933385417160002408427950"
        "0295470238003737903138964229170029641147550066555294617444125756680352014437431112856968897249350959816759"
        "2236046524827959672222373231938825328608517533711548379199837592813292143627291147239524233411932374697495"
        "0076147620325900633348562563414895932402962713954954623414922689851738589686706046155327824502166704335474"
        "0483802830489519355136211942835589461562419698678550112002073553337267646181096609192841991425028505763676"
        "5310643658630077974934313260104372537119221193415761606516937805300536262521389430432123931165919988196641"
        "7445153541195275166274485974787587695265918859779451904129303848765483730964831465826136991381645202636718"
        "75e-300"},
    {0x1.3405ef09605c0p-996, chars_format::scientific, 742,
        "1."
        "7966676643662128335665392247768118683231502978059871166650153469309831612890500966882039821861868400342764"
        "6561658712020662099545587837211036370546812947350494432238004683763664567568973440673650283854843511596346"
        "3698442719535496115538726433986266863862950537061969082882291651460484133576667255869437876496100220690327"
        "1627540775195602113421651211440307831129924696845524348946549788527717960851496934136922932274256932207250"
        "2504730017520700249939263105447824182001422269657481368614500917398558972900508936492536325012033905462034"
        "2733517067914324213319731475850729738988853204799698138245429919661266017564480782965092181767914524772807"
        "0114038343552765434718432890065190765206137218078347442517180856079439532635433351970277726650238037109375"
        "e-300"},
    {0x1.d446d39179d61p-995, chars_format::scientific, 747,
        "5."
        "4628196945287030878864501228515552805464723717056197760606756889643903510249553048439017711133773671440354"
        "6393863354679463635258948740705694069667341257396888036371466715243466156053378293733554928216028872449926"
        "6270281940200034766664065924797146527366094882988718989577228548661057271640470276933597886851166967309922"
        "0490286146185662487877704337685653857174654805590027514341847429667755625338708736633025559983835650906911"
        "7082144597398445022686629737262804848201604027875209019963234888348727732753557137541010501446542044860603"
        "3076124889789498045902945493217533531235155103049453504888178998390271594265142786559200789840036462465329"
        "0699411376938730047962082755849242672666320969811738379369429636779305695104547169194120215252041816711425"
        "78125e-300"},
    {0x1.2a6191841a2f8p-994, chars_format::scientific, 743,
        "6."
        "9617062487220514621989094015930584333539423148144476551620642624680348776495275585358068724521997148409410"
        "6383911454657957927017181245452872915474622111096382221071681697520914214818303865707205751044498351025044"
        "4536884198365605166521031955111219642419220298954347889214534531094837790091823656984057353139300007125800"
        "3293035204706020167948760755422183994450699458391794656901738793039684960506013257067218773020004462578765"
        "1439009842232692428211132570873279618568830654102695286917053708082753966210260483718165254879075265420369"
        "8658797634666096444025144902359009191385276894101485935046230814418030394044362489237345080002513507196221"
        "2292725330139318787534438587025433685744672341079724930282999161273299604246744820557069033384323120117187"
        "5e-300"},
    {0x1.43dd16d8c3d1dp-993, chars_format::scientific, 746,
        "1."
        "5112507155402444702013530602239356519676208975557545662433849515130820968525645380967790058631717581998946"
        "2383489016678007812825705103181297543850063798852533579279995518512249438119478194724227415435927609478553"
        "0478989334370229123257813332123709533239479541328383215098833929934144690721346831873831758199105011512667"
        "0141483262312008742676060289776355889496425001520922157519067534910344942859758756256865735756093457144432"
        "9997703898734942358076870125601377536544377173388533764111459177194183621681873341290551265610317343464385"
        "3672019620647251124865042369790323166084999111485707852379027804775884480582808977213872674467521399597635"
        "5584951293948756727528587090551401340178932148867448233676410270702548249710517325183900538831949234008789"
        "0625e-299"},
    {0x1.1e84f4437de27p-992, chars_format::scientific, 745,
        "2."
        "6739808737490122536400919026942802234689576692371479366784405643483990062433008551497319332426200403535689"
        "5030064921783009805791888470580796419933084847761281293880427379962271237851947800328657537013648988481294"
        "9516962024244211760960748336098090994846015649655386170552493311162069257719900379903030507008588526031419"
        "9767588940990499498807868924298521846143186141665068730082632329712887735907185105610033092499947885537087"
        "2777021779956743000754547833513581633478384242279856707134228104860925927074204711269107333714275775531468"
        "3776136264937390122187354227141214309429715495082890329538893471744410403270954316441211712985000610177269"
        "8944311067042059526539301195418948431941957516625083848704359299592279997082044928902178071439266204833984"
        "375e-299"},
    {0x1.c7925872b0513p-991, chars_format::scientific, 744,
        "8."
        "5033691573552436743032359501867675425844556882485721384874628070407223682326838306017437077936494642893855"
        "9999659947344275015058137995788308286051472366936034180700376051612641241581279358969439631011755807941264"
        "0180009205258501662816829998856768170023903650537160919301714607898859451205817572487894938437883022633598"
        "3376290822291404418924863244602723542510196397911516919435936905242919732102909562672293761027406048075865"
        "7835985167284620389463467848900582426969335519962264577071777190480699878841459712168172042966775236944743"
        "1326712331419045036441427176290319828551714549495813962256861277779164177883181431486896646293602751921197"
        "3383768944719374984215587270106299004243931703144739402048268194422506183194343520881375297904014587402343"
        "75e-299"},
    {0x1.627c15354010bp-990, chars_format::scientific, 744,
        "1."
        "3233106901096892065379397808572390395445480166333342374132370300121192775365256676551830867982461560404647"
        "3777896550467847979014748844578467275598314335113075595369097593300537485855884838260655662363690589028654"
        "6498407090340200266273232047853174074580694696818844330785856152531370577370227513485232394640688728493031"
        "1135847573135818241585024900463197122494596403199246606733219005485941416655806006702981687133567159445266"
        "5264784897912598384678392200864189243829386425598374397938130908968237282949373565710105887439242496421421"
        "3457126729435160471794471801982845652213879420707161040622898225638702937020553616740975943614118011210770"
        "2980056185861897975475259225613788646834383911028404539765069186955590008203387242247117683291435241699218"
        "75e-298"},
    {0x1.1d2de00ed154dp-989, chars_format::scientific, 743,
        "2."
        "1291789776720231974744171840452344550382511057197936020876953529640730687265974572615745465067992041620069"
        "8777501121683256345606354913401960704423029842081367774831586751504524522776674423749062780692170748646712"
        "7042943546561615399294326604589514550653819458352282966533750051174678662358361943789708146595937329877498"
        "9140003486840484348673799695074315983476709436945484939187203715033177550788146372453950458146622857219661"
        "7273106008632520237983276624844623210830411434978194668918585129565128333659485382511336320510797758394849"
        "7066534832654912056496337016989948283722604021746733182517415331234370695363197261511199956180205135316943"
        "0561914971324547624168015418679749304199862313667091306116297604131976095587219788285437971353530883789062"
        "5e-298"},
    {0x1.17d753cb61bd0p-988, chars_format::scientific, 738,
        "4."
        "1786486152355461374776858263541260614950495378611306967856664376317856708608093736614315389654405332780988"
        "0689426945941220120153421904054106863117496760957640139892128130420227762590755039729804157834222703199862"
        "8589539320999048052554586101710114818979133947966212532305905925289774542948861040799079637308077821570870"
        "3072502377172962357928714199868899047024282661076090342274212069139243739604752292552932633409518449469092"
        "3515593099815763625746247415708072838144287073191379829134836259189096560570733143915925546748005565580401"
        "8976745664144920158206659169946960403857699609960069561793275867483380048607554657047054862232324598082497"
        "358302008075588962346666145156130842715967918196794561008886211006529975975354318507015705108642578125e-"
        "298"},
    {0x1.3499cf58eac56p-987, chars_format::scientific, 740,
        "9."
        "2161893778403732513862252343445239008981140568922643687663896941163644334084345821330989953720210499840621"
        "9160441214807915624700581299217694372147060099730582608651734963216528832267933134373355153359342883308274"
        "1031301445760468599085716685646380991547104769050790451044679611799053816971826590912754216056544099398818"
        "2528853848068150300509122056753832693713094307177084179547175302766171211400043481645401436905858815277797"
        "1778893603240997534730307040753686951999518274826840134999719889934188564885663380751476200671715491306522"
        "5875510502534842446581576198070129986491767883536217287215961728669453640209658291317958839138963689034141"
        "88789632715887110086986492180657573226368342685188914874974230699578026104745731572620570659637451171875e-"
        "298"},
    {0x1.51a27e8a8fd04p-986, chars_format::scientific, 739,
        "2."
        "0166542228894893663309521343065653027086245497896068869059180976583615938098889986991041485859172655850284"
        "9231212781790493656064318876082158442840914388695516071513871282541627904960007529256925655758366238004656"
        "0935056627139456537528211198364194749602836764902987565025944221130708673443828163387359505375370290009445"
        "2745724436276139585419606556712353250612586551744106137528572254128169189469681750106767803119244277794048"
        "3750210471579159462599857421379948439622868937356578266959909594120741362514869852677384097257555841840521"
        "5236796758338972388174626883880522031537078122191460297407274783067835677391633127317778686117811785197733"
        "8577887683038299362987414194915000779858380976854620285433129268926055743804681696929037570953369140625e-"
        "297"},
    {0x1.28c16b4ed7098p-985, chars_format::scientific, 737,
        "3."
        "5449747515908893859520264700887688271107416558032715906653570211101157114219987495688096790234026558681710"
        "6753141856950390441673389046891140333791267175538211915142881836447148902272897131242054424760323762734875"
        "4141190178165059795776451057876420487228094750780831495237996530558044233292884300493086993773653449202457"
        "8818090715338972401729596065603472996108834056777416770233084403727965152368376850711830195137130645640590"
        "7046607319098707053806529570935342883620442701491795272567870361575635905003352499512824154974326187486698"
        "9060265662902975470835003190344156534010770165498653170496875412652458097421921303135343195297833828784423"
        "96301612754526570175306033284095638792306713346530524716480707592136667472004774026572704315185546875e-"
        "297"},
    {0x1.519084374060bp-984, chars_format::scientific, 739,
        "8."
        "0649390857434579193115655390618626369629653008353154439327413620740314818119036634456720430925246670592130"
        "2576840115065505875190702262346443580413571712749788204695695123012277087263105239201891820479284533969818"
        "5186455177319075030110798057602091473932084908015034567525286047273421566565922229061651406247462013601709"
        "9678838136927214185461292825117230319532485842557112068939568153450865993280216546928857042166319106957693"
        "5849602489732653894260268826761621079492065154996852043006813295420056272714448441938250959284349518278972"
        "8109873701528734475851958983525486767921479203821534881357550897232367303129611065194955396175464225609057"
        "0653475980420477041519013852253561174979884533208594899267372506368456441805392387323081493377685546875e-"
        "297"},
    {0x1.bb4c1e678fe69p-983, chars_format::scientific, 739,
        "2."
        "1182119864764602130642094783087206583734941656216310675491273631944013364753704741751950662508914029324838"
        "5386753482217342594034540534307701346332311222871574796733810364341680474829175453754906619121554670765885"
        "5503073696569114420021537616341893639125948726900059561203121631918388786858610891472826691304489021041592"
        "8204921425043137414284707993217579365651624846035324808539913069705011705983388530603140990470370905914366"
        "2429130360743269466709195978765360244654637182808686838641860759085152084357532663577478471344174751577529"
        "0972240748548223967022722809144914777444077303014654296707516764326758858020731632035706253909022691553299"
        "0280045685258559475635362835015005020199131435664704208816162996076304381176669267006218433380126953125e-"
        "296"},
    {0x1.8fc48720ae1b7p-982, chars_format::scientific, 738,
        "3."
        "8204276533494359839532778695795003743446747435092568229275870270753905396609753758094766310024169594340308"
        "2531804530234533427497205555769804527722891005758348613020336577997700742420034577833321799026159177505203"
        "8674621644837883321860447905574589203789932596264453065004201158075133646977415286488731152080905405203288"
        "6266679457055618321561423956395086302343657062006032766471353302180451828901269627826024873174709466366952"
        "2603971081606399156333469955622929484291725938608707418721047578358097887363479034370662134536373850191404"
        "1367247728531590692172129197246521625036149275003013119095905494187761857146715048378242133953612536023019"
        "323048284861285524529772302016446491866534790783641858391019539842314856059601879678666591644287109375e-"
        "296"},
    {0x1.df9d17014fcc7p-981, chars_format::scientific, 737,
        "9."
        "1669699368021086682830030909381357128562123247466233909897185256173290436869196843837665941337171529679475"
        "3554027780942902843142861485494708552404216026343714053469828571423620780701853124085458958213035274017523"
        "3562430379023280135911193419908156405083538884612994163219093960837540940184158271766902246238563881542840"
        "6251457874360114711958891056340399560828449448045550476994666752321648418727132667488079133200123889863209"
        "9770597084200640414102147020755519357329067231460009340640433675296982654429366131186868621479458580681292"
        "8077014517560803574745671039698546093195029449723264978711517158326702241626826015082812354952033962735634"
        "40918968053523398319267275737964394466129772993407912666757701714015382776779006235301494598388671875e-"
        "296"},
    {0x1.14f46f3c4a3e6p-980, chars_format::scientific, 736,
        "1."
        "0587007370833376930716458861240726931462968747989541788325161898554411576600043532117576307710243415965780"
        "3371982184680260925510856439625563819378279886442352941227379220220640407362537154862374128710810114674567"
        "7514478491771437336532301602490071369439129589842422269461377654471657420744038482489238158431343585984336"
        "4112273523714497764911231356847826305616843916838285794259969923537096357742706370960263518594403395298085"
        "7182155015332054436960602985037397127457131249088164023687141746534813653668115686827607828769158632621634"
        "8211661922776018594564117076133002365617217752004182146230232982446412088873912163365353558350257031136436"
        "6418258839009664698934453704098273993991469348626790718931843515715485182226984761655330657958984375e-"
        "295"},
    {0x1.4f1412250492ap-979, chars_format::scientific, 735,
        "2."
        "5617734189585967686818299768257372568423106543272584457448193134718128599177000553291346980043202473956121"
        "2180367126021412392244741193093745572031930603983359883904384447106760541450042234370555490923410636519399"
        "5271125408960594257515760719605036779487548177007694984011771817662329599641936649037337848258202676646918"
        "0324868409975856119135278174695452389974070452340956443806736535092875052779083369995045277193094102198751"
        "7882529396548606924708322774133458177969737673112380202006832077418450022973957900587161535254837673962218"
        "9939870489332022672990844324757213970295295844625265990020341139334420341388520264993199887535744618476933"
        "977079195980768174754058802045425915342354542418540247245180296875588510374655015766620635986328125e-295"},
    {0x1.9017f415ef785p-978, chars_format::scientific, 735,
        "6."
        "1176671633415973759609001711717395696866869599742022471777599404256210233902902155237520408258615349882123"
        "2345052721336844845647017772470586010537618628661882879046216714785572845072040142162072217724152815520427"
        "7434678258158119268340086515696034960671064545207292832947525798713291829364263480267044200323637785949438"
        "8102548829612274498076763793880960706749651498038909594010336103449964450053626521644029697954744301714206"
        "2487861183843172080607954096705021991049257049493594690141603262357639301600484671778732997391911525141831"
        "4656160745439460383763946147928236577727544572145499722938153200720552176047316890086301362717234566541647"
        "151923209709182593285429056144712640551237160829125782371580577478908935518120415508747100830078125e-295"},
    {0x1.96e1ac8ff079ep-977, chars_format::scientific, 734,
        "1."
        "2442918509206014012028953502157484899302248375526922745314229166692585546772990892217496229641056244180835"
        "5613151956891377577895885020022496772410413988317059045245377611213388418239106676765461468848383746280664"
        "0929738154742991672225168441354650138195822558318864938044614007032745608778442983632656067307717276665535"
        "8175666838652658690245143514862764213610885902701104197953459657922797754442670964483945940232205602535173"
        "3747561716472202211817409708258360725922875465550779760937086007766054677009929064967760576046514113812222"
        "3636084341489934911882403581096088174673455142188302497447440448899021951800042462326739293158886225459160"
        "08495285196154157875508821587667877847598940277661829097687051781662148641771636903285980224609375e-294"},
    {0x1.fadb23cfc26e6p-976, chars_format::scientific, 733,
        "3."
        "1000512351261170557348686264751638282347697441603952716948646046693942464502542196818852403552824031750041"
        "4947458847906837349261846175883025166164806498599908783951915826113591552191892899938026717712946307353394"
        "8255638002534280965595353092919104693493427497172744505685162739090774795106876820569693546699239184707928"
        "5679683543224431856784444083274091500700420703555836987399712520363953870514465047148032607184325622329241"
        "4232090453376616525296057392478727384385760735974124403991028933509493200214488404622950198348128729879347"
        "2514307330004432461763750012676803885387452378858427867468188188241476144860361211975943760433595129660724"
        "0419261927649158173573533413935670423949606511027942182777417112760076634003780782222747802734375e-294"},
    {0x1.c2d100e9fa8aap-975, chars_format::scientific, 732,
        "5."
        "5145996431260139100993467191842543303968665047751359175490329248140080201690655843472208689617281422163505"
        "9465153760311444328611419690134650231524119310940944686897401473972303914830917415065953443301454685388122"
        "8415224134154043819888549152070816439653378310887032225499836821436715596770866662350547108554679082936746"
        "4674575770464713312264697289274394842495745574537422516867037314585991641886069493735438794004631014086781"
        "4902330463154994955086532232557782440079216740709862709191364247832437561527741320374664494632591901127302"
        "6587248425665118907646056283387444873731418111750757745277659752247589518641113946873407135807482894539278"
        "142676044746795852491585953284333927743046282564834512270046662507638757233507931232452392578125e-294"},
    {0x1.47cbd89edc28ap-974, chars_format::scientific, 731,
        "8."
        "0195180800119955218580043524324296264728715452014332332170246674538871845805219648492909707144892198471904"
        "0400825346030529599798793600046834482647444437487683767751220097572919791242799892524698422822978446221165"
        "7237982567495904839900279146786398360818656186570954245843716698894420854352456620438185242918109562666605"
        "3625235057734407156147486304856183344925087301696163775028804963431540984237380150218682479654930440154361"
        "4208533335453633897462326737963649687648265020685474228502202597648554842420403440696183134806821821458476"
        "7854658453964553739423544076630981269681312843563475213302475499714965733582391790622273205357040908868407"
        "87322202915150173415505785588461369367258646472150182028804099587659948156215250492095947265625e-294"},
    {0x1.c4a8aba89bdd8p-973, chars_format::scientific, 729,
        "2."
        "2148549407571021803058758089237874818004404516229096026612875823708185387519711434118448231175696552473972"
        "5514269341594904066527742443470740785459170633244811385112780556696588157177143608961573643126150562761915"
        "6849281750933181906556668480299887622009529190391532401176424108617948387268885330819182146283103769726065"
        "0618579771433274264469131477484276258449987868177936134280895329165600889520845336168357333217832316495642"
        "0441319644683365839431195202310742805276534309836915086270614032968345195613629397653273340702900233535205"
        "3483609729854816729883780272599181867846846521014410520170084903621204572180935977607232534510932678463816"
        "822029867718281826574420236100747585318545294634398450106527178604665095917880535125732421875e-293"},
    {0x1.ae1dec42dca09p-972, chars_format::scientific, 731,
        "4."
        "2091145246438698296464197678858462022320601841030835843206149990791488671059123306883776612699424108754647"
        "6736165489660708158188897653252826134814761213834692117553854271187898625371210169220451412074088885812485"
        "5710541461898075840990354146023487795168820924822425403426146314849307917765992062977805313760286080036912"
        "5671659281747652562037736469615487893495477714687409716479264021912064773034682227763646081732196052572030"
        "7042509474279237735500174408103971978728587499232657269969095263398622200501943268247798636403094152328953"
        "2031147634770203769239297303467977711453401539253419892970190835849736701525053640119980542501565476014438"
        "53999776062961816363960978393038157465241961259638119909054498890554896206595003604888916015625e-293"},
    {0x1.54ff221954c16p-971, chars_format::scientific, 729,
        "6."
        "6739709449862607565675687782920119483875632502307667185780159162168993863980184050971107230906704288464015"
        "6496699439994300838785152866487131226692050111421937130047388309431505994270060996058822819880128635044711"
        "4884254092561109053574594536003321082373236228343853763690520906814230225860764906029592314130816213101024"
        "2194197916325697362693742596076819693587167915078095246529186795090291998404360439137726334573248196108267"
        "0822286777585677288460873248318553492874197977095601357714718256395148609413826610224397173111647233642602"
        "8926215761392757848297473482615711761267249168799474035866969371240333263088855516815397668226530197493884"
        "525983129937954791936115506649432796777077774136549374872640072453577886335551738739013671875e-293"},
    {0x1.be2f99979a8cep-970, chars_format::scientific, 729,
        "1."
        "7465463640233769100638197360771104302050851103989186606102081931650026488304599327327558753282729200068332"
        "9804678627668050378425568460067787042712273854355127306999057546471422220437915342161900314891762709292057"
        "3721527715623421389755093972134547171078825977573421206869147881140899358764839567176481371382813534485115"
        "9835678704427518919036015896266154533044169369007760086516985334355446363476266907650310724315327746390025"
        "4578075093931194270369530646516335045309634453905095844888951319898980495309981925213072753792773010838101"
        "8242065386226332023454226886482050639863587133447070386576679785063884990939398460469896517681871811495270"
        "565050105345772489759853919318571093384770703357713843295595523841257090680301189422607421875e-292"},
    {0x1.462457ae27e71p-969, chars_format::scientific, 729,
        "2."
        "5532945426002904780507157538181669248527607853073242744554647032768966856497503985566702814500794761713015"
        "1141601224844822200746378164407163008645601989012874056444092985231929202649672787574039697242924779836829"
        "0103900949007393832538886143168315948223660409479333004620541843867294642578845204520026497108979679013560"
        "9295231175581237890039211997494098462608140330553092569686196215361473140966026675727675473684805370218685"
        "8212126583546909956560076422277384338487963183774513252266281901186798524198419702068981637862802969769450"
        "2793001789351434068617111543379937626164684311069822291752668796387656882250217177699698369291172140147851"
        "454964940605010325751218296624302065265450254613545551241049480495348689146339893341064453125e-292"},
    {0x1.c9bf289091a57p-968, chars_format::scientific, 728,
        "7."
        "1671990510048377614019126542833310289999616144912903876805253277584351602647703123458355536528192167364440"
        "1662353287232239949764532980184843582562259507270415311588513053208283288743801563778406068749572307800194"
        "6125568827170156775233327361851224388982041403917785806215783044313688219646403826782962055511360668264737"
        "6897088961002236150471094097641106960350616121428369305065826571573273641647725775688943703343567101225478"
        "9953333312287057640008514453879865778655393259160740174367773735675048949532421715134949497702708361285237"
        "7322542673884527343694192326023200301290131404052076274549091612163177499275646656982709711584001572445734"
        "84733167635547219613675510582898110780193501917110197874105637083630426786839962005615234375e-292"},
    {0x1.c9a6c21c0e44ap-967, chars_format::scientific, 727,
        "1."
        "4331413352279302128149191072605813876697528611345885441115000029609556842920386965482577284207290323742533"
        "2199509594307830151946681984866655822228339143835403194270253223913061678439860917065041842332387051370077"
        "9500944288148698788627957916496725038596154564027501474646179397442030182754135054292301436144243035179137"
        "1270610282715417684609169626900527234807117188403332704905395975649634750649953559577652559528484291031633"
        "4676186094662346061090628337052908713177247664619683224737543046454127747542696798955644966121171604862571"
        "3175695589578575525883542807316083301746126724381306477578494291843709874477007787068278367148644618010713"
        "1875144882846097603267302176234293033266604144621188254848931364904274232685565948486328125e-291"},
    {0x1.080ca19dc76cfp-966, chars_format::scientific, 727,
        "1."
        "6537479214140957496644432073018089012144452120603766472454112579144784777132047524978251678680652305622500"
        "0499253635866315767976997523004602180573355978400757182575064036053958408210190339447230879379051417089690"
        "2600640674876720995879922414089510417178382171731253321930144431314913298710310772875402641130578414655191"
        "1643305304636464367182427851593250624197965599005919337369891600964947788560805510699332326217569801868088"
        "2270353417276939433992552778680098874211345639068458050074871457491113617241586311735177325328666991945594"
        "9361607389174582641520633304112836941762385362003194298015982774531160072879490045018610848272352089449297"
        "1559993956728196016916768467473936479509527842902093242027916630831896327435970306396484375e-291"},
    {0x1.568db6b9c2a6bp-965, chars_format::scientific, 726,
        "4."
        "2908439090205467290104179871798651941226153898698783477673232932487248769134773470874791558624108005131697"
        "3536088629026557536545749155269194293346060062071094839619735992744602682720872020489985764651605227123683"
        "4449315338589395858711154446384822881445654088301480606833643769669528121156913759180085536698487352616174"
        "9640088098036503504388607252321301774363944935742492341884553608844792004824932319261176330222096044026500"
        "1756051164867224989944424575770385717357779091208619818711665610895151705642793452624142140189626570619779"
        "0385808753024813077649775797625712909337310437672688236559439684574369461412897368191004528045867884390464"
        "739907179528687280026756613807116577015152709246269269183216010787873528897762298583984375e-291"},
    {0x1.8094bbafe93acp-964, chars_format::scientific, 723,
        "9."
        "6345631221449255842528627098837665212135824138580247641095033482922043986659116736534146977997184184550644"
        "4601994755561347497711188804648235220805765618575601316863143054761832211432259334276682908110694267973267"
        "9363364525747904721132014099792189719325293711235087718438176498772644269414827594417119678477271996103962"
        "4464068850461484304306996962247952090789771393359568041684499232396514214051736756405489381778675872598742"
        "8157370116667389407454794188886316922944939839391299995745043273460133146343884929041994919904676232308848"
        "7621676588987291499515095008487221366327604330469301849090855522740604347010078082126314423497545739632197"
        "917648583593472744787066092183286022494344519144504612739865478943102061748504638671875e-291"},
    {0x1.a4d81255160e0p-963, chars_format::scientific, 720,
        "2."
        "1086057222075156140699923441456450084308897252727905713437086108596166987468409078397587971487533636066512"
        "5559425961800525159988473481938995387145032563193842335341149252710258276907339069644310335615204766793420"
        "5046245456558650038735730800871978103887994564534273473274917826583210324132525399524175049381515195829365"
        "7369564370243965168645236220245406226889139007890757799017450226883309511109663784656864385739561274426355"
        "7657149281665440973055056669372106589677993963623493823619251634129655150817988363340633174195752548807091"
        "7823271593105149749384800080661837689037203940523891442460358685629634666925659895161508889612895551671788"
        "573863480573115671110693838776867128142144224012266562340300879441201686859130859375e-290"},
    {0x1.555b4760590b2p-962, chars_format::scientific, 723,
        "3."
        "4206800637910766975986348248756809245585722617245253884913765467082902655863539744793091912901291965590203"
        "5289765511658279266066746655823602750349947919758040236162078686374492458909606117047221706343896128942681"
        "5347747096631346945775370008450257597462683149099332669442286046338578340101553491642092478945964573763265"
        "5303976057606048773717878928602898047324228476912795333101577534185800126676720392565056992132832438154329"
        "9424787438555730075039358292293164678724048090901309369949159601150254447351579618707251348992673994468585"
        "9607150588631254483057331394140758973297520621645166366212282409238633290902812737463038899559245953449436"
        "212948563447937782437491106183531864268581560058202217788902999018318951129913330078125e-290"},
    {0x1.4ac2efcbe3305p-961, chars_format::scientific, 723,
        "6."
        "6290167589677367951375617422929271680606864220946847505992857434808143549267256285863593676807534571811650"
        "7990734126024664323017252510560123157213222771972932719343366101285834110047644303294398466421171333829299"
        "4338219373247383273584684158361076342788872926422826115587259635077003684919003684823669045395557799403510"
        "7919232269198025498868586627294909726179966695692030720962338197573754049554465371037256488197839056598921"
        "9877292992603247756361908752192553418763996358838205450960619495274938457068746433456118860927509511328976"
        "9257647430285377053075634126944778075167863283379686258333392834303348019917586267926480779517948478918927"
        "063607609213267237687171277444430229764849742991883463361091344268061220645904541015625e-290"},
    {0x1.5152151a900e2p-960, chars_format::scientific, 722,
        "1."
        "3520946857575770466924336009049788127880386587840573750855126370148211922936332843549880833329104097140562"
        "1291061084670927969996645981504375234327144377801924067740766068048371191442881668323888989913832196109695"
        "2897929141749716680995649364750852884940442785486690547343872512681947134948592736866712512591490524779325"
        "5090731673364236766649870776441267794337031914794723417664812216517460238008000903094550881000779334604095"
        "3306025721701601332578457998076339413637327928622239485921271826646340819118973796496053821335859717066618"
        "7905138168357733394815415483037124393427107254818942235087012334513591656298823628107449960996084615787537"
        "90281688211841686919921141420718345664751217256871473892942958627827465534210205078125e-289"},
    {0x1.7e58e6c112543p-959, chars_format::scientific, 722,
        "3."
        "0651532125319828043611403886497181631776301530986382422563220573322643168258847453877099886269667781939003"
        "7796781862197307930725514343043551254211702279911167296696208484262395929929119796791221572069220941246112"
        "6684609711196673612053116397582155620461783165845586140232413390195514862846452362791383900061129942543777"
        "9683856317930346474170707234461546445785222564966395233185078975823809338083628329613971259053735059038816"
        "9226823931122118444143013014003539703511505762260490564710070701542059395640989371263266941829283247158447"
        "0128679373107055110632193260404785063947141156633187195789592983001451297372755688720100822729534737038975"
        "00046421729618175608545958200349764878121067677996247624605530290864408016204833984375e-289"},
    {0x1.3c778445a2b30p-958, chars_format::scientific, 717,
        "5."
        "0740229754679630015597497635411251704782842388847706892559998222461039019858354788545899536364164695375615"
        "9004970663065251376452644444722367868679833631961456879821363325500296762139359140059831135664037636091103"
        "7851826795084045937024297722699696856108091789878307056427588017412016141242065429389459914673058410334447"
        "5029045630695628818864852040810568120665859876397220638806076762863741270024917808851144173068814023493123"
        "9465794949117932333473719195382807214003119528830022330600771410797617629186091757430776249487934472813481"
        "7295607280179935636124185858339459651464992994383411267201247553011716792219570153380458235643643535470204"
        "673305630435954878625940750273716264569061340505840007608640007674694061279296875e-289"},
    {0x1.d5d886a6af07fp-957, chars_format::scientific, 721,
        "1."
        "5066401531008765660209715620847113430721240845311467067488393060399424689768179013689935270456617217772626"
        "2449294236315192284938560348589795751273940538757255549062206419695642046911817014605594134791735095417547"
        "3496661062569118259538483356471500150312765170021570234313983189886563782145873240440323828891290807194213"
        "8146945071589392359015982750809131377045618332285170839599383602029439803065564549875367002305011744027345"
        "4791998767288977253280431451014572515866251973827561103685944590487910895898225162299074096391327451735400"
        "5702009089867354879711711819298254603418980386599420783790582966667612569549001195037944795412981296229040"
        "7978653640090229326186696355379052802457638497724001780397884431295096874237060546875e-288"},
    {0x1.b4d6ad2f813c3p-956, chars_format::scientific, 720,
        "2."
        "8015937941494582893752219699378451541676163091913910886367587801515223826775770979017901213581846339239008"
        "5972743564483406182138794082415708206777985372462737529604331783161052369852259640641682719407243347401272"
        "7456932011627695318546847116981997986538474037406413302814400876575334916367833693107072636011428947924771"
        "0431832859153979633857644425954502850284440493944167381091614718033977997952112454266036283567034492773027"
        "0297214072392515941181272044503439934946642157033684526504794793241794104430220950327217291773091671208313"
        "5200570135510136075668818444233387687590160584099397367567846354051160569747236486489617845200348490288202"
        "051349985773023756814947896164670199036189450481071361309659550897777080535888671875e-288"},
    {0x1.a3accfb847f5dp-955, chars_format::scientific, 719,
        "5."
        "3830364529866897070892653133613309687768553145998845020770002508286663820178028904357041106164871662930240"
        "4292326281883963909154096452472893947755538934242330914543826959031146221568246692512569359075149804195162"
        "2455286861325460251680876019901469233112170819584404180268970996038988942682994555869177877222572726704409"
        "6706370606363455491707358638817637507737802603692179707323013726519499078873069293802377310441059050095455"
        "8409431256576666225481896876642690857726316749420932215444605654341122928806547906002555368770089678159201"
        "8321956437180967622979120309900059276854565582725176763468818525035142169991443317320021522630614922936712"
        "84130552998907366615149384496898688035417847308483629831243888475000858306884765625e-288"},
    {0x1.490cc71c1b5a9p-954, chars_format::scientific, 718,
        "8."
        "4412342380502576546081430450113714547500629438411347771053360322063370388173904974678292331037009777086711"
        "2099414815476448744759263688277212497420153992338777818006934888909213572957511956634738036763365144586177"
        "5322858389270843029115166607895428831657856603626176699984273793880426192286194266443686243608836600001354"
        "4530110132454205033116021887062016086384595971121585437748216881228804338113019161359341335927611034275239"
        "4037940717746332315355023656647031482236645528004617260974202488109127266152579244998351781422253738236175"
        "4243701550773001844292452055370516538649507594510998476523084758454303188096588303409769684799427283670348"
        "9527961893337125050753747867908906204526854610836750225644209422171115875244140625e-288"},
    {0x1.4fd2a30c2f2bep-953, chars_format::scientific, 717,
        "1."
        "7229963037415353860036939274512602607703473934570316813755563202371450285352667556180727589154087041362056"
        "1283459465386257149814404426731073509224486647540553797898000159803219506010895542832878489629573788723953"
        "1749999981802001417396108156377958282976764626235599595602595041214194378359560862503860866807909172646002"
        "9975659200114921786030177059914763470055885610745129137128591706559908111228082064091725340897564033533397"
        "7713665527965071968852553983251712474158073574273322543402496753700449881082906684354028745885662376033485"
        "1322987488292975046799929539221349587261627100702755350754850783890370827469481884228645990808184748247674"
        "193083168557675793886784178115221749321393784892819667220464907586574554443359375e-287"},
    {0x1.e712b11ec1d63p-952, chars_format::scientific, 717,
        "4."
        "9980227888927947361544276876048945527052628694146361153893340602625907491058574989544577033169635434323920"
        "2363631494369169360431693425214763451868479262473007994553742587698599717845223124301708762653254310627635"
        "8615929213885810712355953882567405745554059674387476562405224374765909844276132250641182466570610855208408"
        "4218918059037991974479006158869305616984906845622665393220531272998910203769643038213835331473037608225072"
        "4904487349755042619016279363453628277094581074974439583045948813522912747444842573673747533613488115993276"
        "5382595260797681368667692815244795049862397821162429723072459989031430648448876485854621050523129541804361"
        "218208441699108218502865720166791044828773216135431312068249098956584930419921875e-287"},
    {0x1.a951cb6dfa80dp-951, chars_format::scientific, 716,
        "8."
        "7286979124915840031811171249768746744436889710675327400944811289743437499055150408336143447207699067554825"
        "7442958324490534088914416947203034596292953382062295275457233755524482929174694081985804881831251240710578"
        "8126951104999460919138178657731447361495992307164569451115113425119293927665641245442265523577467103975280"
        "7359164333796045189813934206387956229569099202670383997385959263031751034359811529335821735321526957957448"
        "2300932318121087160706915252100028942112875612578710323463601402080899019147011869735277375358119396699255"
        "5371084452440315677385870831672103657333622119478297079186131716864900307968338276669280687253563323393612"
        "14932314316194561659184333914511633536505164077112794984714128077030181884765625e-287"},
    {0x1.cfeea9a77e27bp-950, chars_format::scientific, 716,
        "1."
        "9042271010497776332001708801330615626361603928163568681486870742545599127089701284279280984207169692023217"
        "1320030282687303728445015162144559242089873660014349397431364036606843290349007956825150392182396077699610"
        "7081360034058760638306226987187123573951079730136436300311799651097396464377723858909261474710812858063665"
        "1516285060709599373476272758518992824461516136888329866236431665769165459746602035234128545216729573491347"
        "1603418758679870235818016847163544362617754381161439704896309338364473880342545334782765942594159926024292"
        "6776721855571408975646106864867688734105951682537834904812715247258315613008475070905740733513696526664356"
        "90680061075434980258140771483701977439921548818091423527221195399761199951171875e-286"},
    {0x1.61502417e8ce2p-949, chars_format::scientific, 714,
        "2."
        "9003728382951163001336386523617062381286133744090594743589414411368340653555137244271537591451655680687315"
        "9732505961309688819203604378162522072256819193225779837080532812628857860412608929343509699484705718495967"
        "8498590349546873362607386039910958079726915480506740564727937744213886081662414338883958167769615634834449"
        "5208205332455141483630438934437969676485027072711307631327019462760209568508259406390712220813594963156926"
        "1054788729428850637210162360658988869878013349259167463031826438489783029936508298061711618268376301932063"
        "6233705491974210920522838275477083252004563254028764269886961406388361787734609729556483215835413375983163"
        "021711842878443424060979670008305676166815434413592811324633657932281494140625e-286"},
    {0x1.6f4a6043ee7bep-948, chars_format::scientific, 713,
        "6."
        "0302300114805323360867140613666291548447107657508151641660095102893904089283521303828228226597660628182350"
        "6911153986869512195032232066813781715107387668300048677099943316832593032950727022533383996204830780873687"
        "0336786474106255162862393383020101537774908499396139970912718835720263245510686995538097893670858302693490"
        "7891508455961763342319381299089701452017976885541745003090606738691178664596292998458754512228941266385244"
        "8007064836689028083268810534974265755607698465042353718916652874807767108414470421851891490105544576545965"
        "9578607346221279870994992550342662655560173662144012241644703804158632807596075223431027561864483265724367"
        "88800100967001687104564561953359727412837809623624707455746829509735107421875e-286"},
    {0x1.82fd3aeac2fecp-947, chars_format::scientific, 712,
        "1."
        "2707290656410451972148714179141781588967973845926807547334471277675980850408554878248054803892782582018822"
        "2534182569028299426262570059445694988348700318777825258518784535605857425130299671300426071383629977858895"
        "5387337468219031494910244066256770720046737203696728672760192370711138924283768772475940785693724826698986"
        "0466008993894741453396502146202005519277127551424134439683925893021558019255827189881118691971239229665920"
        "6657060745898812201958149661378249840066133255936674274226197607897248507836438905238727384458811013417251"
        "3379082500885683858207793250918021016981595825486761813591464957247173777907417675517257352395503235491976"
        "5037037450328159638720514623892016668749160857032620697282254695892333984375e-285"},
    {0x1.fda8896e44ddfp-946, chars_format::scientific, 713,
        "3."
        "3470583063356332108498766757166506385353764031783485196998561866179457340599432256217213352642082359348776"
        "0065619379843121648679832554328338726173157671099841073635018988556349126405324929433103638921411010000406"
        "9970975541397062403299836691883872720101591275772567836499474144709269745164033553143381865980948114813450"
        "9563323398425378499328625730378201514987590090742627365532394510810911008494010157265556059636318908537716"
        "6588265752427397414769519174240481162648267831006229274985704703073458419860862001834681264408952610279695"
        "8120272042811100264333042992405966114086480503347740480307977037393767702327170428860861334438521055997639"
        "87519384051736961186649658053551804025305127510137026547454297542572021484375e-285"},
    {0x1.f63d0121b757bp-945, chars_format::scientific, 712,
        "6."
        "5966578537292035157422433162339949684328657517781425278937040263737397772577187341772038360860221866728139"
        "7401687446570117084677990224984289048367008807112058030080344286777952675512614595714878804489254477073655"
        "3631788209373029438911737396887226525344476794228878774806817015940622309814103147301158180909849015378481"
        "3123115801307697707920891837072640679333216386798989999483042211053745064747961945094371289546480468588624"
        "6554648581517370471456957394934735507329277236644627330631947684311599090344589073145189553679017707785009"
        "4743043339681131317035896807523747130636300631758866165476656409393301104737836983161194297942630550081578"
        "2254835380854001782230228668880262464513375419983276515267789363861083984375e-285"},
    {0x1.1abe55124f6a6p-944, chars_format::scientific, 710,
        "7."
        "4273986683209386002029183146497792358537735412418076229677375034053108781538417130596628794716377703048792"
        "0439447874391640830497329263769197669372654570210896760100817222039133059067468132996774053651076190226967"
        "3589441074259230065627957038293185520235291906031948115381397829092825319154312472026340183818944682611111"
        "1156145441474169706609373281586299060755244822009110650534665364827404192153653867280756103054142218360222"
        "0934581061734895574051354048724565591943722679704655789621606831198408689956651820414839333271464401183877"
        "8450966879494076305659347420726388904357845227958574995156936912713306237255628189778269960699349488082411"
        "06386418643030651008928724469602099256260174797716899774968624114990234375e-285"},
    {0x1.e1cc3addbf112p-943, chars_format::scientific, 710,
        "2."
        "5312725644714645962947927743805809804618884397617821437572318458550743118084862705289205943966038119003290"
        "9589290532205874362493462899587538183794311484367769029075747596682977338151350446246593552098587417080875"
        "7851469248740093376850022734253382347640497467551967268290362838553891696265966263369157173634431861777730"
        "2846800242763765681365778209538316436546166804404273332427861460075267064607964574701863428965562408362011"
        "0521953699389815696244858788510527465075072050708829210926602831437546879251441709037514462450585484637061"
        "3750986429422869415728090168020176752627553816027216600373170891796638653891754210465863152465601677758468"
        "90651442682066021379729291296127070831634142678012722171843051910400390625e-284"},
    {0x1.c37ea66e435a3p-942, chars_format::scientific, 710,
        "4."
        "7441324100905745554574287302084691280382079597193581631559111336633158232950997129792894980805894193066494"
        "7024126350169270196995072745313996409498284229154731375549048678636733572900612861491971019072075638834606"
        "0562319519438688203810434951289695484950243280779028505894245638965721460493474958616244676132192911374490"
        "9744685596656046149778452097128786811551965968423994803335170886805118220108585832414027702378690965054682"
        "1132637590793226042392427342459479251395153348234719604672659565852875863171207615153939055490446947865662"
        "7069451502833062779732643453355045985620373037341930171564015143867075156826922069841065014424129701542771"
        "86018963546023944039247179557390425574947556697225081734359264373779296875e-284"},
    {0x1.5de150d8571dap-941, chars_format::scientific, 708,
        "7."
        "3528110594538782482365773897168607965627670328398853743572294287489462941040004923609086852490422148378042"
        "3221265352794066364321977056316193229087193345799980407047318859371585571006327608060193056679922161895138"
        "9023450857711029880846747347949781266947671465791140498898018902300018409192427375203800129541619913353668"
        "7913336770565773056104716911264461178801127817029921714572406594873525451090759250061606175297688853642741"
        "5063374341194168250819599742158320993808193105179075468474640923879534600345563234330664743865595922943046"
        "9027013248365025737108296595578764740793659540153206839917157674241108599911219442200327046926386379632794"
        "706173770738386202136504580487326443449802582108532078564167022705078125e-284"},
    {0x1.2fe740d15c5e4p-940, chars_format::scientific, 707,
        "1."
        "2773195914029404839997121365019846678012360652350488064445378102080680878178292751812127902282256650732547"
        "6245703207416712594596348672625016459895425199193206223669274574590781615279792558252820397973515964842037"
        "0516008716769106316730250486845936703583635694598574992126846759388865096988008602912529868185336100299108"
        "0553719525657790562548044625513894808092631398771815402398278693165346783864034097203390263050764499973133"
        "1176557957400353328895833934462164126215289648841232814684151554950526609425364545645803014958449858388387"
        "8330615551788311376615569801461643158576202752253276793725354647037131210454236435093465752334159968626474"
        "04985643869421282773361209076680433671668879469507373869419097900390625e-283"},
    {0x1.74c88e0ca098dp-939, chars_format::scientific, 708,
        "3."
        "1336514683809335823642014056905165811057462424986100566379077646256522264565554151413406651253885848300977"
        "7428810212153271901858767685448835580809572557049468597099913066770055289698506664019615839038475534710535"
        "5795137683512491796292640286340784407826504261360116668998806692920326410697970081470553311956742163565291"
        "9488919030345834471449497634015773733880344369868510365310417368327167250001545295912972407904243385685009"
        "0568326188908814426299175347109946078168784813256752832581828231750592798891910497717653512598209256212615"
        "2163332546148270577877121959807562829701730894716563197686457689793871379392247928709120246303744498721385"
        "387058298586846638108429548307855283528766676681698299944400787353515625e-283"},
    {0x1.130f11f4ae551p-938, chars_format::scientific, 707,
        "4."
        "6243399480760986651758048859591898670257532481551975234236150685657300241821139657878022784585233874791240"
        "4963492241550289496212262096830935350508363684680527380586207161154519672283951737774939811483462728083444"
        "1777428783029826723607606656979273452995057139008359627554000935187030159957139984855268085241021567271742"
        "3431954876230363643507044623195289945422834721951642431654272869278279463263248928505373646536454486629285"
        "0388933272047691776851011626956714255714297331667761444662037758523239544520796498062658035671762514053396"
        "2546352624989961931110902588588758282909374019543277991567132082147774864908128579658562342391043382460857"
        "66373351339663978363866896439428322285181138795451261103153228759765625e-283"},
    {0x1.08835fa35800dp-937, chars_format::scientific, 706,
        "8."
        "8940877727403413478054422469551585361360602132146479276553748560572263855354900108174388413873810810570869"
        "4447652663318550897683068640027357513815073547307056520232708373475428951985938086920965381705362856293155"
        "2372597405794368429177559397287482636064879735202907026717819924195853075278831851189896959260779613681724"
        "9507141535585621250711601400414125889337957763942399330493823244145586671155604257863693476957809385848081"
        "5602432524204309644294980503300147419523958899518054102661427177982614986697817162798859038178707067029274"
        "3666765992474172041115451984467344953683138400045170040908790923436569293770430710009650254127241328424225"
        "1963700416095371587683104442657866517407683204510249197483062744140625e-283"},
    {0x1.6431e220a8c23p-936, chars_format::scientific, 706,
        "2."
        "3953652083727512388926071411736651094684359629139545046331701056101374156295569337074287726281108064839092"
        "0197220354257125643370788918721253430411000497833026470918438064748906303836803667779264399037996493294682"
        "7799070539590992054178881563195508842237166002254838778941432287913764333677699977715082668936870273420684"
        "1637889564941327849417969580798865985391354437385154150217050073066367310703953519083722746947699236233991"
        "0914485251702387166357531280402329580119848376247994125192476520054069021178244018175790204834170600687522"
        "0061280292199496428179636808244244925634931880191201392142822061160051761870987672004337971307673840421985"
        "8403977956304139210111692789677284576299598484183661639690399169921875e-282"},
    {0x1.17acfc1134894p-935, chars_format::scientific, 703,
        "3."
        "7615674663262681818855898106340652384824488135624420876733253077105060946198861732627493193519901047247753"
        "0851516450610526148310774617875503789522940191314377583805558176016959667319286171660282631959695917660262"
        "7948161600893585841102962267471970566960719972616815524052330290448761157948723719283892809603393480152922"
        "6963821818326771744159065697180266351038889725789977121282586495071803503310337622258942765229731736751373"
        "9802285453673323672402567322678297740121435959673931330218239056618465199032675986831449764985280751644590"
        "1051071633900768229571292193676658069223654709451072516761075679530496081880163478624608778936598616058103"
        "8975154763000147609318065712591394600394778535701334476470947265625e-282"},
    {0x1.e09c9bcb32e3ap-934, chars_format::scientific, 704,
        "1."
        "2928212167160485647289050725920773987486183606941436119505729854684825071061879741408404976987332542805202"
        "6475209722120894427905829017312531660824109185257625493974124746918871520377551204868603233138855433546350"
        "7137482116585173531717089284209974439757094815476313032633987246657466217424082287904980049799285173092360"
        "4321033958606419596582626473030678859231047068503703431925355566575260878258096148842990948930661388461594"
        "5556331126875486164601415077624257882874367569017493013432167566077044569124299536340949294173450937422124"
        "2410848684155513238368365796187170024735560371706926710527316014102463624584103054216799753888489426954230"
        "67389883463190992127388374323404551802241257973946630954742431640625e-281"},
    {0x1.a1dbb96340c68p-933, chars_format::scientific, 701,
        "2."
        "2480352182123752808136544940388978663414452868402807172164353048087159318240699108852308410935527799042372"
        "2607479167570828666405584023758943395449623547786265060474719000797492782936683920058858257998717582822367"
        "5779905454921856840712616925561352311554761780822321050704750714835793645031281809131734465005054259103162"
        "0770295421779702653225582120691078585469805486852420383602140963091660990507952839665684312488509192593627"
        "6146801902962301794667900084167998719481932390233466300406339130835304539931159145009172042189525782968134"
        "9889384996716260685606079478830353867971542977200900041965604299936591138903279189511225516719288109338314"
        "76652227485316062853136671872977814246041816659271717071533203125e-281"},
    {0x1.2535112b05fa2p-932, chars_format::scientific, 702,
        "3."
        "1548509399420712639272059276400333316882547293984026315247476639493255963348140121345690526759136674812168"
        "5127366607186078984663434814626878761946743591353198878185556202712852448632736187785808850221879652949417"
        "2466935302619475876494375304284254242084862440019357167612816636962625129579057766644896049407870955464974"
        "7335787221346083512058193881301726918508813388754032954001938768613080740109292797103362848370010728277700"
        "2447037363112380936616653230090833282091176580530259321841919447337344677998409580350026291730548714720245"
        "3464907595976076416622159108849254870594068881747711745858983412187878188897296623397306560923894227742617"
        "663131411366557437721031172117580609892684151418507099151611328125e-281"},
    {0x1.1a21c468e4a6ap-931, chars_format::scientific, 701,
        "6."
        "0713639849830441431950666885186177075226515153992662907626497301095398390732446604186943203382345914038884"
        "7323282265478315251107842926851637284944473721522256210665632511691427823143735225088177817782851258604105"
        "8802465427960568227820236551669931647579766385297520509184110046667024917465803528176712653827604854690676"
        "0539717394672162140625498504576723310423343077058148234412701000131002157689180704997981873225601677878672"
        "5558225608403941078353606559612621001943710817919983755745476941534320115237355705280174943756986505561652"
        "1642323629981253371080878813132722433052139744568133360474352311923115847036015008659884511808602933588905"
        "40549489846723710069942465950010301867223461158573627471923828125e-281"},
    {0x1.fd135d461e64ap-930, chars_format::scientific, 701,
        "2."
        "1910202165183367961031144734329017463226979382701869453713513013968249085356785932288012024393541953545552"
        "9886645511615889973880166664007518614802113825590802875492420305574416936839892706860731192309333765848970"
        "9908439585083718902707887189552668448593889249735204217996658815646772179955571823374833497551591956309240"
        "1541329154965837938438971554547587418225460815133461459523484200094358091531238453626872459122480596669953"
        "8348727335482836669569692921603283834722554959131362093164174528692609148104334930473885438918883552561594"
        "8363008632224664238662463784686332242084676173707932159699210038441526890720252029751413671687868241305111"
        "90159598977575695967511849870934526052224100567400455474853515625e-280"},
    {0x1.f7d9a435e9332p-929, chars_format::scientific, 700,
        "4."
        "3370603492213999246605109863562578922697904205023479088354225118411162637603179888703710226609475240843189"
        "7778308805673483166109113138700510733670800321786228644296296310480876601318227660027323174410959962952323"
        "1073474743346300893802816394194037660492099236546107192724017030062164767337377700574128707882663321060086"
        "3968698996521352740869816450919671756597948507794800031118955538243210878544952125774573985954020360906486"
        "2954843068964485740002357562419225222618117352360709939373196717678314283249625825294875669011304620563035"
        "5933690645526817739372794594388572468529067558242499477463165957541382915860867194951359610429773433468680"
        "7656652381430992566229733198301943275509984232485294342041015625e-280"},
    {0x1.94c659bdb66cbp-928, chars_format::scientific, 700,
        "6."
        "9684715728693185128958785274644908897459959339474683388991916442657376227644833807738962310289463011013541"
        "2100965211658967777232367812792866866542712076638289606844458587892947675905576979450985333650908225454235"
        "1258556803112976410432769807463403605097818593159599336715606881192650863075807426528516907258685085390493"
        "7589052995111653435060748089104567805432665743598861338717605076720671406807599807657542183118213510386647"
        "6758091298822363245367286109870252428162266516719305025469724969389301398868015871079726249945173149617262"
        "5833737082375357463190498230523012813555991495326869696530083748073407599377627499057902905597850692529203"
        "3909987407906166508790406222129121260877582244575023651123046875e-280"},
    {0x1.abe769fc688c7p-927, chars_format::scientific, 700,
        "1."
        "4733311152437789540227053092678323460332933852257475188822441222074344436589917689823247953665290710696624"
        "6909916118096358672315472282160539273894339479994193169330520625936397519235918130249340730882903493307621"
        "0895612852780366731538499350545049966975086920227034460151662663011478742176698549702779007271900180889286"
        "5490797177322439918350145063046375849294907349943601734582058091677850466600549179567598052592528981026904"
        "4947060856836578814899623194745365093095429477087602427196556222424895294076578456413124521507596172456938"
        "8251331129730062208483813193703538285744927685484325243111761550184614450373063948573745792548306864820340"
        "0069389217127511839951041483498528350537526421248912811279296875e-279"},
    {0x1.825701170d480p-926, chars_format::scientific, 692,
        "2."
        "6604406094948299284840023312889151895045655703225518408579970423545100011582978514470567087920738321442927"
        "5307285432371144591909800719245957781141729612931668439653482875327754820963954270428962349149199726835698"
        "1184592735245864921999727092722643583285720404162313925726900614240612356134419032262428558843961823391328"
        "7064205337047968262378349013995361823268143063235754023395627339613127590917817943514492812352700718204492"
        "6865908504249555492149730428374342137900767838918385014099377896161172321732594458974432078343771471436203"
        "7560194621358324729605336632503570581400682087260645108688451326585554293824380869245358022373059672081904"
        "52841033281990330838784331035640207119286060333251953125e-279"},
    {0x1.9cb40ebe2177ep-925, chars_format::scientific, 697,
        "5."
        "6839734362842070796608423358963762521942847688739811715193332262874402507007578228137833409228851937575142"
        "9881333886818972762441084651503135482841878157912998491023471197153193567938330820279182603747487685157804"
        "4499143359656487408812158088001014917344439759287983216092513910053323400256593370050435002396967994998634"
        "7831174253791387681379454495092330365305712925878132005668316354328176029389998813412358306819750991589464"
        "1588404401875403708454179807021556382772917776316285266398822892936165695523171539159535919943189320603911"
        "1057506511608802173147778806205368856349281475078098721211793053402011838737841041885975679740409233160578"
        "2924669070403089223518511285959675660706125199794769287109375e-279"},
    {0x1.ff8156df08505p-924, chars_format::scientific, 698,
        "1."
        "4089452631685326968433243074109517968005896956405243537738629556725543089192340456976745618392509456384421"
        "3295122043611679935471391755079980979501871944052554986009587710715393810226977108801992230611058211129108"
        "9485525691899073270714769067531770667572601957595368192889003105509212398388055993160239542503494835067228"
        "3245379563818248188577432178069785517522144713560421250029225560558108073716075633654170491660565462257320"
        "8077336936537681601495287937831361476225032018916859215383170855286140431926630333405822225809755086425841"
        "3403531304832809177251851959422421163575904569070712506755851911160818342317775969283615277190753064800086"
        "42654648867933132806891383115299731798586435616016387939453125e-278"},
    {0x1.9d0f772cf5efcp-923, chars_format::scientific, 695,
        "2."
        "2755564362864926940281773480518310790479861467637050696098191485132841536234255195968894202054768127594340"
        "5052471207178431622061755181896773453067772352444724262922219671446487226142118896359570378668235229095798"
        "1166316968715768476878377717323676558275913110625496417171332179028764068241742129287569330477989538640722"
        "3078981110638172143427694907604433837129087063112485314874144827336251086973085916732340036992251561259733"
        "9675515620741030786110317330091445693562528485582028687881785896904192513842055970675225542253236829083202"
        "3599170155833556378582588541054835832258928781218529554093314331968991940112828530328124430108304974376277"
        "30945405107483288202618876283622739720158278942108154296875e-278"},
    {0x1.5ae0a07bccfb6p-922, chars_format::scientific, 695,
        "3."
        "8219068582864352723967747931343616562165720978117376164184044778882819856109340136059651353300760019380045"
        "7963875686854151814858111036445511242704770934444137666535548776414562807926044830228719368181619572195896"
        "3465354214067102619271776398409728111334674729760537429642740220094300496716298519328903002429770328300604"
        "1946617762562693335543494641811348659320099800248426163155938515097474857985088679151812942108594818030328"
        "4306883294509926394689017938918992450263082868445216830695420503163246032988791848623232836381428857315417"
        "6463928935563277762910223655851384736110714238400238082211026707573695288948291896607771043645486689943174"
        "76597365746052831735057875306438290863297879695892333984375e-278"},
    {0x1.6fb881d919007p-921, chars_format::scientific, 695,
        "8."
        "1031176278644846070191626517872180531833113532613231879550018095229278369791466764376263012400841347446788"
        "4537069420798897444792340459678011732950473018974004142598230372463984780283182332380363238844680055174104"
        "4882685402671409590390401829607859501011832309453302992160500266190368039980817257528474182247691498330235"
        "4021964279286190987699675882237711813507510953617123368849494245241661812574268038787990734683012163703440"
        "3253494540299453377386417370013446614658571822640671013053242841183193770612060018133599299419386567835242"
        "2302987448586734996718282943690713535168181153513958291979209420682272276968832405387188696007394808815855"
        "34337397162967550449941267487474760855548083782196044921875e-278"},
    {0x1.9fca25adf211cp-920, chars_format::scientific, 693,
        "1."
        "8324734254279028869387784372851448047860823258323750611134821016907972862665862948679459543729058185314029"
        "4109234291012590537213580345220640336487442495620076073943474905128820570844254967289771491084820829982316"
        "9103036957205913876376666459893503223052173089296631419583528827717374000015474402335079386664374426327190"
        "1555348969754355893424268192757537688455844358838861788081285696553822294575029080340122592400621898485210"
        "0980586377051787274079525731758978655809619252450538245824044682934365444142441443713505465606942364261493"
        "3323336396499777095021957372015947166181084102535422709985885556677780495536599067966610216695720290798005"
        "524230155507763549704858263567075482569634914398193359375e-277"},
    {0x1.3567868a935e6p-919, chars_format::scientific, 693,
        "2."
        "7272220545317517868889157965337696025274508420889298588711181595213704043378248791909948540380616435611593"
        "3910336212536767318988081781070397664794560055943968584737578105345111712898159054166131527987411472217401"
        "7866347800567633763552707314540341731219481235621611130507775509864789785266383510150307545015561531035709"
        "6185185351422301629593018870035843562289123275825378701398430382047446661917309450697462735918474031918662"
        "2340850441148530538284790831967160290452968341473708720459139121500038263702725273690181380827057032060125"
        "9532974827496579814102373524204368860193693113227607483201472667063978336888662018926203111235696960255284"
        "736973595876500901791228415049772593192756175994873046875e-277"},
    {0x1.bf28dd0f45ec0p-918, chars_format::scientific, 687,
        "7."
        "8829105150282179084399238370911642114983690457028991880625181033648641884093153361369152425774473922157315"
        "7774153926247698010132275250508458101810012251517742409690624130795818557484012862321262235357269411599568"
        "5913932502489931128923562170444579956137349168575918204365789567048958596408790512900515843150356938508578"
        "8171741990769154846781061888409738831181893137943969463124620309874532188237550188168195998920556942302867"
        "4792427236737851009052228703362388910682325650020113635567569125549130164578253048806221058312058858233667"
        "9214533967590618353077697183881161890577696002739400403994708829285246662769338823361787863906471416520890"
        "065817296459005358855165468412451446056365966796875e-277"},
    {0x1.a393be0039498p-917, chars_format::scientific, 690,
        "1."
        "4793325264349519609224189087172778660628550715159699314589946835960775139104114196387124361744349388346423"
        "5262499975290638162865880048776094965106354069497400210979615410318388465977151507798144171315330304323435"
        "9885975630954582425728852297479422077814813539875382686759895441332139770602381357809077363620286647587905"
        "6725196621533667569514255202620311480396908342237186203988319154990018200960799763004452095958354279543752"
        "8262461095548407540224109002577690372446359884979680520216781761547575060963446756203043820334004229099108"
        "4802146480535794498835721701300992022479494296931692114542127887432405933594739009899021351204586356951492"
        "886187572435401083037476155368494801223278045654296875e-276"},
    {0x1.3a8c0984bac67p-916, chars_format::scientific, 692,
        "2."
        "2180410620430225517898657079973304666136981289307679736753455928805959725081462934224670303724159485938268"
        "8828714380229742386971411041934144824845530951396830281289648621278119877048709460244734297439979032457124"
        "4210910101722242920154336630006086991235669508210185826348819618229937866676364296126489105865139605828360"
        "2048459899956394727237587803958256596040689177850038369317144434041219912680004534927123313725716843926392"
        "9141846933227654282444232967074996992421239352155928725744678815679120998085146002248164874856671200987562"
        "5412875033658742338513264563614366747586845781134774124232829708849899521351684572920654027513944639970411"
        "74444432233190359349261910892892046831548213958740234375e-276"},
    {0x1.938106b73c776p-915, chars_format::scientific, 690,
        "5."
        "6906497436586979168324009384548588036589095543759130627636379562863411660649404239561145787562444857179638"
        "3242916879169401001373374357414748760162350056495718058588423534096485487067553165909715657381402971404442"
        "2468094756706901074082987816674625471919162817470744562403850861742638326686838831329543166906530868544059"
        "4898149718409995904694095670341472420644316999405402196876112361507834250398148271011353848871090482305740"
        "7709927312703785037310249086969034897324787955384440730093355487897020162730857189426818122829178924268502"
        "3478828131783734931249186206288600257156152529666027885484652021194383320420661247802440895124858403164728"
        "133943685880850871239289290315355174243450164794921875e-276"},
    {0x1.f4a40cb3650bbp-914, chars_format::scientific, 691,
        "1."
        "4121156100358157296664884403439661646302276365078485687132001035304070507720766854695035558157858304450576"
        "6940217400099355023661276743227694506565541149890385524583996128825300819463743839851012791085031812663780"
        "9078113983498722820987671412284313866751671649867202543815081237996571345329124002747352450708274021201033"
        "9249382671053582408053415675489886917683768256732181737438581253783555941794602878960721256857697391077076"
        "4877147702942096611971251748274003472604976609538520625018538574328879978037098590719449636953103849833441"
        "8749823932561430082471354799282769696040754873243807348200109701833759917789263818613074275506995243758898"
        "2806943523648328386865813399708713404834270477294921875e-275"},
    {0x1.d90c9ff0ea8b9p-913, chars_format::scientific, 690,
        "2."
        "6685811370633676469151456124462933808944608667956228777777669887667468102141343225224973573822627858520662"
        "8706394471551392518714620362982432694174419506683788723487695530093086709272946848081120027413065121574478"
        "6557772150087296243176647496252440476244799624976290239020794096466570190721144031552410062820989434121667"
        "8829969777457299984096586701156978531800501269895806288448209599476087051536904832327274865690798406014041"
        "9242923626411226561350556759451418729720362364708522318857675731726321139280873439306988245518166084854544"
        "4617167500172223520590496019958399406193343130729441401318451882177563396082993744332324550487662094880548"
        "934381955914103834448525276457075960934162139892578125e-275"},
    {0x1.9dda5bbec739ap-912, chars_format::scientific, 688,
        "4."
        "6692815012344966698882844875437366789005901188975934417131762702284328641862258488125658455485014617892258"
        "7849067391433971807460553436148881053030070580286108356418420118416969143514528711425882108264857440652948"
        "2949951797469318976010031015211593519685235614350499208005655246051120557587904621971388953661755198499957"
        "0757281730469581796681608340143307523472370915834088491490803052108454624701398786420702452110089930576895"
        "3323642622737252465685844839888300778476275250469032520933241067415921740697019684544854238709595905534560"
        "3004485318890117726846497855781173320368657200811902980978359247250167408579989059372735019254137725760123"
        "5072778330693898940495500937686301767826080322265625e-275"},
    {0x1.b3d55416fad60p-911, chars_format::scientific, 683,
        "9."
        "8345480986695514089618875926461208483325452018779020379963044696050432933349843715361682741761584908091249"
        "1003925803323420285422299200257544927820640319697426292214256590284651687321803691614450944195461737083147"
        "0053949450130019955123314130153815851209568829682254278667162756302344761919601995206987208217756224520301"
        "2490168186679900137224439591161763561631529346451548557236425884128203137861028096947942575417821017601760"
        "1378479729168995921054485337026942189492031327824997457509579952046482421043196522791788544424088239606919"
        "5834232249409883053072784499831730816048858974051601859926639595921288052515471787430631231700012801861588"
        "06417666411459066466704825870692729949951171875e-275"},
    {0x1.9c252fe78c1bbp-910, chars_format::scientific, 688,
        "1."
        "8600057734718371714825273518634978354358430652262526675402237331598535844295454808421652847968623955166229"
        "4650573866111151552786059604653573925266743396199432791559547670426194582452576205390410214677534836184397"
        "4555536608449663541605202919437531227398833959534590546980892951601368099412773750211386643708216564687986"
        "8614705595747648294239448551774117577448974310225433244569605702819713532045299071620588883760079184637819"
        "8288424060798361639111043395696475163888439664871728837230441754911577683195623724591428200525516519522384"
        "3673716690874231955397032122819347024452498018750025400425613047170373078212498439755828093049590198255103"
        "6706501029587002005172280405531637370586395263671875e-274"},
    {0x1.37854269a312fp-909, chars_format::scientific, 687,
        "2."
        "8117756756308431810045707418457549719710610000849801105585413392312211123265412907366996179793959773262310"
        "2528407504563563289183363949413319716188120462245043980380898047975666961940548527936494252165792282227270"
        "9751021750995630547875850829787122147998996258733220571087825557332332005588075878604400572352057444304256"
        "6115665804874692939210171450919961655577985423556158382103522613283595365382795523013526774289312455559646"
        "4851187246037583046031577328203772305918749846723310361418283969452255932829276064984353856245298419264081"
        "3659122168387059488839582188262378663355081166412581348801204378576235540860124864292440125940486330437256"
        "312075595780786141375529041397385299205780029296875e-274"},
    {0x1.5b68fa4ac2b42p-908, chars_format::scientific, 685,
        "6."
        "2714270295442504603435251110132409147534667975735926257860278262299612701213671612207350641905602947661894"
        "4494416416416353727267861835534249791206425657048892129789772365623874471751817192007152737100353458016022"
        "5562053419694214377441724668769025436402835091526788281492455721704077602519026610127870369118313142031480"
        "9897533450610949249311456682364212522217340674731787953847187007405298194868195503414511556939417484877318"
        "0287260778212420819630672451773814859942905927714008129810096642973740960075495296454058304959469149948991"
        "0019786761795794622366208715634510022620666391042308290790968346187058669856385832192052476042596874880069"
        "9115977970443669420319565688259899616241455078125e-274"},
    {0x1.1bee12d355aadp-907, chars_format::scientific, 686,
        "1."
        "0250975871333601410285213100183232774538473685218055938897189096735340237340018400725666682494033072536608"
        "4523344487902158562213073784305960609813824694625419037109496021095951526904178029433537609825161518260979"
        "4611783379551401163974146864458329467185443162645279912920460025736906612085102498298245991228083818940277"
        "5148363138806380170433459153981158132727283701179492276737893371060445823347383802426142678436476115955450"
        "1380582707481618618086710570120193173722547747612927374090450924298878319085773548224441762980740444341131"
        "8861570306917779317213969781190995485564962851095177735122684967750904878926948300062887536858489633614618"
        "24513759001631374445651090354658663272857666015625e-273"},
    {0x1.5dbb3bf725a55p-906, chars_format::scientific, 685,
        "2."
        "5253325080332935122289495566127846548934475987700357144674961351479357467092094630453535541284919659245903"
        "8003494070856329734901083535046760786533056388680476864446948292312458125217671960943795156782787115386651"
        "8489995612260332097305108374078181507603174632534081548073471396342504983710412240194257585234633491428220"
        "4317410475710039015821596102435733830265474911659400368786801131458888124352482480324532223906317300645196"
        "6507983841113564976333857639263147106429864722263664851030405649181367011150329531668521843720200537028123"
        "0974830602030567068197067362558553069481671246793360301294886083514645802904351128554253419272228806760314"
        "4347717143702869435628599603660404682159423828125e-273"},
    {0x1.deb564bfc9b39p-905, chars_format::scientific, 684,
        "6."
        "9132961251476578929222904530052273628363552443315557555004747661057069612999210997894255772698684551025199"
        "1243515225364882882698889624584628027249467492666941103078711591669709456393002977814548674714031442490579"
        "1873235024838423268345382820217574525587164194948220489599485554712874650998509771058740523491301689686432"
        "3179317665178723422213216184384022812397384381918414301497856335169286849906525371490446315447355139287718"
        "4968492224551797774340395828836008134619132640683002736269625867150029972744613412338525800662983389755954"
        "4074960661569254434844416849696643611136230480746804569554606627570565749735444390099046341993234153112576"
        "404723484124748011936389957554638385772705078125e-273"},
    {0x1.5179ff1b0d531p-904, chars_format::scientific, 683,
        "9."
        "7473722876297753859094243167038918335732475648235279596858447770771804886894929506661512363400799235132329"
        "9611094127822440521351999791476209022441638779626597351701245970013572675145669042456116850923505846902122"
        "1019543910350446840555896408640821843961400220187736393637951646466301575756491015220368431665646131851050"
        "9727736135505497758609491007485313307150194231963853639010109636728185073120919295228223264260018917015441"
        "5611027124442793742874753965529671066910351191453495845396281368093624689695699465834057840582376163654013"
        "3747927057892605277115304361791933151276527348358808702693259272579380945576312699683565750443374991247958"
        "91878615672343499909402453340590000152587890625e-273"},
    {0x1.5567a7e8b22acp-903, chars_format::scientific, 681,
        "1."
        "9721670909138485406708209875245988754855499584359380143538249663486318133335425048801360176933315465830102"
        "0938111316690961968819801684276456747470648078446092573136974003930909131364649434410677191755964374461168"
        "9449985149741847522870512655148231642390548825459654618135998463059314939845854863862378838430177919605456"
        "8577661945071167810995560010331333745976303201264359555104651738851008461460823371625460226785030567535616"
        "2650233030360899161133192808264578667329162878470873772247704774334161447668174066561587041726468755775880"
        "2755495463473945116677959704440051349739279053896878897062724521932452819827121021438059285702750231882048"
        "720898070737206353442161343991756439208984375e-272"},
    {0x1.82d26b4d40ec6p-902, chars_format::scientific, 681,
        "4."
        "4690483726796048912736648731122955257354188196024231986588312330742257238021456634908826654127234839916269"
        "4465100758770795918495191617148046111636565021984454301308771295767628366526457752766226774136157158677204"
        "9777232414728237847783800185819300150695494868265399989984303418186913936387103778295846707558587698898974"
        "4537743159905346990806740300898994948523687536782820980310082956562976516393428723186369254972697917639523"
        "7517451055069267609733839616408831778853430757895403549124610101368994821095535082159636545165567339743831"
        "1473563149126607326293087358055222847103895464442221682394762176220261504241500948369995664309148768991554"
        "272721200558038390227011404931545257568359375e-272"},
    {0x1.b9adb0b3a270ep-901, chars_format::scientific, 681,
        "1."
        "0205638445192074540686039149619492166036221303655622880582574223699718851191956040320709720157071445964723"
        "3428300334496957481984272637141040116652643064109299002000714912526722350009504846522887500937742299459777"
        "0942012244050224737963234632599223698388649382113915392050770236622145013987906289250667977440016565465777"
        "2786124745824565716876090891358069196313060797768032150978701298003352609463312591961660591133735686117058"
        "6913634840700315149168275684264190692289543505043910139097370899071681006640009246216690670515068530285759"
        "7044837404540088869708210335900301553691604441179068784764324781639073532912521042956144573308772953464440"
        "883496189282908517270698212087154388427734375e-271"},
    {0x1.51754b041523bp-900, chars_format::scientific, 681,
        "1."
        "5594946591458144416815819205468086167159843664426203644788299768110350898895635640473683177179787484935471"
        "0761890097077391170243907498359928566450028944900998781236203230936550568356138185326342260744947797959044"
        "8089980215073756826092589717035140761699187009768022799578563932926539959419689583937077771224903982883050"
        "6603754515352518370426730719503690418615989945023940422246487398920505321270052974773170110606272759183833"
        "5205417118146670159764645404909603278176701604829743198580484412492486663798834003281774366390347368165759"
        "5362339231688365149446598673054797852034665234088747269980370542955955889926977401007116018807400721172485"
        "495540083189069946456584148108959197998046875e-271"},
    {0x1.00a667d829ba4p-899, chars_format::scientific, 678,
        "2."
        "3721122629194563688992695961022591972700965769964962023979613518831273586889391072823312996245341552083908"
        "7786296830599233560970336654641563328353367827061193750339055849152076714473993684277978272782656779678651"
        "9248093278523380946182387181270224161693471305960716801796086350401820941530293610124339885099370122455633"
        "9213480773166503738453729836723477976233921432682499010565949348556862176229902488779233912691955710018077"
        "6162421733605519251254994399050521606947229834703901001343373353991955700195987881196711778257611305372877"
        "0778315767911073839509938476337268634020082539441903467893818834311806047336796227578822931941039658316800"
        "094184362279747801949270069599151611328125e-271"},
    {0x1.2c4d42a513cc0p-898, chars_format::scientific, 673,
        "5."
        "5511359192841546886271708253316622680838450085144175548410195027433013664293688195461190062847630043330013"
        "4827722505022186068415003251035061785241544879329174355829128492380420931948872833966395029320283239106512"
        "8400274603099891349456086079489507202429780609710291427660660349740546127638820776459982111416694789552131"
        "9811293298057424598688814891254105264492191523450049178395817421850597417689862288876716646753931200748381"
        "6862950901304269793360490536140388506490900700818282906806961856225837425294307204020811869910715963415241"
        "3919749269646896273238207930381447337881848530251103441328808489089045268485281854014309335709649584605224"
        "2040258306587929837405681610107421875e-271"},
    {0x1.225c4c3c8232cp-897, chars_format::scientific, 677,
        "1."
        "0734739674446298024207248229790974212690206929738748612035688298132431930940767808978781611808395357190463"
        "1495036629406095455507974294251384055596725229006339887006543979219474079905078476701423633851365003304096"
        "5533581637264699330161053700604940173012198029893482448464528100444472938931188041028209567758949481905183"
        "0490015311349228608723684009581342357121335471812569531901439452988004676219145306228626404952817818807907"
        "7542648436105191086071959808006028363021097640334464264306889872584610305498775551918545763871034864670939"
        "1697784898357237005514529545736458270109663587122574187506989374675610244730559373166968547248456823482850"
        "79432681499156387872062623500823974609375e-270"},
    {0x1.49f96e8fc3b39p-896, chars_format::scientific, 678,
        "2."
        "4398554262702667444398148018038098952470544215124227046286789042553768286136848758427981512172714445409930"
        "1156432338778458633994988719747981697534403350242401988431098023618401338421499127747850118979962781370625"
        "1582218414906726136931294160385412469197440440380909570572089389208878233063263470015565582345570048109359"
        "8639683646815093873774935940375258540408008971091122482936133784909715421457345554809011396322005411855059"
        "9162338229209184168112927326017394605260506607024809166145756193292992255504344399533818727388472020637202"
        "9841837099259731932443851592118412411307461059862509222808177157336752523381613241275274954877922857555982"
        "462385291142936694086529314517974853515625e-270"},
    {0x1.d02b819f5ea60p-895, chars_format::scientific, 672,
        "6."
        "8642158764630495478107887035397014093806406478739147400934802190758122966145509273130663656083449116193388"
        "8223685640572561914307745731515469808330697336384232242413969293063536569077723416762396892707530258707424"
        "4545467438925612214275881601335127633854291543549312798476681105264979340881027849188655526015371664367066"
        "3196129370831861216770934862924684216985743727871460443148241127262602309896093569590960002026708618897030"
        "7759109386838123883489097316625629036908204612253030886781498471111475701705130013263603331962648371224484"
        "2831818245768202447715876348197096113292312233505987050190351763242747076189226988458164602331524196780765"
        "390002443382400088012218475341796875e-270"},
    {0x1.9799ed1e92e60p-894, chars_format::scientific, 672,
        "1."
        "2055339469240307377403402594354358674407642465821440316185387366532834818376870794496751703591990320577027"
        "1070113114076479488114135898545635834909792131037998106545850994330544371266945740534776833488374278778857"
        "4210076011956356747276577674394094443595818534447499249115341998676084394486307876183969501905326447231792"
        "1674817757806138643290162179595339950043670422343416927403419489541542045362472536831804335763027721048931"
        "6956915292444618610846509129090912794604455025923507204700630210668066737375536920033779883548191818661184"
        "8963048722354732914235674141422188511695223505091651304612258808796215869856934551053015669443762235800432"
        "502941248458228074014186859130859375e-269"},
    {0x1.01910e9dcf23fp-893, chars_format::scientific, 676,
        "1."
        "5235738192618518189936618594353198373490038933641511179090306267605182024133053338385048719805469080900154"
        "5957303087100560223792006622980536966737234211755461011587426519659509365351506623505775740873732101274705"
        "9302244480684314824553717385232770551514728255582443659403778984013667349238036092179546944931299320331086"
        "1757505321077871877040854320771623366194214101040976735574958938663792105124704745406309365766329618014782"
        "4771690982829988866222038776007404704345799976200349382370719198260584387074295575308489654601314392380880"
        "6247650486965191635898381488272370659215232130706305838899655353946746170671987732614538924943360375947442"
        "4588216123765960219316184520721435546875e-269"},
    {0x1.55d13790babe3p-892, chars_format::scientific, 675,
        "4."
        "0438764974429647181083693278793666999589651788371231605969383877729524560726610847524939487893537632362689"
        "8846861862368755886367916636298143998039008428394610535517912002245989309306202382454578439356783495073513"
        "2918308903968711752955260187817332338525640497165750231938096458190808206428445911366884923501080893523954"
        "1206093029385768713858239491000151225959463531583588963736180340573010650508237574015975946010392644014468"
        "8165168171854738715370375794081116073467023962896828734809612148557370012497858203113645628993222560967395"
        "0336664355143451919771945115113191166252509180553149351063482548119983121858449386491438816394778188001261"
        "909345629419476608745753765106201171875e-269"},
    {0x1.7188a97a16f94p-891, chars_format::scientific, 672,
        "8."
        "7435562511428746407917858121214372902879051776678981737976322047613610624282685209507466698778142288224027"
        "5455082159625173427591657526511616774859950448070519505134802050234509915695099201889128074783085073031931"
        "4819188183029263829944697648815507866941818927878058242566543632327940530631337555099540355405781631178699"
        "2808924770387346666342826175687898745708869277309879509815729325382945015154228534140524374264126591488175"
        "8531162780816922738713821526003173659290088391480469742480863935095626092090116984973808179531069736545259"
        "3665854547305770395594226542202736076609270724296938582309549515791111533078749081279345889490509807252804"
        "908017651541740633547306060791015625e-269"},
    {0x1.3590ea1f17fdep-890, chars_format::scientific, 673,
        "1."
        "4649312749107112699249078612253466255139190610866048930207234799841567003889985307011573295308929480552062"
        "5046779174563218713759188180095944870657550678355333052939808456821890187651923588680269654593860121514434"
        "9181485500931165058227711343981064209269072796191838297693555979340057353274795768482966261660740325721905"
        "1699070179918086660167018142370691860419426843786474241321383571061970541818509874342719546432238383475256"
        "9862600241934899065233608023840660646981036704306246328305078273787020906287373283828550532772777376154504"
        "2382603061313562240235190280769184374891864894990808094527898696863693474382944773192204352614134786180616"
        "3432873972851666621863842010498046875e-268"},
    {0x1.a490bff22405bp-889, chars_format::scientific, 673,
        "3."
        "9804068003253801924882375719417812536118621472122388416843607937530335021800715604245101187667554747013995"
        "4999377434052851878178252101539359394319413669582928785161047412343231670883353111905217616764325459046667"
        "7828829988706129136467711963276762541096135592752188769472589597065685993694758879579630673912948899179398"
        "4628734396688639664301833802570854901924189530778964826733402354920570755968722831348583712843989489597142"
        "5614412988732348614862400377153642464721973372576680409450027908761770203176461069618154939055565879769143"
        "7413131078539175704147903187697872905257705223315772497825560770376041116692908571522268713665397078024094"
        "0907646063351421616971492767333984375e-268"},
    {0x1.c59bdc303397cp-888, chars_format::scientific, 670,
        "8."
        "5862866606155157862058221336345820574845880378878616534766461334711933967608601405237094305285212951224721"
        "8811224414549999834241924697168185098548362501537290019314014899176707940187530956780726325235279997326100"
        "9452705579499169901168981268202020899909243284637492060661433758304632176006814240421686409284667595109084"
        "8814780526424923767058416281780691829025801360594452925927646668861343662081573038042895131100883925664927"
        "3434566380169524829965025455207365527009316501409537452384812648683458666570530994016398472257935821870147"
        "5792921574606565186297310529472246116485610860468577453516637959521359804094235499407265480713324131561980"
        "9341797008528374135494232177734375e-268"},
    {0x1.b5cd6c8c1c28fp-887, chars_format::scientific, 672,
        "1."
        "6574180187301560277042993359422084230465392733787051007866897996899438544490745152444688834530645625295640"
        "1232710668621853008468276391128301097900292398003336274182420225374479310694714219204498291060859779351667"
        "9876740791517128544885924840330252161606481575353740949876187647749371234129360568830223801641060064222372"
        "3867362631145241282908960084578297501714717916105706062353536412253151235023622382582131429436080455694095"
        "5547690271019911428549317360851577278100317763948693937529484290614370922528247233871396511557553970893932"
        "4974793123602180721204916958184979393062444379753888516263944185940942548772357521469280603746275395797560"
        "303634554657037369906902313232421875e-267"},
    {0x1.dd323693a3332p-886, chars_format::scientific, 670,
        "3."
        "6131068345429969451130373310115607099294864130669813892800930118616243487082666684796081077226753480935212"
        "0688722595031185095810662074858300293333264091798976751709329421719319329249471449113212585104216180364902"
        "0903052455642472114216144930468732881689213430973791424810940744070365363417199107528165592848991563388371"
        "4239891254785518595031411885155607054339603011357809855510923231449073199376203490368131774971870870529128"
        "9254522590611068555644306549625893758075882651211411533144826878180312068875356012841418042267850727474063"
        "1152624795386765656842235212097365641842719519291963550795467751354357546090784488915890550681843124830594"
        "5047150089521892368793487548828125e-267"},
    {0x1.86d3c9131605ep-885, chars_format::scientific, 669,
        "5."
        "9183241751764955109389764976714155872620609643410243773660851543979583503245329654584813732786527982073834"
        "0521636420852725417997261615447417981415016882734448973389564189606166822481467349095902747600636497815870"
        "5655949314017730228570170646553719431745599699755559963097604629279063754642229864212114707279675331717816"
        "8440072594592218022370998643157234465370967008505124175029486015944278448019481201861981653551367410858983"
        "0359527730465346678452762668709266971955765590228540631576870240350592327118633813432163334893809956910105"
        "8186934058654616506900726068423578479775270344220112716254835138009906792965231941252390889503048020114928"
        "107204832485876977443695068359375e-267"},
    {0x1.85911e81c4b3ep-884, chars_format::scientific, 669,
        "1."
        "1798475245572565258836463208928683635416019155375711636848835775165384607837563334358573139483721738528709"
        "1120028390252414848147343275955457018828059343282834073062154638169876178683144127461935561949669627002417"
        "3685557443459253842752241847183852027161270157839527291020148506061113896949022943154133603759166570662569"
        "0345523867216992200844339835298032472528560480231572053267575814735819031230558839583597348451054026157224"
        "2255926498453096842484137847010445108819535016652319334499549429994953654304666027843239794666289393464823"
        "3129548468640073030619432252064931487614833495014858781346346117845149269477579183027503827919826688563897"
        "931771862204186618328094482421875e-266"},
    {0x1.fd3a7670dc2aep-883, chars_format::scientific, 668,
        "3."
        "0845119288706609241776127310550945770260699097294636090232555316906282397758975656802444965817572435648830"
        "9154179460646805809256909673683564407525994808351915660324637706817216948128696931536528727801890757276085"
        "7821998571184112154093996098113552610554410114972749654435078757144390250817251359366357240834609588333752"
        "4472602522735858303857046884402733676415512137932791990670019608401150097071887929689475019078052824432695"
        "8169030004334188899958031100736000503800060878357350714914804570705622357760565433666940637984589125351111"
        "7578209700869532329366449360905532226889918970109979920440676664073492291325343965342652658654645433933261"
        "24487430206499993801116943359375e-266"},
    {0x1.55795032e6bd0p-882, chars_format::scientific, 664,
        "4."
        "1367697432326765352340817035182743358257354812683967551470618307077529029943028853088076762554639432509154"
        "8046642335686562972830560848535832043202751676119898478727926728300673178723638882161179194197617980196622"
        "3908838232485454712767866954880107986586331614093671038168594790202349294527476303912376120107032564932286"
        "7198926794092379193979001160520283118740890457050606561528368852971588670160141873796334891005265000215879"
        "5052277642750755249858943871277223658376131404786971097472549039306650994514211262733568954010543397543745"
        "1964937117339719316717342057260783566644006824506803928857754052307315246529116200657496496984749656533608"
        "6860042996704578399658203125e-266"},
    {0x1.d4b623359ac05p-881, chars_format::scientific, 668,
        "1."
        "1356367562498619145310244385698473525427283564803902471480930973319788737231514592977108114965063815055345"
        "5830977379024144088680682202364780595772824626362655507626398656976630817003866602520718605455234378514735"
        "3087788741804559931776255025847515183240478076966312904995778458881231949209035981411121604045278278843061"
        "6977268547183960163850017321591993093447821248669240119333705313884423383580946619081395963426489952177610"
        "9997766439665027209396002034188443586122091652193792470005755939774105652393587570468729608467321990883421"
        "8208302180369362225717108121963705936493691882457994726492485413609210469134484467589008870790296193420410"
        "02028054208494722843170166015625e-265"},
    {0x1.3fc14119b6b30p-880, chars_format::scientific, 663,
        "1."
        "5494624584252723975906249583375352303256654343181075171301275908694037222380263592504310689836780104021758"
        "1758123367338251903106006965951338021603071523529116946521691907573658498425349392869295127718000433929885"
        "0163756715521637210713685129495086748985049799710299739775854204400714728515170031210558291615920547395211"
        "0992782609302602588568324649970167427445308975305630972919772035489011201841001127297023151195017709922837"
        "8421528368003116558663783106453961275883213934228645792733584503015487388799720683461887271416060866520401"
        "9257084947262289315617219879609164279766856157954598104804131015062387788537884648628367603544198072285098"
        "533029668033123016357421875e-265"},
    {0x1.387efea29f7d7p-879, chars_format::scientific, 666,
        "3."
        "0285755370951038681608683696905621033772278330728553552206929677317758937278752313911937150897127680137831"
        "7003552524566357980703032758133957564184151555886502238750580053267415635428852577548128543311783224172494"
        "8681614868585096210717704389551477048999401562959159801158673751335958285076385209833933722745096602678100"
        "3143061720934102794967836052054893105516224558881550411686422692703782419027059745570753240877996075484408"
        "8749613809519051548412628920654763685820783842694818471287892370778516701681078600125302612513778414895942"
        "8881521605742355054257217013573044606787074642577830411006902168840320052258179872988498243578485424887247"
        "745573404245078563690185546875e-265"},
    {0x1.e65f23fe2db0dp-878, chars_format::scientific, 665,
        "9."
        "4274033334811503748528404757289384726806770032674327402818133341840737332411750121426215821853365474391355"
        "7230387790285083933191457903289270345596270263672196354394182427315526000880649977141656105787327135299739"
        "9155480063881212524740495031457329664415784460015536413542144918144920982279053472736448128968434148254398"
        "7888277231002210993520750386501402122475620747774111346439482660309836582783279713410116736596619463882867"
        "3812504921615547034950622887983231873998865416652468144478421626318837183678578001787452762876752114351500"
        "8392129613740783506615926436788653883816643418293983827325355790595619401175112158521708318652601588105710"
        "56164917536079883575439453125e-265"},
    {0x1.be0d3381db145p-877, chars_format::scientific, 665,
        "1."
        "7291748366915169805535173361311690336060863250937536754419109791788940622928061477911081864929176484648733"
        "0392740026820608012717601990878326637047638718248681993991531006456103430748094806588017738041317168594778"
        "7021878692496904266200427795631638810860354316879657866121076029993751741729645917063224939510035511898570"
        "9999359928300674405002289342033156169213644776362614794679384856915080325537702909530580016470514923381118"
        "4731189167500553098889569815790695467489682656267030416780025246929633596118386225452442180730702839693663"
        "8818669944862651345233138879791333792498482753324138047601610356877377484188814783042194078233402820821140"
        "72181866504251956939697265625e-264"},
    {0x1.15b4bb463138fp-876, chars_format::scientific, 664,
        "2."
        "1531241335994102581545421543905718553261205634596225205065032112054906757350946064401973884364945201367158"
        "9193498889587342518389527340691619196698218268405950444924912994180329555785724990446715258463485821370710"
        "0297914720890097779169205883809457497940081169726676329974463181247441649888441390421006496972025799387444"
        "9869399622491655605240174565953844905584693276335440945576505682668112743945032654000227377822639620983203"
        "2424628169867278960066124057642301935079333533998374656641508551131984260262634639285697704413869791566604"
        "7058344555168615768293471860018877719927801421962570793677149082526170886197341877046699512490007810683323"
        "4414807520806789398193359375e-264"},
    {0x1.c9829623e255dp-875, chars_format::scientific, 663,
        "7."
        "0943811579209456674393546810681034475092272127137349769143575260247208850042176344557556673219122391550803"
        "2134627914531660834653724133266216664851984579431280354615254876343265450440084636894948463058853750279245"
        "4180594190614999429011156768877522268148802551983220139436429766464461164984165663141029854488048705467562"
        "3483604810872383651838979512701583025652350883872278828061474056265146942266842117494952581371563236372454"
        "4745480159434009300924698850473710854892506668277594645356984354898943282803740889954727605047952229451319"
        "9536623800733390878855344111359557724030382934857005734748620310003839032941834111259667519124028078891797"
        "122196294367313385009765625e-264"},
    {0x1.4e746257d7670p-874, chars_format::scientific, 659,
        "1."
        "0372442383613189969714086258459722252660210904892135354666456482486436513413329300096044197495219274963897"
        "8020863794678225957572854635073507252775535164961781534910344480358232648898270595208601349292946268441297"
        "5659811329213404719323722531070098963653390797863993492237598760842383012198699274324054996159547329459864"
        "0580924969673405756953920124756145504369343197985189208048577768929728892896888692456901412684203646115966"
        "4146976253775304747117052161568491733834101439034106718671249125299580172355437057762980472448608774453369"
        "9693661677914745564631876392042680021779683932888965662895943618616656316757734516189595405655232696062739"
        "70566689968109130859375e-263"},
    {0x1.0cf4bc9e57f3bp-873, chars_format::scientific, 662,
        "1."
        "6682266784627316054126786634947099848892653011771160846990224792777416965125633659363823166150708783511656"
        "8115883612889554220377387265788086029467082903772667492283129753284952803154692864161969436641653582454220"
        "2025731166907532844165700456927285153916176469595705886744314524895022139352304559343255941857888068865999"
        "0319914265277282424260166051913216749835283576431746611538506471427827307023604012634806795610432203420196"
        "3154877669659580960959116015504309990919735860857543724951224894412485861253372083552618782145415839816201"
        "6695152261152695946643426485073285270438041876766580343024065650025617255398049533262602511438088548345604"
        "06743548810482025146484375e-263"},
    {0x1.bca9d75009185p-872, chars_format::scientific, 661,
        "5."
        "5161395008185867433415357299266473202855702442652255015417473346516523059631823879137334341688412064252201"
        "6359703316218905950439100436732933226969082782786169311545430229194074907477275505071792114832480787270717"
        "8915637107070607758223870410283818480871009382801702917218018303290530391528205160937483613744722094375755"
        "6647797218095071645532979709602538130511390566521835079669946838247561601190008503934840995758658023290110"
        "6296333354593470671297966973754686923720279528690270848804834944868781772303189955069294165504271947347376"
        "7583033498736701881264169093594528605625061561557706388575048347185417471798563922342096155909674237705075"
        "9387202560901641845703125e-263"},
    {0x1.cdbe1ccc95d90p-871, chars_format::scientific, 657,
        "1."
        "1456020464232507675057122277543685119216460557168252748157621249520884155966158083731684691602468224843210"
        "0075159391224235566394108391370020174395111096729007531631823808928065243014130184606154497386524196017218"
        "1110143712808599775710021657762313485166911340457125405068169443597769672899512513065315032891834699262732"
        "1908035386645038986601439051667243567979139672430921599967702480280650531086256799068476585431284585388240"
        "4720314532219838347561762351544068566196357919731108439498951529832585320483185327879968362288867769633642"
        "3887444215207972301820659320054036430922363633794449770968981950183436840696718769035296336955553897496429"
        "271996021270751953125e-262"},
    {0x1.a08e347eebee8p-870, chars_format::scientific, 657,
        "2."
        "0669818736985631229211433609173300771521838259787418165128492129593346843199105889991555630546885520424873"
        "4500210012141010459200844730111260401895114952654803481888935046927199523015310712190548867351015143128831"
        "7341497991035832678659314223700819815496411587815428866045015831262423046888744843665130751642206640470596"
        "1913785805669387095600713483824728909600527076010029285289082448583244303100393919800739122262878737798465"
        "1267691566022679307642868763358002955970597599049178708475928028052269404319007521539151009465828335775167"
        "5552194266495084558603653401864419204157889257764915433524177885184490559892343474975885675437581312507973"
        "052561283111572265625e-262"},
    {0x1.12459afe073cdp-869, chars_format::scientific, 659,
        "2."
        "7219184652406805993113200069724571033116395794260022510965600900076256395056708441474373792056450106821277"
        "3411179024958530270817243162958424331800455670782255602327569922315956959137078323961271124142919678140836"
        "6427948378212113066025708694772668990832057641669827087574149746812408127966499041381146615522441977831117"
        "5038207495040561355208394644648970017561375493866454210039949616609826369918160587076346295322087365807525"
        "5752221508525467227047509182541235289800893474477444565810299484569003495443070616025087922865386504523121"
        "8586303252491596734499946262272599981000921593324190166840578960162765846077581071744836208048390346903033"
        "78738462924957275390625e-262"},
    {0x1.0001756acaa34p-868, chars_format::scientific, 656,
        "5."
        "0812835426747345075553611923477617398987820369648939551306803212741371571526499464855930630049097064592210"
        "1122379892382479717106538369694733235716438656264863128490731915205653554091870063362517275282717008654459"
        "3535922167621228929536166429804941621134212881365185181432564583359823929240075429731442028191437183310347"
        "4322206835097502207668064791097777030747293208431008738427234530056421963205800084404703834502602573206400"
        "4422225278499492883613711474972843024484702154518332563961230115989187179489623402654993380597009086900293"
        "4536386965363555076444252747751067112437620044942160741851891286975974928623936015302867130749575608206214"
        "38324451446533203125e-262"},
    {0x1.a923f6cf5a94cp-867, chars_format::scientific, 656,
        "1."
        "6876650530578207621570229952797785644682110844600730382828697983205295811627431458729119705328829243777096"
        "7196655799942541178490674643026183703121754253538937824062441208188206739880347984078224093935173556451996"
        "8428512418545184148127106046414566467839390422090352343007549697592858950809976923310636041815949880034513"
        "6248794879877104664837625430195393564841311745786113921932455203585099235154424807349383493024231486017916"
        "7453641477542234843453022929695045828962922773750009075946875267007574023695528840568813676232828754491306"
        "8646813805642245606261257736522932872947412755257832558074192370113465124289365328893661177822593799646710"
        "97695827484130859375e-261"},
    {0x1.1ec90c20f8a14p-866, chars_format::scientific, 655,
        "2."
        "2768831274043772176382445707214941137050004819857296684931317704292669869186330235385392974936135583425559"
        "9391396336854625037981166318159043959947117232845747306996155023939888756843144321245127560309680255408819"
        "8239536295503375270446676949521636344483280297142204797105650413943143524391493206834878212096730282097671"
        "6001570512136786783004641864845978867193614401580700868334274804209917513296587055016135300878023975459549"
        "2547459644523442197433522979067269453221697470469185215254072576985178910173696058780136578510752082477360"
        "1510406473818284898811639918943826900408540402073733604377575240372790188611135900765419792790567043994087"
        "7258777618408203125e-261"},
    {0x1.8c40010a69bddp-865, chars_format::scientific, 656,
        "6."
        "2919183472541600602721754928426186640791713919207735791429339647422629100785659522780692862200166897491701"
        "2555568019104071065737204485334987194383301234768696626240704934209115582338286117696015309238068919260879"
        "2858350306420316229909315039183892926423127496965408791803311714197177193889783060818926773096147698988342"
        "1151170779345326896958734602721257311763761737474562447460745166179129141239961621209497591323866150735669"
        "6648749093728161566479406697838649713830671083063257024116592611233964687353694158987479949427380270159845"
        "5838968120913239056997624353817810715748408942055331411763298560932984099783720632762321067765753923595184"
        "46028232574462890625e-261"},
    {0x1.1efdbfdcbcd2ap-864, chars_format::scientific, 654,
        "9."
        "1140703092024367155067044395221164452736675833151013263211220841163780409432338993660009501481842296218708"
        "3495412014520893619544114461468039750464209587202548042016950090674691007785016340938454849306345780627414"
        "9209340633047382140528725623452408559558958439548164560966946219116473549606304395767765048257811327042187"
        "9425006157651070495838384845023596106870545840216347820462109279705594517393524899645116315147968384649516"
        "6598556482074094825029100883563347947309602750682254364482901382848664076403072603858551382288376096255467"
        "3920959090444603889415032225272728877288017133034340098211825380764598208977109714858111377822069698595441"
        "877841949462890625e-261"},
    {0x1.906ddfd189240p-863, chars_format::scientific, 649,
        "2."
        "5433112499173347793194125621710163645079369331423202898876274087013265664417996337089113018887096628689528"
        "6909980735596949777809152245542352924571623599896408538766930694228602626651083775966167899682411094921866"
        "4528453283677257072323229605736418093485916168131207495359269594380116782753501753335290525716376820637813"
        "1651313649600349107789087387461150989691005378537949674398986598192233131311058346321863230434371277975115"
        "9601698778173244506374886663889558909304985006734120160002143650400648095280239164877277385388078424667808"
        "8998821393839777960585285786855049346501567034793016761392974678965713676407917748223397325091355014592409"
        "1339111328125e-260"},
    {0x1.7ce18a4c43eb1p-862, chars_format::scientific, 654,
        "4."
        "8383034142174994104272069838127782959216294890444624860488117740479459442612088085799847149791718592639569"
        "2514342169545748844407930478209370082097698966466303161266693588296916477694843719922217257850078663588627"
        "4299181215882835731412951066974921021211756829121808175859818791449336493487434400842599626556712001876150"
        "9667718055608502897452028494895946834053067261106309416912495083775349051010869220082426966767527218818197"
        "9310566617032157898763990519492387274070392056149682430213652686973136279413174816037833439958789749907392"
        "5267530473811700835332428644282412990851223505003816036845036704538201885036357457504918588853115579695440"
        "828800201416015625e-260"},
    {0x1.782df6ed4d7c1p-861, chars_format::scientific, 653,
        "9."
        "5571620410084553612231327876427113790261344273014651312134653137692369932119559217494148337440282302224113"
        "0263997567506024287148387776798461354301437476844010018790776658181862075147468952135479241966863723499456"
        "2671930616485340107247684107637321972451853389214118467182112388997076370539357788063452893376151729748408"
        "2915270789468943416839744708329469795749877089097746641157553737198869698139987185436460253491149445310810"
        "1743200834799840591710632180550687823669819744527982460287775503302538194712879042143801864025232229533473"
        "0678286714386718609825203493845270564103948780979172013971383228946576489832464467236161631547020078869536"
        "51905059814453125e-260"},
    {0x1.c8f1f802391b1p-860, chars_format::scientific, 653,
        "2."
        "3218163991190385364508984250447706848286720702433334282915779197051348928890111569809302423668131306768854"
        "9671606004297189773600697112362201312947071746547498935123129686311916312718213019473461585470236625342179"
        "0700948554276270180610568750669698346074396782598841969164523910845529402228142249335459416846310411634554"
        "3338728832295769239658657884743735612915332354292164849060945176872147230331318167350766692977206334410141"
        "9125790001753935727822079685994595251980575717534807762111364585832641492934382986141296078256014490691906"
        "8890930223248032001378178220026349482108995119241996449400126609003650787411201237078750558850970264757052"
        "06394195556640625e-259"},
    {0x1.b4262171cb3b7p-859, chars_format::scientific, 652,
        "4."
        "4322942901196376863360319680933694654308997921164922102745484052756965358320504133937620417038428351006134"
        "3936976933967608342074121415324210078587243517426577185350093924310156264119225838613696398659496989910420"
        "8353518232315947890478652282094992701578651352178291486176574508412703120463808237396444949047768512976373"
        "1251327511010233610480829310705679565613059064973397437654199701626566854193403167380367233618735049297794"
        "5056134852446758581372606649514849162314906568429829544233164063991054988715229534439385687585779318932257"
        "4286727246285838594808424556563360450020368516054773532563608037624243787652624903400377931461662228684872"
        "3888397216796875e-259"},
    {0x1.64a437deb4440p-858, chars_format::scientific, 645,
        "7."
        "2486245456651862023472574370876819260411370718249819818743335943776205307646101765920973802250296286459327"
        "2610893461273931317458322627631905835530944678673175436224034968381667303539572414025175474653846060626371"
        "7734775468528471925761988836228340907693385947639524028564463791929467246414768399226257697924451237021644"
        "3969480729800801902101353001138560925948801924917672399080489050286782872517574693040850996560237083997524"
        "4743120699197301488506127069616803558654617805738359241041246801384050437850303366990706136685985225470569"
        "6051810053431151300980240986285936866882956104322697194439226699982917385446656854952607318409718573093414"
        "306640625e-259"},
    {0x1.68d1c7ddfd3c9p-857, chars_format::scientific, 651,
        "1."
        "4667081257360905122219545067067544733163746805490966430488449206414100150968687775032402756052292826192310"
        "9033050351341337814114817123415079541930647873262150571704767679131224864582828071686888611188799409109024"
        "5011385394511550083590844403769171740415813831118767837488500000872271900044128369701757149831659567051913"
        "4569889281021321327141354177750096990863112151715710379567247962185037697773480199531512073678158854750890"
        "5840170569256617197434173544665833127001525561200203131031135463571741228836842304648117709300656826393728"
        "6667433592776261377970432715687365719647591411294638482443774640687500004641624813672695637478682328946888"
        "446807861328125e-258"},
    {0x1.d75f7e137fe61p-856, chars_format::scientific, 650,
        "3."
        "8322026353591041945549619532350115070542582231900572219630335353346952308164980213456390925558452250257609"
        "5232494591328629456449452280125255079148668498861800706754585208817826976126668888145120396190261611609172"
        "7621191237931458727896037788052038025879689611214479161439961002799972418744907169391423514023327463523140"
        "9141504165184730552533850275002320357839853008554356923544887943781694190440637960551088058658109244864183"
        "4918347642188228638308919041402117875214276091388203088789844277557265644615942295037352991745550805324976"
        "7938517447633564168025048025383225174523163173171511655810658287115429190399515727016854782505106413736939"
        "43023681640625e-258"},
    {0x1.ab03ba2215decp-855, chars_format::scientific, 647,
        "6."
        "9431480258533971970776226476780070833439447534419340955589877460326824250672274858385074795336068109179111"
        "5181741727644326382169942415232772611867462202344841982342436831859881780104169648940151652988950108209827"
        "5370546075553403132538586162373545653948610582831301940723300705685976603592449533077414627581849293233497"
        "7877716272934729294493458229693156484855489071519117809921208470019603290425328615499359681908998029766237"
        "2634261835803744746628765582402678876539119010835463553046443911243526573460491703172114040390276817289845"
        "8905787436203069668723750929115862888028737610673922200768669995165371277212260081590500249149044975638389"
        "58740234375e-258"},
    {0x1.1a8446c1becebp-854, chars_format::scientific, 648,
        "9."
        "1872993990256398393531416600457280450059068320796514631056090469764224373506303894785318601668954036095739"
        "7379178452096086476025584315867174672392450396115503992411623576333908756070286366449656119838691258523423"
        "4303304141441636209538276044437434287446030632450415026343274481569236323844213095362475894936453835494631"
        "5916381176504061003068786853124720741143508000759975764912058080348409246107484554164396410838347897285039"
        "5816761052341102619407499643636683374539552278851416563265692570816851024552511717992981218509470445404085"
        "1058592434129680720256177905954138754010038223227654713022183966981646315616387432623213271654094569385051"
        "727294921875e-258"},
    {0x1.d6414a4bf4907p-853, chars_format::scientific, 648,
        "3."
        "0584908958671776337833997728212552743197169604966979110845813040276451910012854307217756535365938877958672"
        "1422062480805494048637982077473308559243951566395413290867225547157080991564751569942298190170759723875656"
        "7053418426117941253353267909236696526460445120208280487438673462490361511956069037937150670663546570743734"
        "6296769657742269429934163903699889943903922695607261208044403504503321200370225042400066440906017069328778"
        "4261706490929305618215679483092331173245544667709092235091659004587744352478247058204575908244766418147686"
        "2773133919940629127853848611379955271758919464669049389518829342226751666594490586259524889101157896220684"
        "051513671875e-257"},
    {0x1.0035d29019008p-852, chars_format::scientific, 644,
        "3."
        "3327306790247037336907675034392568454272595369411738900867617488007913473551733534201323063199723807019393"
        "4483504697879606878598819097351469420895437630770473232697024322335525318888227840552509675600524255646902"
        "8619739611765019036536534035050301257528705215736828310189129109513417846670742657861223079682981086395798"
        "8927567766792373175362266064722463852642260216366005158732934562712954829503899973208430525614046950049994"
        "3939385349824496739105901495187144509403790073622444198594469799057201540623756926169050435684444872560782"
        "4856932216929044311840257291219286900776173012629452228655688472199201998272255487165693921269848942756652"
        "83203125e-257"},
    {0x1.20220d0117b02p-851, chars_format::scientific, 645,
        "7."
        "4959510555108538799335754813356701754792355065646873389377940176911239971986659490383240376007977904208311"
        "8660847570367526920460011559675059654679049732952640292043242998460981893007748067031656426282809466359894"
        "4693614670185383532442466218699267405223828138978645448763130009589274108419749908670440725967037481300206"
        "2851633748523492548210781300670887434058964089123011544222688423237087102135336306066767496744054282140733"
        "8711019067174933523839551077258961555519024174473109573715905891230366304042366550548239550909206406025216"
        "0684959021066679582680454839013311819960942494580582546135693497151510794086759492671490079374052584171295"
        "166015625e-257"},
    {0x1.3b95c8f65ccb4p-850, chars_format::scientific, 644,
        "1."
        "6420266726944825630454808088054330790688039184429766248449244744802510234416512167593735365107794611013870"
        "9782299643946831257931373691292450527147133474394368778328589464320389279444152929596129775091079169751014"
        "4519842247604265947164098444353337876295194407250912855850267351168187138849274287240408555196983493342848"
        "9933467342587973598710220715138598315391026469456477501218614918988364315987081858415903538046962891966892"
        "4800293313739934982286504732834842708929909888507762225095896368591204588939199683430514018879374199320842"
        "2307913615130573653829855907178088163064254606588826707581097183952044795199332050117391190724447369575500"
        "48828125e-256"},
    {0x1.79a370e99377ap-849, chars_format::scientific, 644,
        "3."
        "9297951542678784560085047330289181715367243624999440411535626335855349124270289750581378228979122629841836"
        "5716041276174947051226059321141415572441753775776361360750193106965033615162658101521745005109053033835175"
        "9584991103790007219099337019871347846863373747416772168678914168817718265590672635122732019115088840685528"
        "4308439255530425901592683130664478484169626574567424147948837034542847458593654965464404208798178515235674"
        "4909406359357588361014427767062561979917000205966828612337591322173531342449808068102635168063343642736189"
        "9279318539070692012686415588482858054953378973526677058505748782057145603377468212613621290074661374092102"
        "05078125e-256"},
    {0x1.9c56d66092450p-848, chars_format::scientific, 640,
        "8."
        "5817991246225452741092042091868243950477436438061983588714379408467689836034614775795371333619284889814662"
        "4881729754285305304028716295937305832118768504741589064001775240877211755650206045802793098231749200556033"
        "1959933582336136059033009322539085521752257781672307684288330420314630742326494970432677741777569981162003"
        "9490095521058458025954384848954814776478898052375202040873522632601594631876073317485237288376180074032624"
        "1165338903507414978168516140117648928081962307140674669659472269099418474948911293324974333980429566047863"
        "8146733257119542873384793509262530795138061221424111646611504484593192093599967051886778790503740310668945"
        "3125e-256"},
    {0x1.421d62e8a645dp-847, chars_format::scientific, 644,
        "1."
        "3408011506316038440876133546193212552863655819964643115232648414608851460824412779274915182857333649885355"
        "0576135355890044448144591074850288974977950713678686563287865201430204637815836053277231611431919085691074"
        "2176504263281383704688378934842635350107826626491841796750832996448091584065997738570818997931555021995406"
        "7467015447979030230032418560932618957121652453967921612902472152407298980304430344846944714451589948955752"
        "5437413743051434352342449627142280703374251033865227110536913247629525335673340273427147625680436359716961"
        "1438811713524636803197146424960795969018772423073980006145654577415796343889398123394585127243772149085998"
        "53515625e-255"},
    {0x1.715254a64adb9p-846, chars_format::scientific, 643,
        "3."
        "0745985371377658309028784463801492290964511331496359833560993895247133471183641249699681449552243237472526"
        "9431831755931005890372074394881882566245495978107635358098347060477106877104572904855819242902252133462944"
        "5267947457337839385094549901547440113445942355135938964379412466831551967266918677931538876399443000538108"
        "6549704757852670657762062506022796246089046295743650517804858349388973761791892305019059446288013874091013"
        "2382985115260402448385415743377226016102355004438263205348482304617941213627282753219081015230403317774960"
        "7573235824693271311509414701066402074719718754079572549356306768426427920154475614822331408504396677017211"
        "9140625e-255"},
    {0x1.f2cbd7490fd30p-845, chars_format::scientific, 638,
        "8."
        "3049473134495637562783372335308040826947988947911227489305609217047398914763715260955078525106138710236649"
        "8636130716831502004815770007428786901700220001409422949750681686209887083042942769382184521970832898856698"
        "1564429427030907959956250390354575017810396993435701154688399222312002352067564686299288641194649680412519"
        "2055831811634890274031010872847387842015145697773860849597339982312872612038388001018205969465761016324883"
        "6221890713622421785887916102589252792760578729135290979060008922160938551159483058864969866471513981057877"
        "1325541600104932329110315094541017055279256323295198054372855898377578376390317771438276395201683044433593"
        "75e-255"},
    {0x1.b2aae429d3338p-844, chars_format::scientific, 639,
        "1."
        "4474411243713316867208977352315208912748300186833139035453984167535475363914803045214345115839914983070346"
        "8107963464265324484638353285518964551567088265107554403873137980901895793359340168401743333116776228534381"
        "8411044885533746274434524620506219125995305723357527314776166432074669080741627207730696930953203477260024"
        "5308586568934283524523440596892702417372491246648480892544416253172082204519214951423032991733233973222191"
        "3704414744084396980182542537483986194053369028249533947601013624027010399377778605496838258484958724080102"
        "8509885320895297831483040255143194596899156238644941664600889849492774963390928633089060895144939422607421"
        "875e-254"},
    {0x1.2617611e9b255p-843, chars_format::scientific, 641,
        "1."
        "9586457971591684628123217698773108935833562264144584623143719864276904693871407795456172875015943670393176"
        "8778961167502825335230168197000394874158844610101174297566165868577953600731530124390559329841336668647646"
        "2468308974382408845446004492911085860270135950244988831730889623751367135007863460811455551400837050028746"
        "4166926141825676068445301167385514883698177546176927308109450223226867704952176417382444892612246343386496"
        "9518502089292929143453729778070058866366076873565593983608492151377810843966575548269321853362612694434735"
        "9338761906490029759018080945247530366860736467759639429490063485076465146783597504054341698065400123596191"
        "40625e-254"},
    {0x1.5fdb1f3504dedp-842, chars_format::scientific, 640,
        "4."
        "6867153674920416790873337244849971076484220776787110409945879501513043147393108951843513448728397762554022"
        "7879888252572412233135500143521775531145980390850992942943675033022307280642493210611912876680597019732548"
        "2421531656498659115150512846925176018749355178878646041710082824033332351824268692851830401035105154057711"
        "1375092493159921425872818144761750136660331176266578771858537248827685693005467675230328337994759363083192"
        "1961798272782320798169726042997383300927368593567279231201682441735999054882957709060176324055801659088172"
        "6724432954799549383358558234672790149531275862362895256284006733585745935188882071997795719653367996215820"
        "3125e-254"},
    {0x1.f6c7a277dca7dp-841, chars_format::scientific, 640,
        "1."
        "3394037849881334765215059992884678582059252311456778113974098621513971288241782735420610917120016976004897"
        "4101237183118229518455257182717275229827659782720693591974491238575838983952697201911225839142407518108571"
        "8387875308026359155400107105741151539207807846271470685787797198661393857298908016252366323393251433958973"
        "7460426086328194140128257808492826202220353818668408282284630672148896793138260476005062793728842134893731"
        "4037303402325371530047168074113847203340154903164323156507991141932470177139673422077096863737284741727886"
        "3808972654184165400453746952390769201581688574999827740403704881609701221600872145245375577360391616821289"
        "0625e-253"},
    {0x1.bb9f1504a1a57p-840, chars_format::scientific, 639,
        "2."
        "3636119615931954460250167869238911011154326491479430909872707793904843481361199550716724821767345510198869"
        "7933841684366181492076821446815839454724649689656529509127038316112414479726862331466461938824094976797737"
        "9143220992333278223132260837716239494499620700131088794260669791925469170854867933113640126889557448864829"
        "9498325434878096355990555941114674441441864914479110196859470066198102332189630543298418737541697203517800"
        "5724591334289072091451093449446509958846630135866773448711738522258235844477343690396553420497616058860223"
        "2307735599284641966598526646351415873074695035701931182197892727567777038100160780231817625463008880615234"
        "375e-253"},
    {0x1.140d6862ed66dp-839, chars_format::scientific, 638,
        "2."
        "9416104456955937221543776398156706685887661223033136149978144195414487069880048080968267584297336066506254"
        "3115356949437725212090915600835200704935405467625569119444005558649057853906959361320327321285798225893023"
        "5229317177289893607816570293832641314174027421888172164237619051576765081507797361682755327770880513040405"
        "7575826358204046303559225686729160901856986719048077867296931804843574430849104888948208416960160463531835"
        "2482831563717046642268932327206818661898710868016377802766481100753130432486192161299895341263446334301439"
        "9966471714416366962788461689772484722397543415502179310786106319420066257386281449726084247231483459472656"
        "25e-253"},
    {0x1.1556a20068f47p-838, chars_format::scientific, 637,
        "5."
        "9106288435436441832925321437439273066502477312033311246968237725276751639214797258968915217210458498406519"
        "1599955142680202342645938198876556661177979692713340361790875196351637828414851815092581530891522562889255"
        "1785526041987019154864916301964965994784344521781015097700885197871228199743117772247657733964373336298903"
        "3343024133323958002289706156266221722389423041489830227675743527604713272295232402604297526043610489011954"
        "4521874334868186828399600397263829823264455558567290365650686459810955354562951522008422782247078306179082"
        "4274297798382230073449857061911562247122871488645554553253686055815790956202704364841338247060775756835937"
        "5e-253"},
    {0x1.8a637844424c9p-837, chars_format::scientific, 637,
        "1."
        "6810396848558273510235799637525049545294830249948222214411090835531380563125319563203943253866909216175104"
        "3257048804487611404557035566261801859080485790221260947098571342313927613866021217690405138818610985006226"
        "6056665647550736011704735446153339487543803430367841295100167579486103332587829562856169336508741156116699"
        "3821573800278394690338640699834125530610486716022332187450360770206194564289972002012617700416236636708103"
        "8543888500074700833328077519662860658313152207041831981854465792023538138098947494890681839362176868398994"
        "9485522109183673226012048016787838896032817586439816560580009379994442797467968375713098794221878051757812"
        "5e-252"},
    {0x1.6c58b883c43eap-836, chars_format::scientific, 635,
        "3."
        "1059777449559429265900676399183362537453270079840668482441014488765656125936602920378930602673659646522508"
        "0750485088311931270354408819089265208117161050801207000067848396965880346198894113665199706590577342696924"
        "4262616672598390077967522675156490575620339033736544018575331426236187140125932174293413904931149686676806"
        "4298338564655493854637072357239725464925528075313439590693619626864606148281041428613600174497025784538263"
        "3459579611621591637238666391502205681590372801573488459837345671891293214092887485037314994884435306602798"
        "687276288545989827758369435248803257946775797031683187521866108295187647314605783321894705295562744140625e"
        "-252"},
    {0x1.36a7fcc1cfc46p-835, chars_format::scientific, 634,
        "5."
        "2965573801445690722158614076883511123532332685924214717774752426044438667279139986749437517515188177140269"
        "5485375202212937664379653938486718551271787640302576447258297441253734512519058771847953071990841730343795"
        "7327930452143347292118755771583009879983230855464894740311328415111572092561634509970907891424846710866942"
        "6864597398228408661760562863344203484553975704767864965698077298580010056954322574128346908080869265075775"
        "5739269716961846858456688528224803759035924554112211405402620391714747114614201404766504398808292555529737"
        "18941456131767751776122974578049807479540550113655955376254567783245175149886563303880393505096435546875e-"
        "252"},
    {0x1.aa3b9d0ec1349p-834, chars_format::scientific, 635,
        "1."
        "4534181673457758400949055236695221048664713095250053797426519767853237041835956791976580225636371098279321"
        "3214068181046129672798657879984495167728061963953124586161238507439156789985644488887055291390992087782055"
        "2701336906544502774398188591604781018114504110735607946242802648806954749263291520974122404938211127908934"
        "3575631285032666899798293647051957896468777447945107059181546956408240664336422516004145304588450388632522"
        "1070737739693194936546919810702692652603043565212622312212995327472532618638556231986680206742586143722403"
        "550783309924285289349297072101420663057753817823364411493644089180821143969524200656451284885406494140625e"
        "-251"},
    {0x1.5f0344953ec57p-833, chars_format::scientific, 634,
        "2."
        "3938479247234097018550458511544817367739361536200950902814825089891669710214106361799807545093859687694323"
        "4520222814663334325501959922339511022417169200258138866716240572516473903243780418299855591784687744221561"
        "4673730495274627840445980495455053691946265275961590944942894884161146186125918812095405141490376065791257"
        "2990007375277218500031379100913127364874315175834774396942682472145171601247554709419898298359216080654381"
        "5234719036377453626738864303434918589623115748337487232265520789623861131272396012356699775618072348868787"
        "76372878894847401207188983556061557308620341306536104552493931900414292357481826911680400371551513671875e-"
        "251"},
    {0x1.783fc5ed947a7p-832, chars_format::scientific, 633,
        "5."
        "1319111420103700499236206263878034212106202950930977551857998220289308747630115765877892885472362039275322"
        "0523269264416102554328703892784714509871799045575377396811614393505255988764201594860924728188446262020599"
        "5816224373606402176926540883831558717591219455218087384224255737945036264103454832864541982601681641504954"
        "1718987656545856396071620261775045714406002201539977040442012225019186665790253178924857163319970339024221"
        "5773002375760167632603757343376191928042229339921704578692579360050525881528852289207475083143721754146523"
        "1243409180954321670387197333315664529506371145190073701706340823791574479173505096696317195892333984375e-"
        "251"},
    {0x1.40710848cf107p-831, chars_format::scientific, 632,
        "8."
        "7414290750552295546310067304417538089998764617839404299068353704815397343149675509135958228378829386585016"
        "7188491498788205872086312288388767426146999394659547867198614986995481660971205928823308477880542196613894"
        "4275623574987168431568745304364621669241457008033758230714634333799159208383480168990161078479986731377274"
        "5020111854169849030780011055234667752217741062441145534653890585011154245157298808199839856876073524543679"
        "2821070637754721727631828680882026195550243758494821815186708842256768881464944978789741055024675233939100"
        "433403212219702473933537591600476985467616468889370663931655085210348232749311137013137340545654296875e-"
        "251"},
    {0x1.7d709da2908a6p-830, chars_format::scientific, 631,
        "2."
        "0810847152471556254401311232032188728447267117360175717891636755620348167659504840695434647539993442189667"
        "9066888555643495483464096384894027472978012957276210634072464269390297861825532386002160928480072354865994"
        "3879732460682150385691303824800896612452662280810299151162782505065316201313287687887744161894093458421161"
        "0513283413566516116159526022930867617376801255296549189477727203602595481316438645897519886431470703998215"
        "1377960435417890291154205919810773879383879482532629222150323363757619454356194585518671919581410963596163"
        "31249245416003787574812480465286687861085268674943439588960990282995311417835182510316371917724609375e-"
        "250"},
    {0x1.3e0695064ed8cp-829, chars_format::scientific, 629,
        "3."
        "4702108400000347766175063830843523770353778618261381349778046912840338008912123330979886734938140131953647"
        "3650404380879594113908738392579171180233191183812382724432641795305629872774983638622063672350876094571233"
        "6499953240251855646705291887761133361595958660743063765329731272882479029390612416402919177315324330478981"
        "7906314100021310207581009790350421328660994413130289544979421802072005157445008442147491610582962042054585"
        "1320886313933389161115405988770793923103408378052619011716334186056438214857870078005536727201067661995785"
        "790466451286588137374823625348339837864856184966498995800830706937034619841142557561397552490234375e-250"},
    {0x1.5db5937ba8bdap-828, chars_format::scientific, 629,
        "7."
        "6318668361521597024921032941163912195843047360807572633855844063123137453078655746202441700789564711179706"
        "9916923337389527280904671103326648100882322011480055143650535250537017261380037289381165619083602515263170"
        "6262769131163996536699740657297258151427870476072005518538156986453060386081899065708959573969700226946302"
        "9719928757736377066684783971457371284337556021383941621372989509463523373387393627423053871399621032962573"
        "6022033942155448268043514668101801250595923776575465783992676218557609418576221962370419170839207704238194"
        "605439691883635468306303649484833033050509910062272350022606615116416151067824102938175201416015625e-250"},
    {0x1.6ac6715436880p-827, chars_format::scientific, 623,
        "1."
        "5834019337617895673529802567022957766337379198918511085508103045110528907733717602402102884849998115672191"
        "1870061098205010006064994116341947870874025934708681989200668415753105577412001082854515786066821742485680"
        "1456062548357689341619587901384884023764854066935774035847090830187065881058547524256867923951849842211943"
        "2276079112931267920833853415931213541677648134703690053765744168086411452423513659991329474857843477918188"
        "2707143218003668264272483816403234724241995471642051516300929038491267945868500721886688596381791055070199"
        "667412232286926092094960561657785392136164166225682260746854268518291064538061618804931640625e-249"},
    {0x1.3c3b00b563094p-826, chars_format::scientific, 627,
        "2."
        "7604974029531470755379958955203393724195949942057591244473815246912413391595013067101010555177517397100426"
        "9851394280913110142349802027895864686659380331926581354881712999287134480758847780103851594645801982342979"
        "0641807148719767698251796504092725134760739333533889568923210722351490145615126375166980861819231195004556"
        "9505026974147140173697808659679428521673427481132186985576932729538148337201682004999096184931755553173054"
        "1128144851232381321744989354016415799229573544122021935326635841125869650200213049730204055454487099841334"
        "7544193726240738861198240363922061035190857842312351787435187322472529558581300079822540283203125e-249"},
    {0x1.0a0ff03dc7b93p-825, chars_format::scientific, 628,
        "4."
        "6451194553246022272173425910248807842189717398564905420998902159587754760551012912411892518528475138617823"
        "1276077149413751767111950364616545937565579226648034335148841326886078901110074148150025254392503526305529"
        "0370216558105709306255319467921884924334139388491595779690971062717608281675484211415461117818876639956161"
        "9813289346817198949598305014082475316385753923603720505835516199626324546859661234530477365388955308858864"
        "3275088066098893147926453981673835512772595499765753830966771751165528157351625613694857586869049470850208"
        "88284307723768352498369060642533108685449620935516154367726782137282270923606120049953460693359375e-249"},
    {0x1.1c1859cd75eacp-824, chars_format::scientific, 625,
        "9."
        "9199020006964591277293509665148114175738068218299722216171684761860715405043509729734134051835419456145780"
        "4061721782774131614986369921373038006621814451564434018015185478894418237919900549658925539440736238657233"
        "2689373586933180978659721914807011300151418921971642861345180133723088014278380959822191416998871835413481"
        "6229989291886742495498869896064739850070478724667412357597823910441887617574862626088827907557313143938169"
        "7371051031113861825221076651489337708984454153330070788022052771042484812220901567775296839230012789253525"
        "76743515243575159677709123598388542132205569638845363104884267357874705339781939983367919921875e-249"},
    {0x1.6a30b52edc7dap-823, chars_format::scientific, 626,
        "2."
        "5293584256227206734436690448860438863560423322197287673071289227707969220482106883975461366052769605665567"
        "3032934775744927789366034483299943037941202054718946505243272833507365629419200820002804983158179977271757"
        "1671721074991839534481385737708488066272572252571245350667982202726521017811552285767239087036275942444147"
        "3374843557581613823597887118702404883540266812295744444400774717845528291905742135010555522440223183088720"
        "6967806285670112170221507665071279926429611065289317694700042420246011589644121085837055088423442887441142"
        "392232124354630488844367280025213630868625148079983856914954021277708307025022804737091064453125e-248"},
    {0x1.ed57ca0b1796fp-822, chars_format::scientific, 626,
        "6."
        "8905280466167352632776620072267895607425419562720887072786636113143019987094343582792471662292866076472939"
        "7730215669170795196785528888685159578923864553514694529384313751243344600123412643351227172604529578659637"
        "2096141206042297685159845546380806896152212520111951628197619447822423235689063793472058111226067963673455"
        "0174591142037230254783839132641626802370354491366421432128406243347719909512208656554280798669191054910107"
        "9454291551252805162525706181057897779052882188595582910816002410243781113060844501237388400738713446722875"
        "308537861185231999546786141281236847796378186571867436281679797360766315250657498836517333984375e-248"},
    {0x1.64e9ee7dcbf58p-821, chars_format::scientific, 622,
        "9."
        "9700406511611006380450058410122703902067520359419945795899511825630118597958866580756336755422909335129934"
        "7926878163027036020163695376425344287053227483975642933460875671431629596491665913660803544069466490750869"
        "9970961003572985859670160028279294993823700602311639161464638127681204361896145848503624511004696881465583"
        "8036376921871076322233996810721470996621854701276918380162974677430101574359190896715256741796115091909122"
        "0856185361682832504647890500198973106127845308319244621499182967427340316386207631543160167022751161619375"
        "39201346108337384023359802355141440629266624923426713678065169688125024549663066864013671875e-248"},
    {0x1.7342806f62711p-820, chars_format::scientific, 625,
        "2."
        "0741563200652302519678516416917490637319537103668252987275223368145627331969006334067507115020665860903497"
        "3765141461912192994606787899859502313760751816479041023020811816052948008049981562060747467660282220009364"
        "7710183989389227941857128261486792713783713285962553612344064327011914894418682422167270443852098206799122"
        "7847782624679359595950024366056315181802777138084183269364044545618872783135809627169533047399996575516600"
        "9060687380227497970016437257881455779017980410088339024792475991575812183540342607164382360274099587700869"
        "33482837896691685792186827022522786412573603601400469044480079361392199643887579441070556640625e-247"},
    {0x1.a34800bb3cdccp-819, chars_format::scientific, 622,
        "4."
        "6848861238967825523919435523535138669568875591721693952497479446960968892754400320865877857137724925758637"
        "6466312176966101394984044901307208121700242179682309442063485879866325529597911633973911504800785909608004"
        "6421048235855444747600807137572005573286478427366497261165548010683612698376700103460067306048636372592132"
        "4059660642721400203275806867777947123755775768605772981974944361167157944352867406159553540359103081682108"
        "6636053116272544880672224430084688270810005976480858092339374406472583258511653370211245655171535530171348"
        "68475375552171532363258796791949094141543712314728307999356360369347385130822658538818359375e-247"},
    {0x1.5d9ceac385ab3p-818, chars_format::scientific, 623,
        "7."
        "8128790561179689261605470119862193017985069838967025530261087587933055171958709784048417131883969881289232"
        "8797406572135239307512241855106659665785341333808027529891639934853547347164191104084961308532479285784922"
        "4142225226040785724236443793549159284110455362352309285581855331258281918297212200744899407805498796041724"
        "0223606030354633376997447668412408687420142278688803934473416390666672371634334561300974538601862070328598"
        "4804418822456502710865535581459474356864773068661534540543910873665770745502929686614726428960140394322959"
        "359752172388948566070676292817051125806874533856884006144394305692912894301116466522216796875e-247"},
    {0x1.0397aff005f16p-817, chars_format::scientific, 622,
        "1."
        "1602344741507901062609933663400332688034477906059336896625075268185503321277861155577877309099200703570062"
        "8717598155228811133748159351247592155729939171162247951338314835092976771138161453964800725190495041903503"
        "0115998861373685927735467998774993942859232888651217060603538892135095615587837214035061210211423585850725"
        "4986658169040416093975183029957643060233052384979024889678988680203420436124343358353115842501466575805640"
        "3520972892965604183687346789132289312009394370877881599615814659100474082740931232740166655750873897827114"
        "15272427588336281066986388648508170505840000460355369849008155824776622466742992401123046875e-246"},
    {0x1.260e422cd6d4ap-816, chars_format::scientific, 621,
        "2."
        "6285314099653654176280875743233612539556461168217321507191666512583849543277500473619693088454262930856098"
        "0983039488026043122846937971785423871648148955714263876626708355772491994903748165606956838961840921237500"
        "7093350457729581755520989176424652492855243872462258991029991096716016371967122853936092377692113114869321"
        "6974910909635803632416076140521430405408494331098431557109315555609723028171644630679617395772994661804039"
        "5898962237787927702930458496474668440982602127355647894730320066735255098153627327592205560893738901018096"
        "0507882534877738471905760480320075691097888868409150620042424861821928061544895172119140625e-246"},
    {0x1.95518b86155dap-815, chars_format::scientific, 620,
        "7."
        "2461952671145799308682942273613242790942104994852816207973587954637784400200604552323859641436019959259805"
        "5416275243813683243530881530312826717587000377649636921271072048731825212743492857367125402295389748557776"
        "9009988607499516894855419967617891078215141053644838762332408552091459298218235738836401360617336568712397"
        "2838007379314935535311449332150300365272142072421910507865927246673247351952415023600273667576940226363301"
        "6530964920377056989684886628111989097851316155861987869187828267689030429662476215473756935600868637399013"
        "945524368611538824872280748159378906498225093109517847000944357205298729240894317626953125e-246"},
    {0x1.a74e934210e34p-814, chars_format::scientific, 619,
        "1."
        "5135575793727129243415548881706639972764602138477489832613301661125525653261291190457252646003879661546406"
        "4557235535184255428202266594734780713103215069500727504595579802054769661280199593841908822623154438852886"
        "5167219048211633614353037959605771745618174998999740314969772733593311483252794879934591349391924024139119"
        "6084831250696806847449720365426721059694382001837632545128601846310630150492094628787281763376199207812883"
        "0310281174844229789408905630908727536976405794432973052507474674698762818002597976646771449616515170649132"
        "35704712171841032071854384668013379767883698598547603797470628705923445522785186767578125e-245"},
    {0x1.33f5e315efac6p-813, chars_format::scientific, 619,
        "2."
        "2022598987138437754955088140950822414079425891031517825754706103180380894029334891007977048969785793187456"
        "3628273401003849229027947643460709548320874194553229940197985486063866961467079881830131956202351541355456"
        "7537809101283096834013388339700196877232995665517358526772416380714017470163654641203667347296739134840984"
        "5462268627991297391371820917998165639554697550184147146843309056835791578191595920503487299426257807906684"
        "5040859907941076591375398817610400020832219000691738654346851177693702055925078500930211965695729283618046"
        "81928981765720671382877489626197246411346537353463659325569778957287780940532684326171875e-245"},
    {0x1.218a6c088e0b7p-812, chars_format::scientific, 619,
        "4."
        "1410759136055035697554355612523273349805779575443516024484433325588504826173501106274906121179378322764594"
        "2484379691318093841368847098623863226362751057949455437358357281291709007819852095728818477728142143877797"
        "0618618828499284120946242604063906544270123754851472649535798272106982211037305830443951538621938405272895"
        "4163702265368813309267001173474115003096471620752013064126070402182426851829272536682605271459261120871427"
        "3261395627080752743556294388041183383938489151395241871318175793857142069803602514255759195099358106829389"
        "25941403961228692586646991088112498341686942122073789018799061523168347775936126708984375e-245"},
    {0x1.666ace219c563p-811, chars_format::scientific, 619,
        "1."
        "0252325908734784187898407846312169662933964451617206135619057870361506177183633250060030678288380992953815"
        "3910350720774420252564370061152467229984493300103561343350506499789324794467185732493962094862799214271322"
        "0434893279799034506854982649170149103444477505174541550420185719057992592872659016813377466213470076718167"
        "1587928184828928855320129149015094685111159435268814365435146233180280512075699541026462959427795332349621"
        "6849064667560874431015731716350235234093796641399858007197207265469483871962411812276890490973250357109437"
        "40918313124555298228499379304666253435895481214111535361865890081389807164669036865234375e-244"},
    {0x1.66ca7625d6faap-810, chars_format::scientific, 617,
        "2."
        "0526028348315092269326491491416671614717274844171552199771340287149629751710490353817825471600522327742276"
        "9848566747186724592570603262783159622679618375839605019976045985194702598494093298790453729629386984648069"
        "0036876519192087476613750641520994696959915507812672382558594635321159278065876914295340826056875441592600"
        "1413614588937378827408562300025096391492039454051283528928602590153392153556731943973383727082855350556933"
        "8189950869666550111368368477078616821706475136695480270170795820169174490625031489877623760618366454582967"
        "116336156971442918961856394686992446379464696305794380037923474446870386600494384765625e-244"},
    {0x1.56e3bc6c4d17bp-809, chars_format::scientific, 617,
        "3."
        "9232668413253934109576315523375410824827635006014532478566376795435761660713281112033855290558209088544095"
        "5118644308491937391706798210947879783273508829940864077425555029743665433796448026542881792523707845529392"
        "8888040646795226366213825411580640005811347292313508735062094848631128449978823754429190527768902694777788"
        "4900217247311196596714046442296568356579966479778682707394799024085491910187918573868394308146580143541149"
        "0916677352788480766516306849228406228050468116273820675030593448761271107798128039605500438662893943456546"
        "783890712558413724203498532897484191055958980230700117175501873134635388851165771484375e-244"},
    {0x1.4b39b2c87742ep-808, chars_format::scientific, 615,
        "7."
        "5796150735595968518238983107483839070003142955986974311581916680225791453486833700764162887478630207856704"
        "7822941859480260584365963321876199100372555439312474681875955134391985832190379567800238426220267234842361"
        "1239623046545996988440924432526210697817982616974975257322206843303081668533190742330428145605682185623573"
        "2670262122379369805524587294726325653350409831517894348004467928232650745530506560430564162969593601708820"
        "4593973141345297028237304870101790866929027772577561222369175133237449464221430999208311216033139713942561"
        "7718942914363891383632845680383464106053752022684744105163190397433936595916748046875e-244"},
    {0x1.be40d1e238ed5p-807, chars_format::scientific, 616,
        "2."
        "0423721499211961109568525534671443647740451225589577776776615350824924185902447511045534069936905640957606"
        "5372006706682415988169410761618104420823540344653655850495453161898116740909085283322163797816690426713928"
        "0588386591469775611793558909607779568837686913517898927696512373572016048102090271465196837631021566949809"
        "3458778713417135141374746058126296881347472422680267110011339066236275056110971927834750821976896185521894"
        "2603002734635679430244400522090001984828634799129531569049286075717103643972525011916090411511711638026757"
        "89249238420106837535506252866076169083468642463652376051186365657486021518707275390625e-243"},
    {0x1.40ae59ac6132dp-806, chars_format::scientific, 615,
        "2."
        "9353293314833333854985102733201521796250036157410578174458181974941681427901748305530776598182206753889861"
        "8636371016267800470669357640180721556010164004214645520298136353408719208286540502372077707795876864389123"
        "4530987039470184872750427478883560918646684350505130722837863014999727875555215685304086401604276801173120"
        "3139790194066844214273369426057653128075479513670720217838142259228046519573053627935149750677307039941356"
        "4828147132972855997122201965456703954022412625507350561624510655574143234052851884708200203074614546619619"
        "9361830208532545550931607060890187286750154134484791512704759952612221240997314453125e-243"},
    {0x1.5c161d88eecbcp-805, chars_format::scientific, 612,
        "6."
        "3723638585700451642795559570510679148094993613910324952290173092838588831267228266631303318254630028045739"
        "0407187178061510576300035754372233822499222282961203456720941314976636497138825053868512001918319562376117"
        "8503122166819829425566310708112327632839687765866542175513644077648632060395171310907363823836647106858223"
        "2777412680176689313447386866112250866307040221174507703114483598510540103447645068390784004440801839078883"
        "7194778885429238978252063987403236158204856335435926863891604588752783057832428086623507826775024249195807"
        "3955716265349471157901811121367537037413035505561964555454323999583721160888671875e-243"},
    {0x1.ae3b20e6233fcp-804, chars_format::scientific, 612,
        "1."
        "5752344142353219450694189702451991296910433408430789019004125131863629296511431154230659503890717620031590"
        "1038316721233788818826571623317203349289987417121376686501945841032567911901250552698960793265396245960534"
        "7373167055651820451912046546618888153412645242490087251350087576649187699383010638982269418082540884562832"
        "7750244082466163980074438483304220415007922943039390750698179386470176966033711270276708288351928574480634"
        "6620427578497508169144643312340209721649688496292864219377630628268116030388752066570843025641533813750666"
        "1505153630440989474460324611066529306552773392890998138682334683835506439208984375e-242"},
    {0x1.c895736ef62c5p-803, chars_format::scientific, 613,
        "3."
        "3434436478293493280593571271178008379632079500385975548283939163497852214879044844517670759497091492926604"
        "6301395881911376324184025424812370739165394698174516004668202850196235934904450092005834916657352885854495"
        "6797122849756889458856656030089637540017312018075458430375030356712402369619517176293964796597028107692733"
        "6877655770322576324057362054878847600831468525556287002358878533444200008041718236056969477827934772656677"
        "9815145097506338920779765572188303868670858298304546602128519970722727663497018972024558384033232006396023"
        "88217361333368030658835443253281029721128182752298840796356671489775180816650390625e-242"},
    {0x1.630761913b642p-802, chars_format::scientific, 611,
        "5."
        "1995664937001350863664258209506916125612045887421035495539968219921552001490404512666597057126511434752881"
        "3007435581863058379511824026420279450528771594711743194984119825629737962368975331651816862223263764907329"
        "8959845059152436168274836787886410245541432791484117122823236508634176085889592513409849869200565154766887"
        "2239050279254533707915364965481634484943025853564537256019007487191319787066437301873020171361092201939838"
        "6184775914931861779759491034394263205676462386582564671334894431929147821752438599108003402914657920461899"
        "226466173041809225803734159361765368727488489941634952629101462662220001220703125e-242"},
    {0x1.8907b557208b7p-801, chars_format::scientific, 612,
        "1."
        "1512226658355749483847981607903749186968456271470668422905514968048682862550587964588422845161815767196734"
        "7161381736286682330197784945747956438186532961339942750020185568887387914264273351910759945563214255066684"
        "6367743093899226009412278214746750427881209859743419090772304032977787125925338802665415242857226084498164"
        "3083102151843503613040369064236192185129466999497241256541067862601025573632294816706426141506628320469477"
        "4696736056927673474964247532394453617303703702170832899939996119301381165251917266354496116545457774453945"
        "0895523040343609292008370421060948365454650044181761359141091816127300262451171875e-241"},
    {0x1.0954ea214daecp-800, chars_format::scientific, 609,
        "1."
        "5543636774561636974984361218111011815787496115988125251761512745799203239114570231530311587628929592941376"
        "2585042010727044016847870464502675936376968118423019078639597656703801878013483722710291570262191347684833"
        "6805205669043926853377700998806089359780103711297258044030751523125011328665317845898485403235762350467927"
        "6134156787944549174068596540770894898876924542106646637655671038405664723034557454476207446791320248290714"
        "5008167400683897298836718888410810473704984083888533798729692197933748270991636472806299358418250481774109"
        "4771758489864324415337151128538238880998079149975410473416559398174285888671875e-241"},
    {0x1.5c2fe731927e6p-799, chars_format::scientific, 609,
        "4."
        "0794930994574949442525316075493436362455473092684438997934986135437654466941332739768956377877473397607134"
        "4064958156084532579410087539106327345372818664352247197277361471370030117784789618983207924927651450687711"
        "4770356574608290123358451973486669321692492332398543131893173963499548478234080992976620729264092514266793"
        "8419538195787260791452711556640767302269532128743048602157910479633566088244594787936712119482747027241365"
        "5907401119681985982507921557024707142597573048794208218331141095078100425607731851283402621691247039292834"
        "2115674805610333210644028408620173696379207495255059257033281028270721435546875e-241"},
    {0x1.6ae6c51c6cf43p-798, chars_format::scientific, 609,
        "8."
        "5037834545028439726511173970387065376495451801221358745541466022111055279447814368476465692501533897808052"
        "8414620606538201959175171073351443366751678402386951129508572093685812674971226575682201470239574972506910"
        "9128943544677360375146178941605556087049517009816921069940296076289616976017445345589202204019215772204351"
        "6311008757552625899436454298892097346319367204313955610412435512953237673867098391988751837296926369447076"
        "5727893031773910333948712489912482607284107894642961799688586136148985510389912656105970673902638925743472"
        "9720838400566841392990613565908529915098046370047768505173735320568084716796875e-241"},
    {0x1.ac4e86c315850p-797, chars_format::scientific, 605,
        "2."
        "0072820595479573216169126231394408838551922619989874786871658199647732697034762028792666015861804714982292"
        "2191591154955291378005015587839555531480612063235835347012810772327501856166588209464579572448604508899906"
        "1772187223684855162442424175711463772705279180982126416318031074372302865560128825632323317889694497843360"
        "7754085808572590924978633945247230403112787302032626015620605415136044530348825415809501368263327044824152"
        "4145945455699623696095441521069129226509344118102237809251029986795488661778437540002054621660753197441908"
        "343343400344601261991557764803617049109707437537508667446672916412353515625e-240"},
    {0x1.794bdcb1e5858p-796, chars_format::scientific, 605,
        "3."
        "5364382089011979980897109687165254886696841520981254446556125956556978294321082019870841710940758511838532"
        "4894179439057364357461159517137903474744654629717453375448208774398730333711862007633962738258032417741380"
        "0685321115393078264140362224325824070666437344191369939443217492221993668605716208990694526263949725175127"
        "2531533913011070118815751448623244063021481460622877756524201582813510487724558551743402584791531847833324"
        "3947677512125596726121471095288063842196951847839048568745797565605397830354659437463682786127174530399653"
        "052185980142212749148863110471344671503768353204577579163014888763427734375e-240"},
    {0x1.d14f7ef9a1bacp-795, chars_format::scientific, 605,
        "8."
        "7228090145957935347248318547742302587087102313285501442514035526226306674555848729098848343284853736028606"
        "4873831254928609967322217177874171796955578934465313147402878865039420827565176878567927435477084189200595"
        "7806847646599109442906678146695129581406643504246823239271381485582046753531471862258384352222573375498842"
        "6169068002044002105223868118456214469943463514242867324395558742911540780602189115030142752959592996857877"
        "2273040528807362627380272902106605717316557112560491693041298619232077978968586186803325882819783307168556"
        "881297598817001041704706994464233425767840657272245152853429317474365234375e-240"},
    {0x1.6eb9675837dcfp-794, chars_format::scientific, 607,
        "1."
        "3749379101340066083857337348176012879302998942040643891959413447462809923213710792385920913367060586620860"
        "5258647049621760492047179451844836572119347356991890024090747092362463756927276284737937087463531842640685"
        "8110822716901060321069319180330630095350071198454014017603381215347279543191075769849271941472232894509230"
        "4179731068530834521111061163476202640787726787899152301887532484498175670012280605395371745814997035811104"
        "7972034718728424120220308910285188823533296077514778262102253723563125528563041143324629454753231680542831"
        "91572629933059608724961728922265061757224113847541957511566579341888427734375e-239"},
    {0x1.96e8a42e0e289p-793, chars_format::scientific, 606,
        "3."
        "0511988184972799383071211924634487175460180935326054116102185981586408321039421266980709352417518315887404"
        "5050170880613243376562389933452426086185695180699312804245142060569472810956533457237033496816457196253387"
        "8125149465944408270649637103835598442140509946028942888834087818054913127959283097911123015576692191085606"
        "8568283496852317230749669582281777159547977023790389787193331339347536950378181463434129630396971207994134"
        "9950377993759212633121226292844763708145719324648259205908825462198868419797842376770017948515553052857064"
        "7693354807915784314898721093603267857929939310679401387460529804229736328125e-239"},
    {0x1.9df5b8438b263p-792, chars_format::scientific, 605,
        "6."
        "2081425746751335610146680295435101859461655681989036586327775217238749061303501735332371382900280575515719"
        "4020730148118435599036452088715313932099113134973129083783128920389682715075150575144731203122222001783294"
        "9424406905553795591369611573268431281518228057618249401975945890243492974663368994552896023782381782553916"
        "5337044719128567721394744671262149404471486748537392698331767276580429963086090235313827296241311355503851"
        "7755830887058852014800933522702452536975068231984788501210512796491195164930952739801311157528383120640408"
        "842401705946246458190149534645571431645816318223296548239886760711669921875e-239"},
    {0x1.fb32cf0b36aecp-791, chars_format::scientific, 603,
        "1."
        "5212878641555802724950846086516145032300326998691190900292301735619031405755263380867819445511072562572943"
        "3287593703388535027004430201878462180974444880722937680016604317123047097924707771861156618306166328988807"
        "4173424610772542026483506595446813945016920935740824692420808377728446284988055043397756717427418778466960"
        "4764984416510689582171300446811130954623811981865739826589607924848307316279607843133793365371483255657291"
        "0067339723232808270374427845927610682612753312034224066285259685752517765740312550171970032472135036986863"
        "8181213742553728087480359007130879811509061028118594549596309661865234375e-238"},
    {0x1.a45aba26ad06dp-790, chars_format::scientific, 604,
        "2."
        "5216166351846410904598804126503919975960206341421556680673122139430839618893068778953528650714452899719345"
        "5246108125158739482741680475817985898310280861272177832678069868601568095686217379876046803162010708112630"
        "8023604716065459630277834590133356599359591175082540998292572569927744367695512232618054512372669109059329"
        "2278734289697568086682228820112428175532506340283777063322011931055911875751981872871842214504360402471002"
        "8669711497076549528902364758613574081434795344422816278952670020566267027219316225416939365006958713799490"
        "66388752655501946377532357382246670784997633063539979048073291778564453125e-238"},
    {0x1.76eeea7b33d9bp-789, chars_format::scientific, 603,
        "4."
        "4982897883519312349700257852074285242839338405891623616075244867023942468017792455826328206218393099579788"
        "8538183326678388281543698838695901138016399892101462657564145324397174804795442702076264717572685786596699"
        "8309206594117460390492150507731013549139591322588458630372846181251298644962778269180438519777882585752366"
        "2061647833682308513660258531274218090943034841110993020477090849934919002278855577982822728887910520508057"
        "1309121300301230873906142310636922125841785801395507975381319776355298465790722044417775302439469856484395"
        "2193959423860928797599218080852621903797938784919097088277339935302734375e-238"},
    {0x1.2f72b0932e6c0p-788, chars_format::scientific, 596,
        "7."
        "2812801441645303966418732522860605234446781581701162951874702445421625014697873257721100247133280933337547"
        "4632822147569730372734556192651075193509364068638545045433634662479604972014032304625118712264784753862330"
        "4240701146998515213155895112699926325225487803168318982122886793550787654412114711135260065548158754163814"
        "6267792175300075972880320531815842324890334392814926595009128071211433776121950591682377947812052908478752"
        "3782045399878957499545795346063587985477731111479849521556134883351589450597232837336115964779975403775359"
        "793941134875836977710206014691163289853648166172206401824951171875e-238"},
    {0x1.a51a411cbcd83p-787, chars_format::scientific, 602,
        "2."
        "0208837171448895837318180903259214725922207568227959012108677599688049530743023941864936723736235817948008"
        "2611403427798946547661988139742169620596220391493753722071403821592772010242534186589497286966518076494362"
        "0678420736321907710661911556894381850108346506265630319767913919399030191431965110937831030511219504532874"
        "0586466146512917773158338656319118663906595686588537648936843031647093427657363683641219540298646042122056"
        "8317426577038520940327301670924988866127770057169548924829741512502567293851452818399420681877823748179849"
        "398737440333262050279769937353134545698907231781049631536006927490234375e-237"},
    {0x1.b808810bff5aep-786, chars_format::scientific, 600,
        "4."
        "2234650668214423350279081718143018052918828845233278512008791451987305685594591145976330970127359480860248"
        "8548917264315584433512455554684826100034965613524346519252961698792900476189960718557697298950778181410013"
        "9640228026095584871810289683508239794468996786987719366315242777184998255799306920272281717213927883238578"
        "8203065386664239152516789871769170789609239941892434305575451880664013613320226313501911783489649376683084"
        "8714814724615946149072474408582468575754684669730712413191753420272477919667200484972631788609536129952239"
        "2188637733793856554789030127543270065615388375590555369853973388671875e-237"},
    {0x1.a522225f95f46p-785, chars_format::scientific, 599,
        "8."
        "0841257435956645678547405463747941035254532491290665291476902755342035620999121915876359426286744536442548"
        "8791455796027552732952087071822418098846022103639505489312321900912629868532623475135095009363265921031875"
        "1871079021611411332741033775270408893701977185246154640873852536013091269615317189935301688316595497628363"
        "2052474049117604877290387290489379052271964810487511690636116959829601543260594988729338797802211604439634"
        "9881544511737095144068929116901090243016127270909040329117435763031291331734916897008832721886597106496144"
        "499841505379496532267678712661840290110148998792283236980438232421875e-237"},
    {0x1.b3dbd2256d4fap-784, chars_format::scientific, 599,
        "1."
        "6733590187416606942028788295822734147043087946233607968651016945006043063743409956982922605165150262493695"
        "2359551337435141043924366256262954714703084104196403532472922571050719624290744697858239688419404203520754"
        "7557916850717553492842057781744688693737608928952458431646709318550288396484391157776279484004370212297762"
        "2085741279270737213198962173572325958013463853117760877665013868039714619089151048393695975458000098063344"
        "6858750098421368476749851793586866701372231665192694279106769119933450898417201549643514656077765935283060"
        "136103656512062492185832101622422474207496634335257112979888916015625e-236"},
    {0x1.6578a562dfd81p-783, chars_format::scientific, 599,
        "2."
        "7448244739455369599852949492552923507948333818208197008468158129083810159695483256360269175415015466412031"
        "4225695400387005807802038517353586335988207343902959393348397621769684884913575361723052144412545323525101"
        "2843207362623477900893247213636680781392280455803632115282785593332780520340251878255628655632838690511799"
        "8586350085644107340826449520555370615285390114023939058381308345313892978294651712108011038387663767010617"
        "3438419253507596733224476414075014265345891995296496120856593048414341827141680276415523884377632032961134"
        "065066676791255166649173319499965817414022239972837269306182861328125e-236"},
    {0x1.c375b704d8354p-782, chars_format::scientific, 596,
        "6."
        "9330212812845955601973051705409859820189947914406991516234621867700438780635584678642245240229377264515669"
        "7338726349371873983367424350097381613788724747210201244748437625890393184241908098354893458187915104119341"
        "7684465460693231943222252870968475205589194276287015578056177004092191366508966567650334814489885848490942"
        "6122870870673228226689067501074893767746717599791972139895758896137999486120056433350900790851566486391753"
        "4010543666617786469916707237836024118874742072934775462928779342329475149180326686989774048800335725396492"
        "694612182396772755548224227706288758099617552943527698516845703125e-236"},
    {0x1.41ed65ec296ccp-781, chars_format::scientific, 595,
        "9."
        "8876088484049352922774021202980270628015087562012427292778038682091273168220811432033616289760109002310402"
        "3704996008069111083741196140661388861826358577996302406407082910484532702903501127304650131518239172470834"
        "2834373731353510858807009428849017497972201623850366494027130268394546556252337263922088889702844419759589"
        "9063387263573871573732612758260782869758009494263629328008981472261588690396371322017572369585846209902633"
        "9510542868187895386861625212297072254733429651534552220213138019454443987615077904499633483996281342741497"
        "11127064592991748928608140845053497969274758361279964447021484375e-236"},
    {0x1.2750c8cb09651p-780, chars_format::scientific, 597,
        "1."
        "8140520866375597592817140173198328456153471086515443891947301419067427016349814663252643281827753782214000"
        "4306072580093724492340899978941054679924199470836173279701306416204849855804566293231708048363754246665689"
        "7132773851376950137481730406496137930367940298307822959184929691157149248171962689707484240913709878645248"
        "7651516170928175691609460578402568818237797997967259089571151773860066324450511535569895183000043741984628"
        "5606114661392523948868455531855100625018508153569679961738521387114799227459274565213553967286187012847908"
        "5175141572936063038323285280528640583952437737025320529937744140625e-235"},
    {0x1.19ea333f13ef5p-779, chars_format::scientific, 596,
        "3."
        "4634694166405885699722665996156819190835305157939379082230431113198584814406142159489506709243038109913804"
        "8087091839156277339696816832118015570005868291208987392092241756886550999683176589757786184600708233295992"
        "9104748617248162737955257920342448513168770535182891455893675197708497078872366516469116334460618374815662"
        "6215995971472457141964876831499902261701806293373256835816802621390185355511566406092215783275965392566585"
        "8442737716827116543576353841785651389340117531460235593391101203276419598915973745824201798081334576050870"
        "430956021545159155021671205931799164545736857689917087554931640625e-235"},
    {0x1.a38c43ff3364dp-778, chars_format::scientific, 596,
        "1."
        "0308725436052673004078265535849362842941462603767068009055817328335165518994401933172454910493217867696432"
        "1845962716686314874470651933591385894469274918631064185075059486235684207315610254821040680581793107781394"
        "6746960625748974345607263573914820643627389442572446655908256314652737333336207566756390293322256348701247"
        "9314565117858212385111597451728156265292208695902500402336262572667655661806388175890193990786445710715532"
        "6444270656212874978801400697046881563390089872226946501545033080160837709416037693167240629952771552441667"
        "361465182176428352680002016594773550650643301196396350860595703125e-234"},
    {0x1.0b0ad1b956d83p-777, chars_format::scientific, 595,
        "1."
        "3123008280909585060094739769474378460538866107048392129824696126606516279205972547670492262550710764284363"
        "3234354641682526072825042161215500583864172196389183875957416010067398215922042534330073715044124724096640"
        "6740630337183260137195168587876580824443134710976924007017901504245366920570333649552524608892742277095894"
        "2579696379671576766979558709660405125643620837514272390698664170189566381311138897213106203693198480966230"
        "9746683046481084817065834830049684480464548077598539532315246634601937680515282851307846303670734268112421"
        "64361861337955626193876000618043775602927780710160732269287109375e-234"},
    {0x1.8a159b1e99b88p-776, chars_format::scientific, 591,
        "3."
        "8732242378153897318097485186350960300031186584656562863006373476206011523682262557811183503862971612833114"
        "6916417461255020728803411155740943257717511092693240971786080135296087495134091242375838374168505261130380"
        "0492598166723089782339674226277801628972688152897218578189493489170331295747560535252056117984854618682523"
        "9305131571924373146542287418567990354344016310437205184558983660529561615320898762527140916102609030211008"
        "2103832765594531080012430285923201547172290131441715644938740240491425394877727279661634375115396176587234"
        "0989930831780784230462810757700253816437907516956329345703125e-234"},
    {0x1.d415deff614c1p-775, chars_format::scientific, 593,
        "9."
        "2010739647813000085411005568727105998799066899037448965302675135776884816654819628173659937259171048554565"
        "9299792147126593896231306003331909077948383910755151878314000991105111186376426687047583016174605352766814"
        "8534331818246298245816068105997048536931836094343752160045427531551482079866068037732986220746545492963890"
        "1238271162895703777874458709089484490860087292013612010824285906041126662575922290223290517197672726442811"
        "0290759243860558664957215585129480394134876729038989456780357462903511930632723604504410411901707601194771"
        "524410246628913870770190286396683632119675166904926300048828125e-234"},
    {0x1.310bd967f9a00p-774, chars_format::scientific, 584,
        "1."
        "1992483584063613937396382002898619029819538686188191051376468587418398044923819788257981810312450970237429"
        "3152236901426529753933885926217522939375787436168025095420854421089105328643012783084193445775178532627019"
        "3002021288587642607408488965662669916337673223002264510994634236841840933737724623832016553236992028678401"
        "5079222380268705401143575325058869567756026714067386945351235295748404808174268116051793510048341986101843"
        "5189240188373810482122213082644041469933620211270257379648322982766563842384538563467443736569589192277871"
        "478824920734897185869982649819576181471347808837890625e-233"},
    {0x1.2a478a0b632c4p-773, chars_format::scientific, 590,
        "2."
        "3452909097606002102998388857387398320146582515932569159622941748507502071602816219003857791914292766210287"
        "1282920701702839101779318975472524788417303881315933266593759151136812057701602281728908118286422653068981"
        "2976721417530770069277611318604358776733743161458118453496278452601803441503553632201747451899227732879279"
        "3939383070761065446832297352683219271773789038387084150729566669981216349132935276369359294821930391936873"
        "0207897372104156558695370518639326240457297236641350456607151007096954463810541500796919853141331376838730"
        "027058339967416700395930195810478835483081638813018798828125e-233"},
    {0x1.a10d1c936f397p-772, chars_format::scientific, 591,
        "6."
        "5583225953784304043954834614176088194295405940341601198073153875988601237261704379055993336597678819170772"
        "5308732928182976190209935831121926799822295206356039751458151538698202210999800319499370069053119068921318"
        "6495513705997548419470722568105046316621424908719955943222521965922140810646651477916277542996197210024407"
        "8354448201804009172919086425145196331932267229375638726444077959998629259488107236621956571918999810323974"
        "8735717531246698300106404621320272068687120569178549223991517121489275313276613889947072468874020996202783"
        "3578890959869765026578336541973612838773988187313079833984375e-233"},
    {0x1.4135d56a1a3e2p-771, chars_format::scientific, 590,
        "1."
        "0102359616097600006944043696266304310402566123880381330525868678360586417700284313711997697393207834996490"
        "6412477557422038262981083901801238882772015066331526420346388047508965204935499624567755681398845856171526"
        "2242364880332481311367223365533330138935433511898794179657484124403659524277293102547115573188942514605904"
        "1262737288899085376795178896977519105000739053421097877918031437721663292284423338700565418149569030815098"
        "1976897643794990537239534181469858547742793045584048036497046009670011336379378447273760163550393934817516"
        "023051483276085451591674857496627737418748438358306884765625e-232"},
    {0x1.9ceaa4e0f9a65p-770, chars_format::scientific, 590,
        "2."
        "5973213970621353044824545188200592183419042385639727292053562666249675544942691912517025505947140109121201"
        "8691791676589598304859963199178052096220362044453690802401185643378067015831822620192178219791939757230914"
        "9709039667116952289847151837424216761341021681339723578337857881286638542378091891939886703814853841423404"
        "3498297625474216866415185214871267451369155514201746224365590408487372081525980706478638859040170095365664"
        "0645570094281836888650858982474863060907436892730671482497330980571409299449161530863472389822545360807847"
        "278223954502168854992227853273334403638727962970733642578125e-232"},
    {0x1.89f20e3a83371p-769, chars_format::scientific, 589,
        "4."
        "9559800065235153489796410194161390966488355617585666542707339136900558711218785557363856112303748107913099"
        "8680237278243350843537532200899336534061998689022480144868594550956871874227163881895319963658374522051904"
        "6712966152320510867618543585720024531194940872820672919233356870518352801434898546241842045716492357747647"
        "7957958540068442712132045749702481116171119884122838963976902383703248102452023124430340570652009799204816"
        "5249261523263392714849956402443956398232588164511714409814006544850650200925905726503033287699786574183111"
        "98129755525915792098434753398805696633644402027130126953125e-232"},
    {0x1.bee6d84bb634dp-768, chars_format::scientific, 589,
        "1."
        "1244377262803143878068016423688012596039718894748761522693123703181634130104650640135262083103846749672518"
        "8012492495381704764285966084753488065021470092208542183182084032595971810165044465057115424454465191892043"
        "3359242751160280842713632780774054505432019612624878172464734301273167678163431120242405621415824776126460"
        "8947838926595118197402289470545118797483097395936263215464251151336740856339180880724959346882809972866164"
        "2692633775304002961981768923100643096019801742272879022489813178847770417859840592829885544529002381973852"
        "04296812693280688440211623202458213199861347675323486328125e-231"},
    {0x1.deb403c7e96ebp-767, chars_format::scientific, 588,
        "2."
        "4089050126555282541403121147937146640322688813110950873494165256577427141764900209847715481143046869400508"
        "7142706729187182868489888726631219010556346470377235782761231255161283491871481571830171798317313191456617"
        "4309783228992987395309874214938085167780197703713450058388341555810443906059468275497970709180486706718587"
        "1313640308216356155999604435917605136780020449205792873192769293405985822537229012759146679613240165097560"
        "5210869334907295625604149011565843196894122999061870059481852780220056624802519719890268394327365072648952"
        "0827818495221097315484026779586201882921159267425537109375e-231"},
    {0x1.3d89cf65433a8p-766, chars_format::scientific, 584,
        "3."
        "1957993198054625725213645741173162786935684857677527438090979500370647810397958920480824463940923329563437"
        "3636851774003368423771672117121283918964674083790880004924598131903193790947820607391613617716363350605791"
        "5622232960627326392860115950940947029579098561357097854414116991950975007688070342833923998116760516870121"
        "5749176970374592880103567554395837929673462006697904438147786695003031463211995666528121763991142543575975"
        "5899718471093397427400766264709037449493655219279456023568676329258618536362702872759367963005063148812537"
        "726423102708329937460263181492337025701999664306640625e-231"},
    {0x1.3cfba273e39aap-765, chars_format::scientific, 585,
        "6."
        "3804197587403760326652898054200801828323214780442215032022007620478359597818401693284013081678136665027405"
        "6490197573287853590724100179977990824731156430940900293657954999782897120810644701128329076885474982261315"
        "2004534567980240484852566346849092151908799371287257255382445454735215000987503928361640304537884889342864"
        "3145781279385770628277566694325711581556041680649755580831709124446178875091795627785989583994623827758905"
        "8753937000671860615795959039778377116606289273494321908010815730672333507357816874258583488584279492533715"
        "5136765021905438655114295443127048201858997344970703125e-231"},
    {0x1.8fd3a095fbb3bp-764, chars_format::scientific, 586,
        "1."
        "6095894110621704153832201294055971532390391615911012418102173691565843809408450333609669585716893417322632"
        "1447397301047417148502624258582835574723816240415594393369665164751768647196218708742592134423663760259422"
        "5725582449224662605981402620585333275787021731573507809506478128418455212296523148679126266426699652401165"
        "5347686788983136076956554273893939557385379020373453645222044106667326598338033048058315587381156417693815"
        "9689442060769621685872330312916464823415664426762643483429352265211453025979662093409239736334483968002895"
        "34637228014489311600510035304978373460471630096435546875e-230"},
    {0x1.f4db39b3ecc94p-763, chars_format::scientific, 583,
        "4."
        "0326128219471308776340774632801968730422798127085717909547582642722780609987155279615390281066933947805844"
        "2834132325348297619070203917114895484113342497422436622422171014950377706618395303383927177010501146744877"
        "5538953564225445443359521685452770061497047825649312653532071752631734104992995726313037715144741959667621"
        "3378577557632829154543778635778400664844147650126586480978710722699215601770032193691389861493527186292410"
        "0599178352375439954606326097129388309765290899844628674147158970800023347955167381151032697590479982052777"
        "90672589771116263168693194529623724520206451416015625e-230"},
    {0x1.77036a5ea0238p-762, chars_format::scientific, 581,
        "6."
        "0387918131443855293985504488455915724451292685267014767829849073500412060744954585531063673030529339395152"
        "3888733562888957496230925242955930292779412423416985599139667873737076545274846108104562187768695151949854"
        "5128012141933364974487522376491162699773763210995107076549084989195346688616058796160233927611226734207770"
        "1687069702978155674956635793332657387620943979787993513510686776554055594710429194494938662706250339068265"
        "9995039549772250462149515137830868639868155808286646814645933763259664624485459438133730144593675207962419"
        "919759523671831669133780451375059783458709716796875e-230"},
    {0x1.16a7ee18d63d3p-761, chars_format::scientific, 583,
        "8."
        "9743230112456742542899279796268272934437787928293448086298107077647616276508988954791659580428804464479810"
        "3641898249421376652724137290600459136448447242365922273624432734917290803189814744215370570273183759401554"
        "4794593860976939114279110402292024483236793330618757059821482848520627476373652688290899567926159549042944"
        "6328543904775889245889306222564992234900589838102861964399884580694207148624055586974244583117165245055477"
        "2427198667133558451445735864240418102343992211275762410613327206706574095487836196314795231910512044608674"
        "78785766697922665624531646244577132165431976318359375e-230"},
    {0x1.23d8446ff655fp-760, chars_format::scientific, 583,
        "1."
        "8798157375327937836177365552311551722298566992689137495408401180064460810275669557368262486050476535706822"
        "2914315437284620215942901943604543564464950435141155358461881045086110693670535222743758425687312773016464"
        "8403232716340427184106949371967480783761089412133835752241924595873877701261614154333943909110324386106585"
        "7106392044433133552798988180692705602297018211749323498943970494194463977408110252138958916967143497719195"
        "2134646702290784545105260132872002148565751843028231690655926702860817601062025257596703145147603743783651"
        "26359435670864994616380272418609820306301116943359375e-229"},
    {0x1.d9ab918404aeap-759, chars_format::scientific, 581,
        "6."
        "1019603119906394823703359893419041043488928668777127321609779602295957755846206771587439667498191607870127"
        "3188407787323422531248450139973168123277344462820437889744367034040516526005744130783797920887934326880891"
        "0151822705828875469292565269036546147893915456863015857572909063802064779293512026308928862177518529874001"
        "7449142693550088732619227748522352368557175278481264314118546468989352818488963814913806525070024091423038"
        "4912650786353791658298950508324864755779932694843174445480821573854098041924252035624281216732196095488604"
        "104431604353842022447906856541521847248077392578125e-229"},
    {0x1.b79a4312f9cb4p-758, chars_format::scientific, 580,
        "1."
        "1326182622927227585026998401953453564387331526632995841434572566012270184131360172862035269820314552997461"
        "2413776329453373615156209188225602299611703931307655537572480430140533142776043280046186005695400263226405"
        "4098695658992751763639680664807306814276096257291132541721885536638354061211829923923336184608179768249661"
        "5655564150929904808543900488190715743181006200383902980812754628242850109644997858821492841688957682488157"
        "0801892773888859331879713604531979736514527913407419982887313114056184858415168691653101367251865741739853"
        "26892508292140337999853727524168789386749267578125e-228"},
    {0x1.0546601b642e2p-757, chars_format::scientific, 580,
        "1."
        "3463284210193605937745722937725857242949709999335060039840423204785367847390302267195263556416334323998196"
        "0737824736070186305672691183645646002343666546236439493821527304306900177800654130523476951053665910754980"
        "2006642369582270152401156269927147775627734652327692830564639498543071813945773867021650033486926053374860"
        "7064447801305583373185311623132192011604915251465977752968767098478902675252505947952937650369501082058516"
        "7696604253619444550313473087062527883887885241945951106616373139101667498193153482586796890932764432009382"
        "89032121165933464368436034419573843479156494140625e-228"},
    {0x1.e06b693958e4cp-756, chars_format::scientific, 578,
        "4."
        "9511263202511957641512399699829602641557623549736408253556822425590975395266427611114962041653194091053383"
        "3336879775284591319617332462680755701831085768322962567258389848441961989693426878116735587887408259374359"
        "2329287169456729011123175424958580526996189794057792610262538257537982706974488840316535755315962922121208"
        "2104534907468772395489064614074689875744296450508670594617851315848483996401206801717130288469826373770474"
        "1070405506427014217576152560575005033081034199467103000860613468937483063135363487535101835560640066559693"
        "432397641632558560331744956783950328826904296875e-228"},
    {0x1.9b121164ff8f2p-755, chars_format::scientific, 578,
        "8."
        "4728535909856012410200041906372414632296215272648004484427766845608477344705431493395232423944742460409199"
        "0778223620807142394934542575683530467976285196904925993313206910110734535883670650682654077675051720555490"
        "7153785753112902611247022137719954694936492237768465584405476424134983268359229541767595642143658069865886"
        "8311486350995177436653307794720582217765353864645824269735870431707954815959499644615997063996698543462258"
        "7493782430960216741916190622401646187797991212327006779815878528741174104469600086982166560311473505952658"
        "790405830624425931318910443224012851715087890625e-228"},
    {0x1.33c105a132a50p-754, chars_format::scientific, 575,
        "1."
        "2686651186489640418613729090000624883664125727826691528539824897946273278972673662123556913679663178920818"
        "9983431026863877108668219641584809556168837216776958126517591068005717065263272298248242603898184394956661"
        "2935545218642071817145322217521025560041269146239403948013671611970850556013445928964207740870533157257423"
        "5474192624851323842879640005145189256370467851069614167518680883900253222756097604564947196666302205472963"
        "5272862815877076419614503481104276280881883230397522547283862747567583163122464808826042178125167560452464"
        "976701592025420950449188239872455596923828125e-227"},
    {0x1.461881a63a0b1p-753, chars_format::scientific, 578,
        "2."
        "6885518067927030135600540861707655056802159939373748083541390174722386534014508552498653876610051009906744"
        "5588072524415445950949218647103736177038525626564873722274278821070632004195312288860329438863021795170526"
        "0348488305643570712966829103828184920483901645182663652301170189091428704104767787904483000287380436224672"
        "1781438144108851865293957093901180296561836196437647790186463949972800429878337528313848596170010590760822"
        "4914495063158132615052678462862682436495900588406487060191263024372546385805536617848116566363084955103460"
        "608268235720874628214005497284233570098876953125e-227"},
    {0x1.0c2407710943ep-752, chars_format::scientific, 576,
        "4."
        "4214640337505111554944922904823248343623564594516449176929291697505388608995390558125712875479191233524058"
        "6693816810894915724128757425416511778571176251130211532941252220691325000829704363646059477032385920079354"
        "4962681567393060012625739634735505971763236487302996987119743532149729213667588530593927826040852059927106"
        "1340719831810161934489555283359505257515360447477172801213945337256578391537827633397957645917471387846426"
        "1200380015132547253153164479656660812754868324751497403180618654707083628746868296897020739943514195984012"
        "2704954168408875148088554851710796356201171875e-227"},
    {0x1.f4741e5e15139p-751, chars_format::scientific, 577,
        "1."
        "6504299596692554662898438315568742680263082991056883014480508018205961615940064061679191491165679723425025"
        "2863380902661161947391420357522669511001475560313481087440258851257182689933724644529724655327662646988233"
        "6762161281034853480590013149229622340795138373021923715805777359887470617461808606384004424205619224951313"
        "3466820813188574640339167232416711196939091660364895317573753947157950137937372932611869784085126390992185"
        "6882812206410494132708440516194191677950453419818231956956927305302147631427349917441266753329544669595973"
        "13317938127585904339866829104721546173095703125e-226"},
    {0x1.5b320400f0d98p-750, chars_format::scientific, 573,
        "2."
        "2900091426989979358392530605461785016759482015004950433915892907133250152886447840948978235687269889320859"
        "8011555329351538993695790173998143655914545077937899287779003767388246713422999451873399075196857287901623"
        "2254708606129229326286431030847922256382404862982847219322903060522246908430848008821265886585966924413435"
        "6907554414094347760036636740432338875043535463497813544269468938114827178091505465716734212496341311036397"
        "3407460982512641208562604885921079704974941535175270523473393712114776663146839494306211123926383134927762"
        "3049276453315314938663505017757415771484375e-226"},
    {0x1.366f1ad138336p-749, chars_format::scientific, 574,
        "4."
        "0950816688862851715741981716510555491131806923753079625646873200101011841833105563713915712920089627877338"
        "6672732937467202519119479522480723407795353914204905417959638564763550732026709549946750372655366146768751"
        "8465985902038355614934756776928998890897769920782971767051608290557297810235286435333791164042348138624570"
        "9046496381294842944373805881307325210054336683711946102589264968227908777678781740079297949761856941279514"
        "4701597319058829218721200150253909999303678357294756834116509540473774653285708580012040678220305249095247"
        "55276801766257221970590762794017791748046875e-226"},
    {0x1.b68e4ea5cf6b2p-748, chars_format::scientific, 574,
        "1."
        "1570396019147199951614746811927139404489382923242367733464441788630888078074734225096038097286016984649018"
        "1257751514645035556156464040606586912645807541608011134962746741848405681341004188686066346084883838015448"
        "7709392372278436106894714725168488891402256613958895568185934523280803785025487945761033682602426807961772"
        "9904564830592280904276028380829012893805188297596888949701179576800381646868176872342258629059497492830636"
        "3044703711795299868868306207209032360457765193935610352982502060997012346564833664746548695777890303893988"
        "73717443638753366030869074165821075439453125e-225"},
    {0x1.5954dfa1e8cfbp-747, chars_format::scientific, 574,
        "1."
        "8221726162720878219391559104158395374959669147213245613503896745402028338069685891693215118247249574470577"
        "5773632834069059255893405040677506968723179290673586481906516623729639441266599175307316096622687835586709"
        "2618728864713924727177719872204601194021364444558707639237904893406100689615370860293434227131712148405798"
        "9380802416798615537137977507699992247403662018950839836603506336485592101596794523530482290152376909489707"
        "0300591877272350060504222949064487781676187937692524103140075795400513362329702290145224825379126327590939"
        "69035679716483855372644029557704925537109375e-225"},
    {0x1.63b19116eb98bp-746, chars_format::scientific, 573,
        "3."
        "7536981380660995920317409206965536403197907919708438483243207276046259780782636795750670960498823863331556"
        "4361973497515074649074065367912595029978418187255189561165849485222600093847343956329389558975557559433994"
        "5426797526359625422480751140301019400455902701141973071402070186685863946369415699476975609655342242607715"
        "4175594829868582239458210962130867456517266283551635612083202636192488879561782024006010046525100412652755"
        "5170158684805557278505285667702165065594214305077880047427292259582451470534124011087495426670029856086065"
        "4499549138307656903634779155254364013671875e-225"},
    {0x1.5ee917be76e59p-745, chars_format::scientific, 572,
        "7."
        "4064424298983799758409921962326965702801554143551704944707467008311784842257503029702562542519306298330314"
        "1981194326469369362196400053024258377938098669978555830397634582317243369415958205231282129633947664312153"
        "1976378191602362283805188798654196420950991548470132438346982289817929616927653810036882833861429456852197"
        "0713465987069320473011773610399506362043394265338556489274108520861453579183080406614208415614734431946343"
        "5152942179725876432292383499756386727340433786992675333060737024142305637908247415113277343120253686591211"
        "890466457390402865712530910968780517578125e-225"},
    {0x1.6a83518d3d07bp-744, chars_format::scientific, 572,
        "1."
        "5302655517853281865519088036641672349453364010152362760912937487442751067960308155681513204043060353114011"
        "9169719954301232130009138770629329047623431367136583488292739563960649306317491883315147232877811185355163"
        "8370183466073023350414179430653267818383940598863187341144619169938988058504946188990166111689037141174841"
        "9049310873563085132522363302203246396131818560894282203919762752828801213801660943168347443587721221760182"
        "4120899083102402432899611516052729144447370268452974713939382192826509551728150820699522893409931803161412"
        "415537068199000714230351150035858154296875e-224"},
    {0x1.82e119223c726p-743, chars_format::scientific, 570,
        "3."
        "2662448520856141582359969116197647314758219008736296797176525214401520867340405444019626396002597772252866"
        "3186968836682916017000501882086507974134707585824404879354484989379169992763394149298116714053649735117003"
        "4620473951673976632347333736927399827635100863212403303690831363747883357719095736646178466990610801108914"
        "5100688546861344607708883052424869986261801888046350637846415147864801751679914776550653014890427156042126"
        "5143357707928115720602473152213992952494569908513824173282587811025445448262815293110163847537687712297826"
        "2757424516848914208821952342987060546875e-224"},
    {0x1.9511005e0a3dfp-742, chars_format::scientific, 570,
        "6."
        "8395808072043960437946888615913144022818684597480409139416604854902806048015891947817642973494886224589391"
        "7947413915725902749084228620358340824715778220783690279558522472606442707272495233483210036215958136787138"
        "4747045125219246721474379386766703417334122219654531636577160208810229335271405672744950103125127528872400"
        "9435300708255534437191306099867781740609566530007646264293977991206060866325869748017718453607135207160818"
        "6568842594609317420574039197696219126111789580806886704377222403255162694449756479070580400807826281677544"
        "8607042875437400653026998043060302734375e-224"},
    {0x1.576318beef5dap-741, chars_format::scientific, 569,
        "1."
        "1596240640257126022580763758808333956544914575696812877152686057979427423806170124631043143735351202411969"
        "4363662457652244105630058142241979306591818240376577457661966478951484782536939435778999430258151174735559"
        "5089966426087501178358421511195473450370805053307045519754477962046904488712634815387123346504771003022944"
        "2722753411960100534791965680527445943153570370446261605271101412760296271908054669579741086604944255251851"
        "3374006349826604238537903375962608496582299588287827376733567575702244649391501104268570722067296520471808"
        "840557770281520788557827472686767578125e-223"},
    {0x1.3c835681df4d7p-740, chars_format::scientific, 569,
        "2."
        "1377398290102081642547105998237554930329666933658618760594961639445573510652955157391280972437083853672039"
        "8540998941814233984546474450984876341146695082690204736204153091292361713610538283246285375156970891488936"
        "4657721411115003246578851078377498053405000389321952672989234337447900215597922146055742073876247357396257"
        "9358521690424567183406689386488112127694739315104861479151904980569027263874934181377723991907538689472357"
        "1747205612378221487781918539268552325445912516413672019263037175191424832565863233869284296762895038863071"
        "250911929155336110852658748626708984375e-223"},
    {0x1.7d9de55918ba2p-739, chars_format::scientific, 567,
        "5."
        "1549054346354190045728099178612284242864048592546973638605764909752084453816898814444030014754736745717415"
        "3939513681086581225782028757920689989789619947673798544076608371701340543491069008762335362774759252282519"
        "9064650634747881447163611830016466349492795111878424263081300113733758864911137921755019812391457219469952"
        "2018826787081963786228915530507044987879833529533084057706702139312734830970335891638672616232082242460176"
        "6946182748458144665440232215693253443416551663932895618598752645643856647100005740868843057170269018277958"
        "2617200730965123511850833892822265625e-223"},
    {0x1.2414b43111a27p-738, chars_format::scientific, 567,
        "7."
        "8908966429612138761442053410825010841147511936821955177458713457438198805466271838051424678765828645719939"
        "8716167726634748358732992726254088667359542908405506833271333150314097274575986309942361703879329062363600"
        "8556508006663024226238472910535467867270836577618155340121918980941880199608993074855517174397941766797943"
        "3257699387199457655420176793846119930278466362457725082492520846136072700371070220886045238515771099913835"
        "3273919581839928751011974288119291623295782179106535018353071051530918600909349102146773770371535343306351"
        "7396561792338616214692592620849609375e-223"},
    {0x1.c124cfe4c459ep-737, chars_format::scientific, 566,
        "2."
        "4268259861629554096961607208386164396338924587886253098651453550140391339378844998393460288990930432820913"
        "5852605544145260297178418009195622867007636059040404647511674582759252082159463333924946122636209365307724"
        "0977873157795898832579503773541214993031434002947123764437546804261294178223949649858284233282072275776984"
        "8867766962872304329173251511142705953025211517869429174767445738885776946304025525607550282127555871896204"
        "6723786844906946927224287601746539109080079061293230280772642604110267497185547395959062910204359782805061"
        "396260271067149005830287933349609375e-222"},
    {0x1.db6ca39d80d3bp-736, chars_format::scientific, 566,
        "5."
        "1376518013281176581393767003881692452539216189638454082513861671056344330553488898982859915462604752562071"
        "3194858456483355295843937655229752763352932747821261035645606743918047613597052911193054514507809178873973"
        "8860992102826623263280195239978630705630377197171290709976656635856120178304492299111334031785584645526739"
        "6623011402146431073232036141359852328057576136808206313364418877233034792328694524368872457314118573580202"
        "7632133284215709838404948187667872353512508935047651023146817004887328668815745386660026858747409429610530"
        "917642563508707098662853240966796875e-222"},
    {0x1.2c644921df46cp-735, chars_format::scientific, 563,
        "6."
        "4923393123279893973798124975067957683661821055302531079268770502420049095140983455228370658848833305956119"
        "7328682798229063527454145383194037041466250579724775714844050640734797607497023266424826652646549956059872"
        "0122438324703282326440711764504014832126567471117309554888078096114310082094633910668580186775907732763117"
        "1603679876938544156082643007574401942740559623623544623788327531808322409634703611830824020277630688513162"
        "5921709679724265116094709949553901139341687598482559954476240751055168594273882198683993792029021073497485"
        "616599078639410436153411865234375e-222"},
    {0x1.6bd13122dbaecp-734, chars_format::scientific, 563,
        "1."
        "5726294053843144363681777730802477936874597299084010995107628966567384953622503257042435468958025681768951"
        "4556296506682508635691790408230988645053782874328147548076915865073026467921875301752650598198704321811945"
        "3256217150144733715978427901629387459284666143864869306007500181496611203249610419580016413429528044973803"
        "0498260886817981140598424248086555342030238604672222152498165969915199735649857611225997848420675936268197"
        "6604047511921835077849991651550299984928801347440824803576874096605998398187416862946416525739844020914670"
        "608135565998964011669158935546875e-221"},
    {0x1.287892a1444f4p-733, chars_format::scientific, 562,
        "2."
        "5630401696102993478539054633433987502198527063819861595789767934541667125215787275857810993033871291977652"
        "7357557274968367720569106246135522165132339121000037669478455657996670633099125384048964216917608128715393"
        "5906807676638979861995899482434722854021681551266558689523039027804336232103222151597704699482237992239166"
        "0359274271916002455343495552557398005709744430276564223663170930770139608062610354384149949188616132053843"
        "2032766932551477934507877337828248379260954800678355110576711200666093855448294052836140256287434172066674"
        "87562299356795847415924072265625e-221"},
    {0x1.b57a6911074d3p-732, chars_format::scientific, 563,
        "7."
        "5641405712977867210175274043088388783420867275149767322122351434047338374177936253438028204899302356962837"
        "0488523999137071089542042803849243123833082314485877867503612078844280060492941395300769301050477461083884"
        "4771708168843517945782166786778563721827463933958843025588740107399532386823702651549747742355276118694133"
        "6160543862549988839807751895579998772653688325470326107232963792745930375230680670041063232822687276267356"
        "9564881628548880660380868326841031190637588018517873017028771871603303484157541767382497748122591012254201"
        "103814921225421130657196044921875e-221"},
    {0x1.c6dd472003239p-731, chars_format::scientific, 563,
        "1."
        "5729507340845360691172961950552389472595381927177044158053486244001384093120472450655528827917252656828986"
        "4216611421173869718771305470695584254626336167914579072549868149824208386320969543895385031322917376889944"
        "7230105143157394883461683090195494454277831621323498297629020214235087735116688238005071860004717990435749"
        "0609359649320526641329699019669238016740369020731988890670133234059565100213750710244133154401228977080320"
        "5276992871702817661919812277763853056745348801031263010975075959504586828496545179759104529564690995446785"
        "137801271048374474048614501953125e-220"},
    {0x1.d8d511e371cedp-730, chars_format::scientific, 562,
        "3."
        "2701700758416348890173944451402027003733394142827984966197329168489787891030628871564620161154472920441976"
        "6307611657940026085950139753419063816685006534077373432881969780274053777402989565349198574634732026976514"
        "3503255254357620386504234408609488451270885440695994276651147053203891254558854795233618129556019768983064"
        "0184701664660375714893506854424496235149299558008859536198192378392345711490047852485737157747848891480215"
        "0630607439567831179019341191103700093381913366407539928796967549450157323322682232329438392219632739110757"
        "31348319095559418201446533203125e-220"},
    {0x1.124f0a5bff47fp-729, chars_format::scientific, 561,
        "3."
        "7943104300103846907465125718962807644452544067635609245252515780846857398156326074983345152492123344644782"
        "1885437295835467826221176433927630707683821690003074953611689959684984404544763811290392050828423812284286"
        "7366414367667191706792193414168278284604872591203010012649027975022160519975882018294860956880832296313536"
        "7584518805465684770614223278321761156339523325948618400016289310007069346377405273846598794682971919776451"
        "3811423318034585497341869887347777030479661972259914559435182043273955731705789607524360400575124535604842"
        "8902795421890914440155029296875e-220"},
    {0x1.04cfd796f792fp-728, chars_format::scientific, 560,
        "7."
        "2152364285788005379377524795979174964552660715900699704053929992547268233990189269000176177971746118345250"
        "6890531596087448200502671823360487351976610446845342947428207102346678631846396319052254600166448960949818"
        "6500465974675840014654365386862246582628238623047987966821810242214677090011418517167697893840061749072186"
        "3813117391739117779902599709017270299269508886378624385770036071380417341488142510535238002530826361679656"
        "4133325313357389734835576150072007476083226753697027000461059379961318619180529733097450138953020404297689"
        "083250588737428188323974609375e-220"},
    {0x1.dad5c3f1c8083p-727, chars_format::scientific, 560,
        "2."
        "6272169024527131679324702550410633379720544552442983857477309996825839785642672113952228338812997232757040"
        "3797174621153077818446075620602878393510121524818246548823801693833402030540125548686331399867214868694778"
        "4260560502252535561694789091997233504905922513669597935518961163028798881022064346029907879394780909043154"
        "6510688244717805991877047303956839696222139417136531025243815182537858993807034353276986207761918342522761"
        "4300384259833292804793092625070317127312066146987547947564826452153651186093453320258026285872153537948037"
        "183014093898236751556396484375e-219"},
    {0x1.c10f6676ee08fp-726, chars_format::scientific, 559,
        "4."
        "9692140757055039685842047867803507007965064813391203944533935860055513779002006825977512730737397856713792"
        "6521109400378936101134773568989454265111600307864836389445565543201080839068439167059749047437910051659606"
        "4625090341000441213521055191798235088826104555942477721851467019646047257372488602165144957533569983171669"
        "7266729296749078146706981079609212540351242271637174021478319280589008464239239745801817192984144557569294"
        "7272035641528057138305985529303378800935731596276356114916201308852708295081464082330730116848424571251996"
        "43996893428266048431396484375e-219"},
    {0x1.09d1c057f71b1p-725, chars_format::scientific, 558,
        "5."
        "8830122891423099384974225173148494713081864421101162087417346023157060407226954996657527710036574230300777"
        "8228849597449568302036718302194461244246668661412782472746574338449486220048071223852647745826445147658614"
        "4430653128313524882251162242029169684145131727237899353273750494174098311927424774952874365921338158977154"
        "6065750542832073408942424875590605836275787577900142528431793301587988020156120572901113235812687331457996"
        "1154642175089610096423965852398002114518436398455397841740576752460394155163561730458765986363084410371016"
        "0197806544601917266845703125e-219"},
    {0x1.4d15da31c76d7p-724, chars_format::scientific, 558,
        "1."
        "4743436359705466669425597004321834607160275202191708101647359884779278816000005465530348819209779595146819"
        "3274657326555527683528423165521075539607371822078683349867541347863453219805292318913772267021247819793992"
        "0891478945700675670578997649636833850295033438465261262013370652846731723982875478958167012077393670206969"
        "0600361602022159246479474998393004303980486125738995295279594477648650045806279857474029772106803426533603"
        "8275194781950606208085012372213473554552613880716866570935356126307329100842696616070606264233683324604839"
        "9814753793179988861083984375e-218"},
    {0x1.88eb0dbcf442ap-723, chars_format::scientific, 556,
        "3."
        "4783661139951836659834650869398120825446263038654374830389179725779207115608018307232395526906385987088082"
        "4300939458172670455150508058822235267367986041627005790042997377904752045570140208853566396039690367647975"
        "8706671069406990269746660238927428872711018746481991387760562749230806116297403149718889702098837849022025"
        "5913529791938285558143796317931984839907097658936340062828470837435597321113430649553015925929159557163989"
        "7200311940047402536426101840440670659097350647474752106036851970713051703441768301934192532745560022533481"
        "96973092854022979736328125e-218"},
    {0x1.4855037984a9fp-722, chars_format::scientific, 556,
        "5."
        "8132163840225073067103367504949528996314796226487824120028997327955421486231049647242313211271414237877849"
        "6575931983419043299641654638440132125481074183643823625939890917321998087428065303811935078982220060216703"
        "3080320155151816220164993979839757227461089845910506971715485581225714522454629832571060428488951781247009"
        "7151684577794782847430343609839366343499101500085822887900487908381027204874540283621144246564638885440392"
        "9804648678499580352812183946211325003975603679026913411470755820684245890767411404683725822603590493997671"
        "72872088849544525146484375e-218"},
    {0x1.9bdf4fb46cd50p-721, chars_format::scientific, 552,
        "1."
        "4584641434878504465497720362417662180955274726977105761716287781409371922551725296330598498660010627062041"
        "4109901686131526983419367027803870618372028238406674358525350147445594176436041882093323966634786798353743"
        "0948325547099905606010669434778234784583536242970120916339292852416310909963648082888736027543685653844861"
        "3952710301010589710537711722090325475348344984737385438871422926542463279581236916939059511106840811631424"
        "9538880185435710253794201340101487723780500252093742594419319926143493063899916744598998091797525944457447"
        "6219713687896728515625e-217"},
    {0x1.5226e4ee6e982p-720, chars_format::scientific, 554,
        "2."
        "3948318645722383698596132966002861356262867738431677803939697357779251148165688995352120160627222611575929"
        "9689826700992662030416378730689248077616852136705267786161545096222007215990088839119646235536279253476934"
        "9003551732144440707467704087139749385796202008451363169785499180779157968872915037551550990021449529891812"
        "5517183603560498907759526081213279162400316981058258462632041089918690774422656232572587897271295319785406"
        "4812435396373595099397773524674835098025684827649463758892584301435835947832788841887802396002360438842515"
        "577562153339385986328125e-217"},
    {0x1.b6eda5fbd10c5p-719, chars_format::scientific, 554,
        "6."
        "2170841982723338730702402774174581104079444355770645227799441152140990179937180891783242637499954374597087"
        "3008464662250243986006844228667869882594430102531078175913907335687966432831398569868860162052899262109384"
        "5883473398478959234838688550011663002757229956068858414758150089312638851089337799986122131137270728206083"
        "2893291385031591432573726834519044254175548566041758328320909158474462834862032394036782743365444459136656"
        "4824457589210171975436779113469419212320975164890670393225444447157944180323651986618178379162547031455687"
        "829293310642242431640625e-217"},
    {0x1.ab54a9970b491p-718, chars_format::scientific, 554,
        "1."
        "2105626076543997255531329501726923857588877013053286207541994102509381369451991729752658885355274540690355"
        "5024928460084443639809967630734347791425042367511569366398014451637268244225964319453806479955920246917322"
        "4725157361024728582311997914670812221434452861298531071639274681709795071912599059726607128925012726609172"
        "1796505804854529742126200406823478966258730629381222482927094750078171044839460480027612836177749536420318"
        "6481127306920043772287163277386036128721081549056499440748286378438450585143025905904301010862500476150671"
        "602226793766021728515625e-216"},
    {0x1.e52475ef13116p-717, chars_format::scientific, 552,
        "2."
        "7486687055906062577881540001431501496575123590678476529391262404690426983095262500085467262333027891722830"
        "9369613395301844882547555622556829703655868321121356990562366845714786526091127616873916492482916608026871"
        "7602849506400147401598589825990533520239405794744626858577327624634743462392529663276150233619312212816854"
        "9072964925682415315626227428381800235264458800518729103506057993613643332214275142683792589021523962328572"
        "9865420017710938892453157987835329199562430315689174276210015076968788768203356014704474147292145858045842"
        "0328795909881591796875e-216"},
    {0x1.351edff72489dp-716, chars_format::scientific, 552,
        "3."
        "5027657450499662471757545735089001918731485641097980290576178547757495509249093266284554696367026278492810"
        "0147173830738518713645420310526648989877752676392141828172888665979441700520145529662902345885785383753539"
        "1376370469690434685885587545230474222594249760620632271040847695338529030730762570328772853749408787613766"
        "8270604712743772537998893069321436302826336423836895233476630313955731119058149690419864151407171234861512"
        "8474122750522428045014018099803822512938181757888309118095505239530365123035368002575324491987274200255342"
        "2935307025909423828125e-216"},
    {0x1.9d894421705e4p-715, chars_format::scientific, 549,
        "9."
        "3718787940821138640143238528704947331582272378326109901966018120838594360065413663088557482229251218067569"
        "2371300339797039083262347018707985682314341168037040952899218264275877516637512478504333541208945387730294"
        "8788479526657955342331154879371913354353728215275083747527094608785656520445709279082581079933935684375053"
        "7970732376976367986120404826719685528839665031396276263448812459785233011630612074800352768861034195271243"
        "4605308321679121688893108324785422380802302551469557739581220727134268270817100629239276843307493436441291"
        "1236286163330078125e-216"},
    {0x1.e5b92a8e62631p-714, chars_format::scientific, 551,
        "2."
        "2015678401956501509913015563202673349273994830102214878621064509890592629710942073381394734079571892066071"
        "7487730292989115288528305280638727413962106934831869139267022072217246445392935266135588703131037280675127"
        "9330987296821526480487767504365898637613452426541908791360526539551414732583564950686053667485060220450589"
        "9377266646047617280040514279127012951123130564005585555626870345590497806540537552635681909822254316423847"
        "6156766516279219677862865539783026980640293512478470347104263432506258267583226624305482721499771514572785"
        "235941410064697265625e-215"},
    {0x1.5145b770bd17bp-713, chars_format::scientific, 550,
        "3."
        "0574111115052798755704223370355788580585808691529488807936764944992602196499942092750844854714155848637597"
        "6497130637186256919022738489601122933480405757980718915295656524814620284490229794811067698027804710242913"
        "0376602599274637302539181859471723845759904668345426627291624744410958365438947344354893144388403260841879"
        "1325650128517766244303228585118902873034286845844905346105029784310865178592908660838937112931288536138630"
        "6009764825661633654047990831795098362102506534239404342245751501345683352411639527096073876144544101407518"
        "61035823822021484375e-215"},
    {0x1.285ec117f96cdp-712, chars_format::scientific, 549,
        "5."
        "3732563210682168420160693837490128172921363352811330680377129309428579320206596965611505276898569179318064"
        "7093390822649793019079985569694858841420483773418054150208979227588072543018999060176454825188719716750266"
        "1464925503548223182782469269863121025084723548092520888452073422375220993719096473946649034335302943612161"
        "3096677012827332884190800037895188734464273611331722229788010640188364868864193380798439305695257683444830"
        "2578304119397235029009490306081909908983761213174092123799691360182549197602745922903305642037707912095356"
        "7326068878173828125e-215"},
    {0x1.1e8cb1b784211p-711, chars_format::scientific, 549,
        "1."
        "0390415242853728816041217572591158422222247006803021323666432451437875045999340376240492922325054882674552"
        "7408607706487609351627677616440371363336671781330254328137763364074729743139935129859512507832805869472312"
        "6339297623061284057853330414173406542547210083549372626832453025030820018846792813026550288561349826779134"
        "9277277621847116668163955578302733989002925493494555577398661411420940027588717214435232462267698247622369"
        "0888792643168096799257646791531616954197624569093221460530831327866723955961876871018773060839635036245454"
        "1027545928955078125e-214"},
    {0x1.614c26f94db72p-710, chars_format::scientific, 547,
        "2."
        "5621446229095083155702111829323711502594107915197651192397683293270975877689437093976421160394334140860514"
        "3508654306899631700199453849808488956890026352075766904074073805277078860674472639414882982434752290186285"
        "7504465252020208455116434356283038730965714616498666771546909185959002909855327970887019228977304196897290"
        "1944724658400811662637824393687273273295100029361142051970122838752977899584677183241852846360865547995966"
        "6687843860920406095408137347378557822727582591951003279152824322080606068595729331652255389428773924009874"
        "46308135986328125e-214"},
    {0x1.cb0371a5199dcp-709, chars_format::scientific, 545,
        "6."
        "6576126403697076608882696856128986307080116494217692992548764570798174913048894445931404315822786110091829"
        "6649348687901768437850106811170410660836029465125717942313828125061569507507709085499361748389979318407375"
        "7272184536689291808393520451326509862470686467487625232638447718595087340927786472243230843937796297226695"
        "3842878096505666768374797711233029598166668335444663888730788648119384576217082726860978665043128401209712"
        "9547423798181108350450372658894135422090442624951810200919587095679400509616314811356385661156309652142226"
        "696014404296875e-214"},
    {0x1.5c0c6be27bdbdp-708, chars_format::scientific, 547,
        "1."
        "0096315129023046456467927747886062404829941065542894028799876798238419315163636763041967115486534078158780"
        "3792746626275267505476475853627997814869597841933589181384945321349031280264494810636851886988579388341166"
        "1080080357956361471549802945541738879096317122362902737135301247488849687812997256313209104551730147943627"
        "9917883447751656421134845380154896344888378922177548945568579291932819057367458807794924092411351316038054"
        "7290591838918031503312280507777151643810289962815833121504010394331494282721910617575677981960780016379430"
        "89008331298828125e-213"},
    {0x1.9b18dabf10f4fp-707, chars_format::scientific, 546,
        "2."
        "3850500688279488736069088312896597807712501153938563573110116042391645632737275531425873467863538337130966"
        "7891010427975650224937133559719351401006461226265549956373571669015855704039359014374848412483435923712895"
        "4250186816972181807777308389417398269916805254701545926256463106859217585143569273237619388976344522803930"
        "4203567895064463853141388798875624607003998797915225340849743889366284235720427859685783218868506557926674"
        "1580214199554455933843367880842257560684391957709515003912459582292372011308966266857067850537532649468630"
        "5522918701171875e-213"},
    {0x1.a3e82b920dbbcp-706, chars_format::scientific, 543,
        "4."
        "8723235743335383007316942037138333939727876640397027548637587311727725444457866859726981985910149027071370"
        "6468340207283669307155333779520424052725448086908738353241626783050347648634151847564260366778472261414833"
        "2613564491961095108182457631457759132936579947589807479206304597712222245032642246469025898682295077537797"
        "9074763121811936361499537945776887634577317313987291053433221818981193498354026091626856226453756264612039"
        "3754530427037991319234814470049958889326819291611453036550148575437432122510385962277368321338144596666097"
        "6409912109375e-213"},
    {0x1.e55d4e34997edp-705, chars_format::scientific, 545,
        "1."
        "1263700063301883961637593345853650848173698173906203553947316800214949500052155115279306618384733383355823"
        "9012593269879463412835243497329655831225472435522686519182378700969305497526912686191024754645697306870198"
        "7762145427468664520014456587758418342960524150909771188685359678729708491944850185052337045874514571952057"
        "4137475072159689914997940459086273680774009478900069713199343055246913368028437896195004050375544491283694"
        "1746714816416655581946140115510899932593584992390168732897366379179420338335127806106417125420193769969046"
        "115875244140625e-212"},
    {0x1.82443127bdb92p-704, chars_format::scientific, 543,
        "1."
        "7927923533931952950586931510282749592790453715109808832297352620022802755310066252394361312560633056624429"
        "8444201320939750950080181045198894675756701860610234013571800216193558312750617204334599296344409701776745"
        "5629192373004068874618729305040214979501665418511156657769937991179760363455405882943393933388417275007027"
        "9238392034119581576347126335201240604873503387124270592794021386497103267133076944317349877812852252494116"
        "1179202904954465216073197261130107718452951168115991671745272658875064850016612522098924387137230951339006"
        "4239501953125e-212"},
    {0x1.c3ddc4e626843p-703, chars_format::scientific, 543,
        "4."
        "1945272696274143506064751591019143690519608938330793458941131430315420967011543669286107587304069881291831"
        "6032656187170995340885670400984520535211128358722668170887203873605927186042732064909372141468474051452393"
        "3678415858455418832312297913362303042355926367090313440035220453662023511344211217569805253299537764581623"
        "9298412580286410353907497125866517188536279462904565662754642482258294680343001078696867682334679872718368"
        "0479454352306477125153503393953171166192097258701941353102439406321508295406082916789713976868370082229375"
        "8392333984375e-212"},
    {0x1.85179680c1b94p-702, chars_format::scientific, 540,
        "7."
        "2236307258538304887715568455167838293359876919019126748017947977725350522616163447033071439365285720056989"
        "1830461200043803436029630915487962565111962873028113557121533529866936632303307488823207702072296748481648"
        "3207014721774399563123795598496459219700635915793195213974388269457089126242058992162724467598411268911353"
        "5041058088826843891771253918599206993317190354583185164130892272323989170581794237052458129973574375453130"
        "8094598405624524073068109367799283444890475986358854047759977156130022709224630661495325512078125029802322"
        "3876953125e-212"},
    {0x1.03abb48e8728dp-701, chars_format::scientific, 541,
        "9."
        "6417543570694105910088319847436003732314160404928095487625173156883373210396589866754925983282318468734151"
        "4860626102306640936393564625714042933596543888017233328739922582864914111709598516057698962957292905855399"
        "0934567441164734848774927916780969315595016517054297439820165043351563820924614514119398727275481604029996"
        "0756386042271669947379377208367499428338782010383566943029832407667528711616577681695535866646659071647091"
        "4123908388130256787445397850940448407274826997829338472227774193835039834169289840737349095434183254837989"
        "80712890625e-212"},
    {0x1.79d5b387ff6e1p-700, chars_format::scientific, 541,
        "2."
        "8058534999670358996633679682617510657197520464930955705056307782763303148434523913703200877980345442582067"
        "4486691061078409468449240314443515147593774451511192439041146470049754857277557200825953109839924060422472"
        "5351798824855369573419311576039958119981039707226303862508802136483934658223688603762220164216055731622818"
        "9010355568985916250984833862564859204793321703030409451231964242558722126734054399784848841245168962609624"
        "2173140130434703254320898457436036968768953024903954353705239159040468922704306131699070192553335800766944"
        "88525390625e-211"},
    {0x1.f9a36c542f98ap-699, chars_format::scientific, 539,
        "7."
        "5098815942701431264042911004176988103520194201365702934373413006724432292697433861353923851217255084766983"
        "6599886630527602489344121303782618389277881882670799795601764912090432524174366596031421997948061932162102"
        "3117734679986634642030304403759434983992681398802899425054501200452186621488202264269552010067268804359334"
        "1738127090236808055131909220403452002271755020123581692062574392122588359572183090485242498908330249497151"
        "1253704899077164433785232677029233050564661707197414749244240081859608324128807499420190652017481625080108"
        "642578125e-211"},
    {0x1.dcc43228552e1p-698, chars_format::scientific, 540,
        "1."
        "4162133808983744258886960127739256541973507395750856304999796672802119573692833361419165044069472916119768"
        "2626134172668197351710112526943632551376973400614773690079165656484698046811087576617553125730497832111644"
        "9781456794745739819723112960798249196264114657578024943397007196103135600134960687383208140764370034939725"
        "6333481638144816073339075261783865664048692839880337281432279537203733127391385250064522871588966853314004"
        "6779946169294976195251626252015124492655057417910144823152616491496420608135059504562036636343691498041152"
        "9541015625e-210"},
    {0x1.d0b8e4fa0662dp-697, chars_format::scientific, 539,
        "2."
        "7608735580016018810532251366986066427701731560219460946383276544412397502773716043763024013333758381762491"
        "2766591900986052852630094841182135458765270892661477506362963745598227260101624863784743478641335048748703"
        "8347358590002100584791242861223336881162576985051154343250452765979930861239511263072723698300020976430933"
        "4957108997036962159641594598842541302828078543085854370441114036051976116492434546275183049970630689903281"
        "9114395235094129047761582275001321029896541652183422416686914671450455067459872626756123281666077673435211"
        "181640625e-210"},
    {0x1.b8f44bdf82c3bp-696, chars_format::scientific, 538,
        "5."
        "2393404251407047567474899294317887937950423337622470825030283559680483919109740585087289336722256687375700"
        "0562612150372259732590220204200981462672070447082476439023788329111668015810993854242609354608168841001197"
        "5721911366783257993585749567931267566346598996672644920149221841635228584772963688239938336655237227386206"
        "8491342840831866257649196363752331752920763018118631801890578071444865477033486159660377821557266936722920"
        "3653830659767569868274491572483668536449410976001011211353130518765763802210844168882886151550337672233581"
        "54296875e-210"},
    {0x1.f859c249f388dp-695, chars_format::scientific, 538,
        "1."
        "1985208897227798591039255948760211295972666003794523598898895366020833219755267124170139715038638699952937"
        "4329645641469104729428750120637526367360593775039076317110708918658483802996513415675328247462305935532785"
        "3345693077234597796127995527491563794867569650848921446775522592734337766008213264400815397407021420615343"
        "1176922528484394185175495700629128401173269414579032286321428360062399315349631550183174906062438748159785"
        "8516867445804419504747204630742763446810820288164538437931161379214648832550182966372176451841369271278381"
        "34765625e-209"},
    {0x1.76c3cf6d25fe8p-694, chars_format::scientific, 534,
        "1."
        "7811558999586523701977647593653910305007237069848717168449377479088923371990969176642927894674055304613438"
        "5672757693904280120418869003651550514604809425577325849506851929562524269723511223669099656493330621079242"
        "8428532458822479610900457972964267869820261321558949972877826760738857749922382498268945857045773232228967"
        "8217862435840327482891491017196268320347469034697494415172295492230087479206891090890393696595327575030145"
        "6994053947741352652623430920429779814837285839361266979135427518008642083779946574395580682903528213500976"
        "5625e-209"},
    {0x1.b9755a541518dp-693, chars_format::scientific, 536,
        "4."
        "1962642963537321076602226972991351491104742192225758657473795663642271950965237649181687944784531856492724"
        "8565355071455733746569152196344022113027036138256316024271384693248884883018412271913955944148702408979980"
        "0598227265908537135628614882879304623430375054715224577326792297458415887012265235615755629258591793791972"
        "1642684984061588604707508785500264498166000046974354417486291970140109533598016391655783942366698854204024"
        "2341326597783970853680579332068366495230471063766360766930156215738360360456571385157076292671263217926025"
        "390625e-209"},
    {0x1.f9c57cc980773p-692, chars_format::scientific, 535,
        "9."
        "6151781021743031816511544979411331543689547428158611066559215048652158551199908498702146817365187884427510"
        "2350184914401779293504720175219084860292010793608864288357348223601530554819113162490280742714226103002168"
        "4787171977026814222128547887762200230029015250967853285838300682440492056232862759485418693647725985578269"
        "1550194921251369678834994115687793640049054121013242722791010216905285005198355969738557592934334727596160"
        "2106476021831384121674402994034324448547614929792406649935288203665277248499698714567784918472170829772949"
        "21875e-209"},
    {0x1.e4a6ad7e5cfc6p-691, chars_format::scientific, 534,
        "1."
        "8427321798270691931419529256184313716571973690089230501201213024968691169451064054203767633648839365337058"
        "9959392624389463429096165611132917690021295878986853446245457921782248607739873408176038083804939583706995"
        "0654397880772093066305522988989510818550541148687265521818289398962787230883040650157422886214071659687864"
        "3792754837833575353871758489957381015893355378481232127208667013672716372137306883068549817908551789512733"
        "9316502913213462282092457461996729259367925729225844679795995907374116934418495361569512169808149337768554"
        "6875e-208"},
    {0x1.7f07a911528afp-690, chars_format::scientific, 534,
        "2."
        "9126998289538513112480448166551114592654020719347039834038759867260996999416181764018441153984388750809778"
        "0175629271501825790485883418229175243037382302172755297279108088469220160306070492618960031004834039173709"
        "4843896631120823118503330457284170724809216045678379076340848600459520650305058603045381131112866260428467"
        "6407593658543022863820181235359501241223422387971893606331689220550564750593432841072650225389271369147403"
        "5512661765215882184128685885148232309762780083810333437476996260755753714866145287487597670406103134155273"
        "4375e-208"},
    {0x1.2f7677b3b90c2p-689, chars_format::scientific, 532,
        "4."
        "6152840107250803974346147876459468792499531906015218999353543308743048639273421787001944283505171919058319"
        "8144255365651071365678271599484595358357673877795342194463858767642709308320670009187206082826373037562838"
        "5820261005469798564184709286723729385073245071251176864233114190345074392110857638137153854209350977844546"
        "6239189605282520378949050856283020490336290298380676951122376139656287149424509011548673735977675085494428"
        "4169319003497073383951870387582031016960451123529784253738775685058440267916068933118367567658424377441406"
        "25e-208"},
    {0x1.c96e22e0f49e0p-688, chars_format::scientific, 528,
        "1."
        "3913867725663096448636565841594072797239179967141265670015911796658179232356371330082615064109491014185571"
        "7852548486936144847167954972821760976259988719708497654837756844368594047016474258346086098675771802638328"
        "1517450488570140127406126304896613526413806573826761435555192929139460417688891661002342541921558364334502"
        "6424879420586382525190545149881043545710069777649964342012328828582070171780832398513896867752356832570177"
        "38989819696745189651711690480619467448362029039063335112658375929128862225070406566374003887176513671875e-"
        "207"},
    {0x1.22d28ade59d78p-687, chars_format::scientific, 529,
        "1."
        "7692162295985285274613328500102516630943365500476087310567181746961135254937482576801750221428295918086536"
        "3285468548760863155815912570868365060156998843371602515772361967652878837326101707102753470819861557367288"
        "3481713892386335979436052605905323135549877546295135146022879990274278167641463897483651103068687816673451"
        "5907500780062167799434488187226465946666108588036946480456968207077669688736279858958332805166846949099791"
        "588247445999167063696700086089680623439003509639588506091337715385447548754882518551312386989593505859375e"
        "-207"},
    {0x1.11c6046b7b121p-686, chars_format::scientific, 531,
        "3."
        "3309984084439476052884870790017880296080055634528788265015815316869436089527404130952395838719945250131986"
        "9730320728842084196597888023818389616975983226758975382992530982514820717966583153778807531118235599662188"
        "9597602340856152965036165428696464896332879564853822887552698906231145653313756449773063821682323652058481"
        "9547805275196402678496748808344099487927760988789865833706607909581306479099658359625457565668934621834351"
        "3757747548413425604442641719595489739459706804383826827911176430511291934877249332203064113855361938476562"
        "5e-207"},
    {0x1.198b1ed81b492p-685, chars_format::scientific, 529,
        "6."
        "8510701846894067422582475523370404378011418963303009769966838302347841714706482962267873687455961537128859"
        "9906207574662056939466225701661938852045145443629892554749935483888325578119293711819310924456525734183163"
        "6915472912399010879835032970087392517046341912957239003522427587484984610921827305673994149628011173396226"
        "3780525714752427605029016226469261556860836160984332674984228909414266256047184662690199519534155528347876"
        "034022294815245715147598466779192478520189164084980440014264351823725096579664750606752932071685791015625e"
        "-207"},
    {0x1.da6addabbbd1fp-684, chars_format::scientific, 530,
        "2."
        "3088921688496223736447698070618132190331861821537468965751360953523467964117030458093659711888679953431325"
        "6791383016641616913805533295082590105365577700220213661827891554176114291090426996418755045595031272391436"
        "5056337843282569335669119776810340847055881483383938852947141165661430884677477472557582460844244118662091"
        "7179971616485032181643293539463714565118379358749880808820996661168372725964919205188069147711554587345138"
        "9108133001777714280339866642455389931961554995216357284980538007966577307428224230534397065639495849609375"
        "e-206"},
    {0x1.d56a8fd15797dp-683, chars_format::scientific, 529,
        "4."
        "5691048306445641604873487344582286150036188199466936663762245861254367951253078053084337328657486501850324"
        "4639933585428847066193727231878618202759175994292635769866898199587603013635816698477200737836786434113051"
        "0572218930930147956667737444440711664958909309074610966569304085097304218562735090854035050636703161868796"
        "8928801205899327226333183208398450978715639442169140673197444986361607235881156993779171410174755922663555"
        "574675719765400978001502127488303683860400844254815568243693565432528291836433709249831736087799072265625e"
        "-206"},
    {0x1.f3aa6275d60fep-682, chars_format::scientific, 527,
        "9."
        "7270783116371221191762939854842941752679733416007252745486261609859880583198730913356445623264907215190864"
        "8560349300936337143532788944063699216212541764989243921159202999554308982439677599213591449347542999436251"
        "4845075367400598016897410898113328837764425820423149230175473845973261109374719277837435612064676023199513"
        "2475233045514061072806455531384785125604686392921739119523946853964894459653941721178135905207621152684004"
        "9022573637782547046925665674774262349927107727157916980699199453741510268400816130451858043670654296875e-"
        "206"},
    {0x1.0771405e2a869p-681, chars_format::scientific, 528,
        "1."
        "0256959546160606488726805315356855337658063975579249432725148357253870081722014642762758518975160176683096"
        "4808276510052018475391378929787195203544548808862085870952275388594930486183074992699706535882260315165688"
        "0892231031191155150934789100065019417689392678461684332352523612060746529016035174062783183041957589223796"
        "2611722543461090395136869252370957694533919461366539737366218664440312378620580551773284635761441384637008"
        "17283527981808733394394904977790897574079405672970002302133341216816564411828949232585728168487548828125e-"
        "205"},
    {0x1.ee86c40e3a880p-680, chars_format::scientific, 520,
        "3."
        "8508135367330314292296381359837063529186758232718527682702510581759040588871922777381914733711030542054411"
        "6504406319838169445218070711077138616618166877563823794260052689199619964193690292172702945639700832394191"
        "5328700138150745001949277117267453139446838790491763636519220242854305248572010509495178581545932452964994"
        "9108075855219014019756123543254738453324470847942263428819845634073838218187937116566664828909343554431079"
        "815240877180188791702678289624792713938430940614004939666348281690488875028677284717559814453125e-205"},
    {0x1.585a84931d29bp-679, chars_format::scientific, 526,
        "5."
        "3628739344977650941399396994664062909446794105596352721943281729728627450572873114769800695622557543189087"
        "6170408118377833454298924787139421021372070641261228862807374926415125351691951403510273975967747017495700"
        "6029397110551891149991745218172557472670307074649319964465385236521148916045120642010778039075647952239021"
        "2432361954484400227604278580711506847746818030711390963728533887728476714567950565229014485423029218375353"
        "750732081888124338330413581757188688331103832532131348029085481099453858178094378672540187835693359375e-"
        "205"},
    {0x1.7a49530caf5a8p-678, chars_format::scientific, 523,
        "1."
        "1782670406981829321748342170270093032401355879831618957954947784523973296396796916865369743006762277930095"
        "0567702062680043666952893020944559270149791677273250353005779342633235074698481516601654762622366900001635"
        "2281219998184870480772600739120486824490248828894700930458720074575576880726612790401491826496007397517867"
        "0647685837737977220505846996881709361842165075378521510676934361503017940903085360306384528629882989519304"
        "090767877812950822319769876550077524994542753523582646391944239727678223061957396566867828369140625e-204"},
    {0x1.3b2a42806488cp-677, chars_format::scientific, 523,
        "1."
        "9633198540986483775799261383979870216240862506382911577912309546688800104365843575901826331397993154616681"
        "2471280347835772651872541523676383736038356840857212840087851443915105283550968900875649801137459350855386"
        "5821482142774480083157679864221799425963658261456298178545244297451518724341603830296153018149068454475650"
        "8028506847600398711903974966533330036220169201991967451668704148602041768160661383832744400783773461300798"
        "358098723210470279803874144148526265154314849414816574238971946808618440627469681203365325927734375e-204"},
    {0x1.c83826db2d099p-676, chars_format::scientific, 524,
        "5."
        "6840339139060946981762684285710865654814425966664609557362410206095193210907436592806745280940604984084917"
        "3638712394538581010752596199682994606441641293311620399555882268983726840264501484788914059102776623643905"
        "2122858877029711702866367625234785883294752383576438575622547825433771433309812245628796339307339366141624"
        "8327266687372571881603606669105061926117522601057432280607513852894404333029087097387483751980844478298920"
        "2235197876029202131802937817666288074953338254840490731769654664251589792911545373499393463134765625e-"
        "204"},
    {0x1.ab36df94f8e93p-675, chars_format::scientific, 524,
        "1."
        "0645321758200814413322079175861714925420398312598654352133555760997816258375072365309746623458451602566928"
        "8892955587817123557658132010249725751416542814066399908321499983973004793509504161485004080347135156251003"
        "5442658249039229363606436055076672347113866815163628981036236168445495284717579960502642475861507919904976"
        "0415239301735078975625527410821978439898777022303097916766691649207535368545176326930298026323109512486224"
        "3828406557136280207205919064795260099278785611381060600944513383492306957123219035565853118896484375e-"
        "203"},
    {0x1.50471d0714b77p-674, chars_format::scientific, 523,
        "1."
        "6758731287663245067929802646359253751876178073393718529381383029991245143140589642891986998226638001813841"
        "1884571540760722831242178043882468016912989619180020502706117428233351747395942121515884241840494596513741"
        "3168379056082846586489400073062815260306226775250614217297608945528700853686763895314550239200685720351426"
        "9290032819751222225759992649072668129215176147377509677947335109118716015043007331011463548126614761292320"
        "640235481244469082541147893929952413974668845082847184134976215030832236152491532266139984130859375e-203"},
    {0x1.af855fc3c3b42p-673, chars_format::scientific, 521,
        "4."
        "3010538577728233744816436369978549136976645950673498532952391599320329530671325173016013614684923269901956"
        "0268052180793702299742913140983893922344975035501831505450412114109672135334397735251037816337885684958047"
        "3992723015478174654344760932744538761509098314194729572674808143340483916485684814524519684382188211579232"
        "2879301647036270532651278165887797562530738322949801980031349707060037709951853600603902434774229050505469"
        "0763471466516501229666796891561067299047712433489573159196839302609305377700366079807281494140625e-203"},
    {0x1.ad47ff12ec668p-672, chars_format::scientific, 518,
        "8."
        "5574595335115486808557631060044950010564116057553208117505835698979224270605230907269762845091732308470041"
        "2661175089528304438909809546901546014735177540676134332138472881953762100352137042313700018497337879496165"
        "9189580288095025616031282691409656494757870534052617087201115566268802280358798705227412553213249254918373"
        "1480193588714200446263056192475952356968184570908882976764095565692431171738149734334933275867032274731426"
        "4652633278520834947286422890756022706803482172043515997794660421504886471666395664215087890625e-203"},
    {0x1.2cde48f104883p-671, chars_format::scientific, 521,
        "1."
        "1995252022699291430772090009162585049509756433689356686849255866758337996064757995487412332217041915275396"
        "4502645220981501885133249216447042172461355588080996605721879177162634972981475480497356065079367468236338"
        "3237004497147886219100337958851778353767446944517197980739705022950728600049945132461920818493416267256795"
        "7907818111439963640990460062983183893943301010505311294044136435378077390399185184359595876312531247040973"
        "9561953852017096495437565634136727399479205502966257918494308309931284384219907224178314208984375e-202"},
    {0x1.946b82be44de8p-670, chars_format::scientific, 517,
        "3."
        "2247460965180460029537786395406798165049710692182337402826426147217110915625857896714231641153250293652179"
        "8048216973815754542961726075194872454516155016492934790014344438607116755383594469734469708786475281532119"
        "8632661073619619247275295413044208923754797487662014202281803328562662568942790221177840910386833830029037"
        "5416632087550289611906245010468012912803588788333467800241460580247976347907750916579605580990918756438712"
        "680014884999019899375412526120418451580793367541540907217356703995392308570444583892822265625e-202"},
    {0x1.4e2c914eb1616p-669, chars_format::scientific, 518,
        "5."
        "3292453195387590853998556300829021590225189208980014515926856740122155957485101726194890227274448168718106"
        "5927924279053206776354571063402558326010932660840917790876541357680066598140056129283600893403415124104507"
        "0961228748867478240688904822297467593907518308374935005892642075637132415584498144496749609150067413936743"
        "9954339942007959039524337809360913993203485623878501836329594368309888038663244905138395997368272478763961"
        "3141872635547279188040318374333051363586680061786428168335572053138093906454741954803466796875e-202"},
    {0x1.031a309da2912p-668, chars_format::scientific, 517,
        "8."
        "2640741741205575704886671257776920898830696348304845258875783028559751437157907478574887586455610818958574"
        "0117180728435510741583686422632774929222632147511918567229325831684032651922903276735266790117843593501601"
        "2515772658634021392622635795100871872629560992833058770828358801605333052744848692059467100573291501861921"
        "2965168501531832990733805673234966033806861779304385144732204173637508580888072780122033030001124800084442"
        "798088493409434384997049557284279503347774175966576788721074109389519435353577136993408203125e-202"},
    {0x1.a060575f96216p-667, chars_format::scientific, 517,
        "2."
        "6560666151344702603270112657977499843280481963854547007415424282841408834245148563080751707062214127712174"
        "6575089241378645724002796193936213328030191138196663527134590072339814022756945163490059566462430178303277"
        "1228244858625675383094839366484676870834540231014217479000886731065845109947279954974574188657815117614123"
        "3386435630286269060704468642455055794196959719254965002131476394999432110093478415169008939749380189172464"
        "419028229169215643606811336644663330285421791733774070365381447800245950929820537567138671875e-201"},
    {0x1.54ecbde19e11fp-666, chars_format::scientific, 517,
        "4."
        "3495214972934750530933724968222678819054125647445515129232273277394298473692482090246833126125365966736388"
        "2354688517832178150409693045033840944581780922681152100231430786789827130799202367673361512373001296052937"
        "0144885754098436449140938587128444015910802676078333389890644004297198057112836294886007788657922515419803"
        "4578833295918606774209296834570437196389294791061023161018923830592981622192484695052880013934282074495956"
        "590306105321231640691595930251310123645268261612767922430489164753453223966062068939208984375e-201"},
    {0x1.9b65bb5e316dbp-665, chars_format::scientific, 517,
        "1."
        "0497223657147530461540305772931267585053715061256250505487087888061029408785894563215220970697678764383480"
        "0325939065916205702309557577375277159458987036426427633182733447713021968370263145361858036928289137615212"
        "7401495504331960559979975536391905723334450553852881134362068216711904999364434749875519041157852477294908"
        "2822453778469194141465743679238160144163995956438907303935779751926152780243481780495784919204856732854249"
        "500399151396209309650004291796200412761177808216423411324935699440175085328519344329833984375e-200"},
    {0x1.9d9f0bdc97dd1p-664, chars_format::scientific, 516,
        "2."
        "1107936672284170528945594825984539537267894560074842735445651564636232548380045553302817073544554452002495"
        "3381174620534078658991556593400119244710172233781404038272600835408871699423495545285788169382119890019819"
        "4201664584882960325446094595491519667713215219785422905110363553929458253876328347995783978350150958928634"
        "4404234645121978246820592353953489916252647358865343115582584946414230154135689901732367690272225496245117"
        "49407430127543500008710404569387590416050499587800361178668850925532751716673374176025390625e-200"},
    {0x1.93eb2c4f59fa4p-663, chars_format::scientific, 513,
        "4."
        "1225583388333102048516138791115797958837443685538615330228158010372085611196534261347478949518515573803887"
        "0427766833577772299895100679885999472136933656647575247856639421484005247092295404547283959255810537283939"
        "1536152805377136989128030010671552377676024122283837285170688576898765577337301783627428040617023286366646"
        "6304756840766048041588267560017035084467460711609718511878343601909600068154087444256240183857041447304877"
        "66761632079166770683820072204968831426390708208735980111470098563586361706256866455078125e-200"},
    {0x1.8700df2babc4fp-662, chars_format::scientific, 514,
        "7."
        "9814802786247251835728077164402394423392733891469600650972933646922261786684070011768202491345213497635405"
        "8363929473900800406081157910353783243643114657359608848833361253991272841241506805336597404984340460111575"
        "6660220570634633816720601395545604136254404189400125104060973148928687734799098012124540258682432908196877"
        "0832041763169112950312043616184359878531487269768561814660148368024122515583353773744932580874663344179382"
        "612758572700658879417422882008015735820127939371092240516958327134489081799983978271484375e-200"},
    {0x1.b201def031dfcp-661, chars_format::scientific, 512,
        "1."
        "7718621999986474927820511105591201858912597837406619766922788131515103038772434517005243859964561302258421"
        "9802754045709795325932881605994542308608831118420588061617714154977002180480859035445177618929493918433782"
        "2591600499156132639399865379537611196535055279648285165951017807905457511484142062562046872721511722442160"
        "1426553623832184397323279116431379887141296247183522062676919582794723562211028612905055854024015629021129"
        "8337387790447592797183168010955799288442025804339585715041494040633551776409149169921875e-199"},
    {0x1.eea8eae3e8e15p-660, chars_format::scientific, 513,
        "4."
        "0389599243158304571394333253525250389507631147978093452054769366480656241867872583554732831311043329402127"
        "3363893780503478092860643094562529070727567425705557388421503723273887240863523056769045564816791339544767"
        "4811798960347663619673711377735935298979851283703861602303938137477503201616025923026704439389500584641456"
        "9114236964868927498070315671368575179598358409648827561251869544093389097568519080961306269611881755257923"
        "57071395194827800525263513822042296462436685865367291814465033894521184265613555908203125e-199"},
    {0x1.390918e84e1b9p-659, chars_format::scientific, 512,
        "5."
        "1119492579282878449920089216681553851133879719260531373201034289194388628158048325602868518451980288065475"
        "3328687915381964890604155102827426856253986507040691348861285321350417983375890401837008594914469552729077"
        "4041634025375852486627406374778113240174679877779001695754357098999719528767000365619537633912001008295810"
        "4111194123452305704581476943981312220929979415555290962822172556120286736561042880277446914041656226018140"
        "0463623856109377838127752113794699265665949440735904563126723587629385292530059814453125e-199"},
    {0x1.349996396a2a7p-658, chars_format::scientific, 512,
        "1."
        "0079029980377603525237940067452489874385429612174195934573594706121935473916862429397131565712352453110768"
        "8142811950276179105213171370309953751158020788719826912383098267593711702326094595805498105681922999726532"
        "4909688432503132216386611947197870773295666668788871748938567859669346354132428937646632915596507684775523"
        "1852907339258584868938933224714470378079481955959311832805716821495059947675108015714103667421409304485555"
        "3792288834043863450758146748423007478214340356358069694664436610764823853969573974609375e-198"},
    {0x1.f935ab4c240e3p-657, chars_format::scientific, 511,
        "3."
        "3000803685506844689972816481749463828043574066484070851351960926134710393016865520510979359197005978741538"
        "5457598964481630013120758369194087749928754243965822423618640689642584934167891050733801943716663854770925"
        "8669749210069487078131864042347118088271846481163803328753828032361946128656564185923045562644481274673168"
        "2442894934517445593122976663972120711272481059100994734541198539955373713891254486701781695330533778123947"
        "552216106532507338730815426432497099038104195443954491651084026671014726161956787109375e-198"},
    {0x1.a6f53d0b3c96bp-656, chars_format::scientific, 510,
        "5."
        "5256081634540492912099873315946178218679701636409896216166339425112476137903833335081550464272182350571563"
        "1649173618325315650797318358082316818623716988646890803244474427212087305270872800356709989796858446518028"
        "0007153929447642907339740642327205632776395602540495277658534898752570556826974137137544575680121747318156"
        "8109294857884968121748814804138707666969927662354233378783086514773899604185508664921655337560966881995309"
        "90443024609879186497798459794215161380336108314093035431824318948201835155487060546875e-198"},
    {0x1.fd60024c9f6cep-655, chars_format::scientific, 509,
        "1."
        "3309156466126676327720798888520711121310973719016756617814609392099367961465512997004022190634798593712344"
        "8090126543369123336008687248835603759825341297324826585552662290670252876445576563127635381521847011482567"
        "7842445245383024757386520155419520590180607348277590132836378469352051761008545687687211422030370707996919"
        "4632854436567543001424200212283006776315002739251470698678414022677441491080589922168267970859024072320361"
        "5400917553291417625497725089895008484400045455087191470511243096552789211273193359375e-197"},
    {0x1.e59d51e4b3404p-654, chars_format::scientific, 507,
        "2."
        "5376664846351879796446894886180118923517375928916788468439012038559075591863943949905482322123331177881875"
        "1175818045667507501033007502798482889114822353165030685871064806380979997518713085247211620359113239321892"
        "0137447365082778750155424105285638558275846595641108095833746918637233220466393816326595449266228517373855"
        "3977212332931292826069615658590284856893342692154277412999385588950569011586612223617034264066429835291956"
        "64034560092739263995560422194101981991352402767692097995677613653242588043212890625e-197"},
    {0x1.8f3d063ff6ff8p-653, chars_format::scientific, 505,
        "4."
        "1725845639630823234884227494718580270580351053715713703971375362827503015835943180643599018229301247410673"
        "4531370235114440276681218585911086934300107994205504714104860990795054228564285081786387946659435399143288"
        "6039995130765713915101684430478057187716062578581352152485071389375497738696764199545096908565956533808131"
        "3066078143179085025594301665865165419361839755147261933143617447462954222697482489653056327589852788118074"
        "865087443355257133659824688533856429351574790498347056200145743787288665771484375e-197"},
    {0x1.8159ef44ecc50p-652, chars_format::scientific, 503,
        "8."
        "0548915652553614245327177394068343716266241601526344429862653871128012696092458059218804885886107480434857"
        "5996679239026442252671328552262873096601408628711791229287582758527981933915133142134968110008715888249271"
        "4360596305961404470471333694306867890527358826950270156557243671697176671195161373933098056018737049190157"
        "9062338058785059859208293885656813869546314004329986095442735468526295545526700031871588905460237269435492"
        "0045505660403734502280634268682688319158924361573781425249762833118438720703125e-197"},
    {0x1.72d55008d0c7cp-651, chars_format::scientific, 505,
        "1."
        "5502849382509784344046037079839787991991438980451926341439221279817304432312682866647314718184756317272284"
        "0418818164653948573900468129228650155998421452040946741052202506711300163335367314534852081645212273850483"
        "4936009445548134585828779634942569389313670043772850997818968097978274270563993945839657893655782681355924"
        "3399450305997531733663209449593963941246859189366865487597377476931307594702606413878721039121116753323533"
        "807929870963298864021730228539197981164725337333010202200966887176036834716796875e-196"},
    {0x1.9201b21128595p-650, chars_format::scientific, 506,
        "3."
        "3612132087463898062764140684189935461768684214886003230114344682573470604125696689595274182067484837098156"
        "7388239748345166372728200991082722447070470950976867382049849321900596490945089196119817194645074654642382"
        "2293731129894706387694427155598543964629550957151612379995382696796015118450028002145601154875875180150576"
        "2629218754188327338915245534983749038112110319832390876772625179935411466060958956629202109968362912633613"
        "2681375017182897009957109717175163086000551360132959644033689983189105987548828125e-196"},
    {0x1.bf95124bfe3cep-649, chars_format::scientific, 504,
        "7."
        "4845511815508472389273098151681950055020091161609473435727151103841950465792552422516369304948060633102603"
        "0748543057238889168858814345038221851332602680360589796942496976998706591507226986479450583156967310376947"
        "1550616591376104244996055290823711542442328688452990316118309517988468414880165494471060878616231312672161"
        "4660037498120830248157761796212768295676112842922578987382164266246048592784044581707325600021518482162211"
        "18106040902173381508385840983168502105714325889351812293170951306819915771484375e-196"},
    {0x1.05319129bc0eep-648, chars_format::scientific, 503,
        "8."
        "7354525906889357430513499319853860181982631924149000392085053971647451377290292578090547222488245265834970"
        "5414899403485023309716361193505231457636757444187175708777555726402719541396118635204985184043477505618747"
        "5847559854756176999196488474136708647066869380958111801978413140177547807244097772736963227119156935670681"
        "3323315849604381739911974325657778568932885367514619084065148363560917676654922798826780533306406883703832"
        "3167938402444969732430229950789418789762474926163804411771707236766815185546875e-196"},
    {0x1.45af476abc232p-647, chars_format::scientific, 503,
        "2."
        "1784629336342830433438401052550444396082133172046876130098970781925971096906924659862775926914085559598218"
        "9400663017394445060955050790938880349417984181161062059937297849164047537024227807102802573693182922323768"
        "4988835519769163005404421634184916315156946538119863486913379372954302859826455909344216690658954228864068"
        "6518489319695139936631205914340242708131038022972028056540459137983053554561488795642242191718171201322878"
        "6261160061353215424961010708322035390495374773678349811234511435031890869140625e-195"},
    {0x1.08742c45210fdp-646, chars_format::scientific, 503,
        "3."
        "5377948750753546389134876678525502149469329636100241627697547777540495032071588666485860794956076980685142"
        "1648973041035651788522826916676596088401130357999256151013354430964513824609480628150120736931652913772699"
        "9982913797176673718855319142272201371103880783459641259655175318625370923447186213384332996959675405576982"
        "1423466528711936764992224608103888079428547551703232208782450602977450285489861691938795324543533418630584"
        "0889333459077886488131187709654153499168327545731926875305362045764923095703125e-195"},
    {0x1.e06706f5cc1f8p-645, chars_format::scientific, 500,
        "1."
        "2853400648125002047663650303839837768770868178827228680425989408577299035277697772519128024365042269006137"
        "5219583393883196975265503479494447072597343928704527629935234980629701495621199539547037556144229442345470"
        "0796064280527920406982515008146955967451695398724643112299643103663775673910972184612760788176258685407613"
        "5642395098320769603757825318678910573482963656312687065092042077801896417210663056529091563705356552511784"
        "8744898314956824515887701286388062303644996831053504138253629207611083984375e-194"},
    {0x1.c3b440515c5ccp-644, chars_format::scientific, 500,
        "2."
        "4171125083478185854577296568973058488028696120773687858171527751677783966413609421158848849895950071414992"
        "7767427664623224802204953078177500746806460413182965492695822167375307505348079714337003905535333983330970"
        "7181502126431081191942010252850595523287033985789669321526444757608927731550951889320987373819142026991025"
        "1567538566070467758974459713102558552732954856343026723690055888710021350990995482922051405478223152042970"
        "3251711643812898068027460606431856653120160416392536717467010021209716796875e-194"},
    {0x1.ec1433b7cbaf0p-643, chars_format::scientific, 497,
        "5."
        "2663240453669009136451576689712462018780864628757726838532298564973456520124312425159168990966344080685284"
        "3720480382087984234515131775332141605827039252921143204800571618187675999431430968489137764119560673111591"
        "6759478685050363495734853368006928166562436836138049592492697802548236478358520529617766739001729760991012"
        "3862634939696554148089055580137656188780075461507170901101717759741393603409206482184290891472920793565653"
        "5253609046038903154631796610265874469813951463947887532413005828857421875e-194"},
    {0x1.8c19569a7d35cp-642, chars_format::scientific, 498,
        "8."
        "4782562742821825187637774072036156880782589649318925320904558902615305403899383502544659296812445003369004"
        "6922729704209086787736189120322426639864121576693397330358676265593198834037152235715817069429196893999010"
        "1011594016395775564940509800763785671916185917507549352955056824078478279323005977928175814655943739879529"
        "1538021924646821332904342665749434907103144778825208546062155400334839930506320175047419033723187526321855"
        "64516811751524813377187526721215880820547994289881899021565914154052734375e-194"},
    {0x1.173cac50c28d1p-641, chars_format::scientific, 500,
        "1."
        "1953794466200874950308910223847802663992105229667520001447180957079004440344103290919539635946785467448663"
        "5101108320842702261329824849337500079159383293237143393259388273511334641497706315723447326003299101241322"
        "1117379942112771102982874993847323660037994013482573676273472522789803757300898880108155726096998947940489"
        "0006031075166624593609122438130204229832717825013013180449460185827436065860119332649187858804645882720105"
        "3492998972995592881612034128274647988565693168538928148336708545684814453125e-193"},
    {0x1.08135c62a0056p-640, chars_format::scientific, 498,
        "2."
        "2609509033348430712795357140935977280309512733698287057990757911935349021821947685234330624308209739910346"
        "7772270922940612799108025398381661528666224493282545567170070803473785763542388437441950076122245663201438"
        "0804220304282042074737823775324236510491104141195362756591323881292372606025430047584104793476982829997116"
        "3833702491013210688436845620875268204319510942541720735041457845466698101522952622178680700662949823493228"
        "83116291501047308902301260328539765642741343754096305929124355316162109375e-193"},
    {0x1.72e01124a3b3ap-639, chars_format::scientific, 497,
        "6."
        "3506864504234787217892916858872910373177620746625376458668035645917888586328943349478973125084439934368395"
        "2454007404739476733674972532888856971140947480305553043580744964130001124409209147401842341895272817350358"
        "2967907318694311580157475110469517637645997431939894575492729066843808617131234673944976587290456837115006"
        "8097358639249101610267432497854886217853527900415351535406568855784166730515150549809118454920495773146011"
        "2041598585348160002997507320447907741556292648965609259903430938720703125e-193"},
    {0x1.e830eea3741c5p-638, chars_format::scientific, 498,
        "1."
        "6719092307496787724810559419625415421265345344982027451035214168134737544212060731999082598951652542812153"
        "0851622757957648957787354945239842973641168921883094179012153842080031968856243689294313054164220779419616"
        "3185205252988408837352595118420621916054112930407241813976472546961527155883577597985057849232945503946152"
        "9700917317130576683212396338930885138139608143780624593505064057096724037453800040558676726388410965108000"
        "85511376306229931840104611302550048634874002573269535787403583526611328125e-192"},
    {0x1.a55edfaa629d8p-637, chars_format::scientific, 494,
        "2."
        "8861375664964044259358368710583120953117948717615414732645978781844725959856063670973732226688698008775290"
        "8855286029832137603479464792748518405725776034634453198114500345112924366610049934881872894137471578343997"
        "2272095705181453677718281937893424772356043639946249738131015138508747363998350555539212469835793234130222"
        "5611134741196263127354006994422412740010583624493733640101270323986057803752221480551347236346238685334139"
        "3126740018852601983569028279257018265724354932899586856365203857421875e-192"},
    {0x1.e4fda41f3dc12p-636, chars_format::scientific, 495,
        "6."
        "6437958622447088767008821269554630170953468199463824514799297420575734289189965271614292158798703423278770"
        "0211670773747181252710225781433614349909082934153740628607832041425472458132448888355030553558474449140267"
        "7532352029048675127730409628858188469012202328932369306696111994192499642393175288938545581909362670265661"
        "4142505131384975210072259285428843744450254240067804540915295982013954480300602499657994651473650515508069"
        "48573291876921601661574797868976827164289034044486470520496368408203125e-192"},
    {0x1.b6c6d5b913315p-635, chars_format::scientific, 496,
        "1."
        "2021435877944512549874307758373463485567732529548696497108946777892373338498825233998851190169288250470729"
        "9837565510492003253409646038667103199192178730894714971640838750321839454360839834009539364164168776033623"
        "4187003338717194709455390020102928159467155523872584982511528028983638984992933752520154204626796100307564"
        "5349437387211946890857172860201104002606422391817193670983149333434914995143903809339065936913317470198921"
        "690228366842475023103730967012105212976535995039739646017551422119140625e-191"},
    {0x1.3d5cdb61d5eabp-634, chars_format::scientific, 495,
        "1."
        "7389964555399592703024922101071638710228058853010454955816287203412674019899135279944202376472905021337258"
        "6258962377260188928899086845828533503606946253121325963450366034526072666759964392438712742370869822534456"
        "3874894747840335256486925055706840475130878149016154785918583949575125805400818453276293215346026410674679"
        "8409452115405004337540444738954378827964445928741978867217483445923848187815353826331562166817109812355851"
        "91326326911503365880101742535317199678246424809913150966167449951171875e-191"},
    {0x1.f66ce3d3a114ep-633, chars_format::scientific, 493,
        "5."
        "5061029114396530055781180408544466257723099083034183419703118907194804421094663580781660676273528898210088"
        "0431574966784461117119754411304894464276186456426615997746028595767878242155456834626624868962582541328173"
        "2698743091955612694553222682503348082494541469600607497030280636718224508777918266791407040625019889179303"
        "6039432538320513687547095452177893522474675770324240828465783630281774188233607627719489884195763554935119"
        "805608804359250562788832806214445181325345402001403272151947021484375e-191"},
    {0x1.172470deb171cp-632, chars_format::scientific, 491,
        "6."
        "1182680642406057145274956363318000274544013834890966296936024088988282930612184978650264904063655374278708"
        "5820049824373260415590233856953389263574865715472704679815904138025683990166563353576868412611739320572220"
        "3061670363833037695225389013764717715215814805406610147515377607379775485559684197286852537353051075869007"
        "5622999002133683147106802833986208071593930453200187676542794020322742581458245280814157780849754554959666"
        "2062989989245184079000110764778863625679150572977960109710693359375e-191"},
    {0x1.cc8acbb3ce387p-631, chars_format::scientific, 493,
        "2."
        "0188412709311976353396884746311782549660027699626134416908249213603286354301183164885857133455556626170175"
        "2986650828364633304418446703878674495167794883307172379160008761496010293765369166879233431965874199769146"
        "1247264270712989910977467696385844786711157938997013783312673882579017433385308124601678176538989823901426"
        "8504426857552292598582757513121935280241619514931840030076728470889198521213809709086287440776710908200405"
        "735357811794408235582388012711863023440628239768557250499725341796875e-190"},
    {0x1.9d46d3757a126p-630, chars_format::scientific, 491,
        "3."
        "6232946244639112367859903422212363335346720737453523731673042531604023172777826136821456024225495282135527"
        "9147249851468071176677140162008005389158117032353189569393774872787748437635734676141743605239899596247807"
        "9173907474651509305526426663536509510071332191959766754013674972380722084744542075898159198263972544323990"
        "9862127078321763680723742293917247854494085650342015232239396059322574446979695006954270328936113654558116"
        "5109048996725791055641976122492220468984669423662126064300537109375e-190"},
    {0x1.5c67ae0e78895p-629, chars_format::scientific, 491,
        "6."
        "1090986836497964518361303425180367723651770315999856077892729499033830962250844499257483134844993286529957"
        "3396737151577326827495417291920603068403409539650431533658243587896155378299195574892619397055020676300748"
        "4081137435305555643552213889591461713709239993638313481580791776559826037819644583208179233694714627479712"
        "4038277978644551890909885049639824861857655631507863094307400842947454757116813778845481873427571851486232"
        "4305325582256049241387124183744194994005738408304750919342041015625e-190"},
    {0x1.2f87783b2188dp-628, chars_format::scientific, 491,
        "1."
        "0644449452139395541202935621152473437563772434876136314750186066160168868665485527429324719400873126529471"
        "1776208189233000924188079381994589329829074340081641242779083161698962978837918189289798934978657684522178"
        "7193869606025896830482212763406278603126524969759522714284262548258216685128420411064588664951016966673939"
        "0845242506290804466119517491841125808875606147358759849354078294511591903760561737780825280148148379041554"
        "6575626016714499472357838456837431095891588483937084674835205078125e-189"},
    {0x1.45f46f0331583p-627, chars_format::scientific, 490,
        "2."
        "2861786222533954646339338691509779541402264763066115611162751161332286389741951997410211952913065640508722"
        "6575869024011507037043987193802942274169970521619512563506532093525808423532637902062603827257377383924857"
        "8834042883646674050483274861201465476232289908450602259119542804457889706508812587002689534404145674260289"
        "8921599918546506922933261671353147226446502233455978523651976194012189261061433226344919763518640419647944"
        "054596842767851933093579096245573367696124478243291378021240234375e-189"},
    {0x1.6faea09dda3f7p-626, chars_format::scientific, 489,
        "5."
        "1576905486221095495936291261435152848936470928518784833293608233493425320242788522830160136503780002845701"
        "6048122210607633734845264378147025848275264231001539119629139628017208552752229789388978000511788179842606"
        "3317970612546358672835740360045451972628457734270690142631590928444025538183708917796524126513769584005208"
        "9566588457104934404172248545830966642830155623590373212577067124362619633973442089846035406156342718763126"
        "22767073101055486120613234601872676421407959423959255218505859375e-189"},
    {0x1.fd11ba94c244fp-625, chars_format::scientific, 489,
        "1."
        "4282019181687436415805061570582957797941162203963167425601499169707767566576137048543241444320531168598156"
        "5115836884276861958472129897937475431167531842729039094949094354884306009515806723673286503437496509105787"
        "3782638327303358403092014499545668583556513012056701640438893215817552078525004382652304169786365593370561"
        "5949165720580529687699459243337232320280125250787257153626075271940536628789995287096375595375273874864083"
        "00778929339319455162830678485175184277977677993476390838623046875e-188"},
    {0x1.c90c420cf0b65p-624, chars_format::scientific, 488,
        "2."
        "5645102658000638077662655089472362542882984305302201347516398173403533180585976534161315640938051666852184"
        "5162493546322932210500567375141201380918228455858352480628723115250797285514387548153230939412238584051887"
        "6678363214204154015141209497251639796833017773424919290240970816054977116200075111851757962310125684874866"
        "5271116317931001749649690210063583111446018923027887259222427377589680137555787871347433236980870707367622"
        "3030545509731425180281923215108719205090892501175403594970703125e-188"},
    {0x1.d391952e49017p-623, chars_format::scientific, 487,
        "5."
        "2470856179554396914220750697206729680930693393806189392472186972317553487714556786098233769482799791950847"
        "6936934598345790216268399728663746626185262113984143990716591357062201655858886386541140904956275446729344"
        "3451534230378626979844440459329023491130157174730485458049630374966675633574693062515331282157551074828734"
        "0588927778646025401932502132098401926185663426957522247203760063557453586246851349782431341310393754891747"
        "355941298035050636481939345667768748171511106193065643310546875e-188"},
    {0x1.e503a112289d7p-622, chars_format::scientific, 487,
        "1."
        "0885720130033327524143787276552924485207749474236947745950934265104724459837447523248118491135661241355555"
        "4232574757514637326804013587665252102597948137223374246525570157421645385185077366595494308247722426388075"
        "3119476116577310064807731317312781001077692695195412670562534730271894253873410722316538605384606174341590"
        "4126374880046187387430900137190727541241598691090538953096044591639726558323746143783829642440266358936970"
        "699956723022336843044975684957620387649512849748134613037109375e-187"},
    {0x1.e034bb81e6223p-621, chars_format::scientific, 486,
        "2."
        "1555608982793881032727700454096876448057956857157050502496261686574263161511608285224246722003343000927303"
        "7170918392497696227267889285573432933779319637407407790610774179847495887678439501670748288585196870929692"
        "2631032851601097932395854292976963625544033998797106811775949503368245505473163357535226402013752099869119"
        "1325549281307961732743070166406501415911305100704902729441738565684824332740737975732433035435605707383320"
        "56586222159526048335574655023805235032341443002223968505859375e-187"},
    {0x1.7b3f7b7659658p-620, chars_format::scientific, 482,
        "3."
        "4047560211390398233126309568152129229163573085233746529962515141769860702660931684182926361748771674041996"
        "7495013736445763182743473510953840736163870669821867413809602871013516774422732969041413817218575179638005"
        "0875945116419344891273141268326046666030950270526350859421486707701849832266291902224529676973277412963424"
        "2022391711546658347775048931980490466521054406862017429528749012178022403631956930652304619750657559521682"
        "3978488395241784846001475983712225570343434810638427734375e-187"},
    {0x1.c3de648e8e3c4p-619, chars_format::scientific, 482,
        "8."
        "1134394501696493643970170895844859050224211984805270797934948972160041994065592646160497525561847540423315"
        "0813807595154285254949233279422425559267946284083567427347887635007556376708519246514086205471778512341436"
        "3518932443771014783422046775533781186699620751308267263855491161152739861928620614332415977705700567596766"
        "4862641318690146376278630164143314536054904863747143635960925293922708102025814503615280997269393301674470"
        "3307415890333677450929616981056824442930519580841064453125e-187"},
    {0x1.5c1fb09f4e5a6p-618, chars_format::scientific, 483,
        "1."
        "2501335652550156692148201907563971897160094599357553635775710000794313839387986491396580421848511127121467"
        "2834212759262118551641268797951714831348473471191972599936690879566720474936486069169882451620075746975670"
        "6186070712175957038367674918959121878800275599658681630037550050069344073450148603507547516824435960857783"
        "8035657183539595621318513297001759908054939222484006322563328047101387846029777029392729213061137991735191"
        "96290497784021327441761339827053234330378472805023193359375e-186"},
    {0x1.96cb5454dbb84p-617, chars_format::scientific, 481,
        "2."
        "9216455145197990881697076029069682383862367622239909838970901266656416619071823783376826565064724501517459"
        "0701539592225503271024718266218547248626039047992425493790137556386884876463021059476422710406079165707647"
        "8035331425667060181110341423930489375804406916453089986931472266944633195682980465023708899952177106470268"
        "2690151782591846080679893335942503991582720417747237342953988826766205275785907263374548647122176495933127"
        "570825962591766385145763962327691842801868915557861328125e-186"},
    {0x1.17e326744eec7p-616, chars_format::scientific, 482,
        "4."
        "0203689191003500137032618357647146694952938707754104131177614885341123472548521527075537816698643711941179"
        "0099119606618891309209407696274360253203429336179171351133531689315057310507797931718347867905142878647295"
        "1295378015371889396345363159252325592648677983269855951990787798154248325992797181678229344332440102948264"
        "6293076484812638568001554150811635968863201084650719977028858419487757190406448299518015352159703896986728"
        "0321388645943753679945498191727892844937741756439208984375e-186"},
    {0x1.8d0730dff1c35p-615, chars_format::scientific, 482,
        "1."
        "1406014918543048611129579046078472017190434076827676333703184492562745517458722933909773128140863811860680"
        "4407235198747673113581675421832304460289731814158715726226721499893358385121455295036409753755696291856376"
        "8098784914446226027812795614298253285437604990024681376542185656441137513607157191982929093989227066316968"
        "3454585239942627682309380956856546873709262441718817170600788510391208708618239903357485935403444561300988"
        "9522537510867503975087178247349584125913679599761962890625e-185"},
    {0x1.84e464adc9bbbp-614, chars_format::scientific, 481,
        "2."
        "2344564074253929881602452952105121463033999896331509753060278603561383062671020092513964622839910827392979"
        "6120725053806395919718505867953302822071585340945473684155811269041734009391899894892884998655950936230307"
        "1669852431153178035825596725766172839564272885227331529420345731439115502642545507672856789487309544230679"
        "8912794588961931961324587403615865918507170866263260790615432342540019426259929855207218540356013049043725"
        "298895767697004814678063411292896489612758159637451171875e-185"},
    {0x1.0f78207ab56b3p-613, chars_format::scientific, 480,
        "3."
        "1195598970627892124787027828771258554467274331378106474180853903784890176470576278085246910031864176926682"
        "3810097575938279721843585234379937227458526717860732051290204395780473433869536107639158198822468448383115"
        "9850946360996498401289488125559457224226066168139585512180838489229070664388435003461492126740239264693377"
        "9324794218572275222475371415195959735820466509414273243741084753632448488495906132266682527804921511867261"
        "44134988124453043700778920310767716728150844573974609375e-185"},
    {0x1.5529ded69b52ep-612, chars_format::scientific, 478,
        "7."
        "8408892826173784349899140483375110468365507426372771215508168337980921036043285415746083661506063036302466"
        "0337267991264308099236262848998613132804398487495251763436683220632776620778652222684238885184627406388017"
        "3229920844992419303692750294188388326470646133479933189911245652940004567736087396799055775383956456338672"
        "3024800062465207795949876534463873259186889135949555497350644501301606934956057533627187656477601229539927"
        "078260013316828025420335279704886488616466522216796875e-185"},
    {0x1.a04e5d2b8832dp-611, chars_format::scientific, 479,
        "1."
        "9135749100368870646470019839026295232772871223966552993833368138787991754425940205303288817218434799653336"
        "0676967652656209466863703861565021219253899628393157406814397593941242505553200228515413826724835127232051"
        "9185851595688434551396579504904836374850383234197454697279713290430878565007147332017477402669464535867351"
        "5775192868362553696596252586924323504526235631150752451721765189140363973209619061479811966865121637316157"
        "9595099193750774857480934088016510941088199615478515625e-184"},
    {0x1.ebf813b0bce87p-610, chars_format::scientific, 478,
        "4."
        "5227279193825361739063351116581608889422003874799378804732418515554268862505634014557098902874036193318621"
        "6690467386983882756961652575255407524524231250012838933730250624835733642161557413446773017614154929610452"
        "4998635489828297481285095734401803451480336950909547116497526559046290615361439294561656735211425759983595"
        "8658796913640401549715379516221334359696133496301930305779915803185229950546802865949446986687845586568652"
        "642876913762791379891581300398684106767177581787109375e-184"},
    {0x1.c8dc05f944175p-609, chars_format::scientific, 477,
        "8."
        "3999229662967713528086187594173418172158294345371367977068288734445756810245726239154122121417804811678553"
        "9260638908340859917786703727950548339528508554698659192678302294445813989552010648988331687084249678986072"
        "5134086126172959651037933921293267583373144983517760442249968121280748656790906595397770655757785243584311"
        "7665011821890292937224415194440719059952578889148712792501100830129843689192652755309251105434679191014804"
        "94498409103999725378031371292308904230594635009765625e-184"},
    {0x1.b3209b1f6e28fp-608, chars_format::scientific, 477,
        "1."
        "6000703209667125522791462448559322479873062933223276333349152772387295549263802853627258955887541875044108"
        "2947080038083309540852416217060880963411880129141024234284664106285251262025261537496173726779635481066239"
        "1399956818327965395732286282182169589674025784504944090995218716248499475156431003783177219541707924492549"
        "8325814926158454470942474826570277646630983287446062760977259012870381602771233702771674396301817368407594"
        "07891672679545569391024173455662094056606292724609375e-183"},
    {0x1.5eb78be3e1518p-607, chars_format::scientific, 473,
        "2."
        "5793451325824551491141095667675624912529344342712005389262969789586908298595671025931892803478199322507986"
        "8523010849281646737274885718408262502576874120606976940116290679237340341259636981155466151665848618173232"
        "4032607948080657805132919680722936044837224175094957632003247401297641357721425657261766165473818699028835"
        "9825505903137699079686289257017072435439734264967279514362822953866073386940049227380450195986556441556177"
        "8167473687417565741952785174362361431121826171875e-183"},
    {0x1.8c46fec031da2p-606, chars_format::scientific, 474,
        "5."
        "8288366507307604041374269061151039091481400225143596125768084467228171073647588417776611518319759684136669"
        "5557291353852212593508193848018264294866764758668148761093094182833021715126098317988401041652929218002060"
        "2358184934865157857832670838256679385610036129043203830159719538870546915932165957386758340306712837687657"
        "4139690927957720219748627972540410054088613214587368073136947535541347600289632712236225552316903946201217"
        "43439748913939713048648627591319382190704345703125e-183"},
    {0x1.86231c6dfd804p-605, chars_format::scientific, 473,
        "1."
        "1477041919553151503755311242286463359086338700939173534433881149141551312845676541528433370751398526129520"
        "5360200123442369544861627337651189410728311021716825316418209072205209059768027017097741944446106051476144"
        "9260586341856618907842200283371765359783819221589931961870907795236477229042736793261103112697240517930987"
        "1772095882680155257799467917171661002569274579372573148249479204708825803923891308204782759202811211858909"
        "4147011638036293135201049153693020343780517578125e-182"},
    {0x1.6f91c9cea3db8p-604, chars_format::scientific, 471,
        "2."
        "1626294070138318712021828339014812165466875626132428688506066130661223800325245624218990344615529115525670"
        "7498826015032971421773458480080315944694557039046086653470574190248564560937128913048158665762605822060055"
        "4638663222463820196556288005293509078032902091923457112717105630806377089745970685933260769211709292606271"
        "3883265602154051291339880146519818852439242793594288516683321266294987653057491978352698407891148399388724"
        "79857372155276351577413151971995830535888671875e-182"},
    {0x1.2c556f28eff41p-603, chars_format::scientific, 473,
        "3."
        "5340830852507131965886973628844009684695670072958139623317371787746358871058121738979142765604242918427270"
        "6832415724931842814426120166478731717470396051187190782581219012149682498960891262131383887862540827723812"
        "7643023274199348054497036263959980391539791048593977360916969031572048106601825361653601806771067623066557"
        "4051011657281000462617858827996936464081367646380909919085410798272389504087757458521098222151497599140581"
        "7346111169208189295432021026499569416046142578125e-182"},
    {0x1.e2ce238120917p-602, chars_format::scientific, 473,
        "1."
        "1362518681203582246140939809705922332332975015608228604463964843232561988310452537437790568021290911866235"
        "0839847885927093395163376953078064940732037455207673242572744714448661683497842412332824043550192279636628"
        "0503312783365917365174312756198857236845666628455487179177649489943944605272828958999095810535518041549318"
        "9818268179755941618181564000540778433874330833462914620292376177100970824204171827936477371939329301106083"
        "3410329727610754702027406892739236354827880859375e-181"},
    {0x1.24196dd650362p-601, chars_format::scientific, 471,
        "1."
        "3748749674401770954459165335871081766876292885886953638318405208098300543963268873795361532633351527309260"
        "5183293467910096607640374531111183083050881483551578535590574862217605392658691254251016040206211732176264"
        "9513738716450171265643756029288065693302635054394259859478975337052256681676444287259784856070495950346420"
        "0147147833503265827822922002568340246087493652923517964388001136742818825550149740093584171030834883177820"
        "79866403999179880202063941396772861480712890625e-181"},
    {0x1.02bbba1fa294dp-600, chars_format::scientific, 471,
        "2."
        "4356505490995989137168281913610731830019560936055966573555888682095611638946741848058176225505118866181664"
        "6626267444282690413817201444989379537984347462429716702593341950876461070954522685954552542326714837267824"
        "5393625964579526328349325430932794835417522958299065595103892073242338952253770707833051812460982697751239"
        "1397642546757797290343067143148163681852061908086271106945153788678767070284176602262881688759899668002859"
        "52308775805352780707835336215794086456298828125e-181"},
    {0x1.7727a07c4162fp-599, chars_format::scientific, 470,
        "7."
        "0632264615999984553004824523934828389746815912663087276342193164535550939884152883670041383967458297749541"
        "1936486820912787231863213987513973227977769787492778564103481765224649564842940083968386889634962937410157"
        "3069328602934415866941417964147777899133182591019874029905970963950870131654961921749867946840387912428480"
        "4538594740895098332413481316117502058978520795751015258819941676721527211850355917929781785411532757190855"
        "2225891930742562863088096491992473602294921875e-181"},
    {0x1.8f0824209bbd1p-598, chars_format::scientific, 470,
        "1."
        "5025541635379650323807804926251313131836557909893686530962020768745327962627687341360811479854106994068553"
        "4263173419339530468602130784596336253828333239650646771645717369473848852911124115928811400443967809140245"
        "9813215515621469873636992676768817063884474168442971019069351420018247479917638346466764078010317901152627"
        "3081216374180988281024361584175357121212766604713032037039974454629576819451922761645310017488437158483350"
        "9687996466741566337077529169619083404541015625e-180"},
    {0x1.38fd6bcbd252ep-597, chars_format::scientific, 468,
        "2."
        "3571270014353365322336931950633836856113223159844998673765836415920035201232388224807330916269590271324890"
        "4334731033242228233263401451666324072513909789496747974372655367892497264045352322984236122954019123722538"
        "9295828403612962912512216580766983652588284187430913252738151214604768290342680303710604633254838264665098"
        "9962035785843582809055612178144212382821531464078007017087908041952151860790529094170570698810065899235103"
        "91969274646584153742878697812557220458984375e-180"},
    {0x1.c012c11b55edep-596, chars_format::scientific, 467,
        "6."
        "7488790504233201532404821012783315024399985087878933914326993678810118949573654609919916051799477574590605"
        "2555587820395782532203892095091092520933306954962049724050297871723120684162663655400693709284384679579844"
        "4229626121510547440413205330956979446376661290569033353380029097827152899554534893469580751628492269227510"
        "2307945654300221853112443217811972597390157707545064145290234402918947143290826226229722152773665129123377"
        "6865652327359157425235025584697723388671875e-180"},
    {0x1.1aba0d7a89944p-595, chars_format::scientific, 465,
        "8."
        "5168606875567321498727662037372810859520433921783123995459117425504744477611215726819499227583845539616812"
        "5239580447740616724353434082982514047154634288153751058253832016000933674669111863819139788156587916539153"
        "3715294248439635842170170518537437533149976925664023652905320015380511107595544259672890160470678028598596"
        "9007664706297339134454910441203849873467808766000671452678283228867172077673641166000719771578738611874552"
        "84682545908481188234873116016387939453125e-180"},
    {0x1.fb338c7268b50p-594, chars_format::scientific, 463,
        "3."
        "0557865935212958394376086957173324154082751196112498539965546191859384115363199888292606660746361125668283"
        "3404840375713838316990182046660217446344946472933812140353250354288117258476863349697332813418892391221042"
        "5909219328122261566214838211818211400416693170662727113985478183823335721980028025030361593055215041959837"
        "1905219233320642590550021466201626391931891093110222234205139677685160791537656843706503862113584384899329"
        "926543742885769461281597614288330078125e-179"},
    {0x1.51b04971b0adbp-593, chars_format::scientific, 466,
        "4."
        "0690125758357819313890653104659603597467313761268844991087784245249784829428847210475329294275518716491653"
        "4121363796664234945241951639537426384878238066930222719005716702736354770121804434103616468073547678393421"
        "3866666956214335399982637848595661597381697776886918409632666455919979846021303241798302378411367222817251"
        "8260900155291238599964614405125995189283239303437292544747420798857552235240907507102919238856499693549029"
        "737782429805292849778197705745697021484375e-179"},
    {0x1.a8ca233514955p-592, chars_format::scientific, 466,
        "1."
        "0237088948578388358098853060992576583367816569954351981673902681175827710357388491891184587825924676377634"
        "0849697422669866470721371511852998301084735245899689191518783967305093246868883270208809502585863440586583"
        "8719400606468608999474499247944762751706090711502562362059161157946679758864812671596322877059632473937360"
        "9857690212696944678148132075078524683281354026644263575846458787445324344890837847883377169654004993848352"
        "318697170204586655017919838428497314453125e-178"},
    {0x1.402ec07779db3p-591, chars_format::scientific, 465,
        "1."
        "5432289335652199429529596192176095228012899535553233590378023000243990210617168196490459969107617309775975"
        "9271595161852061445606846570553485751629922977685294026681803756969797432088015163086656410384375134034845"
        "6654787834477195943853030778904275812187520216131508463375328855191606753215808123343539126680637528150749"
        "5586400182624672163254831082909010625241829629378479391253695739321009052894816650751602501038193173413725"
        "84218017749435603036545217037200927734375e-178"},
    {0x1.f0aeec50d31b6p-590, chars_format::scientific, 463,
        "4."
        "7878677416379371549125789239926548827527615154124045791534979434488720324473118535175349175451116574955482"
        "9196846477560962493984753090692845809166165686038186185598545516804955486444807934972963947481576822992280"
        "1413673914161293747159398543359951739982313316116576662886014320825440802061395606568618051069946931111084"
        "3403784158309126949658184006386667169743740687424550046011927504256647287974642036460883111432322478315769"
        "254120226605664356611669063568115234375e-178"},
    {0x1.57d294d3c2f9cp-589, chars_format::scientific, 461,
        "6."
        "6286789908919767154439712855163324165485647125775879469082523552535784443231882065986199405578268409671614"
        "1775524355094157699459438893136009843313395926452650072279802208152136503116316085826330120645706047536069"
        "0707532743601948118549864883622173092720567735244279208420288624269214419901245909769732036473350606372685"
        "5287774209801534211907607596434562429271112638134066194967154756089303850511085273262727747824243635776236"
        "8270840624973061494529247283935546875e-178"},
    {0x1.ae73fe6587cecp-588, chars_format::scientific, 461,
        "1."
        "6597719647556534585125909210073988053664761497437503116043924519032075968467392138434096782371133771691041"
        "4692966359530302893843702342909948977224093225788840850241158526002495811490793284029994355447936207717953"
        "1701030202592523890664293391660227483252564706908710533792330581122217799978898141257599150318157143299562"
        "6438491757766678273670461681099223694022755564691644672587301285547650231438839095722621873493583105878962"
        "3693172643470461480319499969482421875e-177"},
    {0x1.fb67296e3acc2p-587, chars_format::scientific, 461,
        "3."
        "9129616361835474995816830113427371139394783748006906776846465564831734796400082279893725348246088077820873"
        "3724773721727647969237518001871833488349905404751288122720075258042368323832359271430311964401334649219933"
        "9519425305966013506257262632784489759265561057060941101640097783767987620799907927064604185859394447002994"
        "9081905073803555079273434996212221006831413351082560112476320410824712380110268981480781210164473159999337"
        "6480739470935077406466007232666015625e-177"},
    {0x1.3ed3dd4d0600ap-586, chars_format::scientific, 460,
        "4."
        "9174333185201845885701643304817719285286793119402385343997121743834215253289182597526179950619953400075056"
        "8215327569860654293571277325952168912585808066003526425979416007658121367350545330904392662818296290555095"
        "8363362875972718209741260985284999305425043970836369172025830193280142465849744222930368949184112590984937"
        "2570588281489240090240019398068143537541563361531771384907078697949056986176353435518052413541351141658408"
        "696599735776544548571109771728515625e-177"},
    {0x1.c7fc47e8e35d3p-585, chars_format::scientific, 461,
        "1."
        "4065772131663601624731605132771376030687013595023265826246899604517310916218342653982498273578257694903797"
        "8468638033545923123797757358334963538697635759700073763508738768671726201090282961141287767540599357579432"
        "6842542570723744576605062186938060430296209980469258502851293064721411956550060490555280947897869268535238"
        "6179746516768341436744109032500119725007587257232992073560146104583620982534044853267658149002760617409663"
        "0464731561005464754998683929443359375e-176"},
    {0x1.e55c37b92c6adp-584, chars_format::scientific, 460,
        "2."
        "9943788764426966743964594522375614351628056540175421741903002166035225397433156307925002196026795564333321"
        "8608007322600239902857674736096887285429346165120286356617612333602815378437074971902704269699125569824971"
        "8734965454790960376519785799921911505099839114997820088040932021308668960743662393965366462481244219250884"
        "9572198239276132947860029194547765807895534142629802891987129320208281337887778316462208527447689848828560"
        "332805182042648084461688995361328125e-176"},
    {0x1.d5f79f14558d4p-583, chars_format::scientific, 457,
        "5."
        "7988273284859469245975909244211226235064534468838026322900953010973310895710460351625303496060697525894981"
        "7548467994482334725806573119794681098598188149502821244093362724432709697646779140442854709952519834481575"
        "3552685473794970090692535724337831399571800371346050428402437303389817593443709839557440032105433568682862"
        "4757675607836065407289464361427118285829539423788560868340267151754097473537655899023331355796062082375019"
        "741675714612938463687896728515625e-176"},
    {0x1.02af8b4a8eee0p-582, chars_format::scientific, 453,
        "6."
        "3837373791831109164464429226879340089313583401475598285331493581326429673206288607877477935245231280837188"
        "5647870091324083042948466168427797571451303935851646140779239476004716342445942378983444119379324329844134"
        "6151467615682475506740110029481560213541664875596554901104780563157049593014023988690619684414077863454296"
        "7876711134989798226852771797948262135736554301036508910870959205653707241544181380479035784912197892815299"
        "83782093040645122528076171875e-176"},
    {0x1.590863ea685f4p-581, chars_format::scientific, 456,
        "1."
        "7029147394060241225903488954267271489892327386935164464069609449685702563324256490556157119037765012843166"
        "7310922276302573508422178617217778935442879125612302277325623482105142657441536641590746592972611280474769"
        "3325030138100672596616353372172516265836210204580350417097583162091337255177727535194710323672332335205952"
        "4514418255814217675702145734323793974251426625781831584646489266954982049226992568944037760889998259217215"
        "09303097263909876346588134765625e-175"},
    {0x1.88afc27ace629p-580, chars_format::scientific, 457,
        "3."
        "8762215209996964796089923759037167832249242753682372854337872650601972808271639583174726700107777427008492"
        "5501806670174866216009677450964270651295366445299067761270362555402692011724280700725138145693269599925464"
        "9548206525351444569181879737766662552654721137751514033505841091039998863734933754460921996873791362418981"
        "3877322683660487034814611363469602337211596081779924811843071508227249052874980749704115988758129120184126"
        "037429450661875307559967041015625e-175"},
    {0x1.5c7176f603643p-579, chars_format::scientific, 456,
        "6."
        "8789882161917508509670824126173614140304474268001492195639974058156288616291688554218622136287337053108089"
        "3419613781966113824431849672860148904218174388005163947601938431582715382608955397928680356858042289516561"
        "8106610762680714571764269279291838992388844607635676991533109853040114513708619359429236357658230665495532"
        "0578191159151869528057193739314193893582637371956923500775255998034385509158645247066496985387717630344717"
        "17901396914385259151458740234375e-175"},
    {0x1.790d4472e6dbap-578, chars_format::scientific, 455,
        "1."
        "4887562197711446908978121836254756656593526509585899499756689436794712354563618715575348874663612719205860"
        "8812204683915199610533975015269320265559281666130669232952306547433129957755583211217665345578272425010678"
        "2491820289781945266397473512670935662579443028260948228067153672789706239267967937964617523411091552992446"
        "9346136169054560512819064301157801030140723999008663632807032826898858941509657991405075602774164128527800"
        "6989756249822676181793212890625e-174"},
    {0x1.c378249bfd0e6p-577, chars_format::scientific, 454,
        "3."
        "5651743098904664145382811359911180260058861554103089185268982152317863809687513381561548742845716244486591"
        "3339519437222363016273356520765126496768749718777737323105845875880161315828096125505939574746537095716796"
        "8204318690266014998655565144550272896236561789845289241609388463168613747026527843760982680001585378259619"
        "8640242466945887021327694298597975835869968250249240285430911246574479070674348728464172280055825836608818"
        "235617945902049541473388671875e-174"},
    {0x1.012a9572308e5p-576, chars_format::scientific, 454,
        "4."
        "0615954239203778285980217159357064260763320100626199584318312723187831388742625072953964794756680641316452"
        "5187049730893926840073392280738696074481503657716473125301415875810091183435586269507991482810462712565678"
        "0885586781210885206452316190347498731570541051286629973013412217129841564336368659136736331103393064703397"
        "9450485811165942478075559148657607681083750037261710068110348985087259076445035649476524760030822502887559"
        "721784782595932483673095703125e-174"},
    {0x1.56195178ec146p-575, chars_format::scientific, 453,
        "1."
        "0805981132105149879888828194236853539061686084662780914854471675383228243117452879571122473537783026978971"
        "8424874479211805105139792453651861428584866033364818684675278744191346541679918674777914698058883725209587"
        "0918149265106456137485286704653323044943850364593356260109867034399495400691418744678903519925194377801076"
        "2381486731478479183022737197451235240098008967031811463223159118911278393762876998825339197552938830249047"
        "44161176495254039764404296875e-173"},
    {0x1.9d2601c0463a5p-574, chars_format::scientific, 453,
        "2."
        "6100490335909980979552265558355493219704695290513080366093465835681490016799462387973765729881171426828168"
        "2417332590133992921463694477503388807139807845292305705181442388256835168226672308962563672964438490805297"
        "3384732142938193798164642599720638713195222674660177386067424332816501896648413308447588486597263343965697"
        "5571046238161474247493645115957000348819974290112611670238924589617136104709839809219214750270546265831228"
        "53844542987644672393798828125e-173"},
    {0x1.b1a83e573f7bbp-573, chars_format::scientific, 452,
        "5."
        "4792243323914630975072406281613606832261951011145665036504979668985390735600110157767758785050009028843723"
        "3069196872688278263180607019226460569942714717248153474281746765628088520324003473535650431537768304962822"
        "6352434526342626991833896405159190457009628685312050850428276694131688178962296877209863921698707625891704"
        "8767076718398953420167969591438265381595345439024715691196807395095536129593152744587067381250994335672999"
        "1137399338185787200927734375e-173"},
    {0x1.9db5b347aea9fp-572, chars_format::scientific, 452,
        "1."
        "0454380162673489713965397325213210055216387987310910537716239241543349829428624537085690812460149858173021"
        "5858895362945461402133653079036345203985491835929817281954592025413065471497974913996205317355421037620462"
        "5461005863476843387305393280877162550277919224926407850550461402739010315434561658615507741623588071536234"
        "7189767875031969711231284078903547104466269425076082101727424913763945754500035848790708990687509105654839"
        "9137682281434535980224609375e-172"},
    {0x1.3df2e64e62b17p-571, chars_format::scientific, 451,
        "1."
        "6069032799845684304837025898602516055352533047665360898514249707918755589705310767056414015917650944256637"
        "2059407021909524012789333201080366212249374842632041801829250909350915204889376556367323396385595859359363"
        "2026744656404079205066647203536888565373193524222234484027163667384520159643669604080393032721274484448190"
        "1820454994441082559588679931543647630524022363479603462003303851739929994528409740117298461041517310121662"
        "376332096755504608154296875e-172"},
    {0x1.3fb9aff5a09b6p-570, chars_format::scientific, 449,
        "3."
        "2317634556278561328898229389131235973792702732562633280991403487915739132162432712906493266003295399869372"
        "9842545240820838063867420776343008017269498231628387206082119219270972996042897891079135898914037979639792"
        "2628678340369132274813716042402578734967764593771810395739266217871863837169342502454420046781060151049163"
        "8476195268941251133713791394315017124881357339068944310325585037652194459172678551852687153095322614149154"
        "1056893765926361083984375e-172"},
    {0x1.b756a80b08275p-569, chars_format::scientific, 449,
        "8."
        "8816113793007975094594031352311578123949416737178828130854708415442420035465070777620177348898079141507841"
        "7796406238021557467994937388956410627563305885106754023883545285183176270892863135364360578393441082982527"
        "6089987266954588114848541270166660775652880062869381533707804994144812325315805417332298566443583361231344"
        "6487476518149284318543738637159669254492391164491862892635863291851603301999049071455106466738138593086659"
        "9665023386478424072265625e-172"},
    {0x1.f7329a0afd825p-568, chars_format::scientific, 449,
        "2."
        "0345160158699940505892624292575175803854303259223972778922037104994094712540208045167546542096546399329092"
        "5568741352851754686883111360672231989108344218909911608003767338157437940100332128954412292965650257298986"
        "2399508197162346096661909599065879618173136942841150302867570196096215393226563365157688113883373826699019"
        "0133804036385605415722207224450777798150430412030970963249225767509927828485208128706060882323614080746665"
        "4223389923572540283203125e-171"},
    {0x1.0dbb0dd4c3dc6p-567, chars_format::scientific, 447,
        "2."
        "1811364732319512379299888562598205651832586862578556577373471722160887631668486562918227829168345226693356"
        "4477152396005065372978045785609586439600163180898405459353425875008497418764842761473430968015877893142753"
        "7144073637743030489800810787461796351034399996774268268113982329617709594542586517687546529900207424315352"
        "9571645636159086028928066553000090306544475559951765315539204235148847117034688163479628705831991908326017"
        "43750274181365966796875e-171"},
    {0x1.f37273553a82fp-566, chars_format::scientific, 447,
        "8."
        "0774068916080526911822864255084323152268934947928782821744873097715265550575551375438531877561394581122040"
        "9981387823919747733730008958851185059841992813660027980133828742374911473631504963198955136372118833915445"
        "9270356424436854717354034107500870354542325791569854174511255863352105517142777144763847882237666874762494"
        "6628127548310914850138612320071626178258920473997347412686438015422955451063231513707035488791596833380026"
        "50998532772064208984375e-171"},
    {0x1.948f132293c63p-565, chars_format::scientific, 447,
        "1."
        "3085617726519541939747154125479359905912083343808525334106458195989110396773558319983334774985646548651422"
        "4001778904513903298081176394305764399493112846351303350353239502484610555690434248628579595201736161689146"
        "6336607580363322588353007728783819901789415921638100352602461638880220153348552331791239223807821536185010"
        "2983913584124516775569012523471486144188013970774833418807493808520624064940293843848631225035283875968161"
        "73754632472991943359375e-170"},
    {0x1.1ce9174ee8dd1p-564, chars_format::scientific, 446,
        "1."
        "8431087174635782043252618133185158278565571369229321208308841340213027211857844123697256040862519901567725"
        "1326726395183648543716289037081590754301619279792859862700397570904034465465726650754241810398171714853256"
        "1992992808930081880678923005030883215333996109506247186677474230868515683431825040191371852399000466202113"
        "7975049434489578580438315462876494403387379133295692106882124354166769411650396731530785615627010542993957"
        "6424658298492431640625e-170"},
    {0x1.3f6d7ec03ac34p-563, chars_format::scientific, 443,
        "4."
        "1328064925321326743823603312867683387167979700016372758868184808065548286026722508349641027855711185659446"
        "2152961711974203123360596743084083781406915821893135130157239833260145924419520141522508884955957878888182"
        "0404459798243483214581582816502707353740530994471599110522744654340322094456670675212886409515158274968834"
        "8421670736899255799425452401539295289292709073381110625359305055039988110166265680798375337090533321315888"
        "3154392242431640625e-170"},
    {0x1.d271d5b8d56dap-562, chars_format::scientific, 444,
        "1."
        "2069870317233675409785921174121444821305867547484647026031802481804471906324306712077013729055445084455143"
        "3999115380573910887578371341979222946847987949711339523886024386272732747418877700383850969235187003203291"
        "0037612444082501641811469305197024541046308746885012559865055123703620520256489024970530609600773121721925"
        "2509953590142701977279265426554214972769816776184129905490996033298708068601791479909982052198813562426948"
        "91989231109619140625e-169"},
    {0x1.e5620509d2608p-561, chars_format::scientific, 441,
        "2."
        "5119843525307733558434594260816051677090309667396793035381864422174122683981429619725915214786050355950948"
        "6239204789313430961464462590490736435598083042927274138263378247661251164296052912696897186466478706288935"
        "2642748759037672326378535772807239429456532155654974325325269095690646913354309930487294342711006492165995"
        "5315549232098416962449358057714977677229240849969698671418318066142700050605778916770760567089837422827258"
        "70609283447265625e-169"},
    {0x1.daaeb48f4721dp-560, chars_format::scientific, 443,
        "4."
        "9132134419173275300225535204544729851911649970165869483463440887839418340380665622292163306488996250106549"
        "1350976425275433250304984863280428171634552315241314266603032484551607070114757965733712324125396174103372"
        "9226789364662827961018036133320427313617289178588424239333846712216532419601164460554698110560287829079138"
        "8448732419818004683184996584630381592680288467103992938091395362608822911344140526874318952721409914374817"
        "1627521514892578125e-169"},
    {0x1.79db46c531467p-559, chars_format::scientific, 442,
        "7."
        "8220288221977700063059894664378227368411242897337007442348771025734261062567460361432757911617862838819629"
        "3795797162626830091814571929935183642335516230967612876521043115431354642305807169176548620989324925775808"
        "7062177758498404099890663358857738381451506168661384596087031927979812839991222673925208238906810303540299"
        "2951541364381739672960888215163802051676603836709312773313559283595797003584392382939671772845713348942808"
        "806896209716796875e-169"},
    {0x1.5eec2ba1c3720p-558, chars_format::scientific, 437,
        "1."
        "4528932941845978123954041823161320670444209002673199194875936774636685005800572366209642420084980102688522"
        "2284771627441317362560849791307952496665289476714272091976068922300999847479343600358850073272097152220030"
        "2906669435860845485433716289821162240358438688669844790169613107356205858019787842075248471375056422020616"
        "5606463372742572760669498115895300190252052394461218022126572921109385011864418429938794474765018094331026"
        "0772705078125e-168"},
    {0x1.0484bafd678aap-557, chars_format::scientific, 440,
        "2."
        "1572028357831314739248769724465999741271766633293079884733473069385467128577256574275705244906939184117582"
        "9038386984094283473151970125795043177080588238644040574776169825974122573988755713447254935101455602327279"
        "7444385837941145779765796154296050920630528440861628624187628402654542146737760578131033795692117902664174"
        "7620343404617522327136474787371783786459139769882545368567133405075767410255971768401339616616496641654521"
        "2268829345703125e-168"},
    {0x1.6d5d28581864ep-556, chars_format::scientific, 439,
        "6."
        "0507342105712640753626842163097646809308860776311719574201719128177872342977742833188684816835118633113178"
        "7469902672162020402460054333735597377259788893050409419567542473760275232535702628013402757453555954460066"
        "7351435740725219890174284399124917029076743181228148661697596212430136719929459778243961595404978812094624"
        "5720008957977972786818679608200766196761709853673787110020335195594341069592956953993034829863972845487296"
        "581268310546875e-168"},
    {0x1.bb2a34ea37314p-555, chars_format::scientific, 438,
        "1."
        "4678367854256142298667827818101418425641171158235873201689619347389131481467218178604900546424188785128526"
        "8336878307696570650647319626714281180108177890970382493324330201954352563963102778896234442647145321597454"
        "4934864973158225723162874678222498197027137108636727761413525838697942842193364203301906166874401738418313"
        "2646072919751818499258993671664303007808184992375802139546683974996661430648331805870476785003120312467217"
        "44537353515625e-167"},
    {0x1.dda66275c3391p-554, chars_format::scientific, 439,
        "3."
        "1641143055571888721675810050989542109785465028434827969598434513594568939907735780944113164818353072371269"
        "1472274425932244055295948253650409847772105060655087817291808653621495733409941136183312201214290111148995"
        "8367027559058113415177240496976939184069245076394699362838845068654932477476209593443045636001585391168764"
        "0813772856068351759540302693121233132284473037020618452899137221945934076678210757072040593129713670350611"
        "209869384765625e-167"},
    {0x1.ae53c827abeabp-553, chars_format::scientific, 438,
        "5."
        "7012659962131172748331801135657757849545869452984033576198099915159574664118824194511400497947243457984780"
        "5462116330084017885988449660823105199629138988659606033366015659128259656868559311576294716708666983658509"
        "1151417828734600815851793300182954790630057074667385636416663954055631149802259850642458557110755505661731"
        "8968904489469062159847604242814589351698444276015868870497315679527347144186144242694602723986463388428092"
        "00286865234375e-167"},
    {0x1.8a5ef719cc23ep-552, chars_format::scientific, 437,
        "1."
        "0449784962477287548783251955237842370155156614682633486401981005538590595074075877132082832649026253806374"
        "5178776147247109081094734941639330363553681011985727972623039202822527299326384345045236499496566530651968"
        "8594839664257358745546726073837195205368734856443137664431116736502834299388928251796513021111914290343565"
        "8352635759488131161489780485873740697437859266638088959535098381735367626006998759136124022006697487086057"
        "6629638671875e-166"},
    {0x1.0a8013bce024dp-551, chars_format::scientific, 437,
        "1."
        "4123103050632778867079410198580307726871240292054106836891157576370049073328446726336757729842328297539268"
        "7130135769634683967418176373335886121724564479293530828467869228845230209513050262924753268824301017453219"
        "4011901728294090601781190078090265727142204298288503540121641833715510263559360460931322723029926320336771"
        "7097431398505056111687252861128855861691714189014884325150929764686547454902946358012982841501070652157068"
        "2525634765625e-166"},
    {0x1.1c9bc398428f5p-550, chars_format::scientific, 436,
        "3."
        "0165478216464074512212005380921449232249896009416388345909558008845922680766679989900406888605168527800772"
        "9156847515877911950031988284153897746333486898789272568844785705133463127705015634359057096161632900627980"
        "5162991598947429131105988549014486141475892089870149610321000309897505488330122362804139249717716232071224"
        "3561484642920486418632362138024921480131995555150640263619194765536340598175053806517809107390348799526691"
        "436767578125e-166"},
    {0x1.472b04c33821dp-549, chars_format::scientific, 435,
        "6."
        "9352686559745381219629204415882645570340784420147777997532775506263318841002038546151778930213422949524749"
        "7247338585103033841186687904998992673315180478385844272679998694228379216159690401411169743129037832534724"
        "3997549961343698246262935026970483997121083598418491471419947499240108314702249560972217943633149438923305"
        "3529333671768056532410769536588940137956502217616423212346252026017570923308377950355918528657639399170875"
        "54931640625e-166"},
    {0x1.6e2aadc8fb08ep-548, chars_format::scientific, 434,
        "1."
        "5523915631659218211654033359396501132440764681876474497751136639122155364971012804370210703738009265241858"
        "1215759342693384516281140289868088753255070953848917975089495962398728196671418875605246865007097905910819"
        "9194200320736265532747460554648315694463585924985028588151664651715814237876462229975810345451375987064856"
        "1867718950564534290667687163868632147450459471857685230728295838544660435309036072837329811591189354658126"
        "8310546875e-165"},
    {0x1.79e0dd8d6d77bp-547, chars_format::scientific, 434,
        "3."
        "2040881224406470104070105421447199363651981713125257613338523327774736749929132144470271088534670292970793"
        "9332666973487821118966580744192703719425525128891426882244292259084076067532193285611697408370057076213402"
        "0817519404294049135074882815764210025817010708368161243484161145536272444835580693740277441857916573303193"
        "6560847200506946165778530591600551545348474288707176758359411167341011404587763911067099797946866601705551"
        "1474609375e-165"},
    {0x1.50a1c6dcbee64p-546, chars_format::scientific, 431,
        "5."
        "7087065996614392467041253154630145625242817661293175265664196357354858848843609759764525139516246750819154"
        "6800113857365848905498771900411790329918307580100153169495954152713830350478046241412786653023542349115414"
        "6722690420836671854852719370789115313287766786109595137579201772327062305581861872141887474541157775863540"
        "8998524829801519942291352361441050850385032916477495024457844951280632243145740645218211284372955560684204"
        "1015625e-165"},
    {0x1.862c46595aae8p-545, chars_format::scientific, 430,
        "1."
        "3233342513427446533220846176980084180352307495935298772563684034576138699777035986613426588992064096929624"
        "4845573413990218913068901383100060791443228776423588462888697503055590150915018973328299846328628471661195"
        "1393315603019845988865964947204500622134618088187057959743436057427473338804629924458598854986541360321208"
        "3717503132967830519046643299291922805519127421662183480103792153741442023939800520793141913600265979766845"
        "703125e-164"},
    {0x1.abecaaaada1d4p-544, chars_format::scientific, 430,
        "2."
        "9027492682223769245463501295368700005473044084194294943260531463212751655391460399814755446587701909041474"
        "9357432786031241406072562727822572506649901334086394861768322314208033554135758133295052719658033386416436"
        "6820140576973418864131397514691999982985832569462960667909084778059718781902132556507382819564321302015716"
        "3424326728187578875387306118496551002665440241638148086882173459801728850060431597057686303742229938507080"
        "078125e-164"},
    {0x1.27363043a03aep-543, chars_format::scientific, 430,
        "4."
        "0050313185332246980379480793530275790838034216130234269239697945665097491937671792280674809190792923657176"
        "8852195478275993329637976842756444979578128393305680093053021087734539543173563658797050864465135277447744"
        "1606453018747691217753280777119448590588588328443857685929471452269672993927502101792232928640358924482952"
        "3991254114083701145132411140665518759135223474616940250607472942846200812672119440094320452772080898284912"
        "109375e-164"},
    {0x1.f9396910dcb42p-542, chars_format::scientific, 430,
        "1."
        "3708394080755749882353739878794548975711060319922576116897896423058078740860088250207940293013167382216341"
        "9006732222086034323894484084689341216849641479224140162706297861465282366851351586406974904598321862463844"
        "7467632641139961223891013812536479652440735884693444562940524558164549745388180146106893720295017931658690"
        "7829620444413074029684670336457955213142348285380185813403038234527882462121528561738159623928368091583251"
        "953125e-163"},
    {0x1.d5c5aea5e5776p-541, chars_format::scientific, 429,
        "2."
        "5492926252346403699480399559723131522475692333126746007271937061542803045775918073816174245595068744449375"
        "6897045095772044904146125927159052272308828398501309068340258447459074741175325962308804749526641331075081"
        "4215616392500626374978271647156167704249652658943675636494935189465329052215140979594908979807630334047669"
        "7056289062895628727450248207182214063557902486967781907977747553301723845708970372925250558182597160339355"
        "46875e-163"},
    {0x1.9eff9de8438cdp-540, chars_format::scientific, 429,
        "4."
        "5041091507036545799166835714074572890973281642718254791920274591194041492121447735125974303212253865292637"
        "9956781548301884168031234796205554552277059391393411410991884557672724397409012081748646328143893420883989"
        "3697531955943794618870985059845862267848439181439589090531245749517761564002445364628152426757015371501016"
        "3957628881209237239059125078916075999874661387134914030492787980695630969951714916987839387729763984680175"
        "78125e-163"},
    {0x1.35efd2c76fbddp-539, chars_format::scientific, 428,
        "6."
        "7276831657939996199173247920738175748428147489414967017255708514301722548148393714375353958474701042207610"
        "6789338814555349198970333778333109059056976956517846868239691306501960145686115152454044713905123500514611"
        "0075237349741554326342899856503196071852473843842388818767105974929475307629768643213482436875111072007913"
        "1704627264173704339529068829140553825452116336982891479634968447435475896734047296376957092434167861938476"
        "5625e-163"},
    {0x1.153e8699c8ec9p-538, chars_format::scientific, 428,
        "1."
        "2036075452964588496228569301122721156525464871926940161129067123147023586573727518394806164231402726198423"
        "7749837183196555799200371216024834938526447430132500567697920492429156919627160529487552376377185441574529"
        "4149576799984302279677976161507766568997846724405958600191220802794683903667424716117063509411388751879558"
        "6940287978563712681000947575682247836826937306646431995714552203610801101030247650669480208307504653930664"
        "0625e-162"},
    {0x1.a972fefbd352ap-537, chars_format::scientific, 426,
        "3."
        "6940271053456158204818523935502210337755894478159207791982138392485477834969511571329007609766637419171039"
        "2759126610360094205450884682246809737165114335090151986083381777065321763615316038483834946612248296528505"
        "2765157487090496645351674079514261542379781046580777315105509837747199023673206838144493261571740029835395"
        "3756296447509425775852372321989718301071508531673976172450162203846416031360888609924586489796638488769531"
        "25e-162"},
    {0x1.cedcd588064fdp-536, chars_format::scientific, 426,
        "8."
        "0377497486029463796907310997887231749986322040492207560557729723370806214523480524090767477875661565204951"
        "7694248285106989633954680376204841270502625916650274862984725526583670182750426489618103622160278962969969"
        "2859802003702012845796674268710432520262677389871132077322222514180605600807095690066984447887518374820105"
        "1435419316066722225251905327148732308104216510737234667068193476021156773647646787139819934964179992675781"
        "25e-162"},
    {0x1.cb43f5da906adp-535, chars_format::scientific, 426,
        "1."
        "5950567846572765244507927820377824901317858913529875732063943109841715337321381611732771703577489536903502"
        "3493796238094804046934236086714128000654855531067412929636750704890697323743904633485510251869076888268108"
        "4279306285811281206887100844614192075426548612302663962004264088177849786782954944307405424456628148596509"
        "4248487469731734128190901062790141762240880188100041952915632764231981810532090548804262652993202209472656"
        "25e-161"},
    {0x1.cf8a16d1be8a0p-534, chars_format::scientific, 420,
        "3."
        "2198008776677365715483088235590941078068129505484886301991581386389243298290941875520546912655676996881281"
        "0441917229942979342204911774403664097134020776067023160848590990575248460251418985831836138485385022657308"
        "6973362244606926901073831212122632895414679410788205226590464932818260131222656038901409342927690461162453"
        "656396066174341396517780764483920907682608083655719332828054092543457187503008753992617130279541015625e-"
        "161"},
    {0x1.27815078c4b63p-533, chars_format::scientific, 424,
        "4."
        "1052288903310634043960832987571931636234400160954032470064104477855048188571156057943012804319643271386198"
        "9257969872076510180980285118874101869727065976609233032449496732356088241557456578015929237728817932232804"
        "8388309232337303750030778612509711908501951809831162651603726739987027097299398843085135417047599817866157"
        "4272744294799819204667879819235963165001435696452328267353628992418490550875276312581263482570648193359375"
        "e-161"},
    {0x1.94cb793c06293p-532, chars_format::scientific, 424,
        "1."
        "1247015311011619164388570519415046282988509125973527974174792513587997406324036881610609032812580610918323"
        "9424576993216500730132779180552061858976096213910756516933563665760090369803621666784511143304283240882248"
        "5088788757268226486530324074227172828587904589966139213296169528291499631970170151695928941760193584329233"
        "2629190240565533263563800574591121957879184091543084291008630540113777396271643738145940005779266357421875"
        "e-160"},
    {0x1.fb79dd59284acp-531, chars_format::scientific, 421,
        "2."
        "8199919854660424181406498611767457424061948125885429858945745962442848819176197726683136969437028570888108"
        "2830040755467647076905556002995811053078143823884675889610939027344604289894269581058754232110640784754856"
        "3781536173906753112551553439539348939569353136479925510922455594220822191463137765761460800308028834455808"
        "4468684208204756019731248859110647696119656846453414657236217176483616952964439406059682369232177734375e-"
        "160"},
    {0x1.359571ef938a9p-530, chars_format::scientific, 422,
        "3."
        "4406501648078402345831943940992850675010433136247541593007126579014461564621507825989069421046377258353352"
        "5266279480436005810313967603484552689107264291271767543364013759019524730559490934549343018230659686062274"
        "2466309500895727273464880490026271211635573150397503406895568336637245126201262342174169526481361294262605"
        "21133278102774052246731966461848087618487349311800460637664395881218926120936885126866400241851806640625e-"
        "160"},
    {0x1.dc1506c0bf6c7p-529, chars_format::scientific, 422,
        "1."
        "0582157294697288713963195158371767274324188519857217198944098155515218457859889527082041394743997571994198"
        "0782617107314884480425902230968999173789160718211219459793393266039878135868700464888388541483290580441123"
        "4276364643529183272406529036702764173345831700785070362277638232538650696886272801586331584871705734800017"
        "93016274242856198979073331588237555754089321977604226135305401194919294738383541698567569255828857421875e-"
        "159"},
    {0x1.2d2b9e28a6a75p-528, chars_format::scientific, 421,
        "1."
        "3388582036266355541959404316699840795114375100648807498487442232547937540767560212253164334353383449534594"
        "6743958644332602294994034082624978656972696903905477947930595101845262918336444821387696088794686692195304"
        "0167045482466019883897788454591971526214814157238791252917209606217864777959421032096816467916409844038417"
        "2836004474854932106579809179603391993269887733998929837348564227117453384607870248146355152130126953125e-"
        "159"},
    {0x1.bfbb91d629252p-527, chars_format::scientific, 419,
        "3."
        "9808070524262983112904656865346504878132939372419465371210599523355680262235845071654587488829808528826255"
        "3211542596573645028294042617979689261030895068039674263323248377753554749934026854747850685855751439106084"
        "4862583279339947687017283592856642221530763984147033229022671292069654536582029312632080382570358728048793"
        "26080897160088621835645648574210621835117584474315503701422926108310917925336980260908603668212890625e-"
        "159"},
    {0x1.81261e2a2b58ep-526, chars_format::scientific, 418,
        "6."
        "8487446591097199941568879338773260958022232603308129404577395366943751087141371095291924550966687048416161"
        "6769294776395348321020638598156727873424656596843199381833408121608182144007626543586767966079553232265060"
        "0491832255616582246035074672018377924273775286911895790270086967708681272931741809331769970454006868479980"
        "1126128292639790394592107549831084067660125239545389747952523762375420801618020050227642059326171875e-"
        "159"},
    {0x1.baa3429377a6bp-525, chars_format::scientific, 419,
        "1."
        "5742030359655316135314019631790472127126364419477776829501394414493294958623139441874916754684678732509715"
        "8991033070315380568522405485975093110902491134901423225555834565328486328064118867427922601658085650759434"
        "7866705253552661370252961676208893318743217957734924116551774986936407789322905691142636861514631034901222"
        "50101193233407172333537545750830117935069349686134489453548900017576528398421942256391048431396484375e-"
        "158"},
    {0x1.9a907771fab1bp-524, chars_format::scientific, 418,
        "2."
        "9202734088397782914748976105327502984069864360599784056489683368011606263857076661142188306671405159781423"
        "1670256843555408784320151853777095713405165964263539211094938101679106092335341904570196983657111607404300"
        "3839001894312185913020143290160018732262249780193598708143728594996072940408519441822653019593776771607108"
        "4536867135236252471735572482767841378465604833111435732133191744974709536109003238379955291748046875e-"
        "158"},
    {0x1.5ce3039935233p-523, chars_format::scientific, 417,
        "4."
        "9631432238623663477546167552731124003328921514474820413997492211106129001776874436254409714844492300472015"
        "9111477138859528039163853994425999126996609683227170224030873388958268153423145767609226993844753478328382"
        "4259195277427492686885377724220076528946842969848256726439179741579269576223391510486187927658224539225843"
        "413775535462042906286635028827134767522968000184340037184670124670304858227609656751155853271484375e-158"},
    {0x1.b45bcf37c8d61p-522, chars_format::scientific, 417,
        "1."
        "2414975541479182662530661958882288430785834775491841525389411874824159995097885756544225128758410546645621"
        "7648773130036540949365023441814765140175590447946206316753149905087898914730214365332693362747497929964614"
        "0492013260693375349748541774845381848399320823459041716554134838029493474244785198203045687110985403998184"
        "411933091955954072991836879522317775602854761084515929797124356159798708176822401583194732666015625e-157"},
    {0x1.3a2690b025ac3p-521, chars_format::scientific, 416,
        "1."
        "7875996042719942144684408823686534589648628475912376125631821356837144462300068766162676042653370244492773"
        "8923771107674341441242397371908288063262833805963550278795611140294172228349290732312168702927741365063323"
        "5640923880607318621527226861884183570539435102743690701331486754067853858196036273816308192289028030388742"
        "38541139810169708202329862942424051508832654330268286681747402777631350545561872422695159912109375e-157"},
    {0x1.8664d335d8f63p-520, chars_format::scientific, 415,
        "4."
        "4428868657860281376359178678068678828865965144798881231178035166970602687133480970061156378529524002809523"
        "7462616854285876469189545810325410817406934099121471189600341416115425999540048866344895066961885974140878"
        "9048876099387012441921979951172011268855276022497405913799786381336671115842409863056361279540698104879752"
        "3362754888079179316205818081708016426963313589920827914418743898039565465296618640422821044921875e-157"},
    {0x1.a79164aa2fc1ep-519, chars_format::scientific, 413,
        "9."
        "6408509408080923610447309847908498668818477504064378536812604606911138032185873877406416092196184093377840"
        "8732022497546793318629212174366316259374071673186690940671105393994035996979527549102248122127114953365994"
        "2125679052983397494126651483669742329979687385596140269710005813496485982376814623846949071924371149153140"
        "14743723316819620786140512242325153138109329199514885809507713787525062798522412776947021484375e-157"},
    {0x1.2bc49fa39fb10p-518, chars_format::scientific, 410,
        "1."
        "3646071402129266218022608455308893034728544720923587430500970464976763025029439675540553811195474237663235"
        "9523834483010519315791469330342593252278915593622431617814522042082490158690280378293849484627353286026715"
        "5225175793585354441642493367039247804878240514821595105922697779865504810971833579265972782223673414429052"
        "93644749971602789648179855297617277419064627585012540456066432170700863935053348541259765625e-156"},
    {0x1.b2a37c764c384p-517, chars_format::scientific, 411,
        "3."
        "9571324550397298455952293967097384825358953198030980159505341889845628196675999913836798970468837187820324"
        "8478294128925979240194223968807640915113276532656464287084729513579896441131394373033593237548328064981059"
        "5159222317626828045607596436841049015855425001023090510787469983857446377619492592718840110454684657613648"
        "987645086834150321214164087322605627281014744584084104339627430135806207545101642608642578125e-156"},
    {0x1.843ae1ac69ebfp-516, chars_format::scientific, 412,
        "7."
        "0692179366582615531567675897574671091761437361338241149656756895396177633253683272883611099990399246500443"
        "7598258992764058950920726978683938929713281967633418748635447629975311846108340480127933613935207582106283"
        "1418275464323041900377706185784736448842459419508045556665132399047286015752324647790319023015284540485487"
        "1979543351655494158128079536161932019562760201123060264938313679294878966175019741058349609375e-156"},
    {0x1.4a7c9b0be349ep-515, chars_format::scientific, 411,
        "1."
        "2035560157157919813062745372089973915433204195518742166387275134267274407820877716584250745353852034461563"
        "9510290947540420847412015550237264275570830129622833566341709883458286591764701770519397372432417712594848"
        "2712272309929483096695073317289136760663753949010538916406220492776005908179269094318962119052575144800112"
        "517791981236689550651499999859263780522026324949400565011981001362073584459722042083740234375e-155"},
    {0x1.3e27452f4c3ebp-514, chars_format::scientific, 411,
        "2."
        "3172816969783969551891233777943526250416932539763293520394005777040356077947428725088477967218198192385517"
        "9173739379747918200529704692932728516243182940513018768265036831234199951980780926608738288565060565046999"
        "2621982723809517078775790931964018019003000211754865589982252409368493331309771709369251704091173604782777"
        "233093007760038948922133043358862285948249785523761316852198177684840629808604717254638671875e-155"},
    {0x1.b9268d67486d1p-513, chars_format::scientific, 410,
        "6."
        "4262723679026234613089358592151495114322567354938475729446594062899894550316581573372400318968212811428919"
        "6470319876282149819515198919937995775425705761798674673066995193119893788442638742100166477114130792519595"
        "0776140684380624064791666341285838548486494556094652195717677079876446559347047552594588771871315680949382"
        "32717074211917422314413953063196922767011329619070598984098552364230272360146045684814453125e-155"},
    {0x1.4df9e0d56e886p-512, chars_format::scientific, 408,
        "9."
        "7301072362246582992731617268110711029353064013073350453998818620182181804740211694728963191497913793567991"
        "1031034017939591604335701819972757665270952692642901948619176904535218754880890639319149166591492630199955"
        "1633152928738414986716903478505634319202980484473770916202240532708166933819170785587530689982280013134565"
        "017333638307204694287737428192204358891274416205018071845955773824243806302547454833984375e-155"},
    {0x1.7d69eb7260760p-511, chars_format::scientific, 404,
        "2."
        "2224325771347583865914578960158321557360842317854318621134693365709148731046280122802494349067538519750041"
        "3130917810364898093092551411950073674123927781422093946252603565097262860073949138157458136720220464476024"
        "9595881705742112157886504025211275233525917071227188614551772891195644263290147759646936048898544911099912"
        "53573791105880281676020497507543159037307514518111428714064459200017154216766357421875e-154"},
    {0x1.d15b6e4b731adp-510, chars_format::scientific, 408,
        "5."
        "4231128112241111883705509773089298055689258334481416666694017403320776689974726528298409316165705979593427"
        "2651133535944542041523246725633760821160380141790144506211196558566480102602131990816837498306875789723207"
        "6504585427720559612691028995704712640626772361153715821779073508058665270716186992631855993540730057277097"
        "798447449807118198421095187366823174718827741476630255323954088453319855034351348876953125e-154"},
    {0x1.3a5731ca0edd8p-509, chars_format::scientific, 404,
        "7."
        "3264353948817245453789075948016247651899446607642030711491920326112691995960046353812600332536813842352429"
        "1656290504702564770688838031055615174036884610469534126066936299706736185979551439500161693073301855346571"
        "2808422288445892090588535812980025454718642561058682378505086089914779359167555255668678072269653119910078"
        "85637914963465670003796036900151548500417677915741432315144265885464847087860107421875e-154"},
    {0x1.fe9875d1d94dfp-508, chars_format::scientific, 407,
        "2."
        "3801222320149624687970238838551821292683756958494975634914436808747089296715116646167927695091570422907292"
        "6369290928298137726435619308975066477116451778078282790249877308178993242493941303767119336504866436159369"
        "4314583580741034633830247502226974735196463810986401237476592299983502726826416248447495090355412974549206"
        "46488679466589507176571074090805100721695650319541248673971267635351978242397308349609375e-153"},
    {0x1.486c8e4f5125dp-507, chars_format::scientific, 406,
        "3."
        "0618730536691985545579000169222995038373293836922890489125504007146208609330137385438091876811492710859419"
        "4560986809112016677495317703714285414101823358342697061863929398148649681794221820608430077282387116500634"
        "0524333371725021719175453309110948816510168122988585283130771853920058975957661080754853677159756800437879"
        "7317284169074057937506011637447702247448555836796535434274346698657609522342681884765625e-153"},
    {0x1.bfab9b8aca208p-506, chars_format::scientific, 402,
        "8."
        "3471948672359081870252474793852930929195495939030283177039922550551126183653446755773285874366359596754283"
        "2502756933262416846096962919049560927597425906971808170555329109012049943787534763467415849596127066744913"
        "5137335706245812851751344457709710650666087089376367629961851390368065008093519365610537666124040492551911"
        "298472615483739376258107919132264624991379871332686235518849571235477924346923828125e-153"},
    {0x1.6e3eb2a2ebf2cp-505, chars_format::scientific, 403,
        "1."
        "3657896771381836370309182418161048341057689712493955806624448243905928334545004278697729898364093587345786"
        "8865313130892630862358886674091915514194799331994886115738707464006492635762748605607064664260305266934879"
        "0678316930885947176435659031006469277337966316027578384047346694343336071347790439049988766926425966011418"
        "1565996765839548397549385581670407344110642310075487415588213480077683925628662109375e-152"},
    {0x1.6acfd1805e7f2p-504, chars_format::scientific, 403,
        "2."
        "7059739547586404103734020958479760826890651200741852274550973101395207195449636437564463046700627498648696"
        "2573403237486822427240404441709874784114954462792607899085616545057563405007609306607813789573026667536278"
        "0471635363727993881117980818158418505372787172646299938963726825437220330053205315677811360493235151514227"
        "6147452978679714962653853072995287764931503400600565356626248103566467761993408203125e-152"},
    {0x1.fbfdc9be7c4d7p-503, chars_format::scientific, 403,
        "7."
        "5775452971095829834740720048137883659078221730037758958977500243027089042030315562065576850353242510972298"
        "8908820640414600991363246465113659524874333368518080485302807469768102470893345904366988820833134850152267"
        "9233594131683886635586807403560296348126596298935394558714901539292174038185034695148230653865497794789982"
        "7035012684127696551603799048515935761914023675867024820718143018893897533416748046875e-152"},
    {0x1.8b6638a74b1b2p-502, chars_format::scientific, 402,
        "1."
        "1796090875694487081840030359311463862270589279053705811580876107483727824962666775311728890626901753646893"
        "1733577855602836561907239918066053974196590031535933155795041615263196884064656501777212660485632917003723"
        "5553003815414569897105068661910842231236269130833379581876621381560616120996039580011757096732043000870625"
        "476753518672332659627018455181383888174151582106663482818476040847599506378173828125e-151"},
    {0x1.d46dbd2abc6b4p-501, chars_format::scientific, 400,
        "2."
        "7949604896251110474468435743440309945288120594039878056554427992195401617178448765891155578587354824245327"
        "2163051998044291731736689754999480979232786217446696064729498506880523647341315312637248430084916512736609"
        "2938786364110450759620750625707230523155311741574527176683116117371581754805189904683589112934565440671302"
        "7853111244031216018263685608830589461614758717278306221487582661211490631103515625e-151"},
    {0x1.12792046e3030p-500, chars_format::scientific, 397,
        "3."
        "2753828239853733863446369582437710222695184799823949849189206166844715031480630276984905665029410879633325"
        "2127316348030245611596414872858686019667951434279227319113223501530777253893140911875570729889382852881733"
        "7051954380499856181898096431741496302183450840154663766232702257784963092897043278167953142643939679211226"
        "3446829491223785021441382997151012842866613095083039297605864703655242919921875e-151"},
    {0x1.91f97f1e1b12cp-499, chars_format::scientific, 398,
        "9."
        "5938032050821536271229835447916874887997484567576901965829125696937852892456863299883609755835723653544210"
        "2841682756532772118758908073143284830054239179665994380300567905166497888249079872424626223422076411420239"
        "9847393492562247437513415173947998719357558940259847465774991079887176648133578620470314414244635744129631"
        "07645174158017020074996772789705377546508324737573047968908213078975677490234375e-151"},
    {0x1.4b9aea9518c4ep-498, chars_format::scientific, 399,
        "1."
        "5828634475728830814843440523506683765688254183130477711430434290240840477584699481675281765446827769126533"
        "6303593028015611137361963891710823183778865940042147787475049837402666312756010315158359598341391818527548"
        "2488775243582874001862476692842480950276260886343365712468475565010191030391942463146663252915623226414517"
        "974202343217299198758136604105901053848697024317715431607211939990520477294921875e-150"},
    {0x1.1106179212948p-497, chars_format::scientific, 396,
        "2."
        "6064697688781666463934826758520573747383519448492866680729950884307524602126143847451988424868593484060194"
        "1716682978957613938305513748932267449077368268937442295833820496383123332506277430625866887250915854592511"
        "1757800801345831269796185208403514964100000121598690191471297899173032180673797887355522464851068977489807"
        "267142354958247478671324520732786021205706905590204769396223127841949462890625e-150"},
    {0x1.f48d4b7371b3cp-496, chars_format::scientific, 396,
        "9."
        "5572143783563679212569396386714562244314668940940271083529053255203811492473894394483995163236935273856965"
        "1628260530221751772117369080803655866703068176768535686143790764735897463820055564420846715137456754533728"
        "3626211301932389420934134356722717872774848179655096293845502516384809908089594305714462025397850425772483"
        "581964588413924537744877269495840494371863282907497705309651792049407958984375e-150"},
    {0x1.38223e0cf2f9ap-495, chars_format::scientific, 397,
        "1."
        "1919359645157150762151885745871298169469988759647520275617530679373213681293098328176454498212756348418279"
        "1181505556016652016850967697539824481686335844121764077022166174838198246329265529449867422827831499533947"
        "7190052647484303927124340167358793615407569077242194702127961550080648296820459406354990529597216843845630"
        "5496010216053623887351146977264459915664407407831504315254278481006622314453125e-149"},
    {0x1.3e9fe67fedbf6p-494, chars_format::scientific, 396,
        "2."
        "4334447753350621478964908361125060043278078662466547499862131283708984042278535636275983077789926684370094"
        "7924178444565748309990660069844962338807872875732613196406804108645775952673011694052762137127630272887337"
        "9411794872081659295112882233786679511861407738863134690326265257013513191916123647888187047926526116330566"
        "078186068092790478450763659348438420169935536563343703164719045162200927734375e-149"},
    {0x1.bf4f6338b1c00p-493, chars_format::scientific, 386,
        "6."
        "8325195696222758262300152108424437528570430091504730873063246196160570278444533395376186268614032140532264"
        "4888404804519145048373433855904839511702044902178408277990112573516429336486994559408882196722920797431871"
        "2051202804979917404513606924385342451021231548098961032710267504632110823167822434654856228970383578198439"
        "78777235944402878039559477534037323920301787438802421092987060546875e-149"},
    {0x1.1cdba81ed92b1p-492, chars_format::scientific, 395,
        "8."
        "7022316670098795959727408762827482104361505903791877283921876903868602415596437465814520086552230400500984"
        "5672509117962584522015252416171153944623922048021811670715197632594303566335424562084952924302166284271162"
        "0992116548640972021637094804825070765198845261168362052582156148171394464612237005333734915500968164199971"
        "87621877146469562458463689321063101213271639977619997807778418064117431640625e-149"},
    {0x1.e8bded2bf3efbp-491, chars_format::scientific, 395,
        "2."
        "9861508065908777159451976047342515240826688859949110638489858234060840988973359424384553665819870965413447"
        "6256943272501564888338028997374032133260948786678076350777407867941949730285495110740536215009936451824351"
        "0024657283742270237945843651504136068975350045379052042474267029695327356093256084645810010718354716697542"
        "68192542916115180944707276419549670486153214454816406941972672939300537109375e-148"},
    {0x1.8a43b5f93a8bcp-490, chars_format::scientific, 392,
        "4."
        "8178117758993382415252081853649016760029538206499370204986995420250082323503440516020366472603862356528682"
        "2407474487671722791487229578768266569205598375311931512631402861579435514639874109138388148482164551601658"
        "9991338662690181015071509492664273040280948122893995104403874967577075668844761974265722111301155846657648"
        "10221611126794232827586086115464157619836527146617299877107143402099609375e-148"},
    {0x1.7c6fb9421797ap-489, chars_format::scientific, 392,
        "9."
        "2976724414783708703425137615132523255799443671421598073694843277985025047735238958873938469833101210668978"
        "7849419886842856325526502716934419983558360032835835080894125849892846465314091581834698079153876328993648"
        "4730102094049772932148827792590711460754459836901369343119647606860551192961236559861883261715726861152891"
        "43456512542275199984831499038060061146371282347899978049099445343017578125e-148"},
    {0x1.fc4d97b6db260p-488, chars_format::scientific, 388,
        "2."
        "4845337797454605412409621847810516244910538112904300134285148151719670450247219375039112563279547871450070"
        "8261201353671779025865604768841322168996196583909997616168972687643361674751144097063023465593797952596539"
        "3871719212044328488997810247788723400358607298489506003722550735501161314071797972142749009847789793383658"
        "4355771901909066274978117572734548357260564444004558026790618896484375e-147"},
    {0x1.27312209461f8p-487, chars_format::scientific, 389,
        "2."
        "8857361527417207852560816625809604310973138050037527355003547400669847002661975613103114130109031618794874"
        "7123850992698667099033685561487362675009968516001114183271998961003820072099355306942878689026849858227367"
        "0224442596264970542245334711246017142526341026122147120651448137089111639290660393218550072182078704511962"
        "93377558772035164374411778261640681986222034538513980805873870849609375e-147"},
    {0x1.77547904a2effp-486, chars_format::scientific, 391,
        "7."
        "3382987425347269650466241166435692135599525604305813942337856931534257940953624331547168348337623202811632"
        "7675134796928634170492220120827081521431892535790219564289416877103465440408362924506713267045825031797854"
        "8465353673947500213159621357227497454897214905553162925688998444394828308276455932000197241734550930846676"
        "6426135760102477320412501970623396496673507272134884260594844818115234375e-147"},
    {0x1.a21026147064fp-485, chars_format::scientific, 391,
        "1."
        "6347598189352821770450540544887874910462748993562374915104923632121430427394154917169330583508545076873765"
        "8921710993603107178696650209105813061398573309841803393393955858839364145480190924253344292068014980758090"
        "8718275496480021313751877719439275878875402393075928784943183580785470118572485534281639981340542519549125"
        "8920008304407477816080785984194194415675127629583585076034069061279296875e-146"},
    {0x1.e33ffe116dfffp-484, chars_format::scientific, 390,
        "3."
        "7793226434705113646355980315406843842730161819232106915137928260298076813313813372642658016571660158177452"
        "3380558558885463980900241817266548165024945160760116563363642163937498191689679806757915110601496243241433"
        "0499266088828954939790981701152596161360776773445374142941503398715913393644403242726936741616261493580695"
        "326300741215037921072531691842576184736657296525663696229457855224609375e-146"},
    {0x1.0d97cbfb3bcadp-483, chars_format::scientific, 389,
        "4."
        "2167773461430841096168944818744711307173047891677654476328304156506561188571555447146574496467644980277018"
        "9032079619071193887326614005453208506142767585099322327607003777151774727915336623087705415153818142529084"
        "2099630456044653627617275033231662411852557050306840891668696221622591255126538876387262079254791476225386"
        "08157385395783430387663692794943115504935349235893227159976959228515625e-146"},
    {0x1.fc7c669e372e1p-482, chars_format::scientific, 389,
        "1."
        "5906736035433478795666492032411048437699973656947142198913549771963049630784995328887755327128517799168066"
        "4449513987454305753588712869415089089334399246465373968206186757087206883763796426378897368432012105506716"
        "9326875666687873260448935727563546153270143949896632947326143345688646515033756768437592665073003021431039"
        "22720410241795394945083183557178740930027061040163971483707427978515625e-145"},
    {0x1.ca4a36bac00c0p-481, chars_format::scientific, 382,
        "2."
        "8672951771554432303752342207397704874686379593615168937776854662187877340530190070806874633750499494532240"
        "8818988088425644366771375033162476683944430496046660877697340757485633491943820158288520141534155518743581"
        "2767248875572624752948053776526726589546868961296725647676685932179510318584450981563941057488017848730749"
        "7168016508884042466468421161973623156882240436971187591552734375e-145"},
    {0x1.12bf051e55395p-480, chars_format::scientific, 387,
        "3."
        "4379041633188433781391796667234074028435987426722232347622158962219748268262338986398326998553663730733286"
        "9261263118140094455518050615101152124817967901873027097068416097734341519818353755672448406009788972230454"
        "9743586116310371815207363078165968507947562208219568651368309624970888523684513951862673701624317481637524"
        "015502112241292046885060497592168093916598081705160439014434814453125e-145"},
    {0x1.7af60d7aa5967p-479, chars_format::scientific, 386,
        "9."
        "4838962310135761344092396167333415391569688763220398309454881231605306514746244823307718893899616717980139"
        "9057332623091728034184656426130519076454149994764188014351734458633392258002552377150853127295195134676491"
        "6390419819472756495777678716502600107256209456679635005594684631820296766940686808383128006043474601256098"
        "97815494060316512924194566440394549289294445770792663097381591796875e-145"},
    {0x1.b73357a425a97p-478, chars_format::scientific, 386,
        "2."
        "1982900216496951912636237517321659702670798815780532692828188834087902755885019342613033041567821756664960"
        "2016365783841795080898673546344147158231616257438737990978384536904134112934509784794056796055102796462400"
        "1327053575991226081531574192187674082752085759776287241663068738388351272800591961971565145686989428887852"
        "50819213532101900745451840933630816010690978146158158779144287109375e-144"},
    {0x1.cba92c6e719eep-477, chars_format::scientific, 384,
        "4."
        "6013959285449562218784849796417406268924809275050240965117618538701248742081787894298428024850220631495394"
        "8843090919478937616929128000444092637251029405884356250538030864103321329060205766394419703651516351399195"
        "6339704480986356625598760310779666153618027622379329597990176509872185236937051592948849485535253991494778"
        "196501116690165993113720808993516442342297523282468318939208984375e-144"},
    {0x1.8be4634ff76b9p-476, chars_format::scientific, 384,
        "7."
        "9260896178364885712586863338954190885910769204002578873260609825376157123972452672117034283698349000727217"
        "8811914952940248175221547710878388778883291965540342485837401637947057005394455813653078713555099106601674"
        "0526456787922005976420018108523974718072488216371523207019836445781599000049045968896364821326508004681718"
        "328980102387774532495348135674451128807049826718866825103759765625e-144"},
    {0x1.195bb1128d351p-475, chars_format::scientific, 384,
        "1."
        "1266048743457620018132449750109616902012501552632301028746300222772300762831245282635755871042079935221433"
        "0397304252105202227560938436270619441940232384938913439609896370609801593025643499862217542244084349248920"
        "7365678039104096653395735733434216596882709167520981641503247868678058348447755344979159303793136769657451"
        "566731575139884695914882679901314332937545259483158588409423828125e-143"},
    {0x1.d9582810d5991p-474, chars_format::scientific, 383,
        "3."
        "7906989762760977010539296420204713197961323178556125566473600056453448874348023486668990302113409067507642"
        "5512666375287866720556532018498012991417750946868079816281685420092627374913565047968810228895304309081082"
        "7776483853652208363091961204475009565583127525351886644817961845159699988605135294441599824142042948767636"
        "76852096147815252970649825547955202864613966085016727447509765625e-143"},
    {0x1.91dc30400a639p-473, chars_format::scientific, 382,
        "6."
        "4364586827198767306358125396341809950796993470218142142343574880083891301701589050045580411828601056066543"
        "8578613541848555355275084443348178823538223876085347005568276012166754572940813489866481451272426938454005"
        "7688367320099074111805095744115674497205307649349993431268929194537492248042883602140585143587994761332590"
        "5648050990408162049774727642148519635156844742596149444580078125e-143"},
    {0x1.bb4959cd66718p-472, chars_format::scientific, 379,
        "1."
        "4199943377251187537949675350005079423187700022228758326221521640526029521346740953695783399936936600872287"
        "4407753705401513284671140970518928691753252515077837559669042688180179223137869737013695121637086330367906"
        "0473230296854766707360327968674338036515155027602470266905967351968056368459849948118636405588195957644242"
        "8067625960673098033625050273798251510015688836574554443359375e-142"},
    {0x1.cab1b98b3b707p-471, chars_format::scientific, 381,
        "2."
        "9387007315399001337843467140701947490646533646383646741168981933069251261075266021456186550679433594978996"
        "7239321904345156747275229367729995831822884324397633531132361947458460677520772536493144275246577960215862"
        "2313197512447305365216189939904546876264703794084991693455204003412709032881758809299262428136448855311663"
        "929317040733753824545242128163380357364076189696788787841796875e-142"},
    {0x1.513f97a6beae4p-470, chars_format::scientific, 378,
        "4."
        "3212757508195659485508065379853979844500716301246743150152785223009553880036241184640287335154013264357096"
        "0952043271132202966879024207483585271608519582168701354278018371563475097472078209541866054396550301840853"
        "5752782166921273364856333578679926605858330352242829232861196385760569862934221186030844482600416992243969"
        "322617877399178251164590935928799808607436716556549072265625e-142"},
    {0x1.23ddda4aa4f46p-469, chars_format::scientific, 378,
        "7."
        "4795674901009501599687387979276428028217065964050376989668893383691257823806867042515842078744474517031407"
        "1895485469191115831640711419412290132762704670408024637792177786766340048068468354031068962246601535160186"
        "2349167111369075434108876998189806009451657247710719467572422765836922739389375015650257781352180780599630"
        "217854761888887876568332568893993084202520549297332763671875e-142"},
    {0x1.37ee070b3fb77p-468, chars_format::scientific, 379,
        "1."
        "5987439857085749128543979468421347404798369339619842909758538091544906123513224004714621004604317341155476"
        "4830277704469716857696790698012386358199581778604043428049370268894875238346646052337439645510118935311304"
        "5871567381746415270150272493696335723627439701097622331692153552932290372744776405111128360907502878298528"
        "8180585511628949125194354419221554053365252912044525146484375e-141"},
    {0x1.7a3e814f7c455p-467, chars_format::scientific, 378,
        "3."
        "8772543479398745912495310674542245392251289103259487422362584185221005555927613777493177235835548528117811"
        "8302432240933992624204868787463842883298566251264050405797426114438754525206002596249474935519087677964390"
        "0013313472242863345433568164189149550863949526447244598726165343683113264168124346368742549505223090492057"
        "351838011423203673479209729890726521261967718601226806640625e-141"},
    {0x1.b008ef4139a7dp-466, chars_format::scientific, 377,
        "8."
        "8572904580841789614754232711686396959759290995923259860158443209002812929627074824889999094798269835513254"
        "0998845477274750334005664050117293551284426384679313859709553221587795313680157822564176364684723674516690"
        "2000693415871071595853995191227910934758948131752454927512504000367582800588546292331716557590430260551314"
        "49871016536323016683784903335663329926319420337677001953125e-141"},
    {0x1.6a3ceca142f25p-465, chars_format::scientific, 377,
        "1."
        "4852721614344735437292541639963060443263141102043656353372955189549517666043979043032187958942357980893037"
        "0840252848547401622923075567638582241455382956074528344237666272700101153478685493953250306368486765749182"
        "4332905746273268182840421417991838003237060783473024229840428934381790407194987886288409466183411626302457"
        "65429564945800410859233497973264093161560595035552978515625e-140"},
    {0x1.879c5a128f335p-464, chars_format::scientific, 376,
        "3."
        "2114166221217845174327447115992392374668964402329268800963712003830340521992537289583647041045528110284263"
        "5303499515391399834686408526191662512438001577893564043814181085298234246800586801045226636006748241313130"
        "7522786571652361908511927539092360053210712569816779695997967844462040278748911843877424273521146041902588"
        "5846797137206727786040705296954911318607628345489501953125e-140"},
    {0x1.a13b758752749p-463, chars_format::scientific, 375,
        "6."
        "8430533321006578298315622206827888634375564457496296600363690350980619762819624331006890836920053795052268"
        "8370402495113279403328072887329458087656201260342686767845714173996590984304971343366016453921898634106206"
        "7674396745885910406868827681945359154367703453121597743174729503689380057241534775569646829196396378247871"
        "130136170076470499001874969735581544227898120880126953125e-140"},
    {0x1.dd22c5548b2a9p-462, chars_format::scientific, 375,
        "1."
        "5651071039519719751268946730433209491685269599788420485953219030692473518449901649555366566818121803846373"
        "5680904417760697692262477792647738252648295215490091671889157286396107620561142080138411428231115221654909"
        "9455747381869282054756781298103540835711990016306871443323392685777042535287304513633281869348053796759051"
        "449311207979673589429925328886383795179426670074462890625e-139"},
    {0x1.3a466b3b9a35dp-461, chars_format::scientific, 374,
        "2."
        "0617783292012132110048484524577034708763801812806846889421937147593782421046544694512376644429350834218531"
        "4226530713713824082127126656554247991288683437918042715199973601623635055616074512412883505084857003066123"
        "3050190132621333636152617574413419624138051138995646737549047491952163495322980116587422304830212863807167"
        "57918646594494906099104269969757297076284885406494140625e-139"},
    {0x1.af63dcdd336f2p-460, chars_format::scientific, 372,
        "5."
        "6602054122048727921826190049712048498669146495554482077926052213769892391972155107823538731408874729899034"
        "6792194827829660599641240756981656489830070688868731818918413640802502222925430134747083688070474879030296"
        "9738046971386503460831112186107202194534175784137625129392628895158265668499896268624088807818901523078678"
        "889008399162559304063080389823880977928638458251953125e-139"},
    {0x1.6ec02ea745f7cp-459, chars_format::scientific, 370,
        "9."
        "6241634559974588550470031663368349943378831463927445452058900881064926118183848091052345386686684876344532"
        "6161315986809133600636497090313419475443507804928279463021903686529521982727237277282770740989981019500686"
        "5574824665465743137968830206089146401495465235722508613312222305895849308346944245441317410343774024309939"
        "3609930015773545886048623287933878600597381591796875e-139"},
    {0x1.9e78dd35e6f36p-458, chars_format::scientific, 371,
        "2."
        "1752909285251191697648113699053702637727489520541042360582333721279125948156690408463090424584646923549518"
        "0942992131659468643940147628854434370427060263285244175515322077650246922688324052450302930384427072839475"
        "7842492386837881192332322824075015094377235565634494864419445464055485911488407505261872310932269115328920"
        "21280816813831593403705255695967935025691986083984375e-138"},
    {0x1.9a585f80bab85p-457, chars_format::scientific, 371,
        "4."
        "3072629120188103249512398775746221992085610716624708892374467991779261742776439264109609536390646567234426"
        "7525349801934937730247292561608380009185242796805519587479768507806463318749894112461752099897976376679226"
        "5859716833133142309161784445679684796923222134468302918127430999767436216601957379453800307851317225326157"
        "33040986549275130901293096030713059008121490478515625e-138"},
    {0x1.a6e65ba502986p-456, chars_format::scientific, 369,
        "8."
        "8780896980845694512355699450135667167474608494983516478858968409659482574692196941169154704757494026767065"
        "0881004269664970292068439515226078190024902892002557556809749308704779003267551048192576495608146500136488"
        "5058786848795066433476360168510321692410412462444936724066019551372571776922263017000926269477966339109356"
        "079124769044186304967070100246928632259368896484375e-138"},
    {0x1.2041239e921cap-455, chars_format::scientific, 369,
        "1."
        "2102860505856427441863506911416438557648140836421513056577062373671144072180353513990930639340259058767237"
        "3257099356704235139962445699680300772732754695176822292468996066789589373242949311404414022027874115262780"
        "8785308312747064770780467959018293493486808663697190464543529527135601732353052334628323918972488583866538"
        "415926878032025104658941927482374012470245361328125e-137"},
    {0x1.e2c2206571f8bp-454, chars_format::scientific, 369,
        "4."
        "0538881189604874758994800103224482110424419984906922206717025596060356483137003469609681462381640957524317"
        "2911889262541296693730039817442824706217992206174740879595790963900654804304187742835595325686164988374589"
        "0322213024653290007771883621311168396610036064921521154842858228344839533773793548383142400170080167454900"
        "059158143070525692763794722850434482097625732421875e-137"},
    {0x1.264bf10d7be2cp-453, chars_format::scientific, 366,
        "4."
        "9426210322338252635572061070906968405888216870034632652951803647003944472039593835210475205592373220399127"
        "7018801884718299712534752193391140108918824839767655067751800656957226981466137842744520790572580634924148"
        "3459928010949501467461950221909399691687985514158948841431923008834959479285883564251332461521178735704628"
        "190938091092387907110605738125741481781005859375e-137"},
    {0x1.cad3f14cb1924p-452, chars_format::scientific, 366,
        "1."
        "5411744957634478558732875158007911309742643791263152383028800246394250010301841139543420118207407753920760"
        "3218589797015836084381494407933290832598692742653536345116174588473355663138399758752109216617072642962120"
        "7135842117636071464132112769695338048041137489524235515090494741996883492492346460319710822961304962419452"
        "460110382008284801713671186007559299468994140625e-136"},
    {0x1.4a043fb92141ep-451, chars_format::scientific, 366,
        "2."
        "2170106143596450609014218157804357964381470241171242549541903911649755928696395840283489106316089146427743"
        "5062966705933777580211869707929056934148231613404163981973357636235389342669699272984120998848954292369787"
        "2554428392780018075983672770091316945354715295754269008522521640290584844958554224663146563346799785217835"
        "259873951636588884639422758482396602630615234375e-136"},
    {0x1.d91f605f33ee8p-450, chars_format::scientific, 363,
        "6."
        "3567575408975392743526724403263859606835265005008746398722782311228825240165088104697549263316148656313234"
        "6426578332847489634158927173716225287463270003583594203279044269022582967257937898723790101285177867709597"
        "6655741399044978428732881345094886140578723570628664975737909788927071910708005133352031145300938446489913"
        "435412388853507081876159645617008209228515625e-136"},
    {0x1.653fd37ce380bp-449, chars_format::scientific, 365,
        "9."
        "5998267065455804136465170482547947366999684488969626917464974228247748059445435327953748521367236770367453"
        "1451560088375242660031278793518034857995227061963548088366069731985696736508405628059744476431105501074451"
        "7632659439131361488912251913663824732302366424969441750856521571686454336063947389316836480712814735548475"
        "72435787250721972441169782541692256927490234375e-136"},
    {0x1.ea583b86883d5p-448, chars_format::scientific, 365,
        "2."
        "6352597315051091964713257494843957096579268453980939881002664775610008832253360604307895378781817021575772"
        "2131262889797575381102714481443132987139497702786597756696037753098692013672145953687801073867566319294992"
        "8316534778995707013335990382676469114470866914005971164662199459123732837094223290390067459830854578717031"
        "59650651759893236203424748964607715606689453125e-135"},
    {0x1.9caa8f7dd9b8cp-447, chars_format::scientific, 362,
        "4."
        "4355852076232533703967017722389898945821857225058681977965240699080262887084660386234585786609389805397653"
        "6231928757581244511544360492016168686756363796237882797468921698797356010241314741136892145667049203620013"
        "8721847402285626290068242713216335744583762528489836802234047080678004035672934625936455690987526985520882"
        "90749606525054105077288113534450531005859375e-135"},
    {0x1.0b26a7ab62a03p-446, chars_format::scientific, 363,
        "5."
        "7429993366141817840812479753542746382814749094420490827347512947579020362059688082352895775572141852211758"
        "0909348864872030450848171956721649351848205979835186312573993891506062416099298516603424161994426165270037"
        "7907106153840215329576081676331897976487016666661306584555944953024603245394667724116557668613623517681616"
        "016498924448541174569982104003429412841796875e-135"},
    {0x1.694c9672ecb8dp-445, chars_format::scientific, 363,
        "1."
        "5533843624429323819438527942729951888826684224818085321658052959257745308554358873724455989172691764656869"
        "5293047034140544314292313264389433797659762881589730183326362518440901757090487907181989255445273967251973"
        "5593544269570691464381471936515939828758279599762414292837467494719157630828112902620254122175049117795947"
        "993016236754471037784242071211338043212890625e-134"},
    {0x1.15ca8f95f7163p-444, chars_format::scientific, 362,
        "2."
        "3886940472478101815516002304586010705250369950263278520937586735205575920300597436987445133566199723253520"
        "9056220889611772034033406268425620639481665338487162539900951615422228233639702916913751658371808451818416"
        "1750465910278224501683266661880297864234626506047662879560009369157585287147781138669192147467158593106463"
        "12523018774953698084573261439800262451171875e-134"},
    {0x1.1c2c03dc16238p-443, chars_format::scientific, 358,
        "4."
        "8871215235872988435170790037236813375378604405677194217241718090326866560500874834949274333014957336071556"
        "9022758867015207526151988895553482901234999063630370884845462854314493655716813545090738801982175971799897"
        "9421127360512136790705971320293037416921996157365427902453505027610932303474146785641141022275140400955070"
        "0580088999913641600869596004486083984375e-134"},
    {0x1.5e495a5a5b735p-442, chars_format::scientific, 361,
        "1."
        "2048289504187995891459061440516981076638732120771659218926621650385434481812842556576460656624351028821905"
        "8966625819337939917796520503670154154436651304901717368743143186394807699935909156584679015642358410947459"
        "3413689541976548679931460273314635130483027907981785192792081387152832558721199653564067984309737744271471"
        "8438765419961100633372552692890167236328125e-133"},
    {0x1.810f44c622e44p-441, chars_format::scientific, 358,
        "2."
        "6488657681982224362975086519642031326070653599531695491298942136575989842374130913957574220303933630452909"
        "4287691741966627719771032423495762254409444179311243835772567386195458292994705194115642989850139200494159"
        "0588928963306893800268427406521691881809325113789150170542748396344959084162370306735064676678771923231964"
        "9187434862369627808220684528350830078125e-133"},
    {0x1.97653902c35a8p-440, chars_format::scientific, 356,
        "5."
        "6050315915746605269229572281796709012860726683120704776540492198506714810181021008440854108255765850085384"
        "6529071987618814344910087704317888361861949507041571302535319807153374858734455612866387542618405871469146"
        "7962651372264615689058812238015769309640382466140672015426133338338772381569455413477985178391665863290374"
        "56071233691545785404741764068603515625e-133"},
    {0x1.d0b06982197c4p-439, chars_format::scientific, 357,
        "1."
        "2786580967537967393170156267226710383127074452677704468202081316753593149446278054272379462839378967644636"
        "6320800166067176943939047031161439109805642265774803971575385755561407104084377645079662000061709133084688"
        "8569611013370819364101411249570919954868002270900165871976213924414176953438451896858275740510024279521401"
        "890935550227368366904556751251220703125e-132"},
    {0x1.7ad59dce3307dp-438, chars_format::scientific, 358,
        "2."
        "0848335483911190942323580514455303482680343446709325008703159284449727956557371856834417264871825204784953"
        "9318713541842166242449663027334071210292408400120764346191285493915664731350155622020867542388811251124441"
        "8594782642109557636315727983442346610806562372007733240534067389665742275872183681831213869255187963209097"
        "8955449855902770650573074817657470703125e-132"},
    {0x1.22c47def048eap-437, chars_format::scientific, 356,
        "3."
        "2003528362030216678821821948371825837897558579366430203164885731689848020333537717135124881473922701620992"
        "2888692730907506242357242214089838597240338986102464283276271560347056644198372344751496698973482209898323"
        "6068759470619965482251995605014430152608968389315404259797294622728604564411967070087013194247143227410060"
        "11785458440499496646225452423095703125e-132"},
    {0x1.d3be4f543da5fp-436, chars_format::scientific, 357,
        "1."
        "0296499233307166051409990566706604558221380043891789602456125181542044296852211953765862019485098933960139"
        "4420734357402502486292275942333853238461193404309849063372198452914528639370611863498197972678354451284120"
        "4496073458814758724065894241925219977128262975118574813009362420632733150442614970604109796889529120935379"
        "002954590532681322656571865081787109375e-131"},
    {0x1.fd62fa30b36b6p-435, chars_format::scientific, 355,
        "2."
        "2426394767283500572344787579772127805358981710503513931978178996544410137352679575618851857302903865882730"
        "1751992291035654960112926310959345577460789432200950261826623585506549029505895986246328713415363125428407"
        "0821805771156523871968356216030311242150331649720790515554019625705236196928987062872353517240543707960548"
        "3585709180260892026126384735107421875e-131"},
    {0x1.170603dbe87b6p-434, chars_format::scientific, 354,
        "2."
        "4568729171490546923419108015884002973420344879350156891911357332634520808703214918225650257080313080960162"
        "1140390889672566806744097301945489507607449341174694978874620449423462236080322660186527317970438773249144"
        "3371566819375998762229137926757890994877314033084529060250209190344653250494453969941105882736470645243131"
        "993851193328737281262874603271484375e-131"},
    {0x1.77ea54b4399ecp-433, chars_format::scientific, 352,
        "6."
        "6200607960369036504168364221207739485773877228613560172975009101038528445698754193218898779976326154511917"
        "3363842872316641841962349364203859251798613207224032137413479473949030378760712878146559509391806548214262"
        "6133671636697690281002255506343628331447342616711548975819904164047980593449147058277505601860937669428386"
        "3429291159263812005519866943359375e-131"},
    {0x1.93170d7796999p-432, chars_format::scientific, 354,
        "1."
        "4197241995605936318075317043001757935035457049201291955866575822547697829794624951982915510254185587423055"
        "9487389305607751617582700679057839905945613876060209570099889526685608968859022154545165173060918859596578"
        "4720429445370267692111528854939925241769500649591614777352662374519950927507309951396734409084237509869608"
        "206969360253424383699893951416015625e-130"},
    {0x1.ff784c52bc952p-431, chars_format::scientific, 352,
        "3."
        "6028982430553334107374243676082305559955741670713515214432745189797018506318167441511937904497465065161068"
        "2213475903496748485769939459318413756361660218138899061663084963748999691972507933997769029036491031713027"
        "2509703637802374239144100499997431894236097897299940723946702573929557957332859418318120851204621000324346"
        "2693944820784963667392730712890625e-130"},
    {0x1.5af297257d112p-430, chars_format::scientific, 351,
        "4."
        "8879393706963279061651865580809295809985896396271068785213668870613554247017676426461356877587014324609933"
        "2229707765029557354523950224816865264246462861886095699349276602653803989153158999090858568594116436322403"
        "7664050403023168762797067327883280705896601134110886320862615955338992676555453042929182604106022776158102"
        "516319559072144329547882080078125e-130"},
    {0x1.03b2ee82074fbp-429, chars_format::scientific, 351,
        "7."
        "3174892255233898487807636785800529379525766260573968879990028870309082137226413786970703775409476682616810"
        "4680726241144403907247560017629565271829849434655181507428399984635472560338317561978206370575594884945710"
        "7129514927443108698035930496633435099731335354533972538276537731498433942868404311764137596868821065976273"
        "843034505262039601802825927734375e-130"},
    {0x1.9fc2b88614a46p-428, chars_format::scientific, 350,
        "2."
        "3429620296922070165437262528679235149465662294858826443217125037749387447136789889409314083302682771001468"
        "0222756477338010049488544385369435757883115124974928734552290063202520905298185016474992670850977943921244"
        "0228311467969508963451461485549943141147936657095208040273361231910217912547166432836108378900052615079196"
        "98260593577288091182708740234375e-129"},
    {0x1.1c19bcdca8429p-427, chars_format::scientific, 350,
        "3."
        "2020192787585524090907938204703897171601201083956022918880219758055616705464752170779213045668342297853927"
        "6218514141557210930831458346531846588992803118289362499502577922826432688268564989495048351325555007141628"
        "6759032612040821481599308776899597909970425095316884308438864676280665908537781294443748170602858163502624"
        "22247396898455917835235595703125e-129"},
    {0x1.1d050f4eefbe3p-426, chars_format::scientific, 349,
        "6."
        "4247592636344160339866493641672423120493138167713318610601027318726114587010038633956202506757668116896117"
        "7536260327713435210153350074908844036866886983227957128782764805685483552587503499283051807011191846971140"
        "8579142730695650817051390788544338188841755967937911393061842504818190481891870009980858467139430006964673"
        "2254113885574042797088623046875e-129"},
    {0x1.11c71a2da956ap-425, chars_format::scientific, 348,
        "1."
        "2342695551721854116452683863845499880701888817578316467000565057081031681549617905907560256885144592305226"
        "7240083781534046249220963683438736274553173251428809235268476409175105649982640214427984817459457410804145"
        "4897293931112550425507422822024993325841784631941211847062895362538601302639805927337145199863994993183524"
        "684354779310524463653564453125e-128"},
    {0x1.ee81e63a1dbb5p-424, chars_format::scientific, 348,
        "4."
        "4587660431030845738140444950938925800210778297935183932030487301692384916913432314579352529747020633396157"
        "6718982792226559730910116675387121867734619940500817757656699817860412688243739129436110739866715672133838"
        "5429894258111317173503504684713165635003661117654688712321287868251005918630130709379141148930754401380482"
        "931926962919533252716064453125e-128"},
    {0x1.dc836471938d0p-423, chars_format::scientific, 343,
        "8."
        "5930403540130827014185033574850155045437600585425997369866718416666609027827328902822137151134768600284621"
        "6279124762562562326885970331685674789827255964644127407691554650046050256430460386721430959519718823793955"
        "1008802980430695929352329472514508171419493761170181627352450560922451007920075807096848500427066497309169"
        "7902418673038482666015625e-128"},
    {0x1.55264a312e91bp-422, chars_format::scientific, 347,
        "1."
        "2304010474281754010997831364457453532363710534547555388355590377279653877735542614715890519378694731622300"
        "6782910963684928592070655580364056608821698264700123403236140552502228229389995505527297808002861636424769"
        "2131602981552825675357276743670326242029680867553906299343023194677184192076335608358703832152999946281113"
        "35259745828807353973388671875e-127"},
    {0x1.652956524c153p-421, chars_format::scientific, 346,
        "2."
        "5763001930484683121866989543781242187607596461670705046008890509721150477966409285424037614285381953347765"
        "4997259597310460635607291805673065230273042570734235752898997793752366928544966510763348120931402869337506"
        "0230754644492619570048227210977560174685317157897957914242825662416808322569345838414941963958465498407690"
        "5748224817216396331787109375e-127"},
    {0x1.0a2b6e525e678p-420, chars_format::scientific, 342,
        "3."
        "8399042293533291316095939321676303114799213077840440281919805704609059805275974287633226980837249931736591"
        "0044710145437381439295690008968031009068382843451057480056121258710576890301225315461825406976833128757025"
        "0854349786862226002299989130792880255411596025381026026745679225130052848864003625387812494718087208411816"
        "391162574291229248046875e-127"},
    {0x1.80f3cf53f1e56p-419, chars_format::scientific, 344,
        "1."
        "1107053483914006829775982286940992882599488872595391539303723414330261552652730527139790712226602314231212"
        "7419956658436525690382907755165110589877692458034515109141334121688675583164152180022072392038346677920997"
        "8618498763060489316670378435241139862270569941618445758195740528710132038842602464041533659108718090635647"
        "96815626323223114013671875e-126"},
    {0x1.c6389b5e53ad6p-418, chars_format::scientific, 343,
        "2."
        "6211336846809098773276314685119387768693234190106735856477190922246722065339865398519354564344593251621915"
        "8248983511966078734456230097679988912873164107313981697736934498486708329908151477908573290741613410601556"
        "0829130407628536830946616731021905982268502134836446565495063653291366241897645429462270546400182169577419"
        "6996353566646575927734375e-126"},
    {0x1.55b26db32be1ep-417, chars_format::scientific, 342,
        "3."
        "9436012113465104438175990673990938076352359286600886903149796902820550632115347356375237735627780655402675"
        "8184464885274554100597829193095879346435654863845212628185087858146802889576223211174464307298442034499394"
        "8110429433813295989818119876936942903021691744560733604484421618817074472770713269558092405053795204139532"
        "870613038539886474609375e-126"},
    {0x1.e8a41e7181c02p-416, chars_format::scientific, 342,
        "1."
        "1279031828486725368285162812517936169788860166634935888590711537150219574688036629032895212853463959440650"
        "3650154654466484722168943018596890328292712388739910978936869648015362134240447110651890664773510091035844"
        "5188415389113650373815757025479195624246867750482014684485575007572491946959890442186741528474147600036303"
        "629167377948760986328125e-125"},
    {0x1.2667eea0c2e95p-415, chars_format::scientific, 342,
        "1."
        "3591220818753578967877485753540957219846849806734534544651217267891770002384398001643363339942878637947316"
        "6328302358041252417529977510170575717126095134299788618696349062141833073414504245591187769088276321436054"
        "8305459034386167488920945628442896474526151212066690180059060509561977041122748851645894198336694813633584"
        "999479353427886962890625e-125"},
    {0x1.ff118baa5e05bp-414, chars_format::scientific, 341,
        "4."
        "7186848778189670994069605940876219782781216914711086309942798924493013128851790778946762990913058749981445"
        "4055147105208148185524779392795023211756732677794200342825699871430136909959253091552973875772042184950963"
        "8515139692290002872112044140465990852885558676453756553237897954025802506482414042289106823058197903719701"
        "57139003276824951171875e-125"},
    {0x1.fa00c13d0ddaap-413, chars_format::scientific, 339,
        "9."
        "3438288096510300708206359179854147909888509692470353687641927888677731435274230558789286142542238872497991"
        "9291642304056969254290225288534313592005499287342065072705040637147124194333306505257478080943345820147523"
        "3518790218936634917638256885277056259540461483126252396164441218119171308576411058848150414934963237101328"
        "559219837188720703125e-125"},
    {0x1.665b3a489008ep-412, chars_format::scientific, 339,
        "1."
        "3234786366979427240557035972871836642676524574733744100764337150714243649312395488035954592443876672160155"
        "2453328962421458549925648630711638265850295574292128380162020867890736183395718452916357821887276692711606"
        "0686026545609252412900499832587222722510252054321150497353766705080322145596004049998388463205145626488956"
        "622779369354248046875e-124"},
    {0x1.cf3a6f79862cbp-411, chars_format::scientific, 339,
        "3."
        "4215813214105460697767882447548971368626256994487285819832925973102312220381249502362412524582654137714631"
        "1911755533093525433960566479878897896249684215009582527023317672508250867310488454244976076546569023883629"
        "7191957544621034981392176942003185295012273726522451681136015314107273762726204980959797408157641029902151"
        "785790920257568359375e-124"},
    {0x1.f2a92a57319d6p-410, chars_format::scientific, 337,
        "7."
        "3665992405027932576502815813307644287807305675409422460506005018551902720267819605398541423809769647828049"
        "9866977319501776335044121496578337140066670655016184682180563483630646645866140852592448554624381952636290"
        "6038236009913051704692368907667120951434121614917932393108410626345799351846363141934487250850338568852748"
        "7218379974365234375e-124"},
    {0x1.b4782f812a1a6p-409, chars_format::scientific, 337,
        "1."
        "2895722651891137630425330384438299474095155094770258996582306778094406533114323313551750471068869202418567"
        "6514306684322130376192414829153873010105653873073220980942636936455031716866157608940595168933427613117398"
        "1279045829482843002519751437286808742894695158893832137633512513924892098960289256708716676413928325928281"
        "9926738739013671875e-123"},
    {0x1.ee7af34b365e0p-408, chars_format::scientific, 332,
        "2."
        "9219365150591819869806878286596392558866811418403158078032655046272755506560359880667466294148560229158569"
        "4781151191877485626592838708956568599966689642307979951883892138750321041592672907937811096196078953938914"
        "7880920600844784042147871987802138706797121319153428637095263913657634075401623927059624463709042174741625"
        "78582763671875e-123"},
    {0x1.14a9643bbe260p-407, chars_format::scientific, 331,
        "3."
        "2696466282687585616618735095593104865627521210668173946224068440449703487453341173667423751071123364783968"
        "4085354894924673886100417360021334173102821673101378406750581340715944228625674542170598795643367302528327"
        "5837865087998562936760655026168055781811414767475009002774837970555003650418701005575528029112319927662611"
        "0076904296875e-123"},
    {0x1.0ec395f04cef9p-406, chars_format::scientific, 335,
        "6."
        "3998932062842191571304885686437603344672159589284746987272459342086482985695887045504776020852483783906536"
        "2172506322079792471903631811738029238588537100394070287934331478185936935198191455534087534416095445119132"
        "7942135351924917315670514758298955554619991631363968830288155815152759638969869613114860307234721403801813"
        "72165679931640625e-123"},
    {0x1.3d46e281947e6p-405, chars_format::scientific, 334,
        "1."
        "4998583170769895145258239667197277367953253255810089766774812142211547445430103147393926520164148452565746"
        "8217264380338598104855388663677112214256453366606244072120286151220936656003436396679154181835015100676359"
        "0584348966466807600606971155966424574894203639782754137091303494195009152389539124755613030970380350481718"
        "7786102294921875e-122"},
    {0x1.5d50c95200fb7p-404, chars_format::scientific, 334,
        "3."
        "3026285632030961027430781526695104834652824763749934105342216592027767938527528216746021154719645500132460"
        "6616794372108054609285611564286855905212986858383047108185221762771718705161049816532541785396613413881621"
        "2217761748227152819627098792981544023621850913148052426306024200164421671955248312885222716772659623529762"
        "0296478271484375e-122"},
    {0x1.31ebbf8025802p-403, chars_format::scientific, 332,
        "5."
        "7847010173866356658135714751782132458915473391965410419281395217763813953559535968598835173728934249636260"
        "1391514459957848282287968614420455369316177721591679287181702700396345255239479649102860468456508414192128"
        "5765602981762140026015686251155088703174799414546865824038807089051963687735763777753028591632755706086754"
        "79888916015625e-122"},
    {0x1.45f7b06a1b161p-402, chars_format::scientific, 333,
        "1."
        "2327531669436545124898364942880066252999983643906149889220149845403378792647983133165166313028540606985070"
        "0818436949056057893055823679249585303051312488233045352968305435308456249734196737179082525750979594444667"
        "7228676476284721228550824045540658730028149589335013698528738527418574216139323697360996590077775181271135"
        "807037353515625e-121"},
    {0x1.df4f5a7e05b4cp-401, chars_format::scientific, 330,
        "3."
        "6253358049975739948158532959144013335613046749062970323972515958518272146127656397527061651233015893692867"
        "0103303942817509059905956200910147442693283287995230815845232814920748801039202484840625264268960547701839"
        "4461232562723775452393614394463284378370218080769149758857505694173512387676848456319333990904851816594600"
        "677490234375e-121"},
    {0x1.ae574f97a96fap-400, chars_format::scientific, 330,
        "6."
        "5099035263477567697676239505583198082407067935910598028302046053953016881173914627929885947779143472525852"
        "9119807135344605329826410498881079099916276669949098538219094433024528915815827831019768695616878227040110"
        "4253286553344639621446432482400791768130297624278687916140708336692433937814041000624598609647364355623722"
        "076416015625e-121"},
    {0x1.5682e2e154108p-399, chars_format::scientific, 328,
        "1."
        "0362549937904696495909186260047111788995618647637336817784404369937467772175933363337212662356207536735218"
        "8030101548183531660454669558507451081374831816640389350098116044525532899664635039328699336476198997181098"
        "1611054570213321448002855193018317174796322288015370915456149081441713079385774642915407639520708471536636"
        "3525390625e-120"},
    {0x1.d4e64d894ea04p-398, chars_format::scientific, 328,
        "2."
        "8372763744588855358195664212326247986525884317469934762680318091318529844306906832798118576979789563617608"
        "7880787247738178476250311898177500090645985936560651576500379515533764989527583633204112961828419907248472"
        "3993397281384249852781206296581626131873567108627993360107656068926314295395446629655111792089883238077163"
        "6962890625e-120"},
    {0x1.8405785281eebp-397, chars_format::scientific, 329,
        "4."
        "6957762796709737155545272375088190271165041022145719332035280937122606597820767289040881062663178655971790"
        "6800163258532738477839926886177406049478443972511824178578427468672843486576511058856103122000518325560094"
        "9669432592376902045278403406836799158321502945965980280664261537807858390208490262374141366308322176337242"
        "12646484375e-120"},
    {0x1.7eb41af181b1fp-396, chars_format::scientific, 328,
        "9."
        "2628413735990423976072574727831848085171853809438809598495177277610358137788162151768704610738207393586717"
        "6239925229724538135518882743778801921512445790917757600220464043852992967680900899632107966724376688268527"
        "6343517164257771308795820514969012334125522761495819641199962003503392009209210788966970540059264749288558"
        "9599609375e-120"},
    {0x1.812947dca7db4p-395, chars_format::scientific, 326,
        "1."
        "8644654417675819487878768291262887764232591738129708040196998864550979088967279045136490762476499773291512"
        "9620812439715211609748176949969393845599259659318287218077670995102127035337504860737911557372641561128410"
        "5183442729822976469520193988570188951048643143750502460453397587635942242792475020962683629477396607398986"
        "81640625e-119"},
    {0x1.9e33a8306e02cp-394, chars_format::scientific, 325,
        "4."
        "0100862103638260260327403702106109516070843800804666499770138974502808794721389200773475598343085572822186"
        "9050575652000849999783616094397321798140965240453403340309552058549632349997838495783548076103129101125761"
        "4639151880210011426990683848939531260460233147640120904706864264441669009481072905032306152861565351486206"
        "0546875e-119"},
    {0x1.fc59e1a319ca7p-393, chars_format::scientific, 326,
        "9."
        "8431817833160122601313212773122942893409910851546209354885728127108295688976875179174547748983566433413213"
        "2025798622516539150550515346244583769585261311971860204677532235067528321744733234706537880403917023842260"
        "7574806660943207182365054888572670670918103919236001613298781456569337992498769374094536033226177096366882"
        "32421875e-119"},
    {0x1.ea48053546540p-392, chars_format::scientific, 320,
        "1."
        "8986595125046416834783391206475835197011693029669966155263156671691418830838428529139208448680176162863118"
        "7695816852367151953603093414023513472452231891026909148753713286042719755834756149864024108431735261809022"
        "0909719089204136527578336674363112487531886729182570991963930462755397177154748078464763239026069641113281"
        "25e-118"},
    {0x1.c4f7cfd35c403p-391, chars_format::scientific, 325,
        "3."
        "5083205445088968495677101873388169021587210288068562220603066512276293052810916395438868133171298860873211"
        "5906573028050475979768658205494632257575125878903299547717299838346765905333055749041027617447665836622709"
        "1941304109695520879458424636283604303800109503244258137414372793865533547291724048022842907812446355819702"
        "1484375e-118"},
    {0x1.3f1b2c8eb7534p-390, chars_format::scientific, 322,
        "4."
        "9430715648584051844621127511504766932271831089032969572932369896232697013659331467295126281359728019366715"
        "0223703961334976370441319425264759617856817683619261680544917442005575369381757511402108712309881085300325"
        "0818301375453449086706715170921583482977020013786182723813883417931808877954225067696825135499238967895507"
        "8125e-118"},
    {0x1.d06093b0815cfp-389, chars_format::scientific, 324,
        "1."
        "4386748780689463441172008927045007293630513034969496905804592655018261534900625376938437377392865739866729"
        "6615558447456358810107305126537258821495219592310542410906686690234000177678885634217857624515847833430176"
        "1013692954086773103893646129885982191773115862652319223214584781092291281001660507854467141442000865936279"
        "296875e-117"},
    {0x1.5f088215f30e9p-388, chars_format::scientific, 323,
        "2."
        "1750535480226043651063968030552837701335419048796120873289665746737982864577869182423674166128902294355190"
        "2567578863327434873478216467219071537837824503113360190943651743419094244810729043431689094699067495426602"
        "4495878370083247028266065338479497333757962125955769283174403691587467726820115387909027049317955970764160"
        "15625e-117"},
    {0x1.1ee7b2b7ec4dfp-387, chars_format::scientific, 322,
        "3."
        "5554120237464134602694119759921381410530091439238523194592402342557057246628016063414378639043829736854188"
        "7370053506577563972296682322952558114285158990250458154246016563621912592790284052637737715198370177263940"
        "5405211316069492320708638950783578941509117218036792610026741347911943130766232457062869798392057418823242"
        "1875e-117"},
    {0x1.e5212858a9ac0p-386, chars_format::scientific, 316,
        "1."
        "2023735450313651421171538785871176726817036060881631127943497279521174527072830335195052010261740485366509"
        "7035885847417422710449856594985414474195173129388921911481901258066228860986222371389439608412512086611891"
        "34406624290828135248622000380630662078487158618897919413632808909031535193889794754795730113983154296875e-"
        "116"},
    {0x1.e5a64b660de0fp-385, chars_format::scientific, 321,
        "2."
        "4073250149223043677529942257093521551685293966172209099803476112751766606813967498557515485126803686976280"
        "2509846959709723111928491817829971430314205791200580751789038145211771394494147327366858698467104394248895"
        "4039058477399630531971831293463019719488441957560055472393256961109557490186006134536000899970531463623046"
        "875e-116"},
    {0x1.a4a35c112380cp-384, chars_format::scientific, 318,
        "4."
        "1701370789218155692754228746962316110046975782997471789899742477944413513185760207420533618377892337282650"
        "3369609111243586518876985010803989860785855249416361813452820232507673882731452960098324300662753351543989"
        "0605798534521182860496797973742972290515095803870329475781942164640259118613130340236239135265350341796875"
        "e-116"},
    {0x1.fd84aa058b587p-383, chars_format::scientific, 320,
        "1."
        "0102559419519475794201171450381673041089322627018053899889380695208263228396234959442210305668054031580026"
        "2617175361107992065273974530599080955152985761274225519088885807436325575834309377713847614939429333357521"
        "3736221842600597238671029059811607467346072347130676068618442925385256248027587844262598082423210144042968"
        "75e-115"},
    {0x1.8cdbd7659dbbep-382, chars_format::scientific, 318,
        "1."
        "5737569358633547811206080917170425167450411520103815909249604594369345874856545245212805027522831482869727"
        "9497837821986319825226191691030482601360852618520169586052322172410999244763978900894391063989290727442929"
        "3647733654219928166653100454479140789463860010824500467182821754168198236101261500152759253978729248046875"
        "e-115"},
    {0x1.c3fab70ff77d5p-381, chars_format::scientific, 318,
        "3."
        "5846791147293954395277110210507684652698239680639314917967800036918115365251759384633992808617776665470287"
        "8948196800507852844357586424000876576667554483947866806149903563073606011829317396890873012538987787373457"
        "9886342475181978767165737092606523456123743582322344239764951045502938686837524073780514299869537353515625"
        "e-115"},
    {0x1.92f9eb50ba810p-380, chars_format::scientific, 313,
        "6."
        "3920642274634331751536794408261143575334629993511050648872666338672571665986021735206183246506631631027507"
        "6674090520833858863401291192443279548090882698094889561395443424178066943634531052696735508613482077083274"
        "38532663382585063040866730643823561567323258792113871334440201865678687909166910685598850250244140625e-"
        "115"},
    {0x1.e5d12025f41a4p-379, chars_format::scientific, 315,
        "1."
        "5412187845587148647082679443541904930956627197223735714308064939313678370864379713857586412466743837378721"
        "4477045757622973435427658211214451056290469467722605684096423425588572056824523259270347609435702307410245"
        "0187989051299157133388192780303421949264106738071728509661029345167992943288481910713016986846923828125e-"
        "114"},
    {0x1.70cc20b16cbc5p-378, chars_format::scientific, 316,
        "2."
        "3399657115069453242799372427454858441916409637026741437784068092438045672968038993507346705421009607546622"
        "3270999126531558453930448337869948963043039837440559106704597253256508416121847397066754992986499963921290"
        "46637675265839770011966526475548357054437982946807154687712923708808876455123026971705257892608642578125e-"
        "114"},
    {0x1.f8f54258baa23p-377, chars_format::scientific, 315,
        "6."
        "4077707249453147734571294870181459497973836656567528268148064225575734467252266106733401529485664591286872"
        "5537475815263199419956592789659795423138900495943348557937327067031684374451512495466067674240016165733527"
        "8642566121441607503387428396992405649535766870058376239570482012231078527975114411674439907073974609375e-"
        "114"},
    {0x1.b425d7b5baa7ep-376, chars_format::scientific, 314,
        "1."
        "1069178065391464118041197835859986853981823370991214279644651068058195236576781864336459899685058699818985"
        "8389076952457334918508095427607000023790685113724227614589746900778059551210150285899771549942676809335780"
        "216735649319371255941752281553265395319094745377493328576212587577298762653299490921199321746826171875e-"
        "113"},
    {0x1.35f98a9945d86p-375, chars_format::scientific, 313,
        "1."
        "5733958801672790951911831966450540333286901510422187698245081061936132440082110172995513811552188806194750"
        "8483008380141477614143817728347389618471096913538493454947739839883504613082714342355282868320572300743114"
        "95047375197878671140995642548351193717183402608319281064104371015144323564527439884841442108154296875e-"
        "113"},
    {0x1.22b6deb90a23ap-374, chars_format::scientific, 312,
        "2."
        "9512643039682987271607130402882275984250978924222980866335903775679967461152359642908392339478572995711210"
        "6711158137101871047341964134538644022448223316135917805111115721985676440930948226211551129468067801597918"
        "4580368796271490374849056743260859362475989065448386808516480217523536566659458912909030914306640625e-"
        "113"},
    {0x1.af8b9b949bd33p-373, chars_format::scientific, 312,
        "8."
        "7618958399039475289411495157932994119285940106393630296173005536001515294054979103676044947610677490024580"
        "6433762089986893052332064562978271936803143494243928200924114342896992504891165235980509540813946170682297"
        "3867935359995281054682095411461508824847074251216971999141856775050740679944283328950405120849609375e-"
        "113"},
    {0x1.6717d5464b378p-372, chars_format::scientific, 309,
        "1."
        "4581718353001727202767958474568085509641315254096668946517258054929653338668760014668801958991413536588583"
        "2166422613380830543504451930921550793798367298723049105942703198978517102345816708317809381648497621791749"
        "0144653395402570757209661432587925807640507185377121211582174264975719779613427817821502685546875e-112"},
    {0x1.e82648ff239bbp-371, chars_format::scientific, 311,
        "3."
        "9644645414828138173162257943342753791936726404197770155908477143700013008038105686863030846404367750060424"
        "4814244967592799688033858650321919135290377962541541757670567069855566579894393167253937584463430211194847"
        "838410815447232136167099214308805859745088063782002314890638705602299296515411697328090667724609375e-112"},
    {0x1.e51cfb8657ce3p-370, chars_format::scientific, 310,
        "7."
        "8796103616943104296862864926637808976384305685460046349264971296098085718108590424082442044168977749480870"
        "2928472617532638674178490816260470459625717085681235305001720392192877266453685066566192314061292465692667"
        "01975452020742004266052294229064688879217955185466426624822655622182310253265313804149627685546875e-112"},
    {0x1.b14f77ac7c51dp-369, chars_format::scientific, 310,
        "1."
        "4076373030698913279542894696649495363335439496734696510065477536845414461119135429499341627348207442652927"
        "4935947857370618330448711125058799086304561047878820957561978470428392090947171839593614746022113900576819"
        "12459797630302957798856517266927440740025132710425346247752609318837357932352460920810699462890625e-111"},
    {0x1.e710d0676d8ecp-368, chars_format::scientific, 307,
        "3."
        "1645295789429928436647975840549801301515330036544211466830277436202701723604780666991621823155867912659398"
        "1980338448054215434328683248511272110006708490433287132241742891859869273554563583159617428780711727619231"
        "33899979676544387692632814983780063270773577183589647492112373328154717455618083477020263671875e-111"},
    {0x1.681e2130ddae1p-367, chars_format::scientific, 308,
        "4."
        "6794637406214600552685009184111994631046788070673294911846952958589294261135845244842000381052918421797166"
        "3686856630365424161431494428961656868717060092984824469137024087943584804835372179942601678375223467571832"
        "515625537071561402276458569226060997833551855877904268772582430102602302213199436664581298828125e-111"},
    {0x1.a823fd627c74ep-366, chars_format::scientific, 307,
        "1."
        "1022787950727771717610943243155103519105415962234389134639983375075983585745388621128252129251831360374758"
        "7200078501494916601004074837757884294948649378776832588867301852289741497219317204928696589057736588055220"
        "25872507231167222528685303920977870186585482457331214116436068906068612704984843730926513671875e-110"},
    {0x1.4154d3aa34c6ap-365, chars_format::scientific, 306,
        "1."
        "6701855515857908584747803132448487756483101832993797232975308804071919095972790016154322704905670927038588"
        "0494132185610153140585022535102018358801929938831640361250668541664980168293360212741724810288220079797390"
        "6720466201397769120663869839685513950245652908075809535415334750041438383050262928009033203125e-110"},
    {0x1.3a9ba6e00a75bp-364, chars_format::scientific, 306,
        "3."
        "2704792321346139269395198188310864980762772459780219667337880506418288619313658795189633157901844118202961"
        "7959899821736910033629581384546366449781130238868918794233156215017316457250215443260494499049530118568527"
        "2846413113018197664085143742641569449064726380745830695839782009670670959167182445526123046875e-110"},
    {0x1.a63e2539171bcp-363, chars_format::scientific, 303,
        "8."
        "7787729275384650464205839686581567124783107846404487702633668032504537138009690656495102209028217361135521"
        "8390388558973430219290482843591529548434600383846735395604846042341730293207372906214891355297527580963516"
        "0087896703692795742861281764048566296912514108556450931342141075219842605292797088623046875e-110"},
    {0x1.5945227d7951cp-362, chars_format::scientific, 303,
        "1."
        "4356894911231067898171923164012923523397719956349474652622401817264054835179242430812570726867562039556960"
        "9395820536576981686866835269785818676298857562755446418526260219235762960808818683579213832173570812722647"
        "1309299601555074913893102541253974308888834531656129855914372228653519414365291595458984375e-109"},
    {0x1.82217c782aac0p-361, chars_format::scientific, 298,
        "3."
        "2111903570682555570830432285106056350808268235667287036759585960084214919407425089581154098784074762322198"
        "4762123193423025747805649805390981226048331145080309572679467705818692956022292826723774128752395133008996"
        "84678865465498234764125959913015552026947590190386616626483373693190515041351318359375e-109"},
    {0x1.098f6dbee458dp-360, chars_format::scientific, 303,
        "4."
        "4169724909246743271783375837700448384399037383754852175667172815642110900066699080460389447141005868057730"
        "0512595879015513339295564000425906636050874382230874106442651414859196934264601320288039760451686440122377"
        "9211715551095402858460824838483699891256643499837415689501796123295207507908344268798828125e-109"},
    {0x1.fc1a3e0355565p-359, chars_format::scientific, 303,
        "1."
        "6902188100294218634935247637485270281651549319941796535330082790416249513368727689884420951594130215709004"
        "0184990306867018953130130856037669985663887665299573761002835240263686645156373136524713074576393774585196"
        "6064973879549502996367695229140698130020298981164052209980042107417830266058444976806640625e-108"},
    {0x1.9d22abb8a3e58p-358, chars_format::scientific, 299,
        "2."
        "7486157518272163198462750357234962521840564791749654630448944205121330934304735487728385237098477486960962"
        "5847974164498179204746922062216049657612246741906384781995063278488580462198784747628586625522717685501064"
        "683276474702628786475061222493509474216607179307414465796455260715447366237640380859375e-108"},
    {0x1.8fe6b364f92bap-357, chars_format::scientific, 300,
        "5."
        "3211348201503955918326994712215674983015794087547371314733947107537140792678543657825063978585635866620708"
        "4197313956182668385962971395188922621807236400003448458010002652773369381707765820726202495191307008424796"
        "4985873179224173871150940905947186618917750283892786899997418004204519093036651611328125e-108"},
    {0x1.3924fbdf3f4afp-356, chars_format::scientific, 300,
        "8."
        "3334785623935782116298108685266686643370574881636034800871153561094144663382514150166540391974744686871180"
        "6417987830668578413862355044420640648941380509579676293326802058743764083969551154493102801167674568470045"
        "4921274138664102521131689349566080338539705656651646048516113296500407159328460693359375e-108"},
    {0x1.59bba3abc92e5p-355, chars_format::scientific, 300,
        "1."
        "8401463566583057000467205063624781534185149195807291439532371443811570882259925022763641473815090371969689"
        "0884731353588984692080088307661553053498541608357827654845057209245110680041052095293937588746057055307668"
        "5104080099519938253964156154017020428131091156799536978638798245810903608798980712890625e-107"},
    {0x1.f91ab28f6d8d2p-354, chars_format::scientific, 298,
        "5."
        "3767844238622670481304274663876506600784579490273356231591616804154663121136971131851337071593432079006723"
        "0801406917418121743555085258692970299942364812832124045965349670231901635472698014492910758725217321403406"
        "44845226572809529157488064473891307432846836840412141356182473828084766864776611328125e-107"},
    {0x1.29815f4575ee9p-353, chars_format::scientific, 298,
        "6."
        "3338293748065631419556714682364874673867676285049644451673425924784138630592498292679137715512703719066539"
        "9099547436808253509249037923744258894826392480910340657908008256358036815594577611142878960404510461173969"
        "42666747803151643950824239942570360031580162414599488585054132272489368915557861328125e-107"},
    {0x1.9b5549ca69f66p-352, chars_format::scientific, 297,
        "1."
        "7514400642486577219423056529958168455121436480387689214857689064489248433753353045222356747974792138413681"
        "2907705310492578831489120381580810440200883241625934295912642633798054015146534242980319769381134505869389"
        "4271570763602292963970708357409197599381992481448744314320720150135457515716552734375e-106"},
    {0x1.124b975a88735p-351, chars_format::scientific, 297,
        "2."
        "3358765579576565334772675826735107157872544630083091706192581114916616667385249065695562210242645649633370"
        "6045442624764341660639114681090349749985529232191675913872702599912722915102318783709303584090894615368605"
        "3705913497996218739612629046751784994643955963022907695858521037735044956207275390625e-106"},
    {0x1.1562e3a0ec3f5p-350, chars_format::scientific, 296,
        "4."
        "7243986610495878878673984778734765597249236867292989667607298760616960219054966616029202455795780518195146"
        "5005795973444987034101304350852038218864051288571350765414212230181767935792865589673805453295871045943135"
        "218617322658165475074435295648383851079801960815007788596631144173443317413330078125e-106"},
    {0x1.7499ec4ac4fbap-349, chars_format::scientific, 295,
        "1."
        "2692169671992971794859529307417627065586882159206511522850272309303557550875672875281941705264110562532404"
        "3962157386294274558513375437279520372365842188678652778085743847538559542383103862214745631648353208671844"
        "45964579981005077479106468489233703280283545311579729286677320487797260284423828125e-105"},
    {0x1.2027f877e5c8cp-348, chars_format::scientific, 293,
        "1."
        "9631316012898760223014058906912067489377912540647879826283094146946912960752087047972415846827587026831640"
        "8529836716359055729125867701272323663315317923152316903512706305527763621084339310460970385816269376507207"
        "732386773493842387889323502724040878468329818229420880015823058784008026123046875e-105"},
    {0x1.3ebd90e3fdeb4p-347, chars_format::scientific, 292,
        "4."
        "3429894872560729418193397434044195297928892591241402688768517638740285594212782549821378697599010953184725"
        "0001479148556894299716929279968971252973761365088083456011722548856128988536198502330225503216761835636784"
        "70959217821493701938086947191985055989095487749551693923422135412693023681640625e-105"},
    {0x1.4363389eb80c6p-346, chars_format::scientific, 292,
        "8."
        "8126165753911829296073940994630312372578087100698810179318575514900600400132302692737889199062390479419949"
        "8337013660830380592269111943379641150657051580457441463012673490810863644239815703741098676074978193264928"
        "62699285514009118677994236229754579522131796576189799452549777925014495849609375e-105"},
    {0x1.36a0109bf8851p-345, chars_format::scientific, 293,
        "1."
        "6929662136678211488078955588025689249252946388568113517812621468398839813210730900263559495041405947214123"
        "3023424598961524341866409500482279716433603612382080707599516239910317980701008812896983399390264869857599"
        "436031413554009831686140961859092949411305373264013951484230346977710723876953125e-104"},
    {0x1.852936e8160a8p-344, chars_format::scientific, 289,
        "4."
        "2420016230315380894459699263590074580121107948381560051483582623204545213465113172292812816818464247780754"
        "9945914113013415578186602251423255710110678586170729782875957266034899743601335079915348892173656670268744"
        "05553342866483389551396854187976397966564068298112033517099916934967041015625e-104"},
    {0x1.149ec7bfca2e1p-343, chars_format::scientific, 291,
        "6."
        "0305298093927812974371236707006850466550484837899433998791788439447945090567504761728273446428158503828027"
        "3815680772046816887312242613127654618110699752592730180526202629349727603958501864226949792627071804458332"
        "9530560909162178292548227844095570554690255438146095912088640034198760986328125e-104"},
    {0x1.5b2dc6b83f4d5p-342, chars_format::scientific, 291,
        "1."
        "5137520077480203129736786547797218619270753778448891209064918076463125636944869989096240366834149603449714"
        "9622117214819752421125106211299219496197133556427938606464103348868389804966690375917611422685068708804532"
        "8321041443260516963902382193582509786917988936494339213822968304157257080078125e-103"},
    {0x1.da0f73386d67dp-341, chars_format::scientific, 290,
        "4."
        "1339493171608475510736380563699750629156862226280416325731522075378368999604060724669971773099651206101216"
        "1017546178458942728313191490202170666992385689982184609191280290273663347725787965403909863535334056723463"
        "899330281266936838654482799695804640972840449109071414568461477756500244140625e-103"},
    {0x1.638d3b1ba2bd5p-340, chars_format::scientific, 289,
        "6."
        "2010359315134640090731319437049206220696431274480364487068426341395584546604605252648624919716507113178716"
        "4770913020638743635294940380183735409118973050619962086116661476750520741067204022527272515483696214789128"
        "06267420333330775690907300282423840649681512360302804154343903064727783203125e-103"},
    {0x1.906c98f786defp-339, chars_format::scientific, 289,
        "1."
        "3967279728811321015556380205763949708026110141846978466576526561943061094238322509857317048680101516109209"
        "4059480169304313282251175137756521835472643562161874889067638864262324158569496198868632887339727876854190"
        "94620032800056105071229529844130628872533872453232106636278331279754638671875e-102"},
    {0x1.758b9ef75765dp-338, chars_format::scientific, 288,
        "2."
        "6059428457609154486911302444167565685187311533784113372214336570808417256412519024956191525183770555440174"
        "2351821205386265043059591636376635678882878599304488236849642358298092440065200725936048618574206149773742"
        "6327712363547867434874089592920722198432503802223436650820076465606689453125e-102"},
    {0x1.7b53efecb0cb7p-337, chars_format::scientific, 287,
        "5."
        "2925657186107486696662256436218499175870505461474569242666233854160474625850779906598158267271520849939229"
        "4202392215141578825785317356572899446095010353693470459520062697277725597854451377947127151669409262676817"
        "805963710919477975920904905105901332162954275872834841720759868621826171875e-102"},
    {0x1.c70cdb03862e1p-336, chars_format::scientific, 287,
        "1."
        "2698160651847152511134198109881258456142759956828081770588497598811394283191928496354871928599416248545921"
        "2624831316216668122250847400605418281738828454092443406664370924540263061336400427843941139863146710024305"
        "866123781960021918923744815065946835164201189627419807948172092437744140625e-101"},
    {0x1.c8620f3a56118p-335, chars_format::scientific, 283,
        "2."
        "5470706341249348902221902622568371957573968152993335291114182491469056877577567806133288792502362191377384"
        "1104198106509806681478945672264147381937969112303470510735230530092792306517987071863243310330652402455664"
        "18482483161473301224825995891891394773409729168633930385112762451171875e-101"},
    {0x1.6de527d45ec04p-334, chars_format::scientific, 283,
        "4."
        "0841165079066422503311958952355012554890105582329316527378510871501269657351408619401715479431010259110172"
        "7331888613681649927397941295691701840380977033084709459930029994062241909437403184233652851218799652841192"
        "43738253055377647337106095646631909179546937593840993940830230712890625e-101"},
    {0x1.32f4268de3560p-333, chars_format::scientific, 279,
        "6."
        "8524262499820672910465946411140257927338084441301598854658498719088905756918548930722944195040062465232121"
        "2741194099526199284333586848262300092485070516184133947332196308672745095179576985257273100178992879756211"
        "3861611774779207012072627762389043226676221820525825023651123046875e-101"},
    {0x1.9504d4e40f114p-332, chars_format::scientific, 282,
        "1."
        "8083260374699234761065257773418498730106022787616035325598600451327358187952165471790323439179847122950235"
        "8546322993371696334394192802862629454251406168400743329730917576310927470940241674403303605819271810565651"
        "3295101069735058671395240667729986672185304996673949062824249267578125e-100"},
    {0x1.cb9bf91a5cf2ep-331, chars_format::scientific, 282,
        "4."
        "1041218769683543865527782587708994321977282570253751835355176353868356467589133067113662048462713562786916"
        "3689797540950303302913366392376656159255697944455891223668807057168630685792060203335559517088803685034984"
        "6654097283173859379552553760216182521247674230835400521755218505859375e-100"},
    {0x1.534d1a72353b2p-330, chars_format::scientific, 281,
        "6."
        "0596402508961119571296495219413977960985088664161517023286865497038758610911606257218864532266059908463494"
        "3566866588930258825411622537414066336047894439146752568610278062157672883821538692535856116708042779936221"
        "736077402161935015293480030935946434311745179002173244953155517578125e-100"},
    {0x1.8a81f0ebdd183p-329, chars_format::scientific, 282,
        "1."
        "4091162264655094096918422902209131451813071235940686704267979933905629962370860646608701739601729195398426"
        "0348123961816264514026789687986440107830948993608087358064153065552612602602023499720117578184592448397117"
        "4376577529462311334822327015502130276303205391741357743740081787109375e-99"},
    {0x1.2d8d843b6d359p-328, chars_format::scientific, 281,
        "2."
        "1541940438019324865167028884178297080890453228868603437885007477923378991221330760569498464981192644981579"
        "9086766356008861141722682975426269705872292139055342559529362293475470513544579470179567050581508580483092"
        "766000531858470043399035620014514424980234252871014177799224853515625e-99"},
    {0x1.5ae523c56234fp-327, chars_format::scientific, 280,
        "4."
        "9562087398984028798002675205915029145934162551746287076478264141066334902604617021355261270418382502703079"
        "9012887618525302370636569884647253237361252245553836239316100690838738298913987463032565645940507442438449"
        "71395465018007039720702891320847083278522404725663363933563232421875e-99"},
    {0x1.2e2fba4d55710p-326, chars_format::scientific, 275,
        "8."
        "6348821682352886680448613345699107777997779283593013133209274283334866227298574857315844433891549697529806"
        "3967453807178597920834220273761421926245222790190624072541898839336096889584915861533631101787200214097731"
        "755254463696422798459940983750726672951714135706424713134765625e-99"},
    {0x1.a8866b54f8da1p-325, chars_format::scientific, 279,
        "2."
        "4261340414990349785900555645144753836486017984360325092686326468941813894749700948319279369699030354562016"
        "2128067628714222500858744515024250725224913377594619406969777600338582044025172737970786616230297899138581"
        "5415528011949603900100570948172862273395367083139717578887939453125e-98"},
    {0x1.f1a5726eaf292p-324, chars_format::scientific, 277,
        "5."
        "6880342032875110801140107811674257242681040973129201120356046066242525206668362776013267547666870081864709"
        "8697301511059933888881427408978800238200024191730958421845191572140573277862850372978086195948703239443239"
        "55228780749141742495715752536700193786600721068680286407470703125e-98"},
    {0x1.449fb8851eff0p-323, chars_format::scientific, 273,
        "7."
        "4208207048148695360887516750671585448954709948122751839360897930189242396581441749888939165021423228508336"
        "3595829634393473133215432271177697513478113798725154449792965648309451308710292572224103743993982360407449"
        "6105070814565044206960464645561614815960638225078582763671875e-98"},
    {0x1.46c05ddbb1318p-322, chars_format::scientific, 274,
        "1."
        "4938910681786228098433397618427083905000278780570950467448198038274216732657666002119768524178303625459142"
        "8113514269539148166937605854031616806544458143119642972251690661738492452061452603871892869715803063032290"
        "16720368895964772527028274762272985753952525556087493896484375e-97"},
    {0x1.6b11a7ad03ce8p-321, chars_format::scientific, 273,
        "3."
        "3198659912779944591755497965186522112578908724555826481398937929092451620495530950235419850252258210723507"
        "6103357799725303807187723552061327603203139944318751411700583753118403087341835633246108094769809451825572"
        "8458429841924240692903336213959164524567313492298126220703125e-97"},
    {0x1.35af01f0d426cp-320, chars_format::scientific, 273,
        "5."
        "6634316286537580410549627430526563174209683489552393365657133589081290878698891065102827260170613964063421"
        "7988490623562854632880516016770172038156097146354316708909596705851523980277831473118340477805634968266611"
        "0387736739752007997066030053900931306998245418071746826171875e-97"},
    {0x1.dcbfadb8b3393p-319, chars_format::scientific, 275,
        "1."
        "7437369721819611306370401524320874706796587550801634394374128782974215775486231933474204434212241812954672"
        "2253205431824225310790378426225749581112311746779383635732956570294552148059878128300037030766362232845415"
        "610269516394232537279639083660498499739333055913448333740234375e-96"},
    {0x1.e33f175f87825p-318, chars_format::scientific, 274,
        "3."
        "5350054379821040281789284265976009753915056027158289663573472460364318135080456532420187970414666391602000"
        "5749792748196365536928031655309360101630870384004441686023479759971468723814758726445507263978188305294501"
        "66237066652626089735718395434815874978085048496723175048828125e-96"},
    {0x1.754e6b5cce5f8p-317, chars_format::scientific, 270,
        "5."
        "4615606193444131862109204544103266030868122735855760371810669285382344869384517529242953427788269452822158"
        "6447733355524512940892011377262788258325539802499302096414943486531804678941620226371353010632838705878571"
        "6076215004574612686683021678391014575026929378509521484375e-96"},
    {0x1.8467156a708c0p-316, chars_format::scientific, 267,
        "1."
        "1364847491964381755809073325658806539668735063951189927636831017735890051798137008661548359628176249486567"
        "5638355075809542316572770260795609472341017048086809154108791537763758262439106114402680050430718549937605"
        "4984664105996887417671104003602522425353527069091796875e-95"},
    {0x1.895d0eb98e49ap-315, chars_format::scientific, 271,
        "2."
        "3020007806568932024585160896856794015905763244531581751345471550226462732325455222444774590029231192793210"
        "3526585809434548954819303101741588289887271759169385050668460900964752827696537189730053914236112530299498"
        "78718850332174066138091195199422145378775894641876220703125e-95"},
    {0x1.40a747961380fp-314, chars_format::scientific, 271,
        "3."
        "7529890242406666427809537541355673359784524729918599611738936303969683643463506435674045097086533000435903"
        "6833805751251437135871962069969241765350603702037415332674882077174238682833668617350553945267812311343474"
        "50183664810112785757689746191090307547710835933685302734375e-95"},
    {0x1.3b6a90b6dd82fp-313, chars_format::scientific, 270,
        "7."
        "3833844812933601001626040712223208545049894159172436674233731756578183832102588069235339862415563708591953"
        "3290144340614000151931192578763645062459485049299914120235431773959612511632269475578724910553760753162725"
        "9035773503789072506886537183845575782470405101776123046875e-95"},
    {0x1.29a514459ca70p-312, chars_format::scientific, 266,
        "1."
        "3934768122159904445853290075552856512674507704664699177572841136493178162330742824621681098250948372789843"
        "4729750251456654416423830571259374225337974011611156252922037258169533613173818100385793804677394622735141"
        "766994054388605073224738362114294432103633880615234375e-94"},
    {0x1.0b74c8584ad3ap-311, chars_format::scientific, 268,
        "2."
        "5042865665627230013905293764731537341817933131283917087004920122084647344228898478210371710543160857493563"
        "2236939001136948844407029210584627234019763143896970351150846985824258803274296439361886009001435481001665"
        "10812608939716590594759537680147332139313220977783203125e-94"},
    {0x1.1e03e68fcf7f4p-310, chars_format::scientific, 266,
        "5."
        "3561230856431216215705891197384170210658872854832333041087321234180910038318181672802850047733820007628560"
        "4182171685972328799651035840891788773709992554797907500387843891228116979454940850233766623349333385640802"
        "273842934100485380088940701170940883457660675048828125e-94"},
    {0x1.713e883d649b0p-309, chars_format::scientific, 264,
        "1."
        "3829457207184735000646794778614053460940210246011933848384018350432995141075648085203697000208221493806949"
        "6871105807765061634200805943647551922633019924217056463629491090846563741317220831180219308859755163461485"
        "5151721147207000139900401336490176618099212646484375e-93"},
    {0x1.86281c91677fcp-308, chars_format::scientific, 265,
        "2."
        "9225397297013291485340291504603700336599579795115816142467807020570283454539177669728489061469790947015462"
        "9997814087950868773198110436893831741279455750950609447941220401713815828135354829102946691124843423371622"
        "00459380729210268068385403239517472684383392333984375e-93"},
    {0x1.45504d79391d3p-307, chars_format::scientific, 266,
        "4."
        "8736427954876516111588556297323223735366132652170239201846287920067706228596656189402267426246839952413216"
        "0049764777409257875974799672905922600908337766650300092966930614776888318933855334348681166027395590583966"
        "769997135959867351484575692666112445294857025146484375e-93"},
    {0x1.8b65fbaa5facdp-306, chars_format::scientific, 266,
        "1."
        "1847214117665037958349200111689262962159366411777270344855697272453913854959328881800526601044047876095253"
        "9508884510689090450544760680794078282991730837875342801146971856602898038792043608811629235497645397056549"
        "789557803741175956435682792289298959076404571533203125e-92"},
    {0x1.15b31d81ca8eap-305, chars_format::scientific, 264,
        "1."
        "6641279667471598281077652098259945521671295549362078378109870769039305816240186759177203366513405424353633"
        "0530761980743920794284685177470701845646722007722289704781280982002937652274421398782929157293977334017839"
        "2330593955435180664181871179607696831226348876953125e-92"},
    {0x1.eac3901bbf6abp-304, chars_format::scientific, 264,
        "5."
        "8818504424690985169205536700281187606567042378602631203335310164716217466374569085773532485133568172286664"
        "4136317480410796037360933641727560690299399698464619034628147686482037707302630902387957209311928858323561"
        "0316787898670110035226343825343064963817596435546875e-92"},
    {0x1.54d51a8657184p-303, chars_format::scientific, 261,
        "8."
        "1698158411107261909593405947137163967522047624097756905903111770746755936496192101549234847884183779745242"
        "3170474746072782115324967751585643030135116010607593205418148559244337424314958917190348394072848060723705"
        "5238019525493786687775354948826134204864501953125e-92"},
    {0x1.4254ea10b5973p-302, chars_format::scientific, 263,
        "1."
        "5452699464889383084423290711151957352280795463335067223992351392751481442851664811520430139228875639213995"
        "7443372996563698494777793436879534495292022436992037556775109404800293598056714392374950920150650171867569"
        "806873131225966044866027004900388419628143310546875e-91"},
    {0x1.7da943773f203p-301, chars_format::scientific, 262,
        "3."
        "6593953762901490298980465769951165569165929629731813929605504263224870936440470834287500461898098845461917"
        "6300712475200183741800575688110181618613341186483104049336857735772610014290974319446787969336623844116806"
        "49009906106383649415647596470080316066741943359375e-91"},
    {0x1.ae4f00acf5c6cp-300, chars_format::scientific, 259,
        "8."
        "2516607665957782806495449548266610202563683706678154753337492221892598865851270347456671454474309415340154"
        "2947108353765710923663409929467862648030890496688726139045114262386812243844497274555150209350984257558006"
        "30762397396278373662426020018756389617919921875e-91"},
    {0x1.8295f42a5103dp-299, chars_format::scientific, 261,
        "1."
        "4826450102010817711210930923040416160476151525185906279856054958041241077876390807571824882338445071789251"
        "3774699575501451998966639677459705092394758161469439414273380135760573163439712286440819442904694661281541"
        "5837368683560359983175658271647989749908447265625e-90"},
    {0x1.abb6488a3abe1p-298, chars_format::scientific, 260,
        "3."
        "2807475032115240062100233478393094020251354181481746915075124012767501350915592204090764547211207441234158"
        "9250311944676967760616784054804356827548506333595288049246369690491136655894910770418537088388769788416740"
        "388219995649965454731500358320772647857666015625e-90"},
    {0x1.48abffc61d5a3p-297, chars_format::scientific, 259,
        "5."
        "0421279276628866771404917521343449655818410102699411247766865670698511764154971706103933661501555850943124"
        "6691132567436980119815055690200132903971131676335235354630998904758603124455624172088445296120063391046502"
        "32281999711059228275189525447785854339599609375e-90"},
    {0x1.68d80a54d6153p-296, chars_format::scientific, 259,
        "1."
        "1071352931313987677170263865765649059990762705126667526251537731419538691260092093877617025045125993875951"
        "8957282035594918033530304494227577752017748915004609937482099729275688967497784979892357979608435015250917"
        "52096634223345716918629477731883525848388671875e-89"},
    {0x1.2c6b77467b856p-295, chars_format::scientific, 257,
        "1."
        "8434860272299224398646710148202596071649163719074503710061903300320517800432749157104831068290668987721246"
        "8288905577843079932802656060133153397763658738705621885098366210921463101614640108441163625096848957520139"
        "530678882078262859067763201892375946044921875e-89"},
    {0x1.6ef654b64f428p-294, chars_format::scientific, 254,
        "4."
        "5036297145461490155658473901364871637444212817199245336544093047170635880998585764076422564090558606666255"
        "1938086353343001846340281510205158335022043844604870268243750850377280010291550976095751246698891426552117"
        "424331189710073886089958250522613525390625e-89"},
    {0x1.451173235af75p-293, chars_format::scientific, 256,
        "7."
        "9789499766966189057432041933294408174821133119234321595322590241361258550194960490787811861606827978987534"
        "0580669985289732544810391373789920254660051031541038369168888736649566723608062419701182989006022283778749"
        "24371282450152875753701664507389068603515625e-89"},
    {0x1.ffacd596082c9p-292, chars_format::scientific, 256,
        "2."
        "5118610569922106564460984688389187692141330531682768924103863645054219481499842629645126936078591972527872"
        "5114722222435312309709437730552329335737166622168597422045113087432814378216341861796310595179875161588614"
        "82397368636299006539047695696353912353515625e-88"},
    {0x1.063332099741ep-291, chars_format::scientific, 254,
        "2."
        "5743284390384121121339828370307253704732203904243798931630246226927879139516091842410667400769648561814006"
        "0967151854945291742251165941694548044712489711348582758259760078958923842987028079231637018004530552653017"
        "459741047190391327603720128536224365234375e-88"},
    {0x1.96f4c617754aap-290, chars_format::scientific, 253,
        "7."
        "9911430601386120440060711986378002682633187804808109392328090664875747637758557400825900344026788010313343"
        "2729113699362461043666923313670271869280829318221799503990742364295320472425956004990574429576668221347291"
        "24604834993306212709285318851470947265625e-88"},
    {0x1.935ccb527a6a7p-289, chars_format::scientific, 254,
        "1."
        "5841152817579089701888246464101800895048854300815732047427000213855511213199411158696917835920060194040385"
        "6832944195530241996774628793343986472070897672191257541684614583042669447587509362813108117841725100392066"
        "653831601996671452070586383342742919921875e-87"},
    {0x1.3b5e38a2262e5p-288, chars_format::scientific, 253,
        "2."
        "4770739864851201045215521130565488910183929199437325725631421672722396652413988843021963416616140085403298"
        "8566619651757547235989152653761825101443066623967176924256056621254930876323270126516930137333399219767881"
        "07482736478459628415293991565704345703125e-87"},
    {0x1.484a5328dfd67p-287, chars_format::scientific, 252,
        "5."
        "1571453461558414690975411195843410181665902370366403386781820716480868872616970347287285000078485643033558"
        "8701703489523571282053738369007553845016143803485386942297636126664238201721806757128415840988374615235911"
        "1636354072061294573359191417694091796875e-87"},
    {0x1.34089c222a3bfp-286, chars_format::scientific, 251,
        "9."
        "6778617084384446515856594489186391560274790969791576420550050955675959857565171616414306909257785259034695"
        "2362288345318732779856813605993054429873501524126201190913398770745075709628316629547843926599154360294018"
        "084598377527072443626821041107177734375e-87"},
    {0x1.e6fcdd939cf07p-285, chars_format::scientific, 251,
        "3."
        "0600555655865200534976772197248794399591456706189630865265707040418808227552314886557434562051285553829030"
        "0716886533358185718261901052219893727742299836868360224318883583437603674338252457160623503337061100215525"
        "655254822368078748695552349090576171875e-86"},
    {0x1.44926d40c76ebp-284, chars_format::scientific, 250,
        "4."
        "0789867108393157187752948756264703859264191233331053076042708075185293288917985839904448038455228974372772"
        "4796581245328847896234645778426859241054384479033713048023996115476263476953358964540485263635494439472470"
        "30717306870428728871047496795654296875e-86"},
    {0x1.4e29f7527bdc8p-283, chars_format::scientific, 246,
        "8."
        "3990628635128793878113999378017349458345655285229811951413205941895445655212208355669760623316311014944192"
        "4895587056060013769855374324172459834228975819398443536073706731699095978262061796216568521405087480863338"
        "4560607737512327730655670166015625e-86"},
    {0x1.8c68f2953a6ccp-282, chars_format::scientific, 247,
        "1."
        "9927178266561660444642125584749374937520778851582251840153437757893208705737778210140182563707851211680549"
        "6000088093483500136470476092352988612163262395625243307278830900372908744130530715872596772314013667190546"
        "46381437123636715114116668701171875e-85"},
    {0x1.daa11a32d930ap-281, chars_format::scientific, 247,
        "4."
        "7718392311175778496834201787015006522460756370577250546037300400638004617260362478357013608710612128385322"
        "1779947181639233169587356613212047538343034581376134935211933499518225742900654242594724446526025006878879"
        "43087162057054229080677032470703125e-85"},
    {0x1.c877431c64f8bp-280, chars_format::scientific, 247,
        "9."
        "1784544610577110087548536112667514918507241599449782305683393170457359980388202548163671022362647074555117"
        "2116019074929067384595406042749373380753064107605729164133086776553397098585026443014794176607191273850605"
        "56179041668656282126903533935546875e-85"},
    {0x1.5319d83c3ef66p-279, chars_format::scientific, 246,
        "1."
        "3637044518063170854462076009090508461307355230988207158833822119619060364687943744832686726236043170915496"
        "3514036585997359479452159849171388489220331093611734663524586436250473091482431300623345135401918559042711"
        "0099653873476199805736541748046875e-84"},
    {0x1.df184ae5a1660p-278, chars_format::scientific, 241,
        "3."
        "8533883620323423714136812889341534099647891816418950569082704468822715181673302421954378737049884964815594"
        "9225657910076871879456492908086055679238145888180249016876041212016385323048783306274907371194102245759438"
        "57416859827935695648193359375e-84"},
    {0x1.76fe5bdd1cd6ep-277, chars_format::scientific, 244,
        "6."
        "0321909257448322486188799696623295177021420540236469007302485328870820788061538273852486152111947182499602"
        "0430389313128435058945575768397789160853250945403152483495552579619178531893547143208613567133330110592304"
        "15185083984397351741790771484375e-84"},
    {0x1.e827f6053cb84p-276, chars_format::scientific, 243,
        "1."
        "5705072660535393121974894551856858865391970566370239367261961889364900750033565832132944807855682429973423"
        "1165743808838199193559492724914123351980041439654289592979913822692992177082452061483603995980466022652777"
        "2692861617542803287506103515625e-83"},
    {0x1.57fe4f2319e0ep-275, chars_format::scientific, 243,
        "2."
        "2134072641839148014616350155697182746271787657512992252495965052383531821160101822839509773517719903367658"
        "9885091166977969534942621043863491561694472421479566604474002796800759780876778117908416951915753084767501"
        "9458620226942002773284912109375e-83"},
    {0x1.47d634f051b6dp-274, chars_format::scientific, 243,
        "4."
        "2188963156964790091976855129879663206858758676041114580017440270985892530256344542758502021499043746143513"
        "2986767861064045946038194991469606398275313429723392840792584921040979778779308359876410281397596940822225"
        "5196960759349167346954345703125e-83"},
    {0x1.ab161f2c4f9a8p-273, chars_format::scientific, 240,
        "1."
        "0992259537194823078078492322005134697759069190880982299089476477421890699462556853397689401906770390979778"
        "6076941515468432802074130342767290219697959626185832487110501790388370592167474364612702816563355456835893"
        "1646798737347126007080078125e-82"},
    {0x1.e291ca105dbf4p-272, chars_format::scientific, 240,
        "2."
        "4840542381260295931026824878265850213738163806945569103735598853085085998454192004270399375665114378419793"
        "9339093426915978383823920259991198886269275880452442035925336260690735668115500978992897615927476495656378"
        "5744947381317615509033203125e-82"},
    {0x1.05497b2f09b2cp-271, chars_format::scientific, 239,
        "2."
        "6899801291961049649259897509032221460182990193199573687789715730498841548008680282752621494050089364971956"
        "1463605015707114076093509216799977300670476900145388353293690677054565291249211441112205284685587880488810"
        "696988366544246673583984375e-82"},
    {0x1.5c2e8d0a58e74p-270, chars_format::scientific, 238,
        "7."
        "1691442839152966800651789754421125674555953045807849165758253326495394357218725180436693959779826838539023"
        "5241811586085690413191170438571390570469553243783321439188124683995544413425828554208859124188824019086041"
        "51685722172260284423828125e-82"},
    {0x1.150c7af401be8p-269, chars_format::scientific, 237,
        "1."
        "1408995211686882396999673277161942905911769631008359348308702974525173207061901437452806284674796790066877"
        "9068752395048930939229325944194026364434225582687841188243409709254873786228664105033274878825411136062939"
        "4766874611377716064453125e-81"},
    {0x1.bb30e9d725359p-268, chars_format::scientific, 239,
        "3."
        "6501624740693435787870241089127783673137622073205114014170416150615960587516148133472666902880108394136902"
        "2414280357161153404157898726888077804987981004743248455675731222748902769395701614578618140506682809842686"
        "765477992594242095947265625e-81"},
    {0x1.8e26580dfb59fp-267, chars_format::scientific, 238,
        "6."
        "5583965679406291322543386377247490770669733923095682391871457649122662052805566842350436869479069566624479"
        "9577994068697065802161796337967353919150253326164238823498761305697129755079000741114120557814781697913986"
        "13597266376018524169921875e-81"},
    {0x1.2ebd25a1e5a0ap-266, chars_format::scientific, 236,
        "9."
        "9735404360143309836615940606941282378612316332479673006818986372431047284827499250652587489448273074521490"
        "7159098256425409638672402820464938454137381883658245598470175431363044393496375251856344602841009105986813"
        "665367662906646728515625e-81"},
    {0x1.430c70559fa8ap-265, chars_format::scientific, 236,
        "2."
        "1285263571540235575696332659335516392967259876634974541900328449762481882645550424221520486704326122874324"
        "5389964017346232785164042207656441873771873947372771748143644161220111890357661173789620596974447863658497"
        "226424515247344970703125e-80"},
    {0x1.b37b4c8d42152p-264, chars_format::scientific, 235,
        "5."
        "7386670202301382796372027888070564929201692176971669630590876089659777060558652704543784738546830046295004"
        "4603280725800304057600452205270691087995607476359238776203611756090465773659736699519777827771527256572881"
        "01501762866973876953125e-80"},
    {0x1.e7df267017ba9p-263, chars_format::scientific, 236,
        "1."
        "2858099560631301338481970648325266446537589188919690394573293863678630154936269933032378796467868286022293"
        "1313596145811383746152520746396771825426169624107483758544143530277325048406906936058276443024528390424165"
        "991134941577911376953125e-79"},
    {0x1.24edec18cb7ebp-262, chars_format::scientific, 235,
        "1."
        "5440597737151946460972322931613150367282007839535034780293980553235893087580481701735620945314590019229682"
        "9903029002040487140597712979475535950195881357446664740641123548932565198031098388959129683040139013883162"
        "98834979534149169921875e-79"},
    {0x1.e259e5060f8b2p-261, chars_format::scientific, 233,
        "5."
        "0850413106581489843264497391468834239896808424048302785732446399420840399817211944222782861236400064717650"
        "0292091292079844810287479922800960523182642683648046932685960291959579642015772043086609122131136473399237"
        "729609012603759765625e-79"},
    {0x1.74c84ba4bd4a4p-260, chars_format::scientific, 231,
        "7."
        "8598917902586301437063592700391486067845391377030263724566219385264035315415509521990392844610347274677649"
        "3187534013093110305784267349454320227788828198489207064733005870559642487953084957850308223115121109003666"
        "7883396148681640625e-79"},
    {0x1.63e925b45db68p-259, chars_format::scientific, 230,
        "1."
        "5008325529570412331623540869231822246729874856884866752807101484418958561722149716692008029675745594666613"
        "3503364128985836668117456388387335023474589528561716496306845300111545482800773821004114427779541074414737"
        "522602081298828125e-78"},
    {0x1.8cfb3f3c5fcb0p-258, chars_format::scientific, 228,
        "3."
        "3480454826799275168273424149426024516039420592697674339471485209977799621418170443904530724423345933811752"
        "6732740417275913568885136319985690578200693894309818221260736539715042738901337997931006995600000664126127"
        "9582977294921875e-78"},
    {0x1.f7c87448db5fbp-257, chars_format::scientific, 231,
        "8."
        "4975685812240518705712137865350408669165500059723872621242165482954565097487677179811044593228751800199178"
        "5436537587101247795788092235280018313908274894860537262681387520877021653599208068138176619399359879025723"
        "7851619720458984375e-78"},
    {0x1.e5fc8e5d48f9bp-256, chars_format::scientific, 231,
        "1."
        "6394772414307022630918211937753726342439186922700005937997030738726779071510104514297590583407610112272420"
        "1605153941665901729175616786406066510329221717620551523250096943414433377873453800532138613377242108981590"
        "7180309295654296875e-77"},
    {0x1.ae03e4daf2ee0p-255, chars_format::scientific, 225,
        "2."
        "9013155013751830433627264368121165637564844007563220302732139238380508640398659878415626116750234917257035"
        "4358021314491547644576387223565138757629841448907671848335714372372538869101956521268093069920723792165517"
        "8070068359375e-77"},
    {0x1.1b8ab942a6426p-254, chars_format::scientific, 228,
        "3."
        "8261180450693601910659987374822551200498589347100111087127385186891707357059664475499120073190271709835810"
        "2333262835696749317479762874812949441156340532185274119802689659385649761565455131279156475443414819892495"
        "8705902099609375e-77"},
    {0x1.0c1e462c5c1cep-253, chars_format::scientific, 227,
        "7."
        "2359827219547880037182260980171407807010957821836862935778233916886051101359252066396988945460218716415299"
        "8058217929659776342575854014888159205157469067456314240460661266281712378036264886327355583262033178471028"
        "804779052734375e-77"},
    {0x1.e7b34d78e6948p-252, chars_format::scientific, 225,
        "2."
        "6324142915079566794044585228208590792665767389780345214640856391021186677025555855415331925777643406404267"
        "4815827159675201972348758945269748619500474089457136522536683890735534662775902542408701378917612601071596"
        "1456298828125e-76"},
    {0x1.19f7b9144e56ep-251, chars_format::scientific, 226,
        "3."
        "0439003831515615676336056485285756533835399224529189344052214824595214456119324049792258875343600293464605"
        "0603560529499605598396432199482500999142131561233177111438702268476676808609806754168936038240644847974181"
        "17523193359375e-76"},
    {0x1.9243a3c6aa988p-250, chars_format::scientific, 223,
        "8."
        "6850539709499319555594997827933889454841898663613334205733556673628208790371074675294281427261965075820622"
        "1271882727206860063168834267557287655720959306207165641773755143610896424207282184859479912120150402188301"
        "08642578125e-76"},
    {0x1.1fcc03dda0a29p-249, chars_format::scientific, 226,
        "1."
        "2427314157729456479934367418834492113980183267925625403583281509539683257573896953625230295290581867933513"
        "9867126855919765889486660234790771255321938873431482613218900832291311030712967558575776649831823306158185"
        "00518798828125e-75"},
    {0x1.89816794283e0p-248, chars_format::scientific, 220,
        "3."
        "3983797108077041005965221970144927011138697559396869782925070589033970948834132451537407163528766580562328"
        "9119716016152060124454015265884051674568238114179095340987075753721931596282312959544924524379894137382507"
        "32421875e-75"},
    {0x1.c60043d326280p-247, chars_format::scientific, 217,
        "7."
        "8416589235876873864289188382541268098206197299049393893562552331589852548698913622637238112143222399360991"
        "5480134465272471761419124295424633425260765943378864906926742411121021916753370817332324804738163948059082"
        "03125e-75"},
    {0x1.80c28d4967c46p-246, chars_format::scientific, 223,
        "1."
        "3291407760196483165741511994194910753052570869084757495085032652859082885914003067026860815170496007105388"
        "2420687980563833583212875833639219887705559466700038838126004537916422394141710561221714215207612141966819"
        "76318359375e-74"},
    {0x1.a40c7ce612bbdp-245, chars_format::scientific, 223,
        "2."
        "9020896579031938453736117362122286671352965063235487145399744925912078407328282009772735936130948465580980"
        "3814778028095486508264623146907774784542240889474784632658103007257975695107679592332772244844818487763404"
        "84619140625e-74"},
    {0x1.efaf47443919ap-244, chars_format::scientific, 221,
        "6."
        "8493063311021444285262622630853901019739233598253225435361636963656204227414135855331310041156163827176413"
        "6297086180878976214390376525714424271780749287936058534182261326294307462493604621300846702069975435733795"
        "166015625e-74"},
    {0x1.7500215776f19p-243, chars_format::scientific, 222,
        "1."
        "0308144847135353771186145298171097410301970246782425463944124259742140545264889430363986396035589042598392"
        "9655776844273240873118061640991963182770593248030297396972216312970955988826543547887126806017477065324783"
        "3251953125e-73"},
    {0x1.4a99b1bcecb64p-242, chars_format::scientific, 219,
        "1."
        "8272771233005929132884988427301378153940847425631690632810979503758848344768354506461635004842080033192263"
        "3901401061824934045326281599520081408691385773308746157750681691937582554891017494469451776240020990371704"
        "1015625e-73"},
    {0x1.be72480668102p-241, chars_format::scientific, 219,
        "4."
        "9351506696419103240061669265502256149959617111583303561219685377261392905223787116563640644769825543047758"
        "9988217137215046802369061635078622989986340228461792966116610916308424326232051626561769808176904916763305"
        "6640625e-73"},
    {0x1.e7a659213dfb5p-240, chars_format::scientific, 220,
        "1."
        "0781250168794165933748349260234324391026463879289947053114193829482841759135318917268811758748161809004643"
        "2679611225514535349967383908198802533763640615597337848108680394109407845240622414451081567676737904548645"
        "01953125e-72"},
    {0x1.8490c51f45e0cp-239, chars_format::scientific, 217,
        "1."
        "7181272168700195560600399255994575019168872251009996740322328861948515810175299840150713970748225557399786"
        "7396379335700002769043874836031870998424017159999796374606522132792154819447283387034985935315489768981933"
        "59375e-72"},
    {0x1.e2624233f3ae1p-238, chars_format::scientific, 218,
        "4."
        "2659307529076216561467963956055319316897246968344236420579031063442725355740818771410564719833709091988943"
        "0309795900282398265726189862458374678051097719482165551080831781337690013222729845665526227094233036041259"
        "765625e-72"},
    {0x1.d34363be146f9p-237, chars_format::scientific, 217,
        "8."
        "2644256896671227468821316614503358331827205136754073205926088157584837967768526931310522556079545315620199"
        "9752392611005149405019628407058574516126059240841495119417818289946466372986044746085099177435040473937988"
        "28125e-72"},
    {0x1.cc0d98a80a987p-236, chars_format::scientific, 217,
        "1."
        "6273802065732597896113817387260276341030974100457666845629201763813055943005389152933610589184732283144369"
        "5959054192608060281009150208042269805343768362769324987082037382895216212630451479981275042518973350524902"
        "34375e-71"},
    {0x1.0361a6687dab5p-235, chars_format::scientific, 216,
        "1."
        "8350586944381437658146209039595796622558843610506614077602816551920309835339246680605412417590509836746350"
        "0907317990415345399158177353222862249035451776703642604718783418757486330941119945237005595117807388305664"
        "0625e-71"},
    {0x1.334f6d8947b79p-234, chars_format::scientific, 215,
        "4."
        "3482861542842136933757337627047159251109583384931118811727977153338308729167124422446490325358280576021385"
        "3128933592905108885143475829591672376873605604435264983395219417897960278995839189519756473600864410400390"
        "625e-71"},
    {0x1.305f84a10441bp-233, chars_format::scientific, 214,
        "8."
        "6134539761559003805548061531588022181123903542512485056622016306145283431381871224850727794432398272373581"
        "0512724266920229223820220601910535835876168753169487298805997950229204618288747496990254148840904235839843"
        "75e-71"},
    {0x1.c9b7f3905ce9bp-232, chars_format::scientific, 214,
        "2."
        "5905952437250455635059237293015822897473731806321263112212662836451190738319086758301231709882273911943529"
        "3270180444466210678654003519384812165597482919674043077699101118816990552140566705929813906550407409667968"
        "75e-70"},
    {0x1.2cf7988d814d0p-231, chars_format::scientific, 209,
        "3."
        "4068276481875121106288335315725238787330858093186688658099540644480044178549555509113134844354121258224253"
        "4525917021069896218436602993505532330186491208047744444804166320805993706244407803751528263092041015625e-"
        "70"},
    {0x1.2439294be562ap-230, chars_format::scientific, 211,
        "6."
        "6157007521363805395917512221628507674702476236714185773792545977038289879884140448995517698614722807482564"
        "316269955719701793397075413905783271318826294501086750761564164204087123977160445065237581729888916015625e"
        "-70"},
    {0x1.7d0e7e36e5257p-229, chars_format::scientific, 212,
        "1."
        "7253632008143088480986275464805616259466461047557408455579172771296622170925567796958477645145988934861094"
        "3280541592636736407336659321916801029023411688490517352222660438058887688583808994735591113567352294921875"
        "e-69"},
    {0x1.7644d51f65057p-228, chars_format::scientific, 211,
        "3."
        "3892588392445132904880849439603103583240865854698042092539617889110357535583974094512848897341060231911715"
        "668847206489491686550142284002714273859791254064651550505603955741606991836079032509587705135345458984375e"
        "-69"},
    {0x1.10bed5717b54ap-227, chars_format::scientific, 209,
        "4."
        "9397904291451873909412488950158690757659293412589473529426279864502529323852039218836670325495060439451386"
        "0826816969882247207957292424991122060599367981196290341226848470690402592708778684027493000030517578125e-"
        "69"},
    {0x1.97ed031bcbbe9p-226, chars_format::scientific, 210,
        "1."
        "4776181570075499135778399888179597296465432706936910908693639807173018504138725021329993525857491897140530"
        "58229777886958874081655166914945387334176236365795347469506899364122265438936665304936468601226806640625e-"
        "68"},
    {0x1.e87bc17774e5fp-225, chars_format::scientific, 209,
        "3."
        "5388392753930521569458603056975605427089057010706444537751899483971678103585409044068753689573306449520087"
        "3620048630042160735560641391063978204063233997161090636218434661575127364585569011978805065155029296875e-"
        "68"},
    {0x1.4ccad3c275ebbp-224, chars_format::scientific, 208,
        "4."
        "8218563385773112223108708692854480026506826778318969834120319390327162934136818773749592474331651671060117"
        "997507815882786838060737091655122402328021117440941168240798979371941612726004677824676036834716796875e-"
        "68"},
    {0x1.5a61517ffd9c3p-223, chars_format::scientific, 208,
        "1."
        "0037463923948035398952377686954725695708749868243331851405077722286769296317670730594311068901851751621982"
        "905208845752049158036704193593034774538757502752294448392761903876557738612973480485379695892333984375e-"
        "67"},
    {0x1.3760a2aa6c254p-222, chars_format::scientific, 205,
        "1."
        "8046301120677577831156523273751381553004340805312555968258097633741380875846144919225810181030729661426063"
        "465509289312072911372495984143831747178764135517056767525796712181573866473627276718616485595703125e-67"},
    {0x1.b29dcf95ce2bfp-221, chars_format::scientific, 206,
        "5."
        "0377562652737656740740431834806965092754376110615663711189065303770401719757724363364437831625604535900905"
        "0665914162340930680631398943831178102597624583278594631650763868702114223196986131370067596435546875e-67"},
    {0x1.3aa4a3e7fe35ep-220, chars_format::scientific, 204,
        "7."
        "2942263641848924709791974333318552392922497189413454562471159916381061755863392570840931492118884350692330"
        "28642932663345158882507360789118899600106765970543491284065751312226666414062492549419403076171875e-67"},
    {0x1.74467fb9beca1p-219, chars_format::scientific, 205,
        "1."
        "7260576914043516299667521604544099503136894225460607729102546218393499372203570873973193901356203104541651"
        "858702919756674718058411944198830741320724457610150486788942736371410546780680306255817413330078125e-66"},
    {0x1.04460adf3c909p-218, chars_format::scientific, 204,
        "2."
        "4135211264249107986888028696130084430233119968060816832629237084810043354459709587812751305641953795863448"
        "29510636863294535714465088337298135341399152847190355737107270162056238405057229101657867431640625e-66"},
    {0x1.4821325395af2p-217, chars_format::scientific, 202,
        "6."
        "0855030282997452019447514867331630657468044127645732990093511432831652591240656693499304388331948005719576"
        "291647734019028586433069197626384835517846818553661819052591486212122617871500551700592041015625e-66"},
    {0x1.6de490a48e2fep-216, chars_format::scientific, 202,
        "1."
        "3571719432209208961682291759079089652207854358802144505639464668566870317288686062650570379736789869557706"
        "865220772694797664743714525554547694672115452339483210146553471275865376810543239116668701171875e-65"},
    {0x1.9fae33750204dp-215, chars_format::scientific, 202,
        "3."
        "0836891319146542654621676435453427927985346471540079478265100941925579218917725745363008519792667726936509"
        "578521025584579103122413515433971308009849425461816976347384500201087575987912714481353759765625e-65"},
    {0x1.b89a1b615d668p-214, chars_format::scientific, 198,
        "6."
        "5371343011973150852898838767014285054009170245914920231983714940724080952210572962111819974100627028808120"
        "47091371176364709303433877377005013842865407407861123856296359235784620977938175201416015625e-65"},
    {0x1.1205bf14b82bdp-213, chars_format::scientific, 200,
        "8."
        "1312459641492482081166541589604817706874171006980185066355810432118883401318669273227828384881320643830327"
        "7572700842855620364346413336010642698923532080491406205668969420230496325530111789703369140625e-65"},
    {0x1.38bb74b2cee28p-212, chars_format::scientific, 197,
        "1."
        "8559814129506473866421804012367533608804583471137464959335795734206066943305396434753643633830322823523500"
        "5214453273509006641309435920997178527079040475538697363422357966555864550173282623291015625e-64"},
    {0x1.22a0215ce7d73p-211, chars_format::scientific, 199,
        "3."
        "4495677626158958674214395696919224233179649058963110430872447723008494208841922384319206038046498414808280"
        "237161710744628525006862200491884428522247284967078805040241462620542733930051326751708984375e-64"},
    {0x1.43e2f21e78901p-210, chars_format::scientific, 198,
        "7."
        "6887156715407682591023832286745406614960750239691936325646278514953457227545274838167326206011205999045631"
        "11087521684757125178339608488309602901621649250645841588980289316168637014925479888916015625e-64"},
    {0x1.a6c0fc50fb8dcp-209, chars_format::scientific, 196,
        "2."
        "0071439114262729837504870375731843208174931765110570173322624378508420496349832547945412094836606565794537"
        "382968664101699765520520611518293913512915851364397379352766392912599258124828338623046875e-63"},
    {0x1.a43598a7e7224p-208, chars_format::scientific, 195,
        "3."
        "9901264509201541515385647530544570777756931329657382905939255041595638020778163201073900580091263032608950"
        "62982775705487829263395483122897991853489149519963741230554887806647457182407379150390625e-63"},
    {0x1.4514380584fc6p-207, chars_format::scientific, 195,
        "6."
        "1736189512288787578528448418416349991749663700847809784694461643519721427376584527516757457805346764750442"
        "95637676288210916584739439369126886970047830556322654427248153297114185988903045654296875e-63"},
    {0x1.8641944ca7d95p-206, chars_format::scientific, 196,
        "1."
        "4822815568311571387774347113736553185061762803960083516201697860528424266401203404618141803921229407587221"
        "857702493025749782597434002635293362003405325086520527566591454160516150295734405517578125e-62"},
    {0x1.f6b995ecb51e2p-205, chars_format::scientific, 194,
        "3."
        "8189270099686453656944330386880851242990199456831493480657744929486472424859446314843153606613176940390537"
        "7110208626473460382988566967594883564850175212447569439433436855324544012546539306640625e-62"},
    {0x1.3d552fcd337bcp-204, chars_format::scientific, 192,
        "4."
        "8212075626309096460733573704691029512918454861204396148089296640492675485760690343627691702192822676968815"
        "63389639383199305786840112696187596685076424095350855481001417501829564571380615234375e-62"},
    {0x1.c5d7efd89b777p-203, chars_format::scientific, 194,
        "1."
        "3790405547409108597572348642030233030506653548234544771446962869832057530013194054847840729805753756239288"
        "5414951947851272710887256062334379377993422567498515984851792381959967315196990966796875e-61"},
    {0x1.bc2f329491015p-202, chars_format::scientific, 193,
        "2."
        "6993809501677146778769479910183262199839109507301803802721972810548917211929893732348630965943238348446579"
        "057907037793339112719528261592247795018823419872788793583140432019717991352081298828125e-61"},
    {0x1.ae773e40a5fc9p-201, chars_format::scientific, 192,
        "5."
        "2320218954487896785355755028514760124845743029055888558216867850774043141361941613159031705933056320069790"
        "15834175581246399137582629331561177468584472767532123071987371076829731464385986328125e-61"},
    {0x1.54177621d4f18p-200, chars_format::scientific, 188,
        "8."
        "2671699641426339340820628302131200394314879529639688939193883369957348095154029848956018262827562450461879"
        "9767543649932136066178729407262731386312436254737434637718251906335353851318359375e-61"},
    {0x1.8c7e3d8c73527p-199, chars_format::scientific, 191,
        "1."
        "9276428005917081988903274894497209583789235200873622102196547773359677427329917758697233946248094995833163"
        "9251543454284154774391128234192554058215314342905610800471549737267196178436279296875e-60"},
    {0x1.1d175cef3afb0p-198, chars_format::scientific, 186,
        "2."
        "7720738716829783366211423523072899760981646584179840305538218818577604522061421136502687349701011005022293"
        "19779605131760929109482801560084493683148998410814556336845271289348602294921875e-60"},
    {0x1.4475513c62602p-197, chars_format::scientific, 188,
        "6."
        "3097149258933373555396693520858956722428887774266681519521577936216995977632340581826830951793982217486997"
        "0049426645388404390460596730442919006912917689877673410592251457273960113525390625e-60"},
    {0x1.777b0397564a0p-196, chars_format::scientific, 184,
        "1."
        "4603881466067395019154406506648622335799728217146120546120015685836648701405196240311851355498324046529694"
        "693589869018846255688032266344721977514853339386036168434657156467437744140625e-59"},
    {0x1.335f347ccd407p-195, chars_format::scientific, 188,
        "2."
        "3909749954573929098486304712726443669214066244454384679654334105674731318682311463077318753893093869615216"
        "2587410648990459456387497476367966217701381548277339561536791734397411346435546875e-59"},
    {0x1.cb7fe420097c3p-194, chars_format::scientific, 187,
        "7."
        "1486821832535713452582704014218377603862581434335880398190116453503559511534348413760937020125432455684447"
        "563995618441814110812057986298391571637449171117140167552861385047435760498046875e-59"},
    {0x1.2b9e54a754171p-193, chars_format::scientific, 186,
        "9."
        "3226518683238715224399565661749611547006242370061528887320716195165308684845154101442598457938086015001409"
        "04741554326054101316920396718331088344207391305218379784491844475269317626953125e-59"},
    {0x1.61db13efbac84p-192, chars_format::scientific, 184,
        "2."
        "2020498812644948762033635142117124936558159878950024605332256666966723974999759217940229530756811212534736"
        "376207515633057521771033537451227692950672665261890870169736444950103759765625e-58"},
    {0x1.b0d988ed3cddap-191, chars_format::scientific, 184,
        "5."
        "3872611595972931554175099145771626677167753110603582724995579755815059161748788482588937205208507054423401"
        "377376127275846562117768446237202968791824009286983709898777306079864501953125e-58"},
    {0x1.5aae85fd3e364p-190, chars_format::scientific, 182,
        "8."
        "6296228594991325157229731878859944777554471925473343599866427363221069537701112240904539206861116322405729"
        "0877271989319006564197611655622440797464012263162658200599253177642822265625e-58"},
    {0x1.b03e8e5e29e8cp-189, chars_format::scientific, 182,
        "2."
        "1518906041456636649540146948591549576372380444424980691438719151181009657554823177254366549770014614706032"
        "8618439467737562606935278910241424697724621495353858335874974727630615234375e-57"},
    {0x1.4f61610cf1a2cp-188, chars_format::scientific, 181,
        "3."
        "3393236367487654889340514543993395885414094092298264710390768628882191685264273016078445381612177618356717"
        "142797177462480388287308407104197853498828152396527002565562725067138671875e-57"},
    {0x1.b36be913bc32ap-187, chars_format::scientific, 181,
        "8."
        "6708313720945146475351007645513441880275082684907503647662074215317905170752758954050433985625724643831520"
        "591378420182088554349024731181705578919594046283236821182072162628173828125e-57"},
    {0x1.c8e61b78565d0p-186, chars_format::scientific, 178,
        "1."
        "8197046818766602603686632095754096661651615753540376705159513693924449853347371957727126685333242730655442"
        "106873499937217143284318981587451002912558806201559491455554962158203125e-56"},
    {0x1.1775e38a634cbp-185, chars_format::scientific, 181,
        "2."
        "2260313359925404901383328255729970205956519425128348372731656993019288377550164061818329912332283919450786"
        "272972464419724461788385182721742260036901228659189655445516109466552734375e-56"},
    {0x1.0e15175ca8a3cp-184, chars_format::scientific, 178,
        "4."
        "3026606722410031733302677078662118124311005158053603782297542165579613935866431571476014496940810383434619"
        "138429936362412482276547319426894533389571506631909869611263275146484375e-56"},
    {0x1.4acfbe5469d34p-183, chars_format::scientific, 178,
        "1."
        "0540262429918153965846666776264916628183054605768575074287470826265255183716784817538128179345311968289342"
        "157486633140791923370468402402534702222425266882055439054965972900390625e-55"},
    {0x1.e17bb356e6d2cp-182, chars_format::scientific, 177,
        "3."
        "0681879985386225718752955391330904327341113602244606377562999866621196092449560501454295722110444234867058"
        "60565642117224838768142549934141161127598707025754265487194061279296875e-55"},
    {0x1.ae1fe199896b9p-181, chars_format::scientific, 178,
        "5."
        "4818233542942428453861995676140864431915789921130840684049211074743678696081616378159770391924796871267297"
        "084151393359730921440980329112542535074936722594429738819599151611328125e-55"},
    {0x1.a3e5b17d50316p-180, chars_format::scientific, 177,
        "1."
        "0702958332703832567616253901818145919920308310633570412149764544456728717958501944115424465582180828240141"
        "48718865247007996674714476958122089111924424287280999124050140380859375e-54"},
    {0x1.96b34187d54c0p-179, chars_format::scientific, 171,
        "2."
        "0733146515683786499609111229893863241245076553478564325616037441745856391159383548352298797077518654354117"
        "66550177248096035898124699092814893219838268123567104339599609375e-54"},
    {0x1.675af8398ba55p-178, chars_format::scientific, 176,
        "3."
        "6639110494840281694548174991298603448018526659230862490333249247127707514516761738926902815833573835511573"
        "0033554552298718973314046770846375000729722160031087696552276611328125e-54"},
    {0x1.5dd2845405124p-177, chars_format::scientific, 173,
        "7."
        "1334288244990372312224907648096701095619611996252745460578769413617469873020204065524906820710806990110295"
        "5125093074988767111613914735646080345077280071564018726348876953125e-54"},
    {0x1.1b379a2950eacp-176, chars_format::scientific, 173,
        "1."
        "1550490218152729646319151841501684609404232393195007305328016237754776338400569798686076059288528676396276"
        "3889248411112118081783719895916373587851921911351382732391357421875e-53"},
    {0x1.050c080bc80d1p-175, chars_format::scientific, 174,
        "2."
        "1292639261534582404213908408502234742842056862369668785710500233303706301115784477889068818329602152581373"
        "76334762627097723751361355200295566447721284930594265460968017578125e-53"},
    {0x1.b43a3871c2fbap-174, chars_format::scientific, 172,
        "7."
        "1162918935221443051517621235069819357956135232874696046768179379869415044499101446193354791112976594195410"
        "557422635999734494396452323672352946459795930422842502593994140625e-53"},
    {0x1.df22454bc74f6p-173, chars_format::scientific, 172,
        "1."
        "5632471909265050611068051615951617519978312479534271514571791116510630486516616104887110827559419704430548"
        "593022161692046697459355757142684950622424366883933544158935546875e-52"},
    {0x1.b833d723fe25ap-172, chars_format::scientific, 171,
        "2."
        "8724553500903598028572546383001781149110271282722642567137230852108467397456216094989216899040621575989169"
        "04794959450945984543606716299368741829312057234346866607666015625e-52"},
    {0x1.f684b3c7cc0acp-171, chars_format::scientific, 169,
        "6."
        "5581707069521569877856870724319603779730281282161256613335172096317790203054916032047180861903076571475476"
        "949770983954945174541038832582984241525991819798946380615234375e-52"},
    {0x1.a5b141082f7b4p-170, chars_format::scientific, 169,
        "1."
        "1006685169756962680050220555041590876254318428865998856904568826933953891310864740495265959403191562163377"
        "069746200609492539396368215864896455968846566975116729736328125e-51"},
    {0x1.4fff666a560aep-169, chars_format::scientific, 169,
        "1."
        "7539896072768474874561864155705114932844071436878901874932631783846705575216123230523996677805058270426469"
        "440568499952626504620988023841476888264878652989864349365234375e-51"},
    {0x1.668bb57ef8bccp-168, chars_format::scientific, 167,
        "3."
        "7433921715043594589736460314331405184962182591207676516772049221533184130039279221624312002874994124075876"
        "8607887085263453345700124241801631796988658607006072998046875e-51"},
    {0x1.dcd176deeeae3p-167, chars_format::scientific, 168,
        "9."
        "9564289980093796889603154154145876739448114195979055992690259022457312971712705761139632367260793438914366"
        "37755164485333344410143696645576483206241391599178314208984375e-51"},
    {0x1.16a3865422377p-166, chars_format::scientific, 168,
        "1."
        "1636497924322522189729705224278622993088292323624873159489348884349299835648653258490495496200575681563301"
        "93520858451476789898436370318535182377672754228115081787109375e-50"},
    {0x1.bce21dad63749p-165, chars_format::scientific, 167,
        "3."
        "7158384115949350614737820871904816925077956940869230941314885111502890909776030181321957172434491271547923"
        "1680692485678623002316733892058664423529990017414093017578125e-50"},
    {0x1.89eeefab48d10p-164, chars_format::scientific, 162,
        "6."
        "5805696341773827568201073427914990313810882433786527452734017775108553768567645871412871223414498597936013"
        "24190138180379207322179269112893962301313877105712890625e-50"},
    {0x1.8fee5ccadb200p-163, chars_format::scientific, 157,
        "1."
        "3361521745438592840663955655631716549469431650538517476774582035584703495979290821050139073573949863898319"
        "932246070741721499786081039928831160068511962890625e-49"},
    {0x1.07380dad14bcap-162, chars_format::scientific, 164,
        "1."
        "7588058594724069068378151340006562382389089937477477155953047822519153788093489690886862546961352922261512"
        "7616072031613314065323638857307742000557482242584228515625e-49"},
    {0x1.0b59bf6c21943p-161, chars_format::scientific, 164,
        "3."
        "5728259387967835757810502314748228560336702191385482390899073723989786692440757890127298326923356779924206"
        "4063605352086812859402353836912880069576203823089599609375e-49"},
    {0x1.fa531504c2a95p-160, chars_format::scientific, 164,
        "1."
        "3532863609445874625424619828095184220811044476992203391714726909818173064528541715965734117428727450051983"
        "0798601500848545205191175710979223367758095264434814453125e-48"},
    {0x1.bcfee137bb727p-159, chars_format::scientific, 163,
        "2."
        "3787372002095833385126791878777862375484338276605231718277360413206612063565553320217163353776596974116930"
        "802973502625109573915818117484377580694854259490966796875e-48"},
    {0x1.151cd5ef2d805p-158, chars_format::scientific, 162,
        "2."
        "9626275330019588245631947287909396699745270360057415499881998525739843605313927572634283409800720682223941"
        "17076967551033424286277551118473638780415058135986328125e-48"},
    {0x1.a50d5e23e121ep-157, chars_format::scientific, 160,
        "9."
        "0029880689123645099794460485807721339684096115950637844009362876227390039831564636627226957537724402162583"
        "602570082390824379725557946585468016564846038818359375e-48"},
    {0x1.82802e4264badp-156, chars_format::scientific, 161,
        "1."
        "6528407152844144785500614973455273336999912777463385056299104335915202959708996003513567290694805135376868"
        "9247248694610022134998672527217422612011432647705078125e-47"},
    {0x1.2177668084382p-155, chars_format::scientific, 159,
        "2."
        "4757619185369808203021240003521593381209663272308204986803350240581317601172411555122448494060667114028109"
        "01342339011156623573839397067786194384098052978515625e-47"},
    {0x1.03b3d0af74440p-154, chars_format::scientific, 153,
        "4."
        "4423898749490084399433969599509826144329330591332567939146106957870737458728262016757657867649861507909368"
        "67056336867509713783874758519232273101806640625e-47"},
    {0x1.d2d07d1f0f329p-153, chars_format::scientific, 159,
        "1."
        "5970369012122509593184775144635604659721100528580203484536611149954537884269829964378340152297825770815400"
        "55113898402168459700334324224968440830707550048828125e-46"},
    {0x1.8fa32bc4d85bap-152, chars_format::scientific, 157,
        "2."
        "7344299616431543522432421912792718134436427057605665499943091928202467144496467783172463158734772458732489"
        "503583523195173743403074695379473268985748291015625e-46"},
    {0x1.67c2abce8df9dp-151, chars_format::scientific, 157,
        "4."
        "9231615603464207242007921876013588518601290251044916876629241339050523954671848627932540076411043836705992"
        "149190718766560426189471399993635714054107666015625e-46"},
    {0x1.73f3b6e413e35p-150, chars_format::scientific, 157,
        "1."
        "0179995696026282273811276434771842619116554426387226609081999306437938716096066552645975664851424917170160"
        "429284839383179406269164246623404324054718017578125e-45"},
    {0x1.7a95dc8122d45p-149, chars_format::scientific, 156,
        "2."
        "0723091166540273850593168126191139912345243921985305222697460100039055010978950792132675510399982633713397"
        "43302659321122494162636940018273890018463134765625e-45"},
    {0x1.af1bf9e405f36p-148, chars_format::scientific, 154,
        "4."
        "7196310508913904671194894358782925911776121787765422306796132134761227959946314353602058140317633579755078"
        "227792840228627113674519932828843593597412109375e-45"},
    {0x1.93bd4a776ff22p-147, chars_format::scientific, 153,
        "8."
        "8399910274584726229868620813946972911876446658509805639346664857566354389109651130454527996512493390832109"
        "06594691158577603573576197959482669830322265625e-45"},
    {0x1.998a4f77b7f72p-146, chars_format::scientific, 153,
        "1."
        "7934004954654291024566203990087592056831316726175324954536665777161166202131665464671804424276289424204482"
        "57652650092541790627365116961300373077392578125e-44"},
    {0x1.e2ee6bf0a5651p-145, chars_format::scientific, 153,
        "4."
        "2295683591056470906800337028618844741657141766568221367835581227246587308429206335630344989589287675262730"
        "91660778125078223865784821100533008575439453125e-44"},
    {0x1.80940300d356fp-144, chars_format::scientific, 152,
        "6."
        "7363600023840417999542393041775431286862924968647585475108908864653553304615525710316981002244346312871708"
        "8829987280629296719780541025102138519287109375e-44"},
    {0x1.fb7e121e4f09ep-143, chars_format::scientific, 151,
        "1."
        "7778710260255370823068118815744034545239196175044810566452485059711823829134148938595203744881815979364219"
        "466006546976899471701472066342830657958984375e-43"},
    {0x1.db7f5ce10385bp-142, chars_format::scientific, 151,
        "3."
        "3315696595658846047469585592309601760666312357714637907805304801690666734362639697081633088940864280810672"
        "903680724754593711622874252498149871826171875e-43"},
    {0x1.1d9d22c7f3534p-141, chars_format::scientific, 148,
        "4."
        "0023019609904230460306129375468853345556873060242695191434355850628634523560076237997206470162408844618039"
        "983898061251466060639359056949615478515625e-43"},
    {0x1.8e16e3aa24c6fp-140, chars_format::scientific, 150,
        "1."
        "1156841616796604932136274348484852039247641538297458130288766038216630495392051161520698228292050021146544"
        "20551642655112800639471970498561859130859375e-42"},
    {0x1.87e3f754c260dp-139, chars_format::scientific, 149,
        "2."
        "1966221825446393623879986362588124795901767213242488227182002426802973438517357803464949551156413886798953"
        "6864355759604450213373638689517974853515625e-42"},
    {0x1.fa5d32abaa11cp-138, chars_format::scientific, 146,
        "5."
        "6765373748004688332440652788786161538895277758131917477071063157004169835839984069461934543412473811103188"
        "1204748827940420596860349178314208984375e-42"},
    {0x1.f67503a2182bbp-137, chars_format::scientific, 148,
        "1."
        "1265477503439072834143778179138023300408281899179844848603578440471818264924572994395463590144925447532309"
        "702169950327288461267016828060150146484375e-41"},
    {0x1.db3ed18fbe233p-136, chars_format::scientific, 147,
        "2."
        "1310740108629266741825276640768152345702055957167240124922338099906733105461315720740092281151001145210075"
        "94603485557627209345810115337371826171875e-41"},
    {0x1.8335b0765d557p-135, chars_format::scientific, 146,
        "3."
        "4726169049944299879453329939481586991700522073634174410762170911503198790930241004432988390365801374063802"
        "6145557404333885642699897289276123046875e-41"},
    {0x1.4dbf09123267bp-134, chars_format::scientific, 145,
        "5."
        "9862794573467662440074595060500155028664274136233854601575667668611139098768423815169512058364388094422285"
        "646611925358229200355708599090576171875e-41"},
    {0x1.5e56a8ce3c277p-133, chars_format::scientific, 145,
        "1."
        "2567777808329330013217753137114716276021058025597090076586824197836408715656044366011499934739896008786645"
        "686949867695147986523807048797607421875e-40"},
    {0x1.bb079ee8f4d5cp-132, chars_format::scientific, 142,
        "3."
        "1785827035279190121784119339542902927547255686713026008937054510447409625558295054802900095791530292975435"
        "312285981126478873193264007568359375e-40"},
    {0x1.4f6e275cf1a76p-131, chars_format::scientific, 142,
        "4."
        "8131885839189464342630285810238985752699527646604098580088304609518450064927286820639649469111945897896454"
        "038544789000297896564006805419921875e-40"},
    {0x1.6e0c8ad2bb37cp-130, chars_format::scientific, 141,
        "1."
        "0505090911062820335561411705941054623172870846458893207124770055231061069218704308882579307096982170963150"
        "87104585472843609750270843505859375e-39"},
    {0x1.98e433996597fp-129, chars_format::scientific, 142,
        "2."
        "3469216079446797138739112899579158124687027232331769891232554936238609927331878316423045145059373263289603"
        "794845561424153856933116912841796875e-39"},
    {0x1.42726d8c4369ap-128, chars_format::scientific, 140,
        "3."
        "7015098458206448453351979822608106339451489448555898068736741171041629697322955547340351680885679134386245"
        "7921431996510364115238189697265625e-39"},
    {0x1.486454058df80p-127, chars_format::scientific, 133,
        "7."
        "5395084299958847860449433646301178540543942807329687696496446852570945235346855720548050138439533096601508"
        "077583275735378265380859375e-39"},
    {0x1.6661274c7f05cp-126, chars_format::scientific, 138,
        "1."
        "6455979868696783534082063751133429136529036015164918660712006211854998013425847958975152867999508163321387"
        "14415123104117810726165771484375e-38"},
    {0x1.3aa7b44b0a502p-125, chars_format::scientific, 138,
        "2."
        "8896506750036806475577971922835255312815452296746498235731599185088314959519438221419769631184574013027521"
        "74387933337129652500152587890625e-38"},
    {0x1.9fd27c3ae95f7p-124, chars_format::scientific, 138,
        "7."
        "6374477588979438591229722951487526821041612993472034040866978911302507182089909043356325487765306689325051"
        "08159602968953549861907958984375e-38"},
    {0x1.da78946cc5490p-123, chars_format::scientific, 134,
        "1."
        "7429312422110310718977979413748775963737044267099005799918778562901268253551041976159609585717708002405856"
        "8596956320106983184814453125e-37"},
    {0x1.f203ac3519f18p-122, chars_format::scientific, 134,
        "3."
        "6588315678322708272314019672027802295093711627258677622098624893717512039023793281375763542569851116681434"
        "1777353547513484954833984375e-37"},
    {0x1.b49aae7f5cad1p-121, chars_format::scientific, 136,
        "6."
        "4153225021810435302055377998130934309169404574711166917674284394429969174601750224385013791146732675674257"
        "961873081512749195098876953125e-37"},
    {0x1.b661988bbdc4bp-120, chars_format::scientific, 136,
        "1."
        "2882866599344565053618788391492597985347367160360079978812335056300495851823386955130707091986101697766997"
        "631333651952445507049560546875e-36"},
    {0x1.7dc73059f4d49p-119, chars_format::scientific, 135,
        "2."
        "2438898905531304113205534342267833215945294680111818683410060358815191180269281387787392467074790158854113"
        "99722215719521045684814453125e-36"},
    {0x1.cdb2f9141b525p-118, chars_format::scientific, 134,
        "5."
        "4272469927212228398680026288174857747043423993740677691930900376873032761152811202056904353336480584246714"
        "8977448232471942901611328125e-36"},
    {0x1.ca41b4813a41ep-117, chars_format::scientific, 133,
        "1."
        "0773562313702051217542870690540839915318470195130197080844837846839614171734258592932298947107694342406603"
        "027484379708766937255859375e-35"},
    {0x1.81c487a032056p-116, chars_format::scientific, 132,
        "1."
        "8138709823870134963339439770612428318675600824578467344813375616044665156285156623700098024384863570901416"
        "09660349786281585693359375e-35"},
    {0x1.72bcb5fff535bp-115, chars_format::scientific, 132,
        "3."
        "4863954234406462550691749145030310991616513432575743908019034815279292363755361258808440757736568649249875"
        "30685029923915863037109375e-35"},
    {0x1.8bd7918860dbbp-114, chars_format::scientific, 131,
        "7."
        "4449617683806484935384150283945931186617540420755360525592411297979559594039747096401091457779086724144690"
        "3790347278118133544921875e-35"},
    {0x1.a7f69dcd72222p-113, chars_format::scientific, 130,
        "1."
        "5947728558224362995607999419897654924356426479146237070985315256260841154700059297961143613131529406246045"
        "255102217197418212890625e-34"},
    {0x1.eb4294b46da96p-112, chars_format::scientific, 129,
        "3."
        "6958300841764796394552603076512147534499147838425848046122473845261325916666391709798763706706914433652855"
        "22304475307464599609375e-34"},
    {0x1.45d8b318ecb26p-111, chars_format::scientific, 128,
        "4."
        "9027929571472789278384447568697681490197245669783486622993745123202427301521908282403838102991855407708499"
        "1149604320526123046875e-34"},
    {0x1.c95d0b441f711p-110, chars_format::scientific, 129,
        "1."
        "3763280779744355993441768388857348578041188915187008104911491475416457823921091900787544784479088377793232"
        "21184313297271728515625e-33"},
    {0x1.98333d0f2d03dp-109, chars_format::scientific, 128,
        "2."
        "4567652907408954862171758719761037178820726837148989034299592147290607067172199302776489787669689235372061"
        "3755285739898681640625e-33"},
    {0x1.dfd8b02992707p-108, chars_format::scientific, 127,
        "5."
        "7759413981215069525017042272423165722552378432976327150239566602665492393820853640382627369742607470470829"
        "866826534271240234375e-33"},
    {0x1.18e3e3b1a223ep-107, chars_format::scientific, 125,
        "6."
        "7621854242881406431627770947480800315291558269137007328403548746185753195763627266309109264952326157072093"
        "3377742767333984375e-33"},
    {0x1.9658328cb8114p-106, chars_format::scientific, 124,
        "1."
        "9564777034032247331266106351051660587948852300059958121203145251012029185530780310726950421695846671354956"
        "924915313720703125e-32"},
    {0x1.86c79844889d0p-105, chars_format::scientific, 121,
        "3."
        "7630713133101953008740171427121495587283910326243938739987716991334361642764145573780698583732373663224279"
        "880523681640625e-32"},
    {0x1.27dcf92066d8bp-104, chars_format::scientific, 124,
        "5."
        "6981175081206400922391655083797863384815261135600412746592359796806200489991016465245177169407497785869054"
        "496288299560546875e-32"},
    {0x1.b6c8ffb6a90c2p-103, chars_format::scientific, 123,
        "1."
        "6901389263110543181102365648652894274606301487002452251574237197576175408299383818092054276860380923608317"
        "97122955322265625e-31"},
    {0x1.39b18e81b6f59p-102, chars_format::scientific, 123,
        "2."
        "4166074419571089575889751347120191547305858469115993073742053892915281348533368963385492556028566468739882"
        "11154937744140625e-31"},
    {0x1.58ad465068c9ap-101, chars_format::scientific, 121,
        "5."
        "3105877964807320710292501984853581657899622371005556307571107853309782196652680426318671180752062355168163"
        "776397705078125e-31"},
    {0x1.9d0ed395b4c84p-100, chars_format::scientific, 120,
        "1."
        "2728329747902230165316181540568536882833839113574207013715404328367409245034930567741504603418434271588921"
        "54693603515625e-30"},
    {0x1.bf9c0e64057fbp-99, chars_format::scientific, 121,
        "2."
        "7586071091388190196112205187915629121694961798162398502469066619619835167200191071434911549431490129791200"
        "160980224609375e-30"},
    {0x1.f3a0cebf107f8p-98, chars_format::scientific, 117,
        "6."
        "1583924748384136682512359017261255450407522093971748312640088161632302368340627363174633046583039686083793"
        "64013671875e-30"},
    {0x1.8d2ccae7cd365p-97, chars_format::scientific, 119,
        "9."
        "7911189758325206052557743537635646483728105421101526676208264656982528338082742008774417286076641175895929"
        "3365478515625e-30"},
    {0x1.aa0b3a331c5bcp-96, chars_format::scientific, 117,
        "2."
        "1005583908999635980523814595285630437648644793626080509594614990803394929735556373451288436626782640814781"
        "18896484375e-29"},
    {0x1.4b814b3a1cb61p-95, chars_format::scientific, 118,
        "3."
        "2688922135094771214795507178565946598481426142285005760621407779950612653330384305139233447334845550358295"
        "440673828125e-29"},
    {0x1.f4068960578d7p-94, chars_format::scientific, 117,
        "9."
        "8612648786366515414854961643790399130167377288239167225981380011826524576009841971391267634317046031355857"
        "84912109375e-29"},
    {0x1.f62c0cec38831p-93, chars_format::scientific, 117,
        "1."
        "9807195772041244841383550163089449103868726897978856906267460422507129962120878130527046323550166562199592"
        "59033203125e-28"},
    {0x1.37c69791af80ep-92, chars_format::scientific, 115,
        "2."
        "4594770057660368495756651818864062387955645568161205513648519067289568355676177002777649249765090644359588"
        "623046875e-28"},
    {0x1.c42f82f902ae4p-91, chars_format::scientific, 113,
        "7."
        "1342307123642233045958095225167156992008276425321789727449239863317162219785716459341529116500169038772583"
        "0078125e-28"},
    {0x1.ab5c60a4631b5p-90, chars_format::scientific, 115,
        "1."
        "3485130668183937590444128052855465890028802588861696634054925499593654875281345528748033757437951862812042"
        "236328125e-27"},
    {0x1.163adde1f573ep-89, chars_format::scientific, 113,
        "1."
        "7558778301243823121155271808116835370371045792990942242404584251962271126273895660574453359004110097885131"
        "8359375e-27"},
    {0x1.6cc1d8ecb558ap-88, chars_format::scientific, 112,
        "4."
        "6038833248427952809663776964936140725404629123882134521116254371057353346474716460079434909857809543609619"
        "140625e-27"},
    {0x1.0cdf536fb5eefp-87, chars_format::scientific, 112,
        "6."
        "7872927594290552636925886720441058685794883580176619836663438543506473958621949549296914483420550823211669"
        "921875e-27"},
    {0x1.cf43fecae092dp-86, chars_format::scientific, 112,
        "2."
        "3388936048665310851316745468303563301324829126576636843972225326095050641772576938137717661447823047637939"
        "453125e-26"},
    {0x1.f45a241c9839ap-85, chars_format::scientific, 110,
        "5."
        "0522652313759764410835719385889967890520096634286257939712790137828674758013747236873314250260591506958007"
        "8125e-26"},
    {0x1.0e0770a686d83p-84, chars_format::scientific, 110,
        "5."
        "4531934926351591660177398201938298068678042808590523162341841824872750582597902280213020276278257369995117"
        "1875e-26"},
    {0x1.0248f281384bap-83, chars_format::scientific, 109,
        "1."
        "0432046065743156487678104545227567829109732926698293352119589937000883328455103082887944765388965606689453"
        "125e-25"},
    {0x1.ac4e19937ae27p-82, chars_format::scientific, 109,
        "3."
        "4598208650514789897486706324846604978683020740045778389727925607329515889087900859522051177918910980224609"
        "375e-25"},
    {0x1.3087a7746f421p-81, chars_format::scientific, 108,
        "4."
        "9199458656109230376671766694383649258995953059687000036237194733378455535621753824671031907200813293457031"
        "25e-25"},
    {0x1.70783708f772ap-80, chars_format::scientific, 107,
        "1."
        "1905894569192662776098050199813402280754741687796493203055674863031360155574134296330157667398452758789062"
        "5e-24"},
    {0x1.e065c19de1dc4p-79, chars_format::scientific, 105,
        "3."
        "104495987602903687782546492307846204182230640542680505726853422594768705522483287495560944080352783203125e"
        "-24"},
    {0x1.c685d70ae0fe0p-78, chars_format::scientific, 101,
        "5.87456966397771796422682549439311465967828126938704643526518826834870168340785312466323375701904296875e-"
        "24"},
    {0x1.a0780c9dec656p-77, chars_format::scientific, 105,
        "1."
        "076546984317854350454897139142567232421318914071250535456926162962421056334960667300038039684295654296875e"
        "-23"},
    {0x1.3cb9bbf0aea75p-76, chars_format::scientific, 105,
        "1."
        "637432580904225448218479784931625372923561979340250699162731128251391243821899479371495544910430908203125e"
        "-23"},
    {0x1.f0a2b8fd92f2fp-75, chars_format::scientific, 104,
        "5."
        "13509211207940396346808840622328108640224488399038307803406533218193441570065260748378932476043701171875e-"
        "23"},
    {0x1.bb04bcebdd6ffp-74, chars_format::scientific, 103,
        "9."
        "1614080145176778862206576960425700831949207923387370233170279819334691495669176219962537288665771484375e-"
        "23"},
    {0x1.0b62fe692a947p-73, chars_format::scientific, 103,
        "1."
        "1058854487286021576603725304903163539918366413893061214895083103904038779319307650439441204071044921875e-"
        "22"},
    {0x1.272fe8508d433p-72, chars_format::scientific, 102,
        "2.441730781169199364855750861362078623225251480968477216777312403805932916611709515564143657684326171875e-"
        "22"},
    {0x1.a4da532053764p-71, chars_format::scientific, 99,
        "6.962426049274538699439196410633694865008161302307608512174481874001941150709171779453754425048828125e-"
        "22"},
    {0x1.93f477225bbbep-70, chars_format::scientific, 100,
        "1.3365747882614801032463352914308130925659506904834814518322032295127854695238056592643260955810546875e-"
        "21"},
    {0x1.dac01e869bf58p-69, chars_format::scientific, 97,
        "3.1416350487962486701379607843901811256471115918449956111273280168205701556871645152568817138671875e-21"},
    {0x1.d259d75a5b1c3p-68, chars_format::scientific, 99,
        "6.172103329535160089255730652790336729118966059186200003960735827046590884492616169154644012451171875e-"
        "21"},
    {0x1.21e65c14b2260p-67, chars_format::scientific, 93,
        "7.673584938657739735290448393622396219109761654559513470441611815431315335445106029510498046875e-21"},
    {0x1.247adaeef533dp-66, chars_format::scientific, 98,
        "1.54837571490893774333213229345009640160216876301445875570468591053696627568569965660572052001953125e-20"},
    {0x1.8590b3c7299d1p-65, chars_format::scientific, 97,
        "4.1246824511333552476207424120489015258619773211916720236265565535660471141454763710498809814453125e-20"},
    {0x1.c16c9cb03d8aap-64, chars_format::scientific, 95,
        "9.51692901231032540579231072092779398477634354654546553799188135513986708247102797031402587890625e-20"},
    {0x1.afab9cd6fe545p-63, chars_format::scientific, 96,
        "1.828195094563646962244514682444059838175275831433078317124485412392687067040242254734039306640625e-19"},
    {0x1.f3fa50d429d7dp-62, chars_format::scientific, 95,
        "4.23497665979731430374210700758894838217662945466715084148756620407993978005833923816680908203125e-19"},
    {0x1.28c638f71d180p-61, chars_format::scientific, 87,
        "5.027552313830036048120204027398570440831332829627331459931838253396563231945037841796875e-19"},
    {0x1.9f197cec56a5bp-60, chars_format::scientific, 94,
        "1.4064120230650801115977574752674439808505632504024500210870751715219739708118140697479248046875e-18"},
    {0x1.23514676b2275p-59, chars_format::scientific, 93,
        "1.974044039127005690154809950489990254937712867841699028448321229234352358616888523101806640625e-18"},
    {0x1.742a3899f4ebfp-58, chars_format::scientific, 92,
        "5.04377526843796603941025189601750138415420441259629479036075139219974516890943050384521484375e-18"},
    {0x1.a24fa5ce867fbp-57, chars_format::scientific, 92,
        "1.13383457288879493881896180602251467830667152418533914770559789531034766696393489837646484375e-17"},
    {0x1.cd8bd478c4055p-56, chars_format::scientific, 91,
        "2.5020470223212867241998736287413513640192596398166731408441165740441647358238697052001953125e-17"},
    {0x1.5586beb808bb7p-55, chars_format::scientific, 90,
        "3.702836080714707117409232632738353992936433317704862655528330606102827005088329315185546875e-17"},
    {0x1.1782f85ff73e4p-54, chars_format::scientific, 87,
        "6.060941731133067066111993215447123683291462078494282739171694629476405680179595947265625e-17"},
    {0x1.5241f4d37d585p-53, chars_format::scientific, 89,
        "1.46695868126617733676316434964942825427625379777242520251689938959316350519657135009765625e-16"},
    {0x1.a9145af5d709dp-52, chars_format::scientific, 88,
        "3.6869770513056370258874447534099887412925645774515459596187838542391546070575714111328125e-16"},
    {0x1.14e3531aa8734p-51, chars_format::scientific, 85,
        "4.8032409094989299117442762699440752432309049459180361196786179789341986179351806640625e-16"},
    {0x1.8d306ae29c760p-50, chars_format::scientific, 82,
        "1.3780266196844444434001720951926995236184146642610670596695854328572750091552734375e-15"},
    {0x1.34141b1c6e739p-49, chars_format::scientific, 86,
        "2.13772429398483853817359285620068290943482478168313765110042368178255856037139892578125e-15"},
    {0x1.bfaa985695d46p-48, chars_format::scientific, 84,
        "6.212619127432842815535315316465814989023408974888607048114863573573529720306396484375e-15"},
    {0x1.a1bbef9dd867ep-47, chars_format::scientific, 84,
        "1.159445109391313455470569692597092094861802556715613121696151210926473140716552734375e-14"},
    {0x1.d4c0489e284adp-46, chars_format::scientific, 84,
        "2.602091364932322080817661116014788518557084191773487447107982006855309009552001953125e-14"},
    {0x1.5256e07f25dcdp-45, chars_format::scientific, 83,
        "3.75632150992183886471662319623894115764293523407335584352040314115583896636962890625e-14"},
    {0x1.71a8a2ed2b45fp-44, chars_format::scientific, 82,
        "8.2080728005574479728778617018482662413977023196931526172193116508424282073974609375e-14"},
    {0x1.b0e4af6682317p-43, chars_format::scientific, 82,
        "1.9224324416725509019750615142710900007101508524254285248389351181685924530029296875e-13"},
    {0x1.7b8de5bf78fd4p-42, chars_format::scientific, 79,
        "3.3711192675176746235914191322624765202904673078165842525777406990528106689453125e-13"},
    {0x1.ae59a0cb674f4p-41, chars_format::scientific, 78,
        "7.644553608444342585595182827876899211462513594739220934570766985416412353515625e-13"},
    {0x1.5dd5fa7afbee1p-40, chars_format::scientific, 80,
        "1.24286662127449181887050977687219485896298609706178694978007115423679351806640625e-12"},
    {0x1.384536c7c656fp-39, chars_format::scientific, 79,
        "2.2188144095886259914737759791032178121987505914347593716229312121868133544921875e-12"},
    {0x1.a1194c27935c7p-38, chars_format::scientific, 78,
        "5.927330708414900645292509942453463927213019868389665134600363671779632568359375e-12"},
    {0x1.a02b0d1c1f1a8p-37, chars_format::scientific, 75,
        "1.182821076754492303774112659466477733005707051461286027915775775909423828125e-11"},
    {0x1.651f948c8f895p-36, chars_format::scientific, 77,
        "2.03001127618364981565507635049392808242185726186335159582085907459259033203125e-11"},
    {0x1.0658d9ac47254p-35, chars_format::scientific, 74,
        "2.98254089359250336024448739896349803990549531818032846786081790924072265625e-11"},
    {0x1.463f50c6fb1bfp-34, chars_format::scientific, 75,
        "7.418005368738489917011425132798547142642942020529517321847379207611083984375e-11"},
    {0x1.fff128a1f6814p-33, chars_format::scientific, 73,
        "2.3280428024704824536772626046771984820171752517126151360571384429931640625e-10"},
    {0x1.514274eb0bbe6p-32, chars_format::scientific, 73,
        "3.0673581616552569753443045750033145446789006882681860588490962982177734375e-10"},
    {0x1.c66e7acce03a0p-31, chars_format::scientific, 68,
        "8.26606194612068018706590240458897955733164053526706993579864501953125e-10"},
    {0x1.3f09f0d9f8a0fp-30, chars_format::scientific, 73,
        "1.1606565070959597058008216612762751596132915210546343587338924407958984375e-09"},
    {0x1.364bffd2bc2acp-29, chars_format::scientific, 70,
        "2.2577068906830200447981735699908012460213058147928677499294281005859375e-09"},
    {0x1.21d26e23a4c2cp-28, chars_format::scientific, 69,
        "4.217465074781223546467325241464407792335578051279298961162567138671875e-09"},
    {0x1.ff8816230e3aep-27, chars_format::scientific, 70,
        "1.4887528604095426785363609988553645901987465549609623849391937255859375e-08"},
    {0x1.81d69783dda8fp-26, chars_format::scientific, 70,
        "2.2458741990672780846062688334639767528955189845873974263668060302734375e-08"},
    {0x1.4c5ef6a88833bp-25, chars_format::scientific, 69,
        "3.869307125073411435703155092889760080510086481808684766292572021484375e-08"},
    {0x1.a7cdc3dfbe9a7p-24, chars_format::scientific, 68,
        "9.86745045636969746077316024100711810973507454036734998226165771484375e-08"},
    {0x1.1241321139c78p-23, chars_format::scientific, 65,
        "1.27709782783028146746994412052966794135500094853341579437255859375e-07"},
    {0x1.a5b4169e66c20p-22, chars_format::scientific, 62,
        "3.92741961530240641102713905485899203995359130203723907470703125e-07"},
    {0x1.79889fa31ee9cp-21, chars_format::scientific, 64,
        "7.0321128865744089630400275037214186113487812690436840057373046875e-07"},
    {0x1.6659647864b09p-20, chars_format::scientific, 66,
        "1.334954758379262946808873659121363886015387834049761295318603515625e-06"},
    {0x1.d26dfc62429ebp-19, chars_format::scientific, 65,
        "3.47517156840570335023048696709846439034663490019738674163818359375e-06"},
    {0x1.793d2e00a8300p-18, chars_format::scientific, 56,
        "5.62129889716887591599725482183202984742820262908935546875e-06"},
    {0x1.39585d365fddfp-17, chars_format::scientific, 63,
        "9.338413843761515393811049878802776902375626377761363983154296875e-06"},
    {0x1.db9dd5363f2bbp-16, chars_format::scientific, 63,
        "2.834895459445888963169284113785550971442717127501964569091796875e-05"},
    {0x1.996aa70581c70p-15, chars_format::scientific, 58,
        "4.8806263333083725435013189297706048819236457347869873046875e-05"},
    {0x1.24d414212635cp-14, chars_format::scientific, 59,
        "6.98157387141301578013796724775374968885444104671478271484375e-05"},
    {0x1.49743faae0bcep-13, chars_format::scientific, 60,
        "1.570959551281101199658729594688111319555900990962982177734375e-04"},
    {0x1.fd541909e34d0p-12, chars_format::scientific, 56,
        "4.85733515795794441871624513851202209480106830596923828125e-04"},
    {0x1.fc05fd5826c21p-11, chars_format::scientific, 59,
        "9.68977731662493927018708905762878202949650585651397705078125e-04"},
    {0x1.b8d7be1e07ac5p-10, chars_format::scientific, 59,
        "1.68168161281527614621389421500907701556570827960968017578125e-03"},
    {0x1.58ae5b82bc128p-9, chars_format::scientific, 55,
        "2.6297079760909843060279200699369539506733417510986328125e-03"},
    {0x1.da353b89e30a0p-8, chars_format::scientific, 52, "7.2358389242134502072900659186416305601596832275390625e-03"},
    {0x1.523aa52ed6443p-7, chars_format::scientific, 57,
        "1.032193246435231769042584204498780309222638607025146484375e-02"},
    {0x1.b12c63dc720bbp-6, chars_format::scientific, 56,
        "2.64388060766413794666629399898738483898341655731201171875e-02"},
    {0x1.8284dd65c8bc7p-5, chars_format::scientific, 55,
        "4.7182495515037774225231004265879164449870586395263671875e-02"},
    {0x1.e78254ba42944p-4, chars_format::scientific, 53, "1.19020777670958699534509150907979346811771392822265625e-01"},
    {0x1.a2ea8656520bap-3, chars_format::scientific, 53, "2.04548882970135015302304282158729620277881622314453125e-01"},
    {0x1.c9baa87f5bfbbp-2, chars_format::scientific, 53, "4.47001106999774300287953110455418936908245086669921875e-01"},
    {0x1.71b66707cac81p-1, chars_format::scientific, 52, "7.2209474535101503267497946580988354980945587158203125e-01"},
    {0x1.61447ddf5fb3ep+0, chars_format::scientific, 51, "1.379951350245121499682454668800346553325653076171875e+00"},
    {0x1.b56d58bd7ad8fp+1, chars_format::scientific, 51, "3.417399494666546910792703783954493701457977294921875e+00"},
    {0x1.5201909da2346p+2, chars_format::scientific, 49, "5.2813455142393816998946931562386453151702880859375e+00"},
    {0x1.b29512bde933ep+3, chars_format::scientific, 49, "1.3580697413368053361182319349609315395355224609375e+01"},
    {0x1.28ba36cdc60a7p+4, chars_format::scientific, 49, "1.8545462421229469640593379153870046138763427734375e+01"},
    {0x1.4a0f954ec75bap+5, chars_format::scientific, 47, "4.12576090006436544399548438377678394317626953125e+01"},
    {0x1.df376fa0e3183p+6, chars_format::scientific, 48, "1.198041367663009140187568846158683300018310546875e+02"},
    {0x1.d777fba5be5b1p+7, chars_format::scientific, 47, "2.35734341792570859297484275884926319122314453125e+02"},
    {0x1.c36ecdbaad102p+8, chars_format::scientific, 45, "4.514328266785161076768417842686176300048828125e+02"},
    {0x1.92271b9835605p+9, chars_format::scientific, 45, "8.043055296192766263629891909658908843994140625e+02"},
    {0x1.3825bbeddf401p+10, chars_format::scientific, 45, "1.248589595287339989226893521845340728759765625e+03"},
    {0x1.bb88c3b81cd97p+11, chars_format::scientific, 44, "3.54827389150271073958720080554485321044921875e+03"},
    {0x1.0d8d78fa727c1p+12, chars_format::scientific, 43, "4.3128420357200675425701774656772613525390625e+03"},
    {0x1.f22ae1035f4c6p+13, chars_format::scientific, 42, "1.594135986971332386019639670848846435546875e+04"},
    {0x1.86358ae5236dep+14, chars_format::scientific, 41, "2.49733856397186100366525352001190185546875e+04"},
    {0x1.60fac84cf570cp+15, chars_format::scientific, 39, "4.518139121214867918752133846282958984375e+04"},
    {0x1.27022f6d4c231p+16, chars_format::scientific, 40, "7.5522185261496124439872801303863525390625e+04"},
    {0x1.4e3d42df12170p+17, chars_format::scientific, 36, "1.711305224325763992965221405029296875e+05"},
    {0x1.198a850ca77d0p+18, chars_format::scientific, 35, "2.88298078897354193031787872314453125e+05"},
    {0x1.b9ed4a147a3d3p+19, chars_format::scientific, 38, "9.05066314999694353900849819183349609375e+05"},
    {0x1.f24810bc3163fp+20, chars_format::scientific, 38, "2.04096104594553983770310878753662109375e+06"},
    {0x1.48f2de574af19p+21, chars_format::scientific, 37, "2.6947477926234123297035694122314453125e+06"},
    {0x1.7b69f67382652p+22, chars_format::scientific, 35, "6.21631761280210502445697784423828125e+06"},
    {0x1.80957cacc5b6dp+23, chars_format::scientific, 36, "1.260204633744593895971775054931640625e+07"},
    {0x1.581bf08ec083bp+24, chars_format::scientific, 35, "2.25515365576250366866588592529296875e+07"},
    {0x1.10483fa5a32e9p+25, chars_format::scientific, 34, "3.5688575294042415916919708251953125e+07"},
    {0x1.0ed9715f279f7p+26, chars_format::scientific, 33, "7.100154148679338395595550537109375e+07"},
    {0x1.b72203719cba3p+27, chars_format::scientific, 33, "2.302320915503817498683929443359375e+08"},
    {0x1.fd9abcf52a4a5p+28, chars_format::scientific, 32, "5.34358991322824776172637939453125e+08"},
    {0x1.2fcaa4b911fc2p+29, chars_format::scientific, 30, "6.370971111337816715240478515625e+08"},
    {0x1.15bbc0a9a86a6p+30, chars_format::scientific, 30, "1.164898346414468288421630859375e+09"},
    {0x1.b00ca87636445p+31, chars_format::scientific, 30, "3.624293435105989933013916015625e+09"},
    {0x1.d840bff2e1059p+32, chars_format::scientific, 29, "7.92308939487899112701416015625e+09"},
    {0x1.6573fbd897a95p+33, chars_format::scientific, 29, "1.19941344491848545074462890625e+10"},
    {0x1.884fb41a62589p+34, chars_format::scientific, 28, "2.6327568489536655426025390625e+10"},
    {0x1.ac014e40dd0dap+35, chars_format::scientific, 26, "5.74458721349079132080078125e+10"},
    {0x1.43fc6c60c1eefp+36, chars_format::scientific, 26, "8.69693373561208343505859375e+10"},
    {0x1.2dbd32a11ddb3p+37, chars_format::scientific, 26, "1.61994920995732025146484375e+11"},
    {0x1.b0bd32c9becf1p+38, chars_format::scientific, 25, "4.6465002353570220947265625e+11"},
    {0x1.a4dd93186c42dp+39, chars_format::scientific, 24, "9.038018345501304931640625e+11"},
    {0x1.e32a7f9fa538ap+40, chars_format::scientific, 23, "2.07518221098122119140625e+12"},
    {0x1.2084411c53fa7p+41, chars_format::scientific, 23, "2.47833888170395654296875e+12"},
    {0x1.0d5a138c14d99p+42, chars_format::scientific, 22, "4.6274297324353994140625e+12"},
    {0x1.0ead5f7d79f3bp+43, chars_format::scientific, 21, "9.300399090639615234375e+12"},
    {0x1.d9bdd70990201p+44, chars_format::scientific, 21, "3.255527228032200390625e+13"},
    {0x1.b1ba144c3c6d7p+45, chars_format::scientific, 20, "5.96109674105736796875e+13"},
    {0x1.56ef390e1980dp+46, chars_format::scientific, 19, "9.4265107777120203125e+13"},
    {0x1.d08de26a3153dp+47, chars_format::scientific, 19, "2.5539139214352990625e+14"},
    {0x1.96bf8d1fe67eap+48, chars_format::scientific, 17, "4.47224427308670625e+14"},
    {0x1.095e52abc0566p+49, chars_format::scientific, 16, "5.8355139054814075e+14"},
    {0x1.d639785501ca7p+50, chars_format::scientific, 17, "2.06806918811012175e+15"},
    {0x1.7a69b71f7291ap+51, chars_format::scientific, 15, "3.328555513255053e+15"},
    {0x1.6f06d69bea925p+52, chars_format::scientific, 15, "6.456802203838757e+15"},
    {0x1.e477d245cfe2cp+53, chars_format::scientific, 16, "1.7045704215755864e+16"},
    {0x1.94b582e6fb874p+54, chars_format::scientific, 14, "2.84788661041812e+16"},
    {0x1.651121f05f90dp+55, chars_format::scientific, 16, "5.0252702075045992e+16"},
    {0x1.7b487047230f8p+56, chars_format::scientific, 17, "1.06758663240355712e+17"},
    {0x1.7784c1fbc471cp+57, chars_format::scientific, 17, "2.11398169908011904e+17"},
    {0x1.7ac4b78ae30e4p+58, chars_format::scientific, 16, "4.2645533513929344e+17"},
    {0x1.312f35afa81abp+59, chars_format::scientific, 16, "6.8721420418841536e+17"},
    {0x1.06017fddf665bp+60, chars_format::scientific, 18, "1.179969481513261824e+18"},
    {0x1.5637f72135e49p+61, chars_format::scientific, 18, "3.082431250837574144e+18"},
    {0x1.027e9b70ce1ccp+62, chars_format::scientific, 18, "4.656624004411895808e+18"},
    {0x1.60c83f40c3bc1p+63, chars_format::scientific, 19, "1.2710318822043551744e+19"},
    {0x1.2689a2af0f3ddp+64, chars_format::scientific, 19, "2.1223673591718858752e+19"},
    {0x1.6bd7cbc72e9cep+65, chars_format::scientific, 19, "5.2435295624203190272e+19"},
    {0x1.b4618e9b7fb90p+66, chars_format::scientific, 20, "1.25778283487165677568e+20"},
    {0x1.b700b394dae46p+67, chars_format::scientific, 20, "2.53067849876474363904e+20"},
    {0x1.69b9336bb3625p+68, chars_format::scientific, 20, "4.17038733696760610816e+20"},
    {0x1.2e73980401159p+69, chars_format::scientific, 20, "6.97405765271726194688e+20"},
    {0x1.9cd16da53fb63p+70, chars_format::scientific, 21, "1.903787364496945446912e+21"},
    {0x1.a5f63f3a815d1p+71, chars_format::scientific, 21, "3.891911610207935397888e+21"},
    {0x1.b0e3c4047b75cp+72, chars_format::scientific, 21, "7.985405687712874233856e+21"},
    {0x1.4d847c6eb42c0p+73, chars_format::scientific, 22, "1.2304624807151021326336e+22"},
    {0x1.85fc1437b1734p+74, chars_format::scientific, 22, "2.8775790596421559779328e+22"},
    {0x1.8a7019581e7fap+75, chars_format::scientific, 22, "5.8208757994689939898368e+22"},
    {0x1.c67cb0e7b2a1cp+76, chars_format::scientific, 23, "1.34140907927602311725056e+23"},
    {0x1.e9cf376a61382p+77, chars_format::scientific, 23, "2.89132459907178460872704e+23"},
    {0x1.f3020a5bb1e68p+78, chars_format::scientific, 23, "5.89124628706466797191168e+23"},
    {0x1.c5c96a4dd9bf3p+79, chars_format::scientific, 24, "1.071473736158360648024064e+24"},
    {0x1.9c2cc74cde703p+80, chars_format::scientific, 24, "1.946441008779422248992768e+24"},
    {0x1.aba488754df1ap+81, chars_format::scientific, 24, "4.038971174128976945741824e+24"},
    {0x1.fad8c14ba9d89p+82, chars_format::scientific, 24, "9.574063461859927634477056e+24"},
    {0x1.f2fda18bc958dp+83, chars_format::scientific, 25, "1.8851337402710215888994304e+25"},
    {0x1.9d8f6c51ed693p+84, chars_format::scientific, 24, "3.124772875373390690516992e+25"},
    {0x1.f8236511754b2p+85, chars_format::scientific, 25, "7.6183220036477407253757952e+25"},
    {0x1.a2d213294f709p+86, chars_format::scientific, 26, "1.26580760756294165874081792e+26"},
    {0x1.50d2867c287f9p+87, chars_format::scientific, 25, "2.0359662658108241074978816e+26"},
    {0x1.3bf963799b446p+88, chars_format::scientific, 26, "3.81989337423178708023246848e+26"},
    {0x1.a12dc41e72c86p+89, chars_format::scientific, 27, "1.008676382053808460168953856e+27"},
    {0x1.832bbfda4182fp+90, chars_format::scientific, 27, "1.872243572018953219752329216e+27"},
    {0x1.b22ef35aa515ep+91, chars_format::scientific, 27, "4.199164189291374906487865344e+27"},
    {0x1.24632dbcf4379p+92, chars_format::scientific, 27, "5.655595157253244734125637632e+27"},
    {0x1.5016423c09309p+93, chars_format::scientific, 27, "1.300173405645727077842812928e+28"},
    {0x1.bbf972700d65cp+94, chars_format::scientific, 28, "3.4350855574179920076494340096e+28"},
    {0x1.6e1f3e3e4245fp+95, chars_format::scientific, 28, "5.6654642115107953004184076288e+28"},
    {0x1.47d35248fe09dp+96, chars_format::scientific, 29, "1.01457070140041083705704316928e+29"},
    {0x1.d31a67ab2db51p+97, chars_format::scientific, 29, "2.89122842438625311850965762048e+29"},
    {0x1.ab1253de2af64p+98, chars_format::scientific, 29, "5.28689023652633609509229559808e+29"},
    {0x1.9cfdf3dc71391p+99, chars_format::scientific, 30, "1.022518671042034182622745198592e+30"},
    {0x1.96152f2254ee0p+100, chars_format::scientific, 29, "2.01082438422738923900836511744e+30"},
    {0x1.b4de90e5f0095p+101, chars_format::scientific, 28, "4.3265449624459285617283432448e+30"},
    {0x1.be778d0492e6ap+102, chars_format::scientific, 30, "8.843189919417627285369414221824e+30"},
    {0x1.ebc33e9f0f228p+103, chars_format::scientific, 31, "1.9480726537977613039106892234752e+31"},
    {0x1.7af455437cc9bp+104, chars_format::scientific, 30, "3.002386285018347878401204813824e+31"},
    {0x1.642a6e844551ep+105, chars_format::scientific, 31, "5.6436715663923718161576574844928e+31"},
    {0x1.41b8b3a301a15p+106, chars_format::scientific, 32, "1.01957610305533992485037451247616e+32"},
    {0x1.0155b96fbcde0p+107, chars_format::scientific, 32, "1.63105345367552336552353253556224e+32"},
    {0x1.17b500de21540p+108, chars_format::scientific, 32, "3.54570802835801091766892577685504e+32"},
    {0x1.fa3527f025531p+109, chars_format::scientific, 33, "1.283388839036855097115531068571648e+33"},
    {0x1.12991a738b877p+110, chars_format::scientific, 33, "1.392377581640218018121716183597056e+33"},
    {0x1.4bbcfb93f0ee4p+111, chars_format::scientific, 33, "3.364225166474354069710570596073472e+33"},
    {0x1.15926f3d7b071p+112, chars_format::scientific, 33, "5.629829199100141824040041065742336e+33"},
    {0x1.86dacf9db9927p+113, chars_format::scientific, 33, "1.585495147785397376655401049653248e+34"},
    {0x1.6aa8e880f9271p+114, chars_format::scientific, 34, "2.9422458257062697580352079193440256e+34"},
    {0x1.44db602f65a69p+115, chars_format::scientific, 34, "5.2711051576274024231085405965910016e+34"},
    {0x1.4aa98d059f6c7p+116, chars_format::scientific, 35, "1.07306053965661318564328070210125824e+35"},
    {0x1.ad41a77876ac0p+117, chars_format::scientific, 35, "2.78603372165060620709063210871816192e+35"},
    {0x1.66608302c1ae0p+118, chars_format::scientific, 35, "4.65199941604955653649793565669195776e+35"},
    {0x1.724a6060561d6p+119, chars_format::scientific, 35, "9.61329185843412549197741860528848896e+35"},
    {0x1.d6cd57f7afd91p+120, chars_format::scientific, 36, "2.444544386985640811823093072529457152e+36"},
    {0x1.ddc593d2d0608p+121, chars_format::scientific, 36, "4.961465895993372192136189659616116736e+36"},
    {0x1.cb5644ce1a91fp+122, chars_format::scientific, 35, "9.54005598637793663997028777762750464e+36"},
    {0x1.1bc54417de33cp+123, chars_format::scientific, 37, "1.1787368324472861665867817538046394368e+37"},
    {0x1.0b7025db14e7ap+124, chars_format::scientific, 37, "2.2217886245582567633425166223452143616e+37"},
    {0x1.c25ad8d3be06dp+125, chars_format::scientific, 37, "7.4828037824613418029633676794849656832e+37"},
    {0x1.6fa2ef34cd8cep+126, chars_format::scientific, 38, "1.22168169555880306340177489939782434816e+38"},
    {0x1.2154fd4e3bc1cp+127, chars_format::scientific, 38, "1.92294090682938928866121043260519481344e+38"},
    {0x1.2b3cd0ab51216p+128, chars_format::scientific, 38, "3.97754940865523918837358639143272316928e+38"},
    {0x1.088b103a41b0bp+129, chars_format::scientific, 38, "7.03276498569342686920339511489517846528e+38"},
    {0x1.e53444dfa15a7p+130, chars_format::scientific, 39, "2.579787897255990868798456303636608712704e+39"},
    {0x1.19ed8692b24fbp+131, chars_format::scientific, 39, "2.997970965091339190918492577226091921408e+39"},
    {0x1.d6393885ae144p+132, chars_format::scientific, 40, "1.0000548245536083788593238972941513785344e+40"},
    {0x1.6acc29897fd95p+133, chars_format::scientific, 40, "1.5431699376188799230066746785793442840576e+40"},
    {0x1.f2f9916765d68p+134, chars_format::scientific, 40, "4.2448087869444726132947292415438599749632e+40"},
    {0x1.a8bb1d24ff93dp+135, chars_format::scientific, 40, "7.2264220268357129106158415886080664403968e+40"},
    {0x1.c5c3e8df3f2cfp+136, chars_format::scientific, 39, "1.544083208152169859594847631211501715456e+41"},
    {0x1.1772e9d5da5a7p+137, chars_format::scientific, 41, "1.90183053010164648774242281749579802083328e+41"},
    {0x1.14f6d2645603fp+138, chars_format::scientific, 41, "3.76984063098152793892190666264816558014464e+41"},
    {0x1.24a5b6eb957c8p+139, chars_format::scientific, 40, "7.9666178829165263796362879580362262970368e+41"},
    {0x1.2ead0eb8af7cbp+140, chars_format::scientific, 42, "1.647924923062673765177664088659074522021888e+42"},
    {0x1.f516ab8dbd662p+141, chars_format::scientific, 42, "5.456371187228343385170833127692803019636736e+42"},
    {0x1.855d7376918a9p+142, chars_format::scientific, 42, "8.479619741110213809967927453284253992747008e+42"},
    {0x1.f44b558dbdfb5p+143, chars_format::scientific, 43, "2.1790888931872989461006813529845663969312768e+43"},
    {0x1.196a6ab9ee449p+144, chars_format::scientific, 43, "2.4514764141293366381415554359835359275122688e+43"},
    {0x1.c970123b86b86p+145, chars_format::scientific, 41, "7.96969010621829343736169074091377888854016e+43"},
    {0x1.23fe1017a3e0ap+146, chars_format::scientific, 44, "1.01744513270938959360968970914297622533505024e+44"},
    {0x1.547b58dbe0a82p+147, chars_format::scientific, 44, "2.37281200493303842948982975659978497995046912e+44"},
    {0x1.6b72d270d534dp+148, chars_format::scientific, 44, "5.06573307308778511819262316883115987825590272e+44"},
    {0x1.9bfa29a521e6cp+149, chars_format::scientific, 45, "1.148424814894339399771081143389126450042896384e+45"},
    {0x1.088e70fa79bf2p+150, chars_format::scientific, 45, "1.474951280394658237786084602544572869491294208e+45"},
    {0x1.1d97a9d8999d2p+151, chars_format::scientific, 45, "3.184462066193894206844138084970587550398808064e+45"},
    {0x1.1b7ddc6783fe8p+152, chars_format::scientific, 45, "6.322074926642195313905924879563454681421185024e+45"},
    {0x1.90f9b356e1fd1p+153, chars_format::scientific, 46, "1.7884100129279887107935363982167269062471581696e+46"},
    {0x1.04a659aa20643p+154, chars_format::scientific, 45, "2.325073960940094003234741315214732474508640256e+46"},
    {0x1.b45db51612c32p+155, chars_format::scientific, 46, "7.7850303756798823507242277549769146173862445056e+46"},
    {0x1.94f1118511db0p+156, chars_format::scientific, 47, "1.44488017324739167332291972816201226607422078976e+47"},
    {0x1.74288ae36661ep+157, chars_format::scientific, 46, "2.6558108692875685669156873835578158454916775936e+47"},
    {0x1.3253541731259p+158, chars_format::scientific, 47, "4.37202365761853212655650514880767316833467367424e+47"},
    {0x1.9d71f6b97eb99p+159, chars_format::scientific, 48, "1.180177332650351500186142018418327053943445651456e+48"},
    {0x1.9c2824d021211p+160, chars_format::scientific, 48, "2.352999434252425166009583916770268278726766624768e+48"},
    {0x1.2c37fa039529bp+161, chars_format::scientific, 48, "3.427891103047345015228894619797641792100916789248e+48"},
    {0x1.97f764d76e448p+162, chars_format::scientific, 46, "9.3163052493008502647057342776183447761954275328e+48"},
    {0x1.a28e124e01121p+163, chars_format::scientific, 49, "1.9116211540697205399927873627877011998254938718208e+49"},
    {0x1.500cfed695739p+164, chars_format::scientific, 49, "3.0696171319662410271698897460360354956718064533504e+49"},
    {0x1.2cd97b4ce81a2p+165, chars_format::scientific, 49, "5.4961511485964129240667100065476685812465949212672e+49"},
    {0x1.d24224f1cf2bcp+166, chars_format::scientific, 50, "1.70359345069614948406404727167574558656079671066624e+50"},
    {0x1.83b3da401d150p+167, chars_format::scientific, 50, "2.83313955071286289178391550929804608096590893154304e+50"},
    {0x1.a3b0d2f93d673p+168, chars_format::scientific, 50, "6.13378673285658591018762418018704374742768855023616e+50"},
    {0x1.6b5cc29017ae4p+169, chars_format::scientific, 51, "1.062109320797658708151958249612931353686624780156928e+51"},
    {0x1.e6bf9a05045a3p+170, chars_format::scientific, 51, "2.845534590927396736753751979474589830905163889508352e+51"},
    {0x1.cc9ed46d0d98ep+171, chars_format::scientific, 51, "5.385580087774829124578596551004441252780605203021824e+51"},
    {0x1.bc208d2b82a15p+172, chars_format::scientific, 52,
        "1.0385481005999034803544914290611356999601747138707456e+52"},
    {0x1.6c981eeb98863p+173, chars_format::scientific, 50, "1.70513616682002662806350067152462430298633943384064e+52"},
    {0x1.af5d7ade9c17ap+174, chars_format::scientific, 52,
        "4.0348216442512827178202027976145404001660863678251008e+52"},
    {0x1.ebfb63d8a468bp+175, chars_format::scientific, 52,
        "9.2036158369142271242411353737258443958178349337018368e+52"},
    {0x1.8165629784911p+176, chars_format::scientific, 53,
        "1.44193775900760462481135039693825192887594892339970048e+53"},
    {0x1.f561a2a30dd53p+177, chars_format::scientific, 53,
        "3.75178096298129453493805795896698130008167991753048064e+53"},
    {0x1.ce7c7938e0eb9p+178, chars_format::scientific, 53,
        "6.92146559638991570078851625625319303554674020637999104e+53"},
    {0x1.77bc8cddcf12ap+179, chars_format::scientific, 54,
        "1.124637789574368600447483337148668908930534274783772672e+54"},
    {0x1.3fc175c6f2438p+180, chars_format::scientific, 54,
        "1.914156990649081570063038235013271375259033985125187584e+54"},
    {0x1.914ec58ebe041p+181, chars_format::scientific, 54,
        "4.804705186047787763539909785825820848780520789991489536e+54"},
    {0x1.5114314b07626p+182, chars_format::scientific, 54,
        "8.071435564947532553915773674998525033942233843077480448e+54"},
    {0x1.e2f0276441399p+183, chars_format::scientific, 55,
        "2.3128140200050004179900419204722717138007627859971014656e+55"},
    {0x1.cf8d0a2eae505p+184, chars_format::scientific, 55,
        "4.4399358958425029747414170378892766455751677599478185984e+55"},
    {0x1.4dda59a8f20a2p+185, chars_format::scientific, 55,
        "6.3953515931602618386692877635154528630077627837316071424e+55"},
    {0x1.bab65f6c0e97cp+186, chars_format::scientific, 56,
        "1.69613692241034722191343016069607921350219320331459362816e+56"},
    {0x1.0db1e999e5dcep+187, chars_format::scientific, 55,
        "2.0665317001185353533780346936985121680840320873792536576e+56"},
    {0x1.16729f78118dbp+188, chars_format::scientific, 54,
        "4.267199288089498798008616016338101124507969437189537792e+56"},
    {0x1.84b2774cd6d15p+189, chars_format::scientific, 57,
        "1.191353245759245872712330749375395405217002847792663625728e+57"},
    {0x1.5e6b2eec1979ep+190, chars_format::scientific, 57,
        "2.148060287120407132486133792062303242882862510466574319616e+57"},
    {0x1.57ac5f28c5822p+191, chars_format::scientific, 57,
        "4.213422729321882403507151670457754635672165551067199700992e+57"},
    {0x1.2c1e6e57e9676p+192, chars_format::scientific, 57,
        "7.358893309664639936881070842796439426339053634941326721024e+57"},
    {0x1.f14d05585f439p+193, chars_format::scientific, 58,
        "2.4387563351268131955594715375272838644628307055389846798336e+58"},
    {0x1.18fdf7f764a16p+194, chars_format::scientific, 58,
        "2.7559621536224231764973310109769900471295096010340351082496e+58"},
    {0x1.8c82785d38820p+195, chars_format::scientific, 57,
        "7.777910645414688648548968750500929149508839351454403657728e+58"},
    {0x1.e664096512a4fp+196, chars_format::scientific, 59,
        "1.90820271006743062589068419007889919427368854321224868691968e+59"},
    {0x1.7ad7e8f87a31fp+197, chars_format::scientific, 59,
        "2.97254819348561348142059994275052781258332713659043726491648e+59"},
    {0x1.8fbcbd9143824p+198, chars_format::scientific, 59,
        "6.27297873989847920060186967507561121071724081221944431607808e+59"},
    {0x1.fffab418f559fp+199, chars_format::scientific, 60,
        "1.606873109429469790133884014121163665471467983941023660244992e+60"},
    {0x1.da1c6d063ff81p+200, chars_format::scientific, 60,
        "2.976043223039824053749757547207391812994613888441872405233664e+60"},
    {0x1.15fe8ce1e9504p+201, chars_format::scientific, 60,
        "3.489997472879308917395719419357749318529849683153472890863616e+60"},
    {0x1.a8f8f1d983703p+202, chars_format::scientific, 61,
        "1.0670380970822515728824154611513147539078615867965386421960704e+61"},
    {0x1.a7c5f2cb7fa9cp+203, chars_format::scientific, 61,
        "2.1280541721170621914318415811403250028099879746592336410312704e+61"},
    {0x1.9a069737b82f9p+204, chars_format::scientific, 61,
        "4.1180373037668160785451413693672802945556196669733887910346752e+61"},
    {0x1.d7fb39182d06bp+205, chars_format::scientific, 60,
        "9.480559641663616628696383637736174353513111344194678809427968e+61"},
    {0x1.8d79cca5204b4p+206, chars_format::scientific, 62,
        "1.59679737690547294653629880448829857591918862991885354225631232e+62"},
    {0x1.640c53e94baf0p+207, chars_format::scientific, 62,
        "2.86073663238193178122650589057504705307874404845642118712000512e+62"},
    {0x1.804d768153946p+208, chars_format::scientific, 61,
        "6.1755045156767433035176829824443396292828215618205373832364032e+62"},
    {0x1.d56e2fb92f94bp+209, chars_format::scientific, 63,
        "1.508691188244574982497059261858774337284894599380994275393142784e+63"},
    {0x1.9de8dda906a1ep+210, chars_format::scientific, 63,
        "2.660508539901083172029910702401831570415871079047501730937831424e+63"},
    {0x1.7625e5dbb3e9cp+211, chars_format::scientific, 63,
        "4.809861739392636763970911315108253399659550567331225058938978304e+63"},
    {0x1.c66583b372649p+212, chars_format::scientific, 64,
        "1.1682993418673641507770337381177220245747542216734811616358432768e+64"},
    {0x1.c7dbe2df944fcp+213, chars_format::scientific, 64,
        "2.3441185866765201891906590922363241098417108629756551288590434304e+64"},
    {0x1.52e75005b7ac3p+214, chars_format::scientific, 64,
        "3.4854210022549138065076113679839139392004906864670443177957654528e+64"},
    {0x1.61996d6b5a737p+215, chars_format::scientific, 64,
        "7.2731162770376529778347980921328038690888967732944646841598738432e+64"},
    {0x1.494416e47342cp+216, chars_format::scientific, 64,
        "1.3545216532450050573167471500475542752885489394641883762375262208e+65"},
    {0x1.d60ab6b85519cp+217, chars_format::scientific, 65,
        "3.86728003636036058641366871128252569918895873439564907057088823296e+65"},
    {0x1.33e03222aff77p+218, chars_format::scientific, 65,
        "5.06610974407740673840531052436472518619916156367111801266415599616e+65"},
    {0x1.c180013aacf42p+219, chars_format::scientific, 66,
        "1.479308658758350330944201788946768123438076335588933997743174582272e+66"},
    {0x1.a8c4ee725339fp+220, chars_format::scientific, 66,
        "2.795839034978863819877803502232039113629062617998185283225294733312e+66"},
    {0x1.e8aaf34741ab6p+221, chars_format::scientific, 66,
        "6.432840401396405792365580284144481229273342573010878029692370157568e+66"},
    {0x1.227ef7d830535p+222, chars_format::scientific, 65,
        "7.64819906204326131860049759731150371173136410489009919800981323776e+66"},
    {0x1.50d3b96e4614ap+223, chars_format::scientific, 67,
        "1.7736014170885828821631467083617455696667197990697308887351889494016e+67"},
    {0x1.8199aecb377d9p+224, chars_format::scientific, 67,
        "4.0608453724544028931786363107981702003718879833309714118046052777984e+67"},
    {0x1.19dbb35474ceep+225, chars_format::scientific, 67,
        "5.9366267010857000073898171317477288623551476762400866883285525987328e+67"},
    {0x1.dc33701787db2p+226, chars_format::scientific, 68,
        "2.00599244568418166158633240420166985299541370621581756051323713748992e+68"},
    {0x1.eff20ab8910b4p+227, chars_format::scientific, 68,
        "4.17833237036618955782462790270901274407866847161169503610707764051968e+68"},
    {0x1.bbe88a3d4104ep+228, chars_format::scientific, 68,
        "7.47984105847088632825661725590567003356199708795195209233577533243392e+68"},
    {0x1.46b387e75ac05p+229, chars_format::scientific, 69,
        "1.100981177656366596121887029311165116283765891574561058397569203306496e+69"},
    {0x1.e666f5cf254cap+230, chars_format::scientific, 69,
        "3.278344263502461615618708692041532796484309585052066932644501920940032e+69"},
    {0x1.e6e69845380cep+231, chars_format::scientific, 69,
        "6.563409273861357872055846937881366142433814631142651266800757371830272e+69"},
    {0x1.87fc0b17b39efp+232, chars_format::scientific, 70,
        "1.0567882407580982568830708317724752282141329118524865643643232472530944e+70"},
    {0x1.1d2094524e151p+233, chars_format::scientific, 70,
        "1.5374031618797994143345255818223153455446312412350835802141987662987264e+70"},
    {0x1.ef0acdf882c82p+234, chars_format::scientific, 69,
        "5.338524581842552093835408600140749961917285261972119383523602533974016e+70"},
    {0x1.fcbcd755571cbp+235, chars_format::scientific, 71,
        "1.09724321606021718480487121388084343129412917209137058037575549878009856e+71"},
    {0x1.5bc325b6842e6p+236, chars_format::scientific, 70,
        "1.5001044647337975163536052292888629019192953446259429967707981096157184e+71"},
    {0x1.4839844f3a28ep+237, chars_format::scientific, 71,
        "2.83165431565250843561226845873096957075695083997080472361101646654078976e+71"},
    {0x1.e268bea09d76dp+238, chars_format::scientific, 71,
        "8.32366412253767450473627272269736199394015241611420074982712040652537856e+71"},
    {0x1.9760fc3633170p+239, chars_format::scientific, 72,
        "1.405812739508858068375342755770185891515789882712544527098421327318482944e+72"},
    {0x1.f9780dce1dea1p+240, chars_format::scientific, 72,
        "3.488618552580639620123899659132615213727580900417550210713537290046537728e+72"},
    {0x1.06379cf942b94p+241, chars_format::scientific, 72,
        "3.619513742366401459360774923805574186193834456864238978452991001371869184e+72"},
    {0x1.54e3dfab69e89p+242, chars_format::scientific, 72,
        "9.410948883835140439259712749284374813211962760503227341524256159409635328e+72"},
    {0x1.31e863bfd9bd6p+243, chars_format::scientific, 73,
        "1.6890382785900103876754997077931661155681683793063575869750399994525908992e+73"},
    {0x1.97cf871c408f0p+244, chars_format::scientific, 73,
        "4.5033691214168135372365182321155169406467422866316271815207540483596222464e+73"},
    {0x1.1c444bdbdf9c3p+245, chars_format::scientific, 73,
        "6.2781991287502835294706934796700503444220891091676239343080273452105465856e+73"},
    {0x1.05d2dc08efe95p+246, chars_format::scientific, 74,
        "1.15650595692360812734551875859766266613142682216011370208563856535394975744e+74"},
    {0x1.ecc77551d4971p+247, chars_format::scientific, 74,
        "4.35332683162743291871502389653473442925183772482197555090046969989126160384e+74"},
    {0x1.d480cb6589e19p+248, chars_format::scientific, 74,
        "8.27773333411108944564788528429675414027959576520140010882381647552484212736e+74"},
    {0x1.8d8ef73cf87b1p+249, chars_format::scientific, 75,
        "1.404849996452092323181663448719164230590611915347499050189329189348495589376e+75"},
    {0x1.48a0c3b10a317p+250, chars_format::scientific, 75,
        "2.322541569987461897646236862872835979235153071147854369984513726383982116864e+75"},
    {0x1.4272a4c4fdd70p+251, chars_format::scientific, 75,
        "4.557727968952480904558449925323762902907761772892808327111565265849267781632e+75"},
    {0x1.ae03d804b061ep+252, chars_format::scientific, 74,
        "1.21563322709765501473251126237121602148703036382587288355792403577863929856e+76"},
    {0x1.0b5dd53c3113bp+253, chars_format::scientific, 76,
        "1.5116664880436697889619534522569417861107074808654256101389938332337600200704e+76"},
    {0x1.fdd951416069dp+254, chars_format::scientific, 76,
        "5.7652801636485908304981079853657826006611591736383711473146661351961829310464e+76"},
    {0x1.3f050c163f528p+255, chars_format::scientific, 76,
        "7.2148358177064735441715850462253186745656784598757713984413999990820116103168e+76"},
    {0x1.d281ec8a5d188p+256, chars_format::scientific, 77,
        "2.11007343253573153040916841042569198900237589785514419724926914360700078915584e+77"},
    {0x1.b1ee0f3407c41p+257, chars_format::scientific, 77,
        "3.92544155933803743324755229116691986569477877247338320380545265297625347784704e+77"},
    {0x1.6832d41e7dc1ap+258, chars_format::scientific, 76,
        "6.5168972734192971123386188207590235648755640305144385763849856436594125307904e+77"},
    {0x1.e64f563364bdep+259, chars_format::scientific, 76,
        "1.7597137621226992026876162475289352988150739628485525054187120773028919640064e+78"},
    {0x1.daa06c44fb425p+260, chars_format::scientific, 78,
        "3.434875728114804814685899568021643975684275456343249710170796956248388352868352e+78"},
    {0x1.36affe847782ap+261, chars_format::scientific, 77,
        "4.49689401318463171959207532471966088045183274122115864667263900282602867654656e+78"},
    {0x1.5a4251d5f8667p+262, chars_format::scientific, 79,
        "1.0023515028874743203760034918542228757355688414371945561530461637433189038292992e+79"},
    {0x1.61672219d801dp+263, chars_format::scientific, 77,
        "2.04606279876720469579937490350496538995031175031291773472748474159827481788416e+79"},
    {0x1.3d865b7eeb438p+264, chars_format::scientific, 79,
        "3.6766863868985022220367084943920216131061939418967080566277924324348988351315968e+79"},
    {0x1.2db506dfa8ce9p+265, chars_format::scientific, 79,
        "6.9870599261497189307442468175452786217368249333102065069521396329647863295377408e+79"},
    {0x1.8390d09306414p+266, chars_format::scientific, 80,
        "1.79508160415808704712141748605675659243941837354766083639370088277774910089068544e+80"},
    {0x1.9b58ceed26006p+267, chars_format::scientific, 80,
        "3.81045742515568238106089113337056938315639562315303996957679473250795050372169728e+80"},
    {0x1.2fbe163c69224p+268, chars_format::scientific, 80,
        "5.62735708283395761680999734220534079897036103282947406804850940523084358392741888e+80"},
    {0x1.ed623087df1bep+269, chars_format::scientific, 81,
        "1.828157196786173258110715724311801689865646019514059112947102608834558509445021696e+81"},
    {0x1.c4a8946c5378ap+270, chars_format::scientific, 81,
        "3.354513608629342758881183607515227358808179514909005943036597166005055102654611456e+81"},
    {0x1.15c4e12be427fp+271, chars_format::scientific, 81,
        "4.116922864713554962262731822113769463098264781458759029065788118035733765689442304e+81"},
    {0x1.6ad5bf3ce75d1p+272, chars_format::scientific, 82,
        "1.0755434708169830468646961963757742494547372019865450762930913468197267328525664256e+82"},
    {0x1.39e6cc7b696f2p+273, chars_format::scientific, 82,
        "1.8609826393606468152836428445460492052838500356054137125720357473673460037122523136e+82"},
    {0x1.492f9204fea8cp+274, chars_format::scientific, 81,
        "3.903192479447499033452350069520597800324534214682007651943346621675247621235539968e+82"},
    {0x1.10fdf067e1d3ap+275, chars_format::scientific, 82,
        "6.4737911159818786400194931508236873102720909642740513708334320479730693747677069312e+82"},
    {0x1.4475e6d3ffa4cp+276, chars_format::scientific, 83,
        "1.53886578090640196755690493218260429593835278923075770789252846079936296641204584448e+83"},
    {0x1.e690de58f29c9p+277, chars_format::scientific, 83,
        "4.61541222592303232645421887442495089995066619544195472117594256018529300800228818944e+83"},
    {0x1.12d15aa66324bp+278, chars_format::scientific, 82,
        "5.2136715880000982561259895823177793906237517288103170230159179545063743954880561152e+83"},
    {0x1.c6239933289ecp+279, chars_format::scientific, 84,
        "1.723128550002755437133951204996418910562653794534546195856270285892794521746348703744e+84"},
    {0x1.b6563b1fc7692p+280, chars_format::scientific, 82,
        "3.3263411825363985053471050648782104121530178846595344015068034571605091406795767808e+84"},
    {0x1.bc57fc9b4e281p+281, chars_format::scientific, 84,
        "6.743849062437124540067369460095704859176196480433913929539186007746583809206972841984e+84"},
    {0x1.f8df107311968p+282, chars_format::scientific, 85,
        "1.5324966500321058049592869611887769487534860026596133853595336640461446056900382687232e+85"},
    {0x1.de346966130bbp+283, chars_format::scientific, 85,
        "2.9031045606668695079086558896866507278227043543999063147023976978260396987770338279424e+85"},
    {0x1.4bcb7614590adp+284, chars_format::scientific, 85,
        "4.0285461203337303545331340422939720789741892918160941159647588152564951369732381999104e+85"},
    {0x1.0563f359dbcccp+285, chars_format::scientific, 85,
        "6.3474382619472774879674901098388887476421241832512569944968136076387350654165612232704e+85"},
    {0x1.31c3c51fb59f0p+286, chars_format::scientific, 86,
        "1.48499905686861542665053988630525851133259775675492961721942835140068121158861530857472e+86"},
    {0x1.43b14acd508e9p+287, chars_format::scientific, 84,
        "3.144137214709148273932932752798276942472276257047001734687113587664554987136445579264e+86"},
    {0x1.7a67288ca2338p+288, chars_format::scientific, 86,
        "7.35111663943683991924868091407140115848506284972761980234658243157821224316229105221632e+86"},
    {0x1.90ee051acce20p+289, chars_format::scientific, 87,
        "1.557747566386344816691965362482515856301711161509577196359183216260647622504160667107328e+87"},
    {0x1.2489551766274p+290, chars_format::scientific, 87,
        "2.273205881098212719172251019697290790177862652621182786611096562647157941278227203883008e+87"},
    {0x1.3e54bc6237b93p+291, chars_format::scientific, 87,
        "4.947293841380347003020105042807568353223605346291404893299918661932182932360249923862528e+87"},
    {0x1.ecf1cc571a5cdp+292, chars_format::scientific, 87,
        "1.532204788518055669527054408252775276561841237278791821067837641365410854525267664175104e+88"},
    {0x1.62c38c686058dp+293, chars_format::scientific, 87,
        "2.205403895176296498667172663255869787229707570210827621989553387899095272142052689707008e+88"},
    {0x1.1956cbeae3776p+294, chars_format::scientific, 88,
        "3.4979111598588176010555116390040342571373179418270620765845075298580332460285709028163584e+88"},
    {0x1.d245370a2c906p+295, chars_format::scientific, 89,
        "1.15943544996190933856633616414466811022505880808156492718239704433998219084021400875302912e+89"},
    {0x1.77a2ad5be5f22p+296, chars_format::scientific, 89,
        "1.86812241557541298892557723890372259123352337205389983867335838290407406167752042457595904e+89"},
    {0x1.5e27d63120bc6p+297, chars_format::scientific, 89,
        "3.48281044472571483629770428112359357931579367395984692863821844484753880315554503889780736e+89"},
    {0x1.6cd5ca4b6a049p+298, chars_format::scientific, 89,
        "7.25763926599453313576032544399461752503111043260623699604979165837300824089149573789908992e+89"},
    {0x1.21ef16216f087p+299, chars_format::scientific, 90,
        "1.153527049014772181210371929535324976526694483335493350780385752130773271127971750637207552e+90"},
    {0x1.39c791a4cdd30p+300, chars_format::scientific, 90,
        "2.496797909293860274452611679981864366431273655911171418054054946652601225349601977195036672e+90"},
    {0x1.b84f065ad9c40p+301, chars_format::scientific, 90,
        "7.007223778789100460674592112903687638288056977455315141802089640807060683661017463323099136e+90"},
    {0x1.5c980f061d930p+302, chars_format::scientific, 91,
        "1.1095288700912676850259655407944409623006326764511603357666977203703446579685558999924604928e+91"},
    {0x1.d11d295facde2p+303, chars_format::scientific, 91,
        "2.9607930405769014382601054795425097838217102889963775497642608889806414863145865310495571968e+91"},
    {0x1.bbf08598a98bbp+304, chars_format::scientific, 91,
        "5.6520050704947556744896535369107614707599849622347754280995272309160258719009203701942321152e+91"},
    {0x1.ba04cbb38e4d5p+305, chars_format::scientific, 92,
        "1.12551007727079359585097814946865173194633864244482778621517929765203808143927747684958470144e+92"},
    {0x1.54131d0e410eap+306, chars_format::scientific, 92,
        "1.73186080336662674773428302451694949383861654865608072294885374856902390005170129581872513024e+92"},
    {0x1.e30ce3214662bp+307, chars_format::scientific, 92,
        "4.91995461222250678150766955487414849320177453519696863021951432129138251603934668204877545472e+92"},
    {0x1.53b14d0307376p+308, chars_format::scientific, 92,
        "6.91966009118651520979803296576329218495201852892814426466356352573178600739540460494424899584e+92"},
    {0x1.0db459c95ae0ap+309, chars_format::scientific, 93,
        "1.098795518726438366609401980967157225074875139569724076317122730302418377716044842181188386816e+93"},
    {0x1.1c3939899abbap+310, chars_format::scientific, 93,
        "2.315894257968477114139855258593793035500513640711965686941821174621775820808713339985182326784e+93"},
    {0x1.373d598ccbedep+311, chars_format::scientific, 92,
        "5.07205087659469518714361132934952967180404131875257868675409772338932035589521892535594647552e+93"},
    {0x1.3df92e8f7f25cp+312, chars_format::scientific, 94,
        "1.0363570999985610218238902711693729605343613482930794977520814186252504820113148082355622117376e+94"},
    {0x1.e43040df434b2p+313, chars_format::scientific, 94,
        "3.1561899942152433381203488205922856539908726361744071551624952459304620181234055813806189182976e+94"},
    {0x1.bd56a038510a5p+314, chars_format::scientific, 94,
        "5.8058899603986402390979930533204289636439533662431550984437804920565671771960313337224984788992e+94"},
    {0x1.47a680f7df241p+315, chars_format::scientific, 94,
        "8.5431764922746352414815315662378944345996354389236714634151510172388323479866864189920524632064e+94"},
    {0x1.0a7083cf6add8p+316, chars_format::scientific, 95,
        "1.38943198710420748341660043617043022583822760533446236412979829417047860471831997112096984662016e+95"},
    {0x1.ca2d6c8c53bd5p+317, chars_format::scientific, 95,
        "4.77861849016998188114122579439270994768860615811890514883370859774317648442079613611698244550656e+95"},
    {0x1.e92db2529dbcfp+318, chars_format::scientific, 96,
        "1.020389588899609153532580957412143752366703719293632571694846387812362664420354081750298547716096e+96"},
    {0x1.7e9337e01fb65p+319, chars_format::scientific, 96,
        "1.596045688776375776841703068858618647181748707273854812785319263912136577406031736557627640905728e+96"},
    {0x1.856a9ca60259dp+320, chars_format::scientific, 96,
        "3.249173807353552076769227343856334408112864749547363816303721235276306516121646129315832634802176e+96"},
    {0x1.2954147067244p+321, chars_format::scientific, 96,
        "4.961638176380709527864130701814524798785240769392200382075051902521140868022699235320535724326912e+96"},
    {0x1.8a9948a3b5773p+322, chars_format::scientific, 96,
        "1.316965383848080426178721677102139575139428518210160435009232507801986304249723290592830277287936e+97"},
    {0x1.9d7f682a48e95p+323, chars_format::scientific, 97,
        "2.7600802833290057294863365648278498083682974322674559612258381363079661754043107711541518184480768e+97"},
    {0x1.1394946666649p+324, chars_format::scientific, 97,
        "3.6789758695100667984355585133798803034265640286914369787158051732884080762893646681521731009511424e+97"},
    {0x1.5cf3dcf0c210ap+325, chars_format::scientific, 97,
        "9.3169776057927388397860971692076748096813463829441115661384293210348344104809158613064035568975872e+97"},
    {0x1.edad497808d6ap+326, chars_format::scientific, 98,
        "2.63621865809578202632007715175239364465008642226141794355213814208815258090680462442156516792336384e+98"},
    {0x1.0da0103363c19p+327, chars_format::scientific, 98,
        "2.87958016292024262706195266242702522208665557458094458094772254523203474127145608787359761973641216e+98"},
    {0x1.e0e09ee6fbc77p+328, chars_format::scientific, 99,
        "1.027147944933023542626819355716472887371271886832370736047056582372410954517572846778976767599181824e+"
        "99"},
    {0x1.9678e5f1a7d71p+329, chars_format::scientific, 99,
        "1.736438949946239757715573812462668203854228021142457473943958788246613058128755016444052964993138688e+"
        "99"},
    {0x1.4b5b869a8b73ap+330, chars_format::scientific, 99,
        "2.831101490449813330351300092716022415336638150557587101281369589000119033315970171347397084924870656e+"
        "99"},
    {0x1.fe2c3d2523805p+331, chars_format::scientific, 98,
        "8.71778003173501782520294586670274195486325481663656287823621692798053380434188606701697032360296448e+99"},
    {0x1.7a8e2bf190c3ep+332, chars_format::scientific, 100,
        "1.2937429393963081102936715388735517174575449745661779868560549590564554071876819476341646368012500992e+"
        "100"},
    {0x1.c20e9fb7c28cfp+333, chars_format::scientific, 99,
        "3.076211787425003964373361588531553092466447952323893670684982577431400448345840350416908836231184384e+"
        "100"},
    {0x1.bc64bd3fbb063p+334, chars_format::scientific, 100,
        "6.0750002047707119351020146056748996020726847090111922770368870774035039300942105887039623283718750208e+"
        "100"},
    {0x1.6fa79bcec5d71p+335, chars_format::scientific, 101,
        "1.00519131923249665159539189045738250625445899193224853577560494867813212309547435281219657555073040384e+"
        "101"},
    {0x1.255820e7b40dbp+336, chars_format::scientific, 101,
        "1.60404356999704584039118751697581736942407721317265568405145483828932537524402503992838476799827509248e+"
        "101"},
    {0x1.24e8b96eea468p+337, chars_format::scientific, 101,
        "3.20332798201769959258478598390469858187503168380540831739211163523937048679598283011990104943469002752e+"
        "101"},
    {0x1.296421957b8fcp+338, chars_format::scientific, 101,
        "6.50468980931338189749732798197360744414144439025939112265821291401038872632313877281859844571396046848e+"
        "101"},
    {0x1.2b239b9bcb1b4p+339, chars_format::scientific, 102,
        "1.308584396599165566045730161590653878587049789341429936525191989129126795868599529420259141598822006784e+"
        "102"},
    {0x1.ea18f74afcc08p+340, chars_format::scientific, 102,
        "4.287864653000838387576078081500217988595704090069841900641074208176801061178027675635595638576924065792e+"
        "102"},
    {0x1.771193f9d6396p+341, chars_format::scientific, 101,
        "6.56295366062876882918926416107436715831157240075745311354357615353582042989302783876335181380573986816e+"
        "102"},
    {0x1.5da5e2bf67261p+342, chars_format::scientific, 103,
        "1."
        "2236285152807307624643628388698918410797745423679381645265829552143290625157094290629079953916645343232e+"
        "103"},
    {0x1.58fcd12ad7c3ep+343, chars_format::scientific, 103,
        "2."
        "4146377765621171182079586051573746443023029345082834585424128063094779334007517592308658607782004523008e+"
        "103"},
    {0x1.b981dd551031dp+344, chars_format::scientific, 103,
        "6."
        "1803976055027187805645727187356890583048090549637147591363651473300874743076219960394574930078255284224e+"
        "103"},
    {0x1.3fc3743a41034p+345, chars_format::scientific, 102,
        "8.952357506110560823804694357950163920534386086340839327084956631888740764686521452344790633972229996544e+"
        "103"},
    {0x1.dd8d36aaec71ap+346, chars_format::scientific, 104,
        "2."
        "67398429934638135811565547800662171127722207675507363429204836809480442600041268010451262282407276969984e+"
        "104"},
    {0x1.b602d12c2da7dp+347, chars_format::scientific, 104,
        "4."
        "90516421859048735586262432552927537804652667466774102274094051591440656755245550064055546651491847634944e+"
        "104"},
    {0x1.fc12bf0bef890p+348, chars_format::scientific, 105,
        "1."
        "137954340248294860423380000818100997225882123662443049443669733096271165751582178114456678003518298128384e"
        "+105"},
    {0x1.3b58efef7ec92p+349, chars_format::scientific, 104,
        "1."
        "41259541205595997693021666042884440773661567606819789980115193551404322394471748056362736136713555410944e+"
        "105"},
    {0x1.5b4c0eded4f79p+350, chars_format::scientific, 105,
        "3."
        "111427431860026306405776387343100771890312921613335110339967675955518358836576017275894982577915909111808e"
        "+105"},
    {0x1.e85ac6ef41497p+351, chars_format::scientific, 104,
        "8."
        "75031714552777887225807383376825846159238826560043847494035938723501665994908088640458130401929788915712e+"
        "105"},
    {0x1.3f23aec99600fp+352, chars_format::scientific, 106,
        "1."
        "1436652181690534377916969838950952681644685698247142823509585599288898244633450308347520694943066435354624"
        "e+106"},
    {0x1.dbfc913a56c60p+353, chars_format::scientific, 106,
        "3."
        "4114830865381290718001185426163995046141306436854142946803189625447986280993214823051741417052475697922048"
        "e+106"},
    {0x1.1c2ebe7ec1836p+354, chars_format::scientific, 106,
        "4."
        "0735774158992452259605808606588504989866811990087038965595192924870048908044819867508613381642465662992384"
        "e+106"},
    {0x1.938cd43ae03ccp+355, chars_format::scientific, 107,
        "1."
        "1569270331282534059969068327328876565308650356045145204600968251326236704641136451976395157408107677823795"
        "2e+107"},
    {0x1.3b62009235fd5p+356, chars_format::scientific, 106,
        "1."
        "8083251599082482702871408072496160530674776660225822272659505156433465172981994959191303658607609326338048"
        "e+107"},
    {0x1.4aa1b1e151343p+357, chars_format::scientific, 107,
        "3."
        "7915158199315730208700932089897195490537797203507832684798974061156166230255562088474361040176159786847436"
        "8e+107"},
    {0x1.9e1c89c676ae4p+358, chars_format::scientific, 107,
        "9."
        "4976410001520505339336923527708275328860082974903541021837498139408575557376218156577936301953315195007795"
        "2e+107"},
    {0x1.3c53f9e9b8734p+359, chars_format::scientific, 108,
        "1."
        "4509958077289753006583745539523455423321886826191606256195412037965739791079509759759293075504939731643269"
        "12e+108"},
    {0x1.e2406d2cc3bf2p+360, chars_format::scientific, 108,
        "4."
        "4241741129837741663461680635414788924903961539225781403536940590382123291201216260256233875042401766625771"
        "52e+108"},
    {0x1.965c4e0d723edp+361, chars_format::scientific, 108,
        "7."
        "4558991654731428914104079934452871426783695817576025114432418056082590624526774397193747962910439748728258"
        "56e+108"},
    {0x1.f33c9e28b3fdep+362, chars_format::scientific, 109,
        "1."
        "8319982128819878475874631798176252605838592272956747638693247379538573339418939590416398806892687983611215"
        "872e+109"},
    {0x1.9f22e896506fdp+363, chars_format::scientific, 107,
        "3."
        "0467669457405912680374116492410644952689237372714665865235539240041221305708088530307721560995413077105049"
        "6e+109"},
    {0x1.b237a63060f12p+364, chars_format::scientific, 109,
        "6."
        "3736125384602496542925846716945019597567502625082164758543137289627204851036875242571151015244816059499282"
        "432e+109"},
    {0x1.1dc76d7407d6dp+365, chars_format::scientific, 109,
        "8."
        "3895522918267103904361494200392714874087254625614035884417862680704246630517746609334588660429723489456357"
        "376e+109"},
    {0x1.e7fd5979d3140p+366, chars_format::scientific, 110,
        "2."
        "8651611621506035093444741868330375337353333541754848851992800934603776249499947751100608389065176163402802"
        "7904e+110"},
    {0x1.ff1435c531fe7p+367, chars_format::scientific, 110,
        "6."
        "0014533329722189329734118423159496255075495318058115363305083019617613945172917917423988971723427568413363"
        "4048e+110"},
    {0x1.5982e576be2d3p+368, chars_format::scientific, 109,
        "8."
        "1144803338413104318522071061957326245737083351442942911782670679984495024861321317439248085744036645749915"
        "648e+110"},
    {0x1.e0c0dbb472726p+369, chars_format::scientific, 110,
        "2."
        "2581394399876124280153365057814815764302068078753638901090175766989876139196030042285098363557295576667337"
        "5232e+111"},
    {0x1.4debd3de5d8eep+370, chars_format::scientific, 110,
        "3."
        "1369126450743351223644868042070675972090081159686147607453289681648331706776244444631548245507008496724973"
        "9776e+111"},
    {0x1.d1c493d286bdap+371, chars_format::scientific, 111,
        "8."
        "7510056100378395690784980624038829114601832136779682652828503892083478742480986973358649610777828405911675"
        "20768e+111"},
    {0x1.cd72d6d8a7970p+372, chars_format::scientific, 112,
        "1."
        "7339706643869121258726938974735603064835059619375884365102866734218900584708555459322587759993837647617461"
        "321728e+112"},
    {0x1.01627039cb9a4p+373, chars_format::scientific, 110,
        "1."
        "9343312542187018384535981752172379437374967713524355748898830982683829822839502209431730310975458370694991"
        "0528e+112"},
    {0x1.a01e0e84d9fcdp+374, chars_format::scientific, 112,
        "6."
        "2545245092335882126108305965771766597669444535111067555804870482886040056811988312399155986378436981153821"
        "884416e+112"},
    {0x1.37e20c15e4800p+375, chars_format::scientific, 112,
        "9."
        "3756223883151274037776724128790650140133888300427596011365023775012865413735920483562596969561373256776918"
        "499328e+112"},
    {0x1.92565f524e5acp+376, chars_format::scientific, 112,
        "2."
        "4189606341952683163954956898091435430652584365332337819227907179820798920177370025314491683238577112989546"
        "053632e+113"},
    {0x1.b27b47d7ee854p+377, chars_format::scientific, 113,
        "5."
        "2244400989180613708016642369319182679190202045827186553245087278546335559625166994733343152362652931456245"
        "5371776e+113"},
    {0x1.1a868033c3960p+378, chars_format::scientific, 111,
        "6."
        "7944746787200907808603242384755872832913064104675448489356275041550002402856992454666698062568933721142691"
        "10272e+113"},
    {0x1.a98ac07f11c9fp+379, chars_format::scientific, 113,
        "2."
        "0467783827424351314753295564603510293706201890375250515969705111536696782068891131403276581805836580797857"
        "7133568e+114"},
    {0x1.b41b1012636e1p+380, chars_format::scientific, 114,
        "4."
        "1951757921839292213759825458518138580350363545315758818513021797966832710089891213192425152837196142758511"
        "89747712e+114"},
    {0x1.999b23d856f1ep+381, chars_format::scientific, 114,
        "7."
        "8805169769477226984395501914952674333569036724903321387668001616095460959550982116058583249541808618961273"
        "74426112e+114"},
    {0x1.305a3f8fdcff6p+382, chars_format::scientific, 115,
        "1."
        "1711035514327281549569479949647964640917578793955961246965709191416705947065939295227543589878996722369308"
        "020178944e+115"},
    {0x1.2fd99084e7c85p+383, chars_format::scientific, 115,
        "2."
        "3383386959238677954878784167726164592108668182912101860698293836127081479738719391011173946982487947813847"
        "224549376e+115"},
    {0x1.5dec261193077p+384, chars_format::scientific, 115,
        "5."
        "3857995214454247079845670802965140023858333719204363366340740225260425158789455385343584022277219076052133"
        "007589376e+115"},
    {0x1.a60cf45de0593p+385, chars_format::scientific, 116,
        "1."
        "2991906643558943497776765144933401250407988823770730810837676141094927055248128228359441124695444705145614"
        "5233281024e+116"},
    {0x1.206f40c937d33p+386, chars_format::scientific, 116,
        "1."
        "7757658123869845357629737099847397447653687701530379687300816584667928918967996853131360707771162482916206"
        "3377989632e+116"},
    {0x1.f728c980c890fp+387, chars_format::scientific, 116,
        "6."
        "1954646341609976085673971120649779342699001513849840231358690997934347214984119446504411488896637852182451"
        "6257087488e+116"},
    {0x1.51e04772f1442p+388, chars_format::scientific, 116,
        "8."
        "3206223754149984905262009476365485915766118890208584807835460259921682480854584795055699327086777320143406"
        "8744404992e+116"},
    {0x1.0912df6441979p+389, chars_format::scientific, 117,
        "1."
        "3055545505825232086506744135488604281383304022944946031545563740443859815673730758680222956937027900408944"
        "93689905152e+117"},
    {0x1.857ce22ca5331p+390, chars_format::scientific, 116,
        "3."
        "8366504348199781380991738809085235392423352317101826308761234478383352326472236353090210178395092413399713"
        "5095922688e+117"},
    {0x1.bc467f73b801fp+391, chars_format::scientific, 117,
        "8."
        "7526706824277039804869639245253352271037282619434215254665000654758996864632114043366545497170167003892468"
        "19052290048e+117"},
    {0x1.5bfa6323e5cacp+392, chars_format::scientific, 118,
        "1."
        "3711034277595369451570589073470256687658486148188112798860899459323262624831806105873306826350434346072337"
        "605128617984e+118"},
    {0x1.82a929b1cf7e9p+393, chars_format::scientific, 117,
        "3."
        "0470421880719791602243842186576186831668322594660054521032291978571860787539774239209841117297370413955572"
        "37497266176e+118"},
    {0x1.e182eb353c038p+394, chars_format::scientific, 117,
        "7."
        "5890060900329810907778135069349980508477554859344923632527216513475121169687165679512398393358954773663216"
        "86314483712e+118"},
    {0x1.4c41f45ceb5f1p+395, chars_format::scientific, 119,
        "1."
        "0473293912342298987927246042991799310231168245309594826043341824105346363795733309621096687761084862433196"
        "1409430618112e+119"},
    {0x1.4ce2d62a959bap+396, chars_format::scientific, 119,
        "2."
        "0986207045386187035799822440645799479070868059612701038836836380807719120666384981860675905079915949244389"
        "9741222207488e+119"},
    {0x1.00a9e2d3e2ec1p+397, chars_format::scientific, 118,
        "3."
        "2361796613868836525379806150950870022180432502860960693384846782308777259801858316206937444651533852177335"
        "846776602624e+119"},
    {0x1.3c23db7779f4dp+398, chars_format::scientific, 119,
        "7."
        "9721938562445268040649779405182935693865706103206722247447720994088701755123003496336677691442819314314554"
        "4747212341248e+119"},
    {0x1.6ad531cf6c4f6p+399, chars_format::scientific, 120,
        "1."
        "8299315060253445306822233068116074307732330134667370038475622918226677729850029074390245769729323917420193"
        "04962257846272e+120"},
    {0x1.c98a8c0cc02abp+400, chars_format::scientific, 120,
        "4."
        "6151785414218586084275351425717484666160584024314001571165866826527327623500176415071801918580197955917500"
        "03286534520832e+120"},
    {0x1.2599b4edfd3a2p+401, chars_format::scientific, 120,
        "5."
        "9230440706966047717326163349200388918611422161526449532524396598065679686912294908338576147662067326812164"
        "89965037289472e+120"},
    {0x1.516e7c40f57a3p+402, chars_format::scientific, 120,
        "1."
        "3614572894634939353142377534464507149983196785530379090825385582763759726965237412732356418889923433893291"
        "96566586589184e+121"},
    {0x1.554ae9a6c9824p+403, chars_format::scientific, 121,
        "2."
        "7540713949104843243302627542794727706292756358581474088345811708780298515935733700113910390877013926695327"
        "834062687567872e+121"},
    {0x1.9f90524b6d626p+404, chars_format::scientific, 121,
        "6."
        "7068091096020020505776863609624159835496159279383022951686130797028480366726992103594952376070018327492179"
        "668721922473984e+121"},
    {0x1.f8c257fe070b8p+405, chars_format::scientific, 121,
        "1."
        "6292678335806154630688166360914362590126745415634992847446511649792612396156901611908157238175191592424439"
        "211776934936576e+122"},
    {0x1.5063a56cc31c9p+406, chars_format::scientific, 121,
        "2."
        "1716027038832320074453150446374026503717287483078072472301776792170195683193847483635855535294750821428190"
        "165824465534976e+122"},
    {0x1.bb50c0252104cp+407, chars_format::scientific, 122,
        "5."
        "7237560998963261164051475899051612535051551295856297249862290579139114947796469709121788745828899583108208"
        "8581314451079168e+122"},
    {0x1.0b03b69a2e2b0p+408, chars_format::scientific, 121,
        "6."
        "8949817308561794549773992006993513829524212638254346703503829281462167149828570295031646850093094407936155"
        "968718596210688e+122"},
    {0x1.9d8bbd0e57606p+409, chars_format::scientific, 123,
        "2."
        "1357574596497743245860643997782974152312583530928288914224621653851840906558437370562946768094258527345206"
        "20544272774463488e+123"},
    {0x1.1eafceb2b72f1p+410, chars_format::scientific, 123,
        "2."
        "9611872773222930848265894941833298594051480342864701926761084411127391592246266694592950694937066266564299"
        "36634490345488384e+123"},
    {0x1.b82d31fcfdc41p+411, chars_format::scientific, 123,
        "9."
        "0931666168547726710852599333169027626752891656307580547988405863720028970181687484382687622774816982835218"
        "76304509982998528e+123"},
    {0x1.29779ec1c6410p+412, chars_format::scientific, 122,
        "1."
        "2290156989602754537188673668770576138329717434120236431962501631025557907262224101324928918849724892961105"
        "9352012297601024e+124"},
    {0x1.8e05bee28280bp+413, chars_format::scientific, 124,
        "3."
        "2889389033303796449610654007165182953567964772463647692693215012898721719963971688537999284434771305893464"
        "950312791814701056e+124"},
    {0x1.cd14abd1e732dp+414, chars_format::scientific, 123,
        "7."
        "6200044935673398642622195088614903967300342277550390461020413082744224194474257008465422235137871949221256"
        "83888888047730688e+124"},
    {0x1.f2ef51feb4de6p+415, chars_format::scientific, 123,
        "1."
        "6491192862717743459504613539680569605439580112970832661186872894477331119766635885443857313224050612361945"
        "47001764989632512e+125"},
    {0x1.413ce3f0889cfp+416, chars_format::scientific, 124,
        "2."
        "1235620018124725762823525254067453590318834283041039191040578016476648938361158060769801016374834626942712"
        "350029888538804224e+125"},
    {0x1.80779e1506fc3p+417, chars_format::scientific, 125,
        "5."
        "0830874862362334487451129733251317057747109313328626544800449217083767630732412027666136584929422598750310"
        "3152602026665312256e+125"},
    {0x1.f4593e67fd929p+418, chars_format::scientific, 126,
        "1."
        "3230337364814056119849144104483197847048392528104234116224062666811174319203483085958637551302540391438025"
        "71352312329397075968e+126"},
    {0x1.5e1972e7208f0p+419, chars_format::scientific, 124,
        "1."
        "8514824347085014041034982349366075446352413910270634757929615930906113455566549359084851716055947436562390"
        "414624100043456512e+126"},
    {0x1.96497bf3d6e91p+420, chars_format::scientific, 126,
        "4."
        "2972556458892421007071921590288958039713385593786669880815207200398101594477491672457613092647411327609206"
        "31315371878690848768e+126"},
    {0x1.b393f1a1dd519p+421, chars_format::scientific, 125,
        "9."
        "2141239833535442307495264704767013470628707238636280750414584559225026149348200036806199690531376531707581"
        "0956198895278882816e+126"},
    {0x1.7a530210739cfp+422, chars_format::scientific, 126,
        "1."
        "6005984240937531553977123570777698478974555023476350130842071714976647285213117935899888129628035947633907"
        "59168408062720475136e+127"},
    {0x1.e3afa67c26cadp+423, chars_format::scientific, 127,
        "4."
        "0927181564650245664684010226800985508274931575889090496315744789588249190795251849188275548896093477913352"
        "511764494291847610368e+127"},
    {0x1.9c6025d074da1p+424, chars_format::scientific, 127,
        "6."
        "9786454159176674864700637406796740953505985859818133214098100802723756933031499786749130394936305869987683"
        "275467906968807538688e+127"},
    {0x1.065f9b19a0340p+425, chars_format::scientific, 127,
        "8."
        "8803093525901790594982236846498580271914853355874023243258275639983018618600818017364376548834290227200203"
        "210514836291613360128e+127"},
    {0x1.28065949e7553p+426, chars_format::scientific, 128,
        "2."
        "0038549597024574338594732478616631677568333105265167477289796063542021264807661101295192553137929339912243"
        "3770669620377086328832e+128"},
    {0x1.dbade2e06f07dp+427, chars_format::scientific, 128,
        "6."
        "4399483471848686999328022709529943105219847426826425963616573474166235421197828954939077104844009424956504"
        "2561286390284027953152e+128"},
    {0x1.67ec7d8c1da11p+428, chars_format::scientific, 128,
        "9."
        "7456033854245786907306605750937459421920460271523533041156858959899772921310171261122772021520178944401570"
        "3751438749985539096576e+128"},
    {0x1.36a68148c8217p+429, chars_format::scientific, 129,
        "1."
        "6822870661885090958385346032176857964800605455135588888859748256350036651024576361188290442850767472967245"
        "64008491547307408359424e+129"},
    {0x1.dc66b421571e7p+430, chars_format::scientific, 128,
        "5."
        "1597778549120001229289458271163044652451269262060879726520252526449648716471874100678026909960298060927595"
        "8445716698126369161216e+129"},
    {0x1.e15c9d78ea3edp+431, chars_format::scientific, 130,
        "1."
        "0427009479036797635591813366203348981474741136468047501540682552044326004263090661138730742715935642137479"
        "038773324522255424684032e+130"},
    {0x1.ae724dbf30ac9p+432, chars_format::scientific, 130,
        "1."
        "8648218159777694177481503600699806145043094305377350786229177843605334855672050247798038788160317453858732"
        "791008998841995499667456e+130"},
    {0x1.430c116f28682p+433, chars_format::scientific, 130,
        "2."
        "7990719302881792634700208092144765627066028833203628809049595452520597537685450205232172055768615049488552"
        "388925979796926720114688e+130"},
    {0x1.b320abff3a613p+434, chars_format::scientific, 130,
        "7."
        "5404073589427982521492145814481406113541244937512463581995784007627029840880320602509298790920487878388844"
        "654553206928916206321664e+130"},
    {0x1.18baac522a7acp+435, chars_format::scientific, 130,
        "9."
        "7296165332704723045704171191722918884493939736170883951246761040671035725057112924877995355372000233079961"
        "207242515380010313842688e+130"},
    {0x1.4fbbb115a5ca8p+436, chars_format::scientific, 130,
        "2."
        "3271929702892176037363768624801721835810256036604734587782097015027264419314374804953369595074041437169634"
        "435618542541666787524608e+131"},
    {0x1.5d9b4105ffe61p+437, chars_format::scientific, 130,
        "4."
        "8467161954318765570206772089452679519024878853690657983280010268378541784588648092071300919466243785467023"
        "587557836850971723956224e+131"},
    {0x1.382005bbee766p+438, chars_format::scientific, 131,
        "8."
        "6541977087367826921470113849963863869585467375989900445327495698166495057215393260668100684145346758054415"
        "8666736089780468257390592e+131"},
    {0x1.c059a164fbd82p+439, chars_format::scientific, 132,
        "2."
        "4862535742483091390191909586457946706024424055353263778438466175657794451813458472398193755926372662623451"
        "83038540336851637686501376e+132"},
    {0x1.979cf64e101fdp+440, chars_format::scientific, 132,
        "4."
        "5207063266727990659368929644998212413214149738920414291494058222664431815342298802512144646301868226085980"
        "50594119641896654588608512e+132"},
    {0x1.83251647fd9bfp+441, chars_format::scientific, 131,
        "8."
        "5873988136460143134983733826396094677529073230527739927893738680563947508807847000923691955914241843467770"
        "2372087294487581239017472e+132"},
    {0x1.955ba92aaabeep+442, chars_format::scientific, 133,
        "1."
        "7982783689310961422227501310791755104585871964598378773168639232069183211020640286592664999710754396217634"
        "910130253608134690434187264e+133"},
    {0x1.8bb4dd0dfbad4p+443, chars_format::scientific, 133,
        "3."
        "5109229274973699347864490677759997223881087663817023913545612763146947306489437899751559803448131425726260"
        "143262853014497255579713536e+133"},
    {0x1.f2ffa36c6b9eep+444, chars_format::scientific, 133,
        "8."
        "8547728683465430818848616424135997758540156493969637657019447732001527537631411528969363199598954727491766"
        "342717137006267941580177408e+133"},
    {0x1.632ab9a3bbcbap+445, chars_format::scientific, 132,
        "1."
        "2604934227155402813818790481090371090896480259008670745003764210449531315889057203384400641053527209665997"
        "31195389894188478482087936e+134"},
    {0x1.7d9bd6980a8cfp+446, chars_format::scientific, 134,
        "2."
        "7086719929942504183980874941517960977139696239895794732813024870408238539671003001155194987629524329723486"
        "9643886677394157405489594368e+134"},
    {0x1.a0ffc9a223266p+447, chars_format::scientific, 134,
        "5."
        "9197489271133585844975485777857856224444082386611780564812362396421052336042330739080175933534182879047767"
        "6111442443375110521989627904e+134"},
    {0x1.2f2d555f5fce4p+448, chars_format::scientific, 134,
        "8."
        "6078455047134678604434818618455571588162294805214457729391162123838507816170041687711921610823738459963116"
        "4804764816415732192769998848e+134"},
    {0x1.a65f9697c0d52p+449, chars_format::scientific, 134,
        "2."
        "3984166963813072130304254866815544719778779058112414594148507465903882624211291997549855045437187950977197"
        "1753138721689172308884717568e+135"},
    {0x1.1e2be5c1a5196p+450, chars_format::scientific, 135,
        "3."
        "2500079608629177786469594361062615885964978686442183195525824456070734494611472398735816156518917726424812"
        "39481297672424409886179196928e+135"},
    {0x1.47b6e3f5377a9p+451, chars_format::scientific, 135,
        "7."
        "4436102486817026391330384910904960377209366279201460342224886867177126680907304411140987558975509995313169"
        "63156312332013839122343919616e+135"},
    {0x1.aad9cc8c1c972p+452, chars_format::scientific, 136,
        "1."
        "9390729656615215196506812000617451479776711512449142787848459303341260609191028331093673283435440617925958"
        "437747265492354517993099624448e+136"},
    {0x1.8cc0ea5310fdep+453, chars_format::scientific, 136,
        "3."
        "6046982835224656412915754976920501824030544272349863266164621223344701329058249574603030560264745117993137"
        "684398776063481336351546146816e+136"},
    {0x1.e8e380e2826ccp+454, chars_format::scientific, 136,
        "8."
        "8835807100315059364957572853053758885118262053119958231473714438599572821951098669770374248448262038769401"
        "918432797048903756272554213376e+136"},
    {0x1.2033b9d066e11p+455, chars_format::scientific, 136,
        "1."
        "0473820665170048878755154408578719330325269921188949224604166784423321269440809970793883543719137433912200"
        "960322988368687585762606055424e+137"},
    {0x1.7564b97a79d61p+456, chars_format::scientific, 137,
        "2."
        "7139682262053297241988392724437792044208285211247000447865789047411414826976478691092595194217736809420582"
        "8453389512306293635710562861056e+137"},
    {0x1.2b82c2280c26fp+457, chars_format::scientific, 137,
        "4."
        "3539205936145104705820726228284843445060921065728394032721829835221039495244642053528782260776415870011292"
        "0667363070863633573415250558976e+137"},
    {0x1.bf1f7396a6e57p+458, chars_format::scientific, 137,
        "1."
        "2999448293666169914859805985488601512306519687598179446463228767237657957150042169876476045654460534381097"
        "3852347955449052461046878437376e+138"},
    {0x1.a657699d2c0dfp+459, chars_format::scientific, 138,
        "2."
        "4557929966471053199872649466981740356692231404103633543942219010330417450053674332463696723123550304578318"
        "75446589644026555749761133051904e+138"},
    {0x1.288594faed777p+460, chars_format::scientific, 136,
        "3."
        "4483764818218847425999970317030640238793097206477624197384500971308224538523438179692769564897834190472272"
        "984703422288615432778015571968e+138"},
    {0x1.2375adab19290p+461, chars_format::scientific, 138,
        "6."
        "7790138521807316420628038773287438668644664004594370167025452117781647057165800982402225795850370051610486"
        "65824473078182953740522326327296e+138"},
    {0x1.83324c05e70f4p+462, chars_format::scientific, 139,
        "1."
        "8011480968834750196365369192967420715415862985071604121776057399720459471533740960032406448817837519216226"
        "379536264641695755986389226749952e+139"},
    {0x1.97873666d985cp+463, chars_format::scientific, 138,
        "3."
        "7914529023902069557105004428400868367552071861042286022257178185224413635321720588745810122575048414255517"
        "01851829776853108766540296093696e+139"},
    {0x1.5bfa9fa8f352fp+464, chars_format::scientific, 139,
        "6."
        "4748700546465721232888949688272095534998009840175105196292202572473650907793490793699624888993654341347901"
        "931540117631355075040339017334784e+139"},
    {0x1.b42b6a79cf7afp+465, chars_format::scientific, 139,
        "1."
        "6231677484748647738284246889132703021787090536862881417070276086241812776564227608785040979834680452730627"
        "673951299390073462133082170589184e+140"},
    {0x1.da02be394de37p+466, chars_format::scientific, 140,
        "3."
        "5279804769813379877739625265790221988342974868955307215219678257545606581258685003954570507986505945443644"
        "9176466265315274091295259079213056e+140"},
    {0x1.3eeed2ed5a952p+467, chars_format::scientific, 140,
        "4."
        "7475258680916253745897531734514044938760808711217428348829658546005624616624979279156129711124921701243923"
        "0326495036221766234765211123843072e+140"},
    {0x1.3666a3d10b839p+468, chars_format::scientific, 139,
        "9."
        "2410438112435489734379685774435069421261232157650793824990530192357729924647916137217180562449829723923226"
        "838139416593417420331177274769408e+140"},
    {0x1.2570fb22b2de6p+469, chars_format::scientific, 141,
        "1."
        "7472268158903567970489376394874270060913393878056825078725374417255330239774644537653308699459602551618379"
        "02768182371165254880871258817298432e+141"},
    {0x1.b07e20dfa1d42p+470, chars_format::scientific, 141,
        "5."
        "1503502855445633918124843079814372660247218165154922786481877126700784289698976045903050168159110788693854"
        "75223702592482681568973998545436672e+141"},
    {0x1.c0fecaa34903bp+471, chars_format::scientific, 142,
        "1."
        "0693743613454128344229738507659554069041113104116305538551763636641133000749164190535494572802701842844775"
        "713873914174897214881753809553457152e+142"},
    {0x1.6a93c2fdb14e2p+472, chars_format::scientific, 142,
        "1."
        "7271039275900878702320064613161114211734760062020379022350617158951989967269777650968393695346424676919360"
        "350528737280818370651311134702829568e+142"},
    {0x1.ed356c6ec0f02p+473, chars_format::scientific, 142,
        "4."
        "6987106320234365309357865348526617076295430864840940367700909254686103875433346901774408206734975670041416"
        "172724241468670572852355997846470656e+142"},
    {0x1.fa2a9a922005bp+474, chars_format::scientific, 142,
        "9."
        "6443133006154375629544673773217995571737351906051889965372169517032873570684626710445723256193599631347074"
        "349343808996878649261861384554020864e+142"},
    {0x1.7779f5e06053dp+475, chars_format::scientific, 143,
        "1."
        "4308385405721830409588986842341221217630751607519642205768203476726949608471686240173850875709383849977420"
        "4490512832595931739164387055612461056e+143"},
    {0x1.2ae00f64ca014p+476, chars_format::scientific, 143,
        "2."
        "2778645782254102124024170465292525325953086411923614498725917672177361290237337288215777392459244097224025"
        "7516688035006692022253572705950367744e+143"},
    {0x1.14617f48912ccp+477, chars_format::scientific, 143,
        "4."
        "2128491843628015690123491447499183775579140689758554402383290954566150779370440635482704842123528539898814"
        "6300675184394950248081186488630378496e+143"},
    {0x1.0e36f018afe63p+478, chars_format::scientific, 143,
        "8."
        "2377152265461927468904475031209979234555951818796497236476191970051849571112509654722312234611809959811641"
        "4799396399785995085176935884420808704e+143"},
    {0x1.b52a83911a3c4p+479, chars_format::scientific, 143,
        "2."
        "6654737215359226174536865647606054602172499959987706988316732285249892439427281825776876900401158871819657"
        "3169689339585153422638164295314046976e+144"},
    {0x1.ed98b659547bdp+480, chars_format::scientific, 144,
        "6."
        "0190791388121617864043227714242098900748708658128288053595523523236653831506983860037384561642314883951698"
        "44387225601064643184790911958453846016e+144"},
    {0x1.fcce356c4ec85p+481, chars_format::scientific, 145,
        "1."
        "2409084690292541652527613045437775018048935473224778548554214581456588840011339733629203404858897924037517"
        "041939851403445857567862463857852153856e+145"},
    {0x1.3dc01483d63ddp+482, chars_format::scientific, 145,
        "1."
        "5499009048061588814641526995523600939707388795282617174767697160344249266869043729431751617061601018589761"
        "944702337982434466462060034234811154432e+145"},
    {0x1.4557a7b0057d8p+483, chars_format::scientific, 145,
        "3."
        "1738661663567816264285516822801972971728151651206469963506380696188890277837365396682106309758742282006353"
        "922475242220366972514288404986230472704e+145"},
    {0x1.669d69cbaf0ddp+484, chars_format::scientific, 145,
        "6."
        "9969095646663514806564458838233472693358039320736641847439538782518050931122329603176958512021576452086116"
        "368782676471010501175026121646448574464e+145"},
    {0x1.6a4308943f906p+485, chars_format::scientific, 146,
        "1."
        "4136130050003495275965580705190245360273003406456889860795577433714410287964689565247783341979195424013701"
        "3541670491478732029287175906702745665536e+146"},
    {0x1.7e7001ab289dap+486, chars_format::scientific, 146,
        "2."
        "9846844767329699730804823460088397797510887741980731170544140686250237048357484822927489181913790614021254"
        "7533066937938143958203611335491240067072e+146"},
    {0x1.44fa24aa8c90fp+487, chars_format::scientific, 146,
        "5."
        "0724842971646726557538500759842253464019052289835282388395679467419407983799647286830871888227794990888424"
        "5889023882897106195080463734761662185472e+146"},
    {0x1.25d657eccb0e9p+488, chars_format::scientific, 146,
        "9."
        "1728610014857275568630794658652531231738100002919045253200249494512141469153567046655808833763172390263394"
        "9642595917883820840553955755394812870656e+146"},
    {0x1.fdc48127436c0p+489, chars_format::scientific, 147,
        "3."
        "1827325058993567033331233752691212903377352608036310991356332821822901954914663377518977669960782647885876"
        "42034976623676783849309720668272859283456e+147"},
    {0x1.50cc21e5e879dp+490, chars_format::scientific, 147,
        "4."
        "2055870839470368973611151678893166078089637115801651589474584679020395433716298683315313593307964143156245"
        "28062235406626283210983955984299738529792e+147"},
    {0x1.5a4e10fb478ccp+491, chars_format::scientific, 147,
        "8."
        "6486157205772329602600102378606658784899216279777069711674137164731822935624882824299743209883343812966340"
        "69075898792649120978628662820343688200192e+147"},
    {0x1.e6b342df1851fp+492, chars_format::scientific, 148,
        "2."
        "4309692254959332536450538679079560253529415066541042380383420527274189578274453585054569384583992487731455"
        "483906898199659271966077737111144370274304e+148"},
    {0x1.bf189fba46a51p+493, chars_format::scientific, 148,
        "4."
        "4663099980821111700735062823707061081964579432094161222504349764876114111980602434939174729613231975280697"
        "191542952742623676348156107248907356995584e+148"},
    {0x1.7744c67ce2733p+494, chars_format::scientific, 148,
        "7."
        "4975640039478889368046232138806074105698824731102334281006775249643928390949836346608458092165052666069303"
        "519645320456702179748989546565091612164096e+148"},
    {0x1.dc39acc6db7a8p+495, chars_format::scientific, 149,
        "1."
        "9029191895593582513042254429613933892519819466440008181362475451661449874055230966283314835362517622544618"
        "4345874717099016754240440378652340420345856e+149"},
    {0x1.db93ed9dfa8dcp+496, chars_format::scientific, 149,
        "3."
        "8006641833677102492887824906118725961379661738962189610447881646688988112543794681781941996783845042196323"
        "6989721829537772787957124251662568730394624e+149"},
    {0x1.b0906aca51c5dp+497, chars_format::scientific, 147,
        "6."
        "9138249940821013776040341733524915351912661776644830548370675524262798977629271437574440357029271950983009"
        "12889719993286829251194606517019647934464e+149"},
    {0x1.108f1f5365715p+498, chars_format::scientific, 149,
        "8."
        "7128154838017157392572522860918668800672134186008534463400197915073924087965859797620971620007008411202092"
        "2177725097537079407027753889855794306875392e+149"},
    {0x1.73f5a2326daefp+499, chars_format::scientific, 150,
        "2."
        "3780639727460606718971338187316809987528213181384630599789933496032265252598793205389604654238668756538754"
        "31703645955198350097511963193717040609230848e+150"},
    {0x1.5d60e9bc96714p+500, chars_format::scientific, 150,
        "4."
        "4673926496387289708030095900258305973038660116707814882439878055497811702692322213460750885548964045810631"
        "90784109692968975073166801707596473568329728e+150"},
    {0x1.3b69dd2b0a7b8p+501, chars_format::scientific, 148,
        "8."
        "0661850781591161677122954721172068591732257201798966036585171037261748611696578597260945643403701202524424"
        "416735637962153511596447310123657955639296e+150"},
    {0x1.70986ba3519c3p+502, chars_format::scientific, 150,
        "1."
        "8852448369964825428928236009439861167135645949955343442728306696583016816237354048060006184106295445822087"
        "64698138596718695789572228160443206070173696e+151"},
    {0x1.5c9ead10d3adep+503, chars_format::scientific, 151,
        "3."
        "5661527237397952344670186371555605241594133611593918425171554010625322731432466488798805829069196773260339"
        "528369728020651143141594374865566386412847104e+151"},
    {0x1.2199c7c3b4ea1p+504, chars_format::scientific, 151,
        "5."
        "9248514116816446405034179271903794942228235937785654591274434436685914444005512695452376722135010343543480"
        "884465555148433997142511793829160779635490816e+151"},
    {0x1.7012b5d2cf305p+505, chars_format::scientific, 152,
        "1."
        "5060587321219466553012870351093686397249916401759472434092827544464856133318187035806973362924090662903749"
        "1671355128894869419427983062506453820908765184e+152"},
    {0x1.5d488913a6d62p+506, chars_format::scientific, 152,
        "2."
        "8583520249281916338866314327559210987065565190673533620469014785587813138788138839992315111228424039110187"
        "8885418173061097660244197201776411569329012736e+152"},
    {0x1.151c3720960e0p+507, chars_format::scientific, 152,
        "4."
        "5354498949077742169034443406216049299770028918272764456328676932798016382716888496031992258428716623824999"
        "2218941837638686010641196013298349788803104768e+152"},
    {0x1.3557fa79ed04ap+508, chars_format::scientific, 153,
        "1."
        "0126026499623770044576994423798637012002417501464985878117760782996493012648396817497758322250050492041349"
        "01434458455631896130313812311189422436650057728e+153"},
    {0x1.34632efda2f08p+509, chars_format::scientific, 153,
        "2."
        "0189450716998492213121147666474166009392711045094381728529008061117293669417942835283009277823392486547470"
        "13008590709252183660814342129605380010212851712e+153"},
    {0x1.d18dd31d25525p+510, chars_format::scientific, 152,
        "6."
        "0957603982087232982909513121211465815599741588204415820396298222851596266515550801404820224265065922278874"
        "3115865057982121845872416589866036396684214272e+153"},
    {0x1.9deef9f325dcdp+511, chars_format::scientific, 154,
        "1."
        "0839728287028179041104779394402998431149044866332968906003742365561718883404305927813627842460928319702403"
        "984206679307763828828827451150213226478513946624e+154"},
    {0x1.80ef70407b9d2p+512, chars_format::scientific, 154,
        "2."
        "0160697875193073281058350414245510320201644882796531994091425667271465650234996404676918103588204703802980"
        "632898021029981572024314647222500081978631520256e+154"},
    {0x1.b15f90e524369p+513, chars_format::scientific, 153,
        "4."
        "5395203367398852029035305208109368042694923882699028139843273249770514204350231474300282943704322434188173"
        "61739058201501829021491250719502352274386059264e+154"},
    {0x1.7d04016826a78p+514, chars_format::scientific, 154,
        "7."
        "9821634470750785005816307052453796709151400402439168637259226600219936117575503983393755774577473554235475"
        "350529315775591347087019497446187187442089459712e+154"},
    {0x1.09207e9aeb4cep+515, chars_format::scientific, 155,
        "1."
        "1108659309948223232073721981058486015639763921196063562755246502603396586456380455178355920137319345651353"
        "1979239601685059643816826533951965329199816769536e+155"},
    {0x1.5eb84ec7e3693p+516, chars_format::scientific, 155,
        "2."
        "9389910968456540497145308817665722993724686326666865780387846928243089920830213473101442296898483553295520"
        "8915016266000487049786013109396266423674162118656e+155"},
    {0x1.cd831a4414f7bp+517, chars_format::scientific, 155,
        "7."
        "7348323201078494069759154153148452216906433545612171796327606278267578531935859682519963528897995839751164"
        "7543570671668790057093880969098511595082212179968e+155"},
    {0x1.3c41b73edbcf8p+518, chars_format::scientific, 154,
        "1."
        "0600772804334341824498673238754643000590112296311638116693641098492271731881033950635386567714769641582038"
        "129703645750077658115580500414849678160462610432e+156"},
    {0x1.7de6915655786p+519, chars_format::scientific, 156,
        "2."
        "5602253164214019794228034929986330634069568667913627567267961346885683499448441433864914716779614560756659"
        "03377049407345319868363294328606411349469066952704e+156"},
    {0x1.e47a65469d029p+520, chars_format::scientific, 153,
        "6."
        "4957894162689224015531687169668567969940639978728659196460226175437163963971643262151792036582074933138652"
        "50447186614103438727429420216590467896398839808e+156"},
    {0x1.866eb1b2a52cdp+521, chars_format::scientific, 157,
        "1."
        "0469685229597165679242472867781707564232232115066593897597547823552733586500623731175655852654661036675944"
        "667470248283335770956666084386262948697191024164864e+157"},
    {0x1.508c027c49129p+522, chars_format::scientific, 157,
        "1."
        "8049425471684503811692336471805744340392676090966559914158167829693248936857451772455022819546651020419395"
        "086693907597563666097234994451590506212471517216768e+157"},
    {0x1.61ee1b28cecdep+523, chars_format::scientific, 157,
        "3."
        "7963414617308415787809596904160555114321348252647420762121034631479538120026400394885418700946009320148869"
        "300117380342424037408264379528162055292585638887424e+157"},
    {0x1.a7da0d015e36cp+524, chars_format::scientific, 156,
        "9."
        "0926768024467341820333176481577483392918662852566121383240080801535518391810171083632685627972390044164430"
        "68688466546996181994685113127876888475052825116672e+157"},
    {0x1.f343d287ffc8dp+525, chars_format::scientific, 158,
        "2."
        "1420954571874796181867803558173897390873628203612099816299639538188847181871424707442829555039446305144765"
        "1015663758672875883679550666916401541316002057289728e+158"},
    {0x1.9c9c3a3327bfep+526, chars_format::scientific, 158,
        "3."
        "5406074604903996493796486071626953502852438595335202338839222961489306095343149732156950905287112321360780"
        "8354960582121162245411977647195367953750953520267264e+158"},
    {0x1.610edb058ff32p+527, chars_format::scientific, 158,
        "6."
        "0591798371136819507430990360066620553732791972857074064150285578732374423137313166606132376705119733187389"
        "5394455715612868333780052349810329711384825746685952e+158"},
    {0x1.f30c74ca208cap+528, chars_format::scientific, 159,
        "1."
        "7129340266632834749953577858343993939516249529867835081849172692553781768247897374384734210875421524426627"
        "95936288492656745381512223241233513801086791472644096e+159"},
    {0x1.1c138fed7032dp+529, chars_format::scientific, 159,
        "1."
        "9501271083673802659787898406127054138324463280765738674858806150954364373930724252610104418333259637179348"
        "62664034468096428283397061878573723884854136941838336e+159"},
    {0x1.78c95f77c873ep+530, chars_format::scientific, 158,
        "5."
        "1731277182329399807450239014797118750746786034562901386123351160720955621307415583371062151381510556778868"
        "4863245902366518485000140068796841840045365854732288e+159"},
    {0x1.6459f93baec50p+531, chars_format::scientific, 159,
        "9."
        "7851226544599463771564921368556921827542040445585447659018246369324390402047706431276015403214773792169641"
        "53369345749073097713940190208348710065187772895854592e+159"},
    {0x1.7906aa9a30611p+532, chars_format::scientific, 160,
        "2."
        "0705659855195211460286170209038937641731272422289152825858212496294807163297965180604186403154243179767907"
        "958537137222057332190533942595916677783931001302417408e+160"},
    {0x1.fa515f09e2725p+533, chars_format::scientific, 160,
        "5."
        "5612314177003026122910357232767009218623136419014789426089817048220952364784685334500211032736310921113172"
        "928546161625907053067205424290791219411580020307525632e+160"},
    {0x1.54d8573fb9596p+534, chars_format::scientific, 160,
        "7."
        "4874640533241470730279851562518649602012685564108538483392983178670598698623549235703802716601073988953860"
        "606902557706179876262726589838088595804228576518078464e+160"},
    {0x1.87e0d2f66b2bfp+535, chars_format::scientific, 161,
        "1."
        "7217053958890400852304842901770937001126359565588473543908015592102961364884006330645313689960462043380825"
        "1320307524080356734627614383764502179134363483408171008e+161"},
    {0x1.60fc1327a06edp+536, chars_format::scientific, 160,
        "3."
        "1016554470379008022068644346655257519265668288613794968614902119460294276336894661044455582708231625230426"
        "882579521337832334896604900954598995797437634695921664e+161"},
    {0x1.992c8531ab31fp+537, chars_format::scientific, 160,
        "7."
        "1907739698299548544761759553441263855094547256115006468689749065750269245670602987652747097354199309800064"
        "670851825256317768108233601492032587469380109538951168e+161"},
    {0x1.cddee01e85f4ap+538, chars_format::scientific, 162,
        "1."
        "6233719112674834819250602540832248747933195166025444180503928859570585646532467134263435983989542489214476"
        "20240933830255782920769862417050715330898449264684302336e+162"},
    {0x1.99388c768c3b8p+539, chars_format::scientific, 161,
        "2."
        "8766398779168217186821712748845526998862701568704494700659767166699492968678738103971887270801356246232898"
        "4464635950443836780167505221033916869036529710130003968e+162"},
    {0x1.6c2ad6bba6ed8p+540, chars_format::scientific, 162,
        "5."
        "1198670788912167528683009615591842433917743580431308732145221701765414223358769100615506655778167511446878"
        "84279178798057513594382918680535607030620295902798020608e+162"},
    {0x1.8121da546cf38p+541, chars_format::scientific, 163,
        "1."
        "0829229605647497287491811471725340667019982382295287441998766070027220247968289288736829697687593326874916"
        "164752948106530119043799024142733614166064793545183592448e+163"},
    {0x1.cc5c0ae184fdep+542, chars_format::scientific, 163,
        "2."
        "5888973619862410055297953386823285447975896175369247744210466527341086214689620755203843473222529430068506"
        "678735966744366849758761825149394672284437121408260112384e+163"},
    {0x1.afe092d15aefbp+543, chars_format::scientific, 162,
        "4."
        "8574461844070456592452814669711010322733557031362825853413619938116374692585676530060249181278323860055817"
        "10108947627014752518519314486521054019823200748024365056e+163"},
    {0x1.5f1a1433b9174p+544, chars_format::scientific, 162,
        "7."
        "8978852482314809765725691489425494641108478398257497378847509387658904871074579765532782187266445909935288"
        "39354232570725767224692678438531015988394836852670988288e+163"},
    {0x1.8ab67f98bb5f2p+545, chars_format::scientific, 164,
        "1."
        "7757792408248608219840650290884562103331609396064383190252928684474923426996907505463604471391579602571928"
        "3383611834930550575178173514581572666518402542001715150848e+164"},
    {0x1.f62458acb73c6p+546, chars_format::scientific, 164,
        "4."
        "5181869438995584155942879986161607327235800888084626274207935286368186289977681849743093295766921622231766"
        "8812532970018869401576788745672335158605915636428814942208e+164"},
    {0x1.4fe1a6ba1c0e3p+547, chars_format::scientific, 164,
        "6."
        "0444067603790198680770375784082738739903558248297596449563137728373742577949182284564959980474547207384645"
        "3804398133039311346050607936591463621343012361379329867776e+164"},
    {0x1.063123904b927p+548, chars_format::scientific, 164,
        "9."
        "4366318060930614275042036245009185089291734679507684985639516919954063657248120231594112076454245476674772"
        "9956337135685250388333452322276527666526976611670460203008e+164"},
    {0x1.c3e4c9bc47a76p+549, chars_format::scientific, 165,
        "3."
        "2528493042703321141413309200996676555863097235776172037843793780326803925005135657769958248885096410603987"
        "58716325831107713950320367933304627208668064052102524043264e+165"},
    {0x1.594ccd81bd096p+550, chars_format::scientific, 165,
        "4."
        "9711199416816592464299002776950161898639000113245240977386824261505093729352843986582700405277078306324888"
        "68641461825918412782352354477687969196944687248446058397696e+165"},
    {0x1.0c6555b87dfb8p+551, chars_format::scientific, 165,
        "7."
        "7279343588562495407126280049885300491080229351189365823501345364553687726140552946628389981545368743987276"
        "85060343548384620139502630275174727089552646218700654903296e+165"},
    {0x1.b1efe87fe7322p+552, chars_format::scientific, 166,
        "2."
        "4988746130766798376827800199823813953256757708767876517238281997487181991551985565303552676809021792458092"
        "123757308008963935169221303180214415444334488294696842952704e+166"},
    {0x1.674a2eb4f0902p+553, chars_format::scientific, 165,
        "4."
        "1380191381421080895240587023700110588669580856565936068294303762090684154630617939500552507881452379030122"
        "57564369266702609329281301036802867992107269395537054400512e+166"},
    {0x1.4d10ab628902cp+554, chars_format::scientific, 166,
        "7."
        "6719679535199355279888354227234517257428645312697123534388363324410221239158316740528269628364865341052173"
        "890153833114361977767211690942890884469581914980429066141696e+166"},
    {0x1.348910101b05bp+555, chars_format::scientific, 166,
        "1."
        "4213879533988812988801489499892461314159660165902092759593012160198840631550914331540618549869245720943038"
        "591573264165447412080305585107256403832151644381045298561024e+167"},
    {0x1.f9213f77afaa5p+556, chars_format::scientific, 166,
        "4."
        "6541532390763673825077519098739600416173657505928203777805647482615365710172842479112509262117196395261215"
        "492125122729032007120120133249597715368097561405386982948864e+167"},
    {0x1.39148decde7a0p+557, chars_format::scientific, 167,
        "5."
        "7693029917278790835343693446228541151083246279328989491902151468261054433974865155786482743975400685885796"
        "8022384319234650521865502886831850045752670251564620807405568e+167"},
    {0x1.dbecf9a36abebp+558, chars_format::scientific, 167,
        "1."
        "7540289541978554536679278449080898961110674955967170960958625902039261628279839229960204922512068948500088"
        "8111062907960551667913609284846202035011913824495680054362112e+168"},
    {0x1.d4b8e3838c0c9p+559, chars_format::scientific, 168,
        "3."
        "4549610389534939614163292665079261900985718205569253011397072055313397970532490532749071748873309501615887"
        "68433100280033360041954344387894356034343704057173414445580288e+168"},
    {0x1.0a21e645d2c72p+560, chars_format::scientific, 168,
        "3."
        "9233349720899516225653006419073082111151059390156664403365001807815842714755260514950130149946827232025161"
        "76590662854806987645471308169316788500685330937565504795049984e+168"},
    {0x1.af01dfd28918fp+561, chars_format::scientific, 169,
        "1."
        "2707854970292210593587573885875803437251996278109312071923766373553351738675154455717211273888077203914132"
        "749180314815054893523728069064065041255302851675835296773046272e+169"},
    {0x1.92f36b46cac74p+562, chars_format::scientific, 169,
        "2."
        "3761271692350110891980215212946227422808590277003177300689353935734267394985067115490384266663644635321905"
        "607600207437156411377406544504086631781775691133562731288854528e+169"},
    {0x1.bfe04dfec51e0p+563, chars_format::scientific, 169,
        "5."
        "2820872264243582355340332232481921609272763546174111866258873749725898989610965360460037699636411260012718"
        "784674393928472275175596068580609021329456130597064239797501952e+169"},
    {0x1.94670a2ba70e6p+564, chars_format::scientific, 169,
        "9."
        "5387489718917882102948269594473215622857013680481211269007794315939403812083737122286688310471818933068612"
        "563309998840782226852329612567449648252694634073100841335652352e+169"},
    {0x1.bf6363fec4e21p+565, chars_format::scientific, 170,
        "2."
        "1105330303243356951146447438805265173253179909270544813724232524968355202014726255584317008254777069021908"
        "6744514884262890299095847660667744123821425839198582550323789824e+170"},
    {0x1.130ebe426a4a0p+566, chars_format::scientific, 169,
        "2."
        "5951425292354768078033905586616956725006215370952637745135245417861224604987531981214225200701240175108930"
        "840201983359378046439994040914451391630102167656335065688834048e+170"},
    {0x1.4846fccf0db5fp+567, chars_format::scientific, 170,
        "6."
        "1945308823207183058683537468760738258329716957097993465302851964798828559561781466290211511455975152392126"
        "1814494546071943712322858477374811036408749349113740468449968128e+170"},
    {0x1.cce40bc89d5a7p+568, chars_format::scientific, 171,
        "1."
        "7393845792769813157591485334728289421339191017476114033077639490417559171554638668857619030907317254081420"
        "81878718092529513244534671322128694195746568199203839343494955008e+171"},
    {0x1.4cbb8d52adc91p+569, chars_format::scientific, 171,
        "2."
        "5114408497872504889849608236610231700159606941723791669619088524835085024738028008402272439623076576729481"
        "04995738811198515357386384926071278483707177078191869448614313984e+171"},
    {0x1.cd56ecd7c5ed1p+570, chars_format::scientific, 171,
        "6."
        "9643125288033973128155017170856729588410994800848488875781660527415029309190846451750710704827305435019690"
        "67430731268878668278955626743849683963257233143847666633043607552e+171"},
    {0x1.974548f633393p+571, chars_format::scientific, 171,
        "1."
        "2296192874342279398035503660585874984268215640415692614185754893612306440618721946387877459034366883413609"
        "36918152006779286929596814740431079796422442812171122552998985728e+172"},
    {0x1.785df63f7e7e1p+572, chars_format::scientific, 172,
        "2."
        "2726320991720393806082142485686217558330202638077848150550875230011082976612969886981829508930227201207417"
        "730127845908876453052097589780463041422857268424951597133270614016e+172"},
    {0x1.fa98d2372e253p+573, chars_format::scientific, 172,
        "6."
        "1180092244552894479108133503846936836371359233960903288151843139474694399086289881596960660601999690274170"
        "051304615631465749824618705719721448275602824998439000878232895488e+172"},
    {0x1.44f76f3ef0c7ap+574, chars_format::scientific, 172,
        "7."
        "8490337018587336573333382241289679251882281880347544433206317733805938361518095340765276962431841975064047"
        "569375644124507699361497786620173012597660819648747164399097085952e+172"},
    {0x1.845aee96c611dp+575, chars_format::scientific, 173,
        "1."
        "8760165681953460413072829118958732692270564661286131167055983545979791077034420925197352908458387625197641"
        "2473853052506364697656419609232890365789316383760219161065634660352e+173"},
    {0x1.6abc94e260cffp+576, chars_format::scientific, 173,
        "3."
        "5045234562719050444563289817930312119606725049565642471521942232460177946069408153684540504194597258990573"
        "1168807151668054670532129843180363278721230005822552578189869187072e+173"},
    {0x1.77e7f7ab33101p+577, chars_format::scientific, 173,
        "7."
        "2635165849153785494563747540191483129521644872733745237579476633099320088983835423243815213775349593473393"
        "6104514254970171070110867729784675843986648873395065583346126946304e+173"},
    {0x1.ec2c8c72e6720p+578, chars_format::scientific, 174,
        "1."
        "9020249607206747490383578565711176171590073672334887637643049626295328537660038412541458277654513402022486"
        "56704594513309856716357813392938070159279476826318762074068165328896e+174"},
    {0x1.ffa5d013ee4f4p+579, chars_format::scientific, 174,
        "3."
        "9545635188621041668458681519635092022565038577625047050999641589933335359562218991630738088787131211935609"
        "93015277645286678140294132386511219265217225137785123722280327708672e+174"},
    {0x1.0e5c252b8b844p+580, chars_format::scientific, 174,
        "4."
        "1792645649574566918909157878760712130302228913462470260602194485414931164079583288497776163194723846747926"
        "67771126097789471772132138304456722148757124945602576369254706184192e+174"},
    {0x1.b285d8728f853p+581, chars_format::scientific, 175,
        "1."
        "3433838372088608392759541865783165685150864489372534049853049621196819773114326777373607298582831758073273"
        "139400905288866876199471807470183600176123459886516500946100328333312e+175"},
    {0x1.830d570659ed5p+582, chars_format::scientific, 175,
        "2."
        "3932438386350752398906060480134131184426749382780138750338631150127979246477473949125606039841210188441858"
        "566259800113585445368689288040865119179350881451516413561225814736896e+175"},
    {0x1.5b7cf521730bap+583, chars_format::scientific, 174,
        "4."
        "2972187544143624764586854064545662595041257012005724100970207585455769895698007795217153843862284368740788"
        "37417713457309033640069443709571991834451783158215011561194532110336e+175"},
    {0x1.5f8ba5e3fe8cdp+584, chars_format::scientific, 175,
        "8."
        "6947889660886424315517334917379237681473389004555025287147425576180688651377619113503080210808097080248303"
        "065713994383176911387666854498724374888010555657160403443732556283904e+175"},
    {0x1.3c656382359c3p+585, chars_format::scientific, 176,
        "1."
        "5650872395957953309347511865374635720208636296528844086575068893754566789157942879574612175260545187823033"
        "6009199988423048858224043380759941961868932909470130132231537427480576e+176"},
    {0x1.0cf69f601cbcbp+586, chars_format::scientific, 176,
        "2."
        "6609127251749555037344451329716993732732872523015958386211791209911418856092668804225952579441453946598216"
        "1018353954777170666779903498891261251335885914232419435941537077264384e+176"},
    {0x1.712601f59010fp+587, chars_format::scientific, 176,
        "7."
        "3041310915282277318283127156341286263678327106712574565671678562056257118035892836027777300336909382959943"
        "9489279348564634343854478223995096490083834564122961187316938125082624e+176"},
    {0x1.d9cb25c6870d5p+588, chars_format::scientific, 177,
        "1."
        "8749367638301195110882726444350992935900646090447817670758440898890197572172958410652798401071911495348057"
        "11539366541500871745028252870081743197260064203842403729644908114345984e+177"},
    {0x1.3f0bce2a16035p+589, chars_format::scientific, 177,
        "2."
        "5251137153536482125661277313165311760764103743192046445514228495477898656364587565420879026668975210962336"
        "21580712956165193248559493345236489976046311451102680851980278768336896e+177"},
    {0x1.4e046f64ace9fp+590, chars_format::scientific, 177,
        "5."
        "2872088975059578152905008327011014369021532127587373171513246370679335597730248232687171558021787964992854"
        "69008136051884913289117970821444349734733325693898128129470005715664896e+177"},
    {0x1.81c96c18da3b8p+591, chars_format::scientific, 178,
        "1."
        "2213351108095343900087303306426544285718316496416974886789244650584122979327515475219578337262395376593353"
        "901364495415734234777395486829707907374874417711021037161711853711130624e+178"},
    {0x1.4d6f7e4292164p+592, chars_format::scientific, 178,
        "2."
        "1111997723509844240784743048023317235372730114142490466670077948439063027728542870283482437925492280294038"
        "014573739362326768950393557886221693829978829496324438880160656306208768e+178"},
    {0x1.8c09c58dce2d5p+593, chars_format::scientific, 178,
        "5."
        "0151567233983766888518548233001321491315735325442193958423073461431568869675027140356293231317677337543096"
        "676819898009801602967325844127445604533459507481195933684935651668000768e+178"},
    {0x1.35c34702001c9p+594, chars_format::scientific, 178,
        "7."
        "8452488438025278621303101815654925040904759740554180738663377954039378219664965548160988021330044581544086"
        "790884596615125296396497742047656667223884572601517271224748933535236096e+178"},
    {0x1.29c65d36b40dep+595, chars_format::scientific, 179,
        "1."
        "5083269248992404848075529200220437643877343516690908500051239020473880544003670069908347719938640019293547"
        "9514139200504582847173176153264857561337534047601980885310892466243633152e+179"},
    {0x1.f096b560fea30p+596, chars_format::scientific, 178,
        "5."
        "0307679766475297900643310003785978353718376020933985994442740062831046797865169439521465673311238868838693"
        "647148360650272015676569826847440171961764782606079881578285720137629696e+179"},
    {0x1.2ebc1ebd45cb7p+597, chars_format::scientific, 179,
        "6."
        "1338034600015482533548856700137120559493090645959837325747342847008896961430122182715729832578195313705013"
        "4105978358652455249997921465483648671250142659113169108289945909053095936e+179"},
    {0x1.bb1e534cd7220p+598, chars_format::scientific, 180,
        "1."
        "7956317799329456455556916318367385720663341620756711043034998103313297163597767928062472500586846121139556"
        "14358367020579719652520207053724496150314508797330293943336699424736804864e+180"},
    {0x1.5a25ad40029b8p+599, chars_format::scientific, 178,
        "2."
        "8053575998151829095892405225520007274617104914173229276735386248671927242112453507121141969275457163272893"
        "568975905848289848712880545718807596992132248150509100180221916786720768e+180"},
    {0x1.920574253404cp+600, chars_format::scientific, 180,
        "6."
        "5163814759421788677873530796634949212285583652947416245608362680831586176277421534822610398383052946554843"
        "94073977159925482307630138907365278448422568005135582757883527066002915328e+180"},
    {0x1.4b2834aafe474p+601, chars_format::scientific, 181,
        "1."
        "0735479295792078221461462578241925997159828607487053072465046193583974474108661842779443009354436634868004"
        "476810418060601519121547906362418385449487160625577520457386019933969711104e+181"},
    {0x1.1a6d55bf92261p+602, chars_format::scientific, 181,
        "1."
        "8311493838142103542752617036118103707188503450539135538038071480595467067235490012901451567915485547679396"
        "737058601282328571489161236550988761960486022562870032145767653310556274688e+181"},
    {0x1.939b15b62b48fp+603, chars_format::scientific, 181,
        "5."
        "2336517217744578289301435473972599375000619053808222966759646632373279789584915010138199152881101065506532"
        "687557038424526575845468735889436101248308704643094047464453357888117669888e+181"},
    {0x1.3323559810654p+604, chars_format::scientific, 180,
        "7."
        "9654625984234070560843023786733559173357314848891567332176073939266324781282852488889033232328603190512864"
        "44191994975384433871139554376806544439859313015268722153010942162317082624e+181"},
    {0x1.333eb164f7174p+605, chars_format::scientific, 181,
        "1."
        "5936468405690222963015531213681703950991673640841216359315071491413902278799067753246551939525046278107613"
        "643503941029543247825376095531505645583899358762232671530237175811966763008e+182"},
    {0x1.d0f59fe9d68e5p+606, chars_format::scientific, 182,
        "4."
        "8233914130112407863285003710689803483456665401306521852174982975280526545361901381877410799671323400152340"
        "9728884313284382907823478860910903091121695170799862320491542129699840851968e+182"},
    {0x1.84e2b5e2c9a1ep+607, chars_format::scientific, 182,
        "8."
        "0684340066596766544572556506252731538802478458154108454504290436861404376208516321210832553563313969262818"
        "9202172627621495205007691501867201659515859130020754039123809607454929453056e+182"},
    {0x1.18d12c4dbc048p+608, chars_format::scientific, 182,
        "1."
        "1652548548873181294322533416118492440051287407763628764843419162381374460114342887075602927194584640147378"
        "9496291184726619357044089201921845860679578715643022102228246746338923905024e+183"},
    {0x1.7af5d345c6d23p+609, chars_format::scientific, 183,
        "3."
        "1450029563312949921705252567556012692518149027203291202593080093166670468850095010731506130052674674120157"
        "74348292634459749772960881227292173172198041386149418679539742007941742460928e+183"},
    {0x1.975ab947edb1dp+610, chars_format::scientific, 182,
        "6."
        "7612935278386641398204727194074041846069648507123655157571111694919617576544597129796919213184659654005698"
        "0488537620239095371500607042229531833011357071487127295321565416010266181632e+183"},
    {0x1.c1d0737b292d5p+611, chars_format::scientific, 184,
        "1."
        "4932090269565783294588036135586081051149351045134466442617688566006012001837540168458670172917118701768786"
        "867474604627194399095522425450416452953980195186577171892642417347609543835648e+184"},
    {0x1.aa02efe9f3794p+612, chars_format::scientific, 184,
        "2."
        "8283859855362886467396009253302481873061245217643500392666314561635040318327151542442172699585268930632622"
        "241589973221227709826283976490647011264056279643437090782685578260187550056448e+184"},
    {0x1.3d7dc9ffbee8cp+613, chars_format::scientific, 184,
        "4."
        "2157931387871262015926870950749405384817650455950174689016344420098137969750444915728016112509860277150060"
        "601492917876180907845520932017756677408045726864238056988978424999333691654144e+184"},
    {0x1.c6879a9f1b649p+614, chars_format::scientific, 185,
        "1."
        "2070899708662365098038931357762390307929244909436176101222504931129437932282921093676660906910327987840252"
        "7125214963888503868333527614117931372209142616050590653014235608250452260421632e+185"},
    {0x1.ab65674d500bdp+615, chars_format::scientific, 185,
        "2."
        "2700631068240273397489316576657874824412711298635064825657580646809427730859321650511948212330668025354305"
        "6092075426388221410551611143867357719504542651007243174106278126401989803769856e+185"},
    {0x1.7c53e1b833ab0p+616, chars_format::scientific, 185,
        "4."
        "0401294303115836967321430079576857543043077310822923673457308264270695997048570907605829914857916971516317"
        "3120245949614126178698831517102780044385664344470114797725850999704214300524544e+185"},
    {0x1.2e77c927411a0p+617, chars_format::scientific, 185,
        "6."
        "4260880103511173776965782050887475772203573881104807170026375206902625094758600314000230697855968658781415"
        "2496590594469715368836313131660803069753435961872139875035538111189185036550144e+185"},
    {0x1.91af529276bf6p+618, chars_format::scientific, 186,
        "1."
        "7068006955155920436381787742211206889900022505144975960971613468630206721351184202513546521873931642016016"
        "70059306842801510185352447629065196450702180793164841642105280807255981179273216e+186"},
    {0x1.e2ffeafa53641p+619, chars_format::scientific, 185,
        "4."
        "1046316824941888643699353613767678576433840888755738142654597510056334162946180327973010169901435079539597"
        "8893668127655560216486714958133476458975838842621122712984278755617826565783552e+186"},
    {0x1.5650db2b156bfp+620, chars_format::scientific, 186,
        "5."
        "8181424134557963372623500529012147039265491223350309547526266523128141272229618057337628218595609572301124"
        "71018315948488391977542573706585784859374641921502790939786006178741349999706112e+186"},
    {0x1.bf7ae95e29007p+621, chars_format::scientific, 187,
        "1."
        "5211116452704720220916932480545333836293750506976740282478412134006158837478732993126688286547314481305113"
        "926160400673257953300679831181284416307088159652747412468645675852976258440757248e+187"},
    {0x1.7f3b57b7768f3p+622, chars_format::scientific, 187,
        "2."
        "6054268526041418370124758261736181886009351044292952840979842879191012038670747908928720486777477687495442"
        "139696169653926332331688473761049756433252163195764050763466390084322743208116224e+187"},
    {0x1.2df5ab759d94ap+623, chars_format::scientific, 187,
        "4."
        "1057853719527927979235446097813905937787889019654170253288837621067841097808464938435949456711502629198845"
        "047066360505800379087691836395031068487812569438457407732512474227630214523912192e+187"},
    {0x1.f86e4bfeb9a95p+624, chars_format::scientific, 188,
        "1."
        "3717626247132139356031030212904093976490026571768063884666249174145828633729237056208500152497070476103697"
        "9181678894768420162515624483582843225609804010781295565639720290288781607684800512e+188"},
    {0x1.f40819bbe6e34p+625, chars_format::scientific, 188,
        "2."
        "7195986230515427628289312046628293937926660068197292410651314639082215733474435689052778088764971396921622"
        "0975232992872917430431261712729880546657888244648604349740292101232975795214876672e+188"},
    {0x1.bb810fa7ba591p+626, chars_format::scientific, 187,
        "4."
        "8243077416927025812147489698712574130435213134316928233651561721184336878749918494519101017806378515809278"
        "608335558400157584055536387755052350186843738994172820141734602267502813567254528e+188"},
    {0x1.b49cba268e605p+627, chars_format::scientific, 188,
        "9."
        "4986787120868551354856124828173860354847443999782529857627384188101971308874000269574276015142574067770537"
        "1858937491969553131423202713212361520698537802948066370938491409647594429525000192e+188"},
    {0x1.6794724f38a2dp+628, chars_format::scientific, 189,
        "1."
        "5645616537346161531395584770690175816359049861537004504171534275505852346677701254291437480648523612687972"
        "06642428914737885631574981113215615320879524124007390426980020724645404028254027776e+189"},
    {0x1.d885c64ec1963p+629, chars_format::scientific, 189,
        "4."
        "1119691994497879656531133766660971874902845844085983857408328096666520143100236614121035494123196391236682"
        "77588476017765557295002078594048079978501293546557091940850855608591393411787915264e+189"},
    {0x1.d4b6a8ce4e210p+630, chars_format::scientific, 188,
        "8."
        "1576445426427843228244475508275094424655570327245201459047094099930186877082150505147571440436295280323845"
        "3225443621893877167039809549667445315862497012784573780315757858692039887497986048e+189"},
    {0x1.0dfc30c10a8f6p+631, chars_format::scientific, 189,
        "9."
        "3978200740875525823346709967358851145517458783872627113059769085886366674405289187962996521127962302157367"
        "62416233629290695818905123073123846308612952343782071766983440677059709153069498368e+189"},
    {0x1.b0ee3365acf4bp+632, chars_format::scientific, 190,
        "3."
        "0139458754847524660871282757055906655014101750771082954413410089116657906300272279625269622507839996028131"
        "322069003748345377672125070777019272622112701902180304760314555069924255238207832064e+190"},
    {0x1.e8516d69c2517p+633, chars_format::scientific, 189,
        "6."
        "7990790502150547755817441151088834982046097343185039910037887278994580105885199523166160292480282346294010"
        "87279124575596835993625675652177630757887466880278880084355993616847248021962883072e+190"},
    {0x1.678bfe66c299ap+634, chars_format::scientific, 191,
        "1."
        "0012275116878428832695316266386275059577472848203452848888799575054312857576278375094172990255241396253407"
        "8869424254770151616712433286627933649089597511713238066169913296314718460937108455424e+191"},
    {0x1.04700a1049e6bp+635, chars_format::scientific, 191,
        "1."
        "4504776964779739227622461272137780904566626980139278483809734254823562877295798245295460035152617301251406"
        "7058098025582676058384729733566966350382985119197142132911172845321643870781582606336e+191"},
    {0x1.42ccf6b7f926ap+636, chars_format::scientific, 191,
        "3."
        "5956024160941395496724152481406517830405700080895194171603810345955158609958585945435113191220307312485239"
        "7179554337917085081215107409583937953090530652396114892869575308843675129211185528832e+191"},
    {0x1.62da3942f3ba2p+637, chars_format::scientific, 191,
        "7."
        "9052400799365436508456422997397376779163961087508758356552926026529470568515992308471246008516852855949960"
        "4255099654858809141476957078618577590864095604243342920714026320377441054472831762432e+191"},
    {0x1.6617ede33b7d7p+638, chars_format::scientific, 192,
        "1."
        "5954884853337538467930960161959379373574226963181525647757921151382491570533826044106708021096634523722806"
        "22563873071483865155214731195109515482575780647056162170021909878210640606642688753664e+192"},
    {0x1.5c71e4b115269p+639, chars_format::scientific, 192,
        "3."
        "1049983313309457947153108285698834046740671768845565652182843514446382696929913134966819032936095111895758"
        "08859645677809012205688992155876799240651615710401257329009039104082564451422481416192e+192"},
    {0x1.f38de0551cfd8p+640, chars_format::scientific, 192,
        "8."
        "9030718451768592943551952273335458583767299556603325749125904384894163964056658026424350130332560793911830"
        "97998040901449719178200967412709547407175233106220746691802662083191769493569324187648e+192"},
    {0x1.7d3104213fa96p+641, chars_format::scientific, 191,
        "1."
        "3587214394332287831636967409123474173198677781114610688477509240066767270036304396583002007338361488342434"
        "7018261468570862106382590370866270622706678119119636711532234507923360885265009737728e+193"},
    {0x1.05c12199a4ce0p+642, chars_format::scientific, 192,
        "1."
        "8659984263282701095961910661127105662619442340071089999966335247066716008995363420012904517869156065414943"
        "28827181417719388414731396372446871312890174002675142689682184688568477822869533884416e+193"},
    {0x1.e7c493c1e5eb2p+643, chars_format::scientific, 193,
        "6."
        "9544124557966781465283601740528161468657156016270358219352828875152455546920314538120334360214601895748468"
        "949215676482982196512810670940274921427074192952089823830554753893672379339452513779712e+193"},
    {0x1.7be4b24c3e84ap+644, chars_format::scientific, 193,
        "1."
        "0832755189816973686838400117394925117567150074253168671073010357437082908429802511685738145825384022747200"
        "287129426299695238571771855677246949457702575625558892201737640633820907147368494792704e+194"},
    {0x1.2de39fee556c2p+645, chars_format::scientific, 193,
        "1."
        "7216892018906268022068471537387743260557559590398031258749108351094204150589638814169822851978176186111763"
        "517875372144231247461814054561524289109891363206828212023676515423816653474344871133184e+194"},
    {0x1.064ef464f3256p+646, chars_format::scientific, 193,
        "2."
        "9919164363027123692749619660627210889271275295150022237744720119394566288350377104728121689125089876410120"
        "207077019582026591233089745125850338025814467578902594716196084232119044216662467280896e+194"},
    {0x1.53c83ee0f3068p+647, chars_format::scientific, 194,
        "7."
        "7511807677676666668993801298197495853096204934459746619627314359135066593918034347577125781457452161330722"
        "2499090718182469027512595486412104282224089391808118934952932553489010283810329970343936e+194"},
    {0x1.3d245fcdf38e0p+648, chars_format::scientific, 195,
        "1."
        "4469419386503595028127075501484846217979200970571120241086108986167836029091721153208882052204284176158696"
        "92393014844961294938705227221973480785926757243856237171772712052212742533379530998939648e+195"},
    {0x1.e08347f6d354fp+649, chars_format::scientific, 195,
        "4."
        "3846223856409726487843137745345240016233497677184702838745534071583111769816970967562226232827874998014451"
        "84284881420975108036710110563126305622808224088979432579122289231488107948520961449394176e+195"},
    {0x1.26dd41c959944p+650, chars_format::scientific, 195,
        "5."
        "3812031636068901652580768033108735321385002279585405149633570661783421571708940731919720466896227207390799"
        "61349180699018841380453909336296408176168776915809695465869463868037226981151032054120448e+195"},
    {0x1.32a46cf0469cdp+651, chars_format::scientific, 196,
        "1."
        "1192297812198031453672538904878583920546310057787196919680564602804006021635275052904716578393230705549792"
        "391736916811871536801023058717321491817885637178624494387092346840642879252645460150583296e+196"},
    {0x1.f735cacad6b34p+652, chars_format::scientific, 196,
        "3."
        "6733861060912076889136215696794553894081750048069183817920228793292867367172061721225671283257865149059762"
        "373032895575586250199621890834068293240362884267618309008853943697973367517798399718981632e+196"},
    {0x1.6f9e96b3a07d3p+653, chars_format::scientific, 196,
        "5."
        "3671746541827261011203354087624108922878597080912646222922380862668287491802597137523711347734694456137577"
        "512510066286097290894101024991650054347426329814100070532676175900514872055547324115451904e+196"},
    {0x1.9a7be8fdf7d97p+654, chars_format::scientific, 197,
        "1."
        "1985977495349634490908878417576139133664292427414882677483198175172572179357980016926770715944365796704257"
        "4692923571443314746208884004956936450441535729663397603260741070812981369093068197195677696e+197"},
    {0x1.da6e03fe5ee66p+655, chars_format::scientific, 197,
        "2."
        "7706336697369672079558112275729991989663502537476696645641921462599178276995772930464951641470258493038336"
        "9099948172126078628543391675565516869571467232515617030599512982766562717569725701405278208e+197"},
    {0x1.46bfd17446d76p+656, chars_format::scientific, 197,
        "3."
        "8163820324215302078655052581105169362206077889882490668181955965331335612783576990462419110014762802040842"
        "8932624183905960507058168406385765800174407011359638209862028651785169944480326048859291648e+197"},
    {0x1.4da5bdbbe28e6p+657, chars_format::scientific, 197,
        "7."
        "7939024383475144406401810111134781235714299871416468725265537823786477278170640693706900927390244735770402"
        "3377635205357481997520059613138340462342666890730126616251260546972142434062110654323490816e+197"},
    {0x1.794508278de11p+658, chars_format::scientific, 197,
        "1."
        "7625808904819878814252834571355017129723543975578058942872687731253785660005190276333451440607991123766321"
        "9689293395397374284887817353554283069192904339275976476169251134939185478796513753207668736e+198"},
    {0x1.eb532e6f9d7d9p+659, chars_format::scientific, 198,
        "4."
        "5908803682224108657912189982052113878795247700619664483730988082961059233697555687474423301586558704416284"
        "05972833885899442431367846953537758531668062429844500799658848386004026176785845424421339136e+198"},
    {0x1.de74ebce4a37fp+660, chars_format::scientific, 198,
        "8."
        "9412828663695769157133701994384037245199508662333984038697424700510180989698512292550728723512369532416908"
        "59581044027690123952861405038640439793801150984027335811429652593548499275325847981191593984e+198"},
    {0x1.f37efe81f6078p+661, chars_format::scientific, 199,
        "1."
        "8668922163822093102670212590302724412138160772937315443551988535235327269727004283188067685097993915779967"
        "857553550469160341100795009241978760744022819053953305820738316178892052108850291867761246208e+199"},
    {0x1.b9ac64ed3cc40p+662, chars_format::scientific, 199,
        "3."
        "3015541406240127652827901285317994654252259108292724627854632423431112225291832993714601701837092532228984"
        "666842289569788469418213910100041040541661269705317791388661975141778219886098547588248633344e+199"},
    {0x1.be00282b03f5ep+663, chars_format::scientific, 199,
        "6."
        "6678007786700799562127526307310207752308193470392815502671838863546949841784370697415483868452623924662465"
        "852932499279515268041523524885590999171088727718673563969761030301929187013508451729059872768e+199"},
    {0x1.1f0bfd13ebd68p+664, chars_format::scientific, 199,
        "8."
        "5828181572124633107524119616284657291987779794200781158316572344105215247476409691264332650248636862250587"
        "399330494835558065432909058158755560573757532140879843155127845886935663226690006104546476032e+199"},
    {0x1.214942705de21p+665, chars_format::scientific, 199,
        "1."
        "7299550663482325854298152774838811504666813994210021794440510040084666159982357767709979637162725720121837"
        "143146658029599367447831227389091111211511620184940759881374673800216802576052457772066799616e+200"},
    {0x1.09671a2b2cb1dp+666, chars_format::scientific, 200,
        "3."
        "1742604212395941520160807475694587693442023879310826245397503160636389502214271931668375341320279482228936"
        "5003537922894512928901216347580242808688118038808320342245310580635968754349465019243816812544e+200"},
    {0x1.ba3141cf23cb4p+667, chars_format::scientific, 200,
        "1."
        "0577387790503057845523967882965492655922506699517901184690541395251648923255536765968073123452432831189428"
        "3139610900523923729546826141802983594855809190686087313938155503860877149671068608237095878656e+201"},
    {0x1.86d43f758f915p+668, chars_format::scientific, 200,
        "1."
        "8697520727929860202205333481871092634806068636093040001347476582997186350991014749554566585582449517827852"
        "1742514396415318804969082463925672708648283454644927469172901217309139068598188157479893860352e+201"},
    {0x1.34d8186824c10p+669, chars_format::scientific, 201,
        "2."
        "9550611658398537729812084104233279581886197422995997439739248023584633751063077706969826068002328821902558"
        "35984668412855709756751449286828670454146045729913364117793350552523245031469165393183309299712e+201"},
    {0x1.e78ec2e502b07p+670, chars_format::scientific, 201,
        "9."
        "3300316023279546564429734710131486172165480903897679792851861579776405133194991445173294823171591618519733"
        "82886503720740495065769351149280072967849485120060333190450091919271255293415847165484888752128e+201"},
    {0x1.f9eb8df3b3791p+671, chars_format::scientific, 200,
        "1."
        "9362841443169071617725977338146969813068537694630772833789523535940605386959607587391035584155361991571477"
        "2188643495718476877510953230360136475999837927583418408929771467314748864760171734164102447104e+202"},
    {0x1.f3bf2b7fd9993p+672, chars_format::scientific, 202,
        "3."
        "8253141404124239087553445135078230149218171629835915005900468691055157253177028433475181721888031353474143"
        "805960645601659788841709440240831940652256561820866616777441445506068582195950276620332646268928e+202"},
    {0x1.7028723b0868bp+673, chars_format::scientific, 202,
        "5."
        "6361345240426447996243602793477311715051878330229375094900655201745476339178578234692042783203586674400814"
        "536523693629016758628762237700239395376218700185658748567853569033785027091761965807224097865728e+202"},
    {0x1.557c7c726b2c5p+674, chars_format::scientific, 203,
        "1."
        "0455633800468254373659208108812590394043317042707529535320591653457158166384116723919640391533814902130197"
        "3914820975343519675720107557611312716650944578510886085691231275003492219818521525260187846311936e+203"},
    {0x1.871a220cf573fp+675, chars_format::scientific, 203,
        "2."
        "3949543282776258275094826997800475448163929702581969665721781303410329417447832451577436710001122472324600"
        "4426134549707543279835675223903160643688382643597490008860447048746541065340198566551705264062464e+203"},
    {0x1.7ab1f57987853p+676, chars_format::scientific, 203,
        "4."
        "6379583986380873399377611822272310491249212463996866783107484973790663759579721670387297986704230593188127"
        "7246512300341294333647657347794641948475142092198438521343984711625050786905805143040315550072832e+203"},
    {0x1.5d3ddba3b5f62p+677, chars_format::scientific, 203,
        "8."
        "5544700286806899054573744398898783238737967644664671325775421780413312594622618697018203609322621774586335"
        "7936953692366755947421731246318689169626782187431645178224405902434053217838696105015610359939072e+203"},
    {0x1.ca1c22f39b22bp+678, chars_format::scientific, 204,
        "2."
        "2442269843101122827421442194256344003422365531162259447063619663210238536932202342459756070387395904494366"
        "08778953178834695527378455121099232622455529116651588866259062455701860787333589107721957541937152e+204"},
    {0x1.5571570a3d877p+679, chars_format::scientific, 204,
        "3."
        "3453762259499943095906115508134893420044494808114889576882963983309648533878483611515604738427366970549017"
        "54178011537224573858899467011609733043254823463231975478542474685169259633176067748962831236595712e+204"},
    {0x1.4094b51955758p+680, chars_format::scientific, 204,
        "6."
        "2819534546304202022756189930697394173859142240118070438830404805760551238633453033097751606807688513643796"
        "33566498059922977393145681190563895952411661162198926892429054001662376306285334661068344151506944e+204"},
    {0x1.9048c53155909p+681, chars_format::scientific, 205,
        "1."
        "5687567004414429430445580613907672440297999372236541850109777310656966630289380682512901660984243147818164"
        "720305606372514460855651668937589154968441803492390245562381549787491329484096179468977774843133952e+205"},
    {0x1.648fda1b8573dp+682, chars_format::scientific, 203,
        "2."
        "7948083967253507158270892062204304924669010291504288163313261458526456348819707571820654705254002837820095"
        "4036929834214012069157615233165507943405007539518079954737799050720625737596053702318674937905152e+205"},
    {0x1.43618fcb01bb4p+683, chars_format::scientific, 205,
        "5."
        "0694600816666434831915046957006568969768474107310483569746183545377953584217498572022390666824444206906802"
        "716110058524003006214659535848234793606862153660055012848214798236108687160590757085244967798964224e+205"},
    {0x1.e3c671ad8c424p+684, chars_format::scientific, 206,
        "1."
        "5167731946556582358338545363873641520855604073445893638689603884306082276318367477947295080031043819110440"
        "8642304100789891065969740635351032828526812314484068150876373570965277810326480540295924136407990272e+"
        "206"},
    {0x1.0083712d8f528p+685, chars_format::scientific, 206,
        "1."
        "6084856808214641304016171526904209487654525042104056698492786865015541204817201677687479571049677306897371"
        "9496544120901191625200109058676087802871541264829133196190867040924564024017823724146856414240833536e+"
        "206"},
    {0x1.1b815b8ce81ebp+686, chars_format::scientific, 206,
        "3."
        "5554800597042668911521270198442508184743882300104078763439099936805058397629458498314099957433687022418916"
        "3184788239468910565398744819870703830959835692636607007655630104135189425612387037272246775462232064e+"
        "206"},
    {0x1.3cb5cc09f23b0p+687, chars_format::scientific, 206,
        "7."
        "9438133343858630565423242979694274909564237766705840868790151212521658489271471983804739253095661366761029"
        "4102333273655557547426416548788317016668008395432111323108190919984834221381915705192746329317572608e+"
        "206"},
    {0x1.0eb891e353010p+688, chars_format::scientific, 205,
        "1."
        "3580600028505664375690662207424245293630538367773374329113241542710551072241261271590612227940725191575525"
        "142268316641921315280475966244961988464253867196651973305962369993832829015492388706895940085088256e+207"},
    {0x1.fe4392ee89698p+689, chars_format::scientific, 207,
        "5."
        "1194339355719443065155494183071752754181073170581919459310323849856827865354540376178837362522389907879317"
        "21861923842646425087948083052097162063136700891783482967154133027296156365640453753060081736636956672e+"
        "207"},
    {0x1.2dcb28f24e477p+690, chars_format::scientific, 207,
        "6."
        "0557377481791783775123253767073183006050784328448801194330172256192676385019587449505858703818171834796158"
        "88079777486184355096973374331860638106502031077122796354840154902424520732833513406609567524824547328e+"
        "207"},
    {0x1.7ef16a0343a29p+691, chars_format::scientific, 207,
        "1."
        "5368136201009418151075746612212978086078021684377175933956334114584860950199106026892088552308405826859681"
        "19867342497053313630101310880690361388894132852824665771671576281871878218340553013779839607256383488e+"
        "208"},
    {0x1.2a242729206abp+692, chars_format::scientific, 208,
        "2."
        "3929799628231874533559162595675700688225267190446002583051852996326657712936124491324505265077653846814113"
        "912468376263785578115495854111182179778355706863388202457043252998698055736229924100641739854177107968e+"
        "208"},
    {0x1.6fdb131897c76p+693, chars_format::scientific, 207,
        "5."
        "9050637526432229460046672429152018512276157466161011681361188012855653217247623948526824848762046607051117"
        "42291766960934780667277783068480199263888364083681949480234545468896885660308486627900438301487661056e+"
        "208"},
    {0x1.828b9edabf8bcp+694, chars_format::scientific, 209,
        "1."
        "2410164169914756986987721184858525130751854228863394397493695090758186348224795318834728620444604824617592"
        "6376358164303658206374976185443979610307101254760486194833808768397406617592883545020705987606790275072e+"
        "209"},
    {0x1.561155e6ffb7ap+695, chars_format::scientific, 209,
        "2."
        "1964388171812186376913149993916068915104358033266046539265645670705967141474979810589471961997724112800703"
        "8529115316543316991123904985184012949857407673490871091790599594254663632479001321411805904083076775936e+"
        "209"},
    {0x1.b770da1a7923bp+696, chars_format::scientific, 209,
        "5."
        "6433556541432481398269867824506950137257397824592518950158176095072875138674793491115526889401777780967879"
        "6605880934558431966021135949322020945206483833796818557605415476191440013445527768217391316223846776832e+"
        "209"},
    {0x1.f39e870744604p+697, chars_format::scientific, 210,
        "1."
        "2832349330194718344755964910746649476665600600204568207096392756190966107514967070128127995587125525057357"
        "87164435029468024484426208026189599769787674284875448040738059630647364948722154118121000407966494490624e+"
        "210"},
    {0x1.e0e0a24f508c7p+698, chars_format::scientific, 210,
        "2."
        "4701961710739764361583234915146397646495281382968205066282530980797542323891939027864029319111708327424737"
        "68191802838701448254783534537720497984389637555995723528330666991979915889480651222080857795966332305408e+"
        "210"},
    {0x1.8ac9f3659f1e2p+699, chars_format::scientific, 209,
        "4."
        "0559435735022988739506375950055455133208181539729336854703561923650777379009124468556720173111749862578532"
        "2257531748255933833911596322305908820799861570096445826119055025147325835330550150749374733298534711296e+"
        "210"},
    {0x1.c6c3610ba0783p+700, chars_format::scientific, 209,
        "9."
        "3442040337209647890991669685854348061912336916202770110402696196597648891199334466408278208881547182645564"
        "8106587676761185019235392954314227170622662103422697806457896662312360195041629483904435021403511586816e+"
        "210"},
    {0x1.7ab499967a977p+701, chars_format::scientific, 211,
        "1."
        "5562829932078268382920536644832525295632207422782065245582452948588014426345451647662593332343942693359043"
        "673038241481043843956079532596179836219776720544331309338107673956968832112826761500035796845304502812672e"
        "+211"},
    {0x1.f024a7d24b0d3p+702, chars_format::scientific, 210,
        "4."
        "0777821620060193266334318275592853491355664469989449372681167607339409531079735731049874447275001327926030"
        "16716647774810946339317774614675085229067529724067990247981819516824938089923609051324757764430419197952e+"
        "211"},
    {0x1.d17a4e72d8ab9p+703, chars_format::scientific, 210,
        "7."
        "6514883571278532762421327618640364228144540224715301472189205747128557339867683312189234312699991722304801"
        "87508384059736711183902958629060763487777480969265193074898840268978802200642734863912959964269495975936e+"
        "211"},
    {0x1.bdb5292735f65p+704, chars_format::scientific, 210,
        "1."
        "4653017873373998692763635837240196213052567229127080389032808605177662267440004448203826088699878670265716"
        "11989504059022347366241536256218557754548387791868248488507236771978085661342065341924858769713800413184e+"
        "212"},
    {0x1.d857daf79aa6dp+705, chars_format::scientific, 212,
        "3."
        "1057366810904797804142405560221570986848449184775478721300104610661909324364621635260801637633691297730614"
        "2606261334956001762657343815208008386132632164433439367427753003032269836143809760867436748508642739748864"
        "e+212"},
    {0x1.09c435c527cc1p+706, chars_format::scientific, 211,
        "3."
        "4949190530723091756757484452691047713061764919333405631459771571062584286466108807102940821362269244897933"
        "428086956552905322744082047362472421201551180358972335992195302859220811917676779815344923699394346221568e"
        "+212"},
    {0x1.9eeba5c11bf2dp+707, chars_format::scientific, 213,
        "1."
        "0912691038049117803356178427580267592987920737973863462643914057428289444459726293430782464645172800567106"
        "4614068269963034242382343536692249482905554535118294035276777785242668121575530849252887857652227101635379"
        "2e+213"},
    {0x1.711ce33669c35p+708, chars_format::scientific, 213,
        "1."
        "9415837118656972047462560151565189440197415599082992072290088348446257818753305865264569453441155760209275"
        "6420682215115366352429937129978148876672274612581009221511800214540957300015697763603036114999165026356428"
        "8e+213"},
    {0x1.e1545d8e4756cp+709, chars_format::scientific, 213,
        "5."
        "0637177196663439781619561019870795438871709899611245250407090659243999851279716213705961203818418561930515"
        "7538837474992269641194547319074000476778106214165601301321107197389998286966901034850873709850498110901452"
        "8e+213"},
    {0x1.87047e172162ep+710, chars_format::scientific, 213,
        "8."
        "2272217902289806712574994697052872917307680452424732799593585823465113857834013351649821539394746533212326"
        "2635474976739710004492416534995515409682723302715699955709445835135054280029223866567934693473678102469017"
        "6e+213"},
    {0x1.23af3f8b0f756p+711, chars_format::scientific, 214,
        "1."
        "2274403548516689934568399779688998694687353455201679256515032382815821350964662324319252582154195626101911"
        "1914744444851247443732162368380389190137963362909858689711281895410242314171242275664220904763668035618734"
        "08e+214"},
    {0x1.15ac6c4e78557p+712, chars_format::scientific, 214,
        "2."
        "3369607865235239602595370981188181022701331236283783740952780871356122483291807368512694950185999530278521"
        "8100126394977849717535313389040668586244128270959371681379343662763181550943073897157616708891762610006917"
        "12e+214"},
    {0x1.0c56bc2aeaa8dp+713, chars_format::scientific, 214,
        "4."
        "5167955247237233591793390194916065252734234001920207621805423206174532999832050143387049477371885758341774"
        "0490893500888204453060916632880059929997600758692057070711667533170230016542638615516838907173350677550202"
        "88e+214"},
    {0x1.1d43438f94121p+714, chars_format::scientific, 214,
        "9."
        "6033333170660723713494533665995506845145565126757011999790859821923401078678587263615504964380651064813268"
        "8455104405640138686956488690833735843738678692699173055317848403275010733688269013616014923336044532790722"
        "56e+214"},
    {0x1.22061a1f36b39p+715, chars_format::scientific, 213,
        "1."
        "9527229344211296204832748491391970313659298630157789538676930343069033760208197589599879702873928992499523"
        "6608990695697929287475783764523709178533697748688667795727026551385542208539829149904757164785331242375577"
        "6e+215"},
    {0x1.b4c6aa9857545p+716, chars_format::scientific, 215,
        "5."
        "8816034098212943144905329698612653757733245362298585094671457030843981001076903239943736481752491562668854"
        "3227615161426933453966662664614700683592817343221033633872435463082384646592207974116998811001000733528031"
        "232e+215"},
    {0x1.fc44623e54a39p+717, chars_format::scientific, 216,
        "1."
        "3688597232290091037311686146350196929925090931949605314752704983267092895217454050659460182543204061174764"
        "9483581360902654275978940750604387256349655240483869060528558314415186446869377979192991730046835020867724"
        "9024e+216"},
    {0x1.aa3773f76d3c6p+718, chars_format::scientific, 216,
        "2."
        "2957642846592151435765755376177922244530341123122404553904849253141951496886105258870876064851615036434469"
        "4876401229921882367852535894131740355268022752724962483511347088356991204389511796637049601111311107797234"
        "4832e+216"},
    {0x1.678f5a3aaf4abp+719, chars_format::scientific, 215,
        "3."
        "8734526664526530409778005021032912808303761236039323145190007542532559613671226628041536207090554119549294"
        "8061656426937652467936129275838297803985174029589992670722287010428685443582031439938587866795108684422709"
        "248e+216"},
    {0x1.75d7f7f1fed35p+720, chars_format::scientific, 216,
        "8."
        "0546540930957455718578031318299747350402171557957209729965273827492992431872786346244627211565631606648257"
        "0059867837651906784602547892574447433749380278807687112313000367428241145025552940533962926786779921134492"
        "0576e+216"},
    {0x1.ecd6547f3a750p+721, chars_format::scientific, 217,
        "2."
        "1236865355155595622735285863955058003135144833957450752980851351717987352331092233045600746747001260561937"
        "2911589467181738965692960395316048567332841520376860127492605292078243192501350963954953525169159449927630"
        "19264e+217"},
    {0x1.0a596dfac622cp+722, chars_format::scientific, 217,
        "2."
        "2954536079504795363105284856238370047575863823791914884578812032736986505844047299679977544958888864887442"
        "9510566699520717810527904738260292999530216887681158564123053793542338149495936402987037020460274422393832"
        "73472e+217"},
    {0x1.2787de7be85a1p+723, chars_format::scientific, 217,
        "5."
        "0938899596925395761826195681293982864054105837836524441779452341587353365337241463927684760423605672503136"
        "4648194990232587849895833426496657214318262747057343259849722485166677259967720461632129749176545382576989"
        "14304e+217"},
    {0x1.017035217c70ap+724, chars_format::scientific, 217,
        "8."
        "8746262567900002440763362220696400774677132584164637737173476368159373848157173276824865316031383654057511"
        "6917032676271566593822293172772155148908084084969174804166746324003981364028953399391198999657379974601464"
        "87296e+217"},
    {0x1.520d5af29b2e0p+725, chars_format::scientific, 218,
        "2."
        "3307227637493685583257214726151633279014217575879330885292007999084782247996596715050756662255030139058859"
        "6805856504093577362456677740310187436887298551656600563966070226993167637974428618236660886457382117786735"
        "607808e+218"},
    {0x1.07577e25bec05p+726, chars_format::scientific, 216,
        "3."
        "6312540549690454783945385341080739270186260535143481461780731546205459439009501621586362243663050889964457"
        "8717521317394394155770001048893530262964476221970496769199098222896949679062427442307345916471566141482441"
        "1136e+218"},
    {0x1.8e96d600a22cfp+727, chars_format::scientific, 219,
        "1."
        "0992397195630485393048029745193332487200099886126458682210102475632557765838176879102348740864174816753457"
        "4339747390248704045938396673455756529493017948310435328593259601916775929373246975163112018310484034276469"
        "1390464e+219"},
    {0x1.d58382d6bdbc0p+728, chars_format::scientific, 219,
        "2."
        "5896743857569934926023999906114602656980022031372964101642331196453139149010796064718269338584040985180989"
        "5930383540586547536756864433922834466516142024080331685331856698277183140964794565531695307462460862905731"
        "0949376e+219"},
    {0x1.dadcdbd4e3d3dp+729, chars_format::scientific, 219,
        "5."
        "2383553757590476797184448014939985757228795670010900864934417139896450486005364935750934931766668175207059"
        "8627645866228627698205946727047137855285251500317423726214002802575650572352763973306837696764851555496791"
        "0612992e+219"},
    {0x1.9368fd03b4a42p+730, chars_format::scientific, 219,
        "8."
        "9002795600414906199791927232216323476110578835375549513066389953710242169294374458723035137744671493186722"
        "2344623964801905532168998413337259450227971247100831382850577108376403193310208004637163414879706007669134"
        "9569536e+219"},
    {0x1.f845eb76e5443p+731, chars_format::scientific, 220,
        "2."
        "2251161587610877663633489139428920395198020363761713051397678295470620772059695788415149018775345563562555"
        "7627774951186652618328217813712607566387789838837146661464469054252780012796887062198095184322259987517487"
        "84652288e+220"},
    {0x1.2f3e996a88e6fp+732, chars_format::scientific, 219,
        "2."
        "6761461913428335040343012953219131824126168324500202272744678701909318477813814911852898730651873743175101"
        "4250819778000778777707356970388797186374553268449512982574137361618840218361257083422429020750694479963974"
        "5855488e+220"},
    {0x1.4a45683f62e2cp+733, chars_format::scientific, 220,
        "5."
        "8293141157683540715974834887298766485149159985000963569603230281649379368678672979104626030220017706653109"
        "7808656147432158208325750276074188178479042973760179434028275087758081085312960935039135142298997141271698"
        "72461824e+220"},
    {0x1.271f30e62182bp+734, chars_format::scientific, 221,
        "1."
        "0417852442068363814820825698485384800961524522909120908757655752739304052271730075835437967141175704897236"
        "2556410412871574621805445900358411362726064828184470316985190862842986536825941080903916401459795872989632"
        "111050752e+221"},
    {0x1.320dd43436bdcp+735, chars_format::scientific, 221,
        "2."
        "1607520560286884617436832975764987909020968782350630804332132448446669047539163848254962584133413017581187"
        "8995110154484414359156320577338034565894700334587682265129267139733146651731675519638135463201585312678518"
        "261284864e+221"},
    {0x1.d4492eadb2bbdp+736, chars_format::scientific, 221,
        "6."
        "6122291466551174411687116860944445324369100982280262642756357833303477524497604895010840854773188953050254"
        "9525240799150634144193389565746980986114542904894941248987392023302371786537801869556014854016254502551654"
        "684950528e+221"},
    {0x1.7244f0d2e016fp+737, chars_format::scientific, 222,
        "1."
        "0456456707732716372836616903450010002831154494297396647575080631941006542008515084980501674726954118373840"
        "9735521916163104123960166329964470337072588711874356885215999169285494689746624286548178297048743319157036"
        "0707842048e+222"},
    {0x1.79783032b55c8p+738, chars_format::scientific, 222,
        "2."
        "1319581917624134663539889420808770033902782634131428805803621274487985682111331673510171714173211779661091"
        "1039629829277554336401367654542736793095757758840646818278190119418471508961695567736328280225796749325291"
        "4289311744e+222"},
    {0x1.0b80e405b47b0p+739, chars_format::scientific, 222,
        "3."
        "0217342386813301969860860986751309707281313502487263088112402249089284054700529175250024750860114807369896"
        "6248431572910876790362634732708648184340418996248893299378516377325328005094981174420298805174626877720830"
        "1410582528e+222"},
    {0x1.8c7da56899335p+740, chars_format::scientific, 222,
        "8."
        "9575645467295136187005193467472727461077360558615067094573133419410373043926814649879385622594635237376400"
        "9489966183043631980224259182358063657298096645467156548473441179528400778016541967929795075170853359231309"
        "1309174784e+222"},
    {0x1.642033bd8f523p+741, chars_format::scientific, 223,
        "1."
        "6091267209523207841500022910819655037186962930388881490129343819406509425737191896112868244974277012096011"
        "1038467987996264830181742307740591777712020726286133123519809683141290064198294007482197011860262930053752"
        "28012920832e+223"},
    {0x1.9bc991377fc41p+742, chars_format::scientific, 223,
        "3."
        "7212585176976675247766032687923578065346254909866031007251748946253430087753480170571456754955495909624074"
        "9651478094351885683772686198754775408289071997059939634841840773532728510497337830251876570543429013738299"
        "94915037184e+223"},
    {0x1.84a5ddbd8f438p+743, chars_format::scientific, 223,
        "7."
        "0243016720094258380256629121268145953304708681155416711569265396443279458019573583115401564863133375895579"
        "6859096569951771745018753431225852318075313303115723130792925295433351462461646612188904437861868080430293"
        "85978052608e+223"},
    {0x1.812a1f8314ee5p+744, chars_format::scientific, 224,
        "1."
        "3922688598771825923497467733635356583331381499542930429409135947927645522102501156000547692907375069729725"
        "3424086286852391418475312237447199829780274705926539967622748047191727176699933588455209360496819723139752"
        "620522995712e+224"},
    {0x1.7c836a459d446p+745, chars_format::scientific, 224,
        "2."
        "7509119604975913078844457489452846297586538028776489989683293722626191306788427967352108424504310704212292"
        "1510358887509501308820023222099507333400854507964230709783428734264017318871243935903761542528456933532980"
        "757779185664e+224"},
    {0x1.c6fd7c21c37e9p+746, chars_format::scientific, 224,
        "6."
        "5786808641025772557077870195899834765281585648313448823239221916239976768108478547517814419358983494868812"
        "1961792138548213478053349624498031839007814676289536377130610928273664129421374065334016220842662500981104"
        "964844650496e+224"},
    {0x1.1910872193e4ap+747, chars_format::scientific, 223,
        "8."
        "1277977211993122424091609085648747668771481082427919683807484929612071497922264732986002271464649933855497"
        "5692723623437402191674871832522296720935189472508557921192974362413118660403885429515640962582691368617721"
        "56520890368e+224"},
    {0x1.e7a0dc9273731p+748, chars_format::scientific, 225,
        "2."
        "8202379495294703177628908917234915516770485003946069942560364371093102020788444507236665052677625643822941"
        "6169845844057611904319010796043241408830954687945583175717139104067419835881477508963222172390156601957893"
        "5599446360064e+225"},
    {0x1.2e360651c6029p+749, chars_format::scientific, 225,
        "3."
        "4957237382552114527444821786045279558301101694570507155653230518370750977939158690454197498146827073453937"
        "9357041460767046371899223744833323015008806175316949664357009319736636567971463779695812041226637688151746"
        "1737018753024e+225"},
    {0x1.228638d331517p+750, chars_format::scientific, 225,
        "6."
        "7210829125928928841973058964356798018780827825223815966852813461948177069149360555141393983156164735751723"
        "5823818387673642184234289003869236885546152556635441516644651051801943950188162055930855976973404579926200"
        "1243453652992e+225"},
    {0x1.daad7920d9184p+751, chars_format::scientific, 225,
        "2."
        "1962690587113569953311452822660049421250275405789941183600119604625335444037052147400073579549578682185130"
        "5152933370080751805332495292333508751983579807351914859852157598709561299138622150754860897482836680616912"
        "0536099028992e+226"},
    {0x1.fc367b64a56a0p+752, chars_format::scientific, 226,
        "4."
        "7028636831137251940639609734997478916542490894502589016068679868179283595091571311071666311276887443785237"
        "1869111339313056178387759693383276951003950803279301146070858225448179998833261120984944413090840062524150"
        "55825045815296e+226"},
    {0x1.f6e5591a0bc39p+753, chars_format::scientific, 226,
        "9."
        "3073245175425146975822441451765732106763977056834211888571665521455385715741928365989145250785190410896620"
        "8744529206415406616189034448656245464907780501706412364806538156020642668889309046124343486486605786818551"
        "08771838164992e+226"},
    {0x1.0816210e741d9p+754, chars_format::scientific, 226,
        "9."
        "7751374002327882454619792493289953471219690074481970634484616771549473550854791181283295264817782922352706"
        "0613265512877596875929151767224750454913626387325900591615071953953614788294221399314042063755887285735218"
        "07551598952448e+226"},
    {0x1.bf4ddbb28ff78p+755, chars_format::scientific, 227,
        "3."
        "3113849645859590322659629554085610294468426876665362529283613898266559089354337883713337939831576365351236"
        "0939528196193498528380921939458491007462238558163393032268756159540201736116486880617747362901481164602465"
        "147231123013632e+227"},
    {0x1.22340a9f27993p+756, chars_format::scientific, 227,
        "4."
        "2967400896826536936196852047787877842228795494777580547365027410425875181924576423119919483371532282787556"
        "2232455935151361784331881438598361263038663101257927399418034873919694038118043368561692189760672875642217"
        "165115690582016e+227"},
    {0x1.c854c0ff61dd4p+757, chars_format::scientific, 228,
        "1."
        "3512844888942568633431706707369991062805896299407273613528709190217372828138600035487313614110546506130175"
        "9796936623799549072454757775050349217072188653452631708762957644242007121213071284462310050544450739174836"
        "8719761509449728e+228"},
    {0x1.a7ae27d0d4485p+758, chars_format::scientific, 228,
        "2."
        "5091984687837548077310743346070326057115446256710579709952705124606433752646975200990447388088323383562163"
        "1791334030723843800987709897669729364377875079217964383322434056974132347179670171459221776205857678918119"
        "2769609255616512e+228"},
    {0x1.63661358f7264p+759, chars_format::scientific, 228,
        "4."
        "2096173288585500632051722258218722470145623127596758211743914667597744472316325964343315995556084458514941"
        "1748410894323120068197403508126028905912753730931116082740279064580499643254386503570744343955198820880052"
        "0321808449142784e+228"},
    {0x1.0300bf26fd68ep+760, chars_format::scientific, 228,
        "6."
        "1356615328552858693888999090215849979187700860450814688847091714791407873355306852037699120732258617281579"
        "9763661313927450726589049261192700026203286795204601573021551354084951812528474694748915250828796925349007"
        "9718987125489664e+228"},
    {0x1.838123317bff2p+761, chars_format::scientific, 228,
        "1."
        "8359608734240248755170094893268138007948817195962710840103000502154170370457597688022569251293279952823745"
        "1289290613961419291935917276298318231224132928876145371187143351232976843971969552091754284038251401659784"
        "6683942400294912e+229"},
    {0x1.e3927b4212b34p+762, chars_format::scientific, 229,
        "4."
        "5822423033700377725172658938850396114672469752451147750170962585518435834434687897863209300864827416894321"
        "6215347383783451339038810851986217331962212638964904591583480945245942892560066540573272482646939275681829"
        "07234209828438016e+229"},
    {0x1.08cedaf963229p+763, chars_format::scientific, 229,
        "5."
        "0185456014215323482120364143447038175745222379826156921731023733604628540256614889772841814066930008300327"
        "3602910676234466758021841379319937225524242500601759755633396331540614052726360755893861226672066982543099"
        "97744334718369792e+229"},
    {0x1.91fca0dbce025p+764, chars_format::scientific, 229,
        "1."
        "5236616837822261183594983552804621208103872014884446947072618527095687605227859507741200359812256479924153"
        "2689156481633910812569880086596174896168270019967462909809080424290632874693002515466863422011218075068746"
        "26551770689568768e+230"},
    {0x1.5297454425c1bp+765, chars_format::scientific, 230,
        "2."
        "5667407186328552576827203298721081448834674879829348839914553768737074771050151832434114399565319657282046"
        "5081841530375765042480824934041898171446714864392159245126640241641295485518295845301454553991993419235944"
        "180577661756637184e+230"},
    {0x1.b0f443954c717p+766, chars_format::scientific, 230,
        "6."
        "5641519599209613942307145023783310917380706370901865075235561351321476204433688375582146368946539399641323"
        "7573577183096836484536070806868174940599051696594494416938549052440323251272405635299695291423546052625569"
        "523937164155420672e+230"},
    {0x1.393f28adab23bp+767, chars_format::scientific, 230,
        "9."
        "4984607723057801580828156622001837886199969801689635785008855370806264451372807995278722828203588180680316"
        "2319437032081291932870713261870296357782603566084402478282838349746893860544685330407950273115161626125911"
        "382367174150586368e+230"},
    {0x1.6ccee9de5f09bp+768, chars_format::scientific, 230,
        "2."
        "2123883505536182924204250993128741492319926155984738095126263216900091278131730034956679001909437190714141"
        "7470461265484571124755535821405407453375268326715135026269092158112467360893312363210642700024821136157707"
        "781468541960585216e+231"},
    {0x1.aa7e5f5e5358cp+769, chars_format::scientific, 231,
        "5."
        "1729616918294319332482875790573450340137448584291350718627223414058673740038801795890236140282159619607098"
        "5515906823203449053186707426569450398359311206667015703761833975688951025632779587529078016359349709485099"
        "7541669026700197888e+231"},
    {0x1.cfc195e85b968p+770, chars_format::scientific, 232,
        "1."
        "1249841891755881470307288574633491096320821816061087251084879090444810632807379547386169351345276341424639"
        "9499235117872522039812782433931100318509086417351386739093630575176672353913163070368040519097536895401722"
        "98591886940406022144e+232"},
    {0x1.09d290fc51ebap+771, chars_format::scientific, 232,
        "1."
        "2896696221903865795055215082983141009246370690618565325493632504690915915499930832192286164683816102053362"
        "7949425734201881702075904632943241830210311449479218601195277680189168934407630942804219498765833001560982"
        "52472908447697862656e+232"},
    {0x1.ec76d7e7f32e2p+772, chars_format::scientific, 232,
        "4."
        "7784976871034017657828998291078668236623487242644644914264847523004671605405345205060382664131477986646772"
        "2581936925994293581013028451474231026238972770111773752319751131971234336498412185333726667594294627984138"
        "99670124201699704832e+232"},
    {0x1.d3759f7354154p+773, chars_format::scientific, 232,
        "9."
        "0717409462351582512879207312640879225431123157848376459340362691044319863360475833972671151727153309116995"
        "3613299761397581849446381550581035600067671862940836812139863996838391322873371913400669773299857668038200"
        "23594898696504868864e+232"},
    {0x1.60b6f9a6cb668p+774, chars_format::scientific, 233,
        "1."
        "3689900648819599419991078858656869356050765416475088609781162654859485781989429631408630164550721129967664"
        "6675163827600656199755269975930968054801793732987317632393636500462380441458195075095212933235225588518841"
        "565183013015978508288e+233"},
    {0x1.a3c77db35f695p+775, chars_format::scientific, 233,
        "3."
        "2585744935086660180085537685216732331026663391625900061588234651372494329208446661750343881062028179841303"
        "5000393796104926802636017982724900777294096366223520808626483957189965149721621399989255737668072734392114"
        "018704118688163823616e+233"},
    {0x1.eef5de3f62c58p+776, chars_format::scientific, 233,
        "7."
        "6843501087185603259794811375183224825835123024830390834443345796985216905971043462468467825065825145047912"
        "1257386904850155677148759667711046827420670638625636122992849194055661087738240939909807864958747679917006"
        "112904357735921876992e+233"},
    {0x1.51ba28979a120p+777, chars_format::scientific, 234,
        "1."
        "0486551202848853375181699262277440337923945323242630048499280070068758124711990691937553067092163306379919"
        "0422222904119665181775876352024680491963078704811585628707843147629411479151750523561295059610495989927852"
        "8033246763355767570432e+234"},
    {0x1.9fd38f9f73f2bp+778, chars_format::scientific, 234,
        "2."
        "5823121007464567046885104979832409380872880762161596664634031051456893788764672118543197766647423252524717"
        "0307633255407546495228163592433100635899361801211866063496903835777314254112040433160116491010111385123689"
        "1366615266610552766464e+234"},
    {0x1.2fd85095f4029p+779, chars_format::scientific, 234,
        "3."
        "7737986251795181095835920164939564313633089884412570875383489848740579279500977251032489962612862718014459"
        "5041934451207574079071891443012396619181365931939022192089253926699566323452121788658413861452700408983211"
        "6221541501954953314304e+234"},
    {0x1.53a0df58b1308p+780, chars_format::scientific, 234,
        "8."
        "4364679691797806256313772114875593122899646244438036914347789201255815561109009718495350779943521128881259"
        "8661124923431217585862647327109933253121360196158567686349248544337235420003592506010834170882608023751747"
        "7068626899846633095168e+234"},
    {0x1.7853413f16c1bp+781, chars_format::scientific, 235,
        "1."
        "8696054522844013509664557489900659356572827490676017450916178967106311547779856491307188349542101112658005"
        "3098413303218486048823934732760541446158555795168870076775230759271001968117088989630442719457652896597455"
        "96271845019699344572416e+235"},
    {0x1.290f64c0a0f5ep+782, chars_format::scientific, 235,
        "2."
        "9516238595214877391019012136241245927442169099813764219039877773719979680097489392174641389610352922713862"
        "8902868757290932493840034681749848237707039012241717603398087699376749157835378926747231022224572282910928"
        "54470262186353488822272e+235"},
    {0x1.20679eb9f303dp+783, chars_format::scientific, 235,
        "5."
        "7312462936233849305925187920881714268750677533351388440477657151051809265440304245372238020717328177593142"
        "9064721353299156284133767944100816062524710379859644110856014276632780205150657944504841760675017542719552"
        "22237400714209314996224e+235"},
    {0x1.0ae6422a72abbp+784, chars_format::scientific, 235,
        "1."
        "0607775243868115711926825104702485099576960722191170461588016074972416686189135822557494910590354927785656"
        "7083850395248216549451922015356056518653041712884366536987636471349052017628975047519627186995177400422200"
        "23553187720638060560384e+236"},
    {0x1.1fae68f6d3324p+785, chars_format::scientific, 236,
        "2."
        "2867476796644975342055548204548289275435560183835346401207452752101236086799245334489159236317267957184623"
        "4879581744011427460271415601344757392670319978490800104037484315382074503549454151575728513063134043673357"
        "388907554946695678656512e+236"},
    {0x1.82f324bb4860dp+786, chars_format::scientific, 236,
        "6."
        "1516444985886181727357453221116535473763949845453173834960261690368544010549543489487454308312467023024447"
        "0967757706399429039098458006133041212560333975577682232332306318262042874572315900263924809244346215012040"
        "747327614291824074555392e+236"},
    {0x1.e9086a4bb3d72p+787, chars_format::scientific, 237,
        "1."
        "5549079171535267166568033413417870991744231184791835809719299710986005512799425681538276698346509703305805"
        "4617203537691090821963960692442929762603678178038455360528641178678620670023850492270840173539406323710317"
        "8254440605458957894418432e+237"},
    {0x1.d652f229fd243p+788, chars_format::scientific, 237,
        "2."
        "9908440313383278368912373533975367049717676756972612940984767586749475466860589818042252470421233810163668"
        "3749783560695211165711422320509360631385450815428687040737896708577856392117557493106122006893865207379782"
        "6470503447254389439332352e+237"},
    {0x1.4c659adeeaf67p+789, chars_format::scientific, 237,
        "4."
        "2274995598601972032222337678751235842978225817536418737171989377903748469688843485647399209132115179868048"
        "9240050082237999694500369311211906203822141019030006735614618819688608441342428976843756087051623925917957"
        "8450042045898033696079872e+237"},
    {0x1.101c96a3868a6p+790, chars_format::scientific, 237,
        "6."
        "9215567271733196558872063527194708064680481237227097579729986091275194772991933509554387747175408105228081"
        "6233796919158801743026047613067889494775889443810654472404347304752284383575581614991240505067988050840315"
        "1299257176295521537490944e+237"},
    {0x1.2feaa8c33880fp+791, chars_format::scientific, 238,
        "1."
        "5461124618479105464453483545545961077350335978041066308476434140961798663738305852609528577253177541004264"
        "0674921875366981747217115434254049147564405886187748105641346990648763559992836126028859532577309470093173"
        "81536957859327362761490432e+238"},
    {0x1.1c3506245949bp+792, chars_format::scientific, 238,
        "2."
        "8916888598976405055845467699371144108721910078547909542725979622689182053188545464466646296396805653806317"
        "0836036200471157333970893400057175239052338998950252682537126124003318313408027335611478030392005373128576"
        "18649039581864838165430272e+238"},
    {0x1.a53b315cae3e6p+793, chars_format::scientific, 238,
        "8."
        "5717036974323367762593030056611124249261619721065331924115997871817897838109316309892238746944064174685523"
        "2984150458218061427298439892262170298880469338557863138712770368068789767923621713438853252396510913427465"
        "63574845645114888312324096e+238"},
    {0x1.745bcebb9e730p+794, chars_format::scientific, 239,
        "1."
        "5154374230926382629786617926068462189415932748214593100290129423498906597965529492278922108386430582250567"
        "9230720413708559249356818004688086218479660300094476630990188973104196131751327920959159056462338543462652"
        "696067619761155130246823936e+239"},
    {0x1.ea5c1c862f610p+795, chars_format::scientific, 239,
        "3."
        "9913651025539569774148436777915199443437437903111488693940333966405933913450275851962963503672699904713354"
        "5044278747331448497501833332967880884570497477720375620658674167625733285219550009450498956408406531707921"
        "573265195554001334403334144e+239"},
    {0x1.fe4e1de13002cp+796, chars_format::scientific, 239,
        "8."
        "3074269080682828035403659469788418623579020747406133262410756205289227611748578907682329529854919761832672"
        "8676047997399722106302513181726459927428568219275795529707364568555469545316952865939501666657645380373164"
        "457301122656345267900514304e+239"},
    {0x1.7cd4c04d040c6p+797, chars_format::scientific, 240,
        "1."
        "2399350584739398620370668363277739542438309813212305563315742903024940157069213691930769271579472323729116"
        "2131263255507441554972403061556545670837455397804297967092115183139920246349041107552795320281845170460877"
        "1159860186649204109959233536e+240"},
    {0x1.5f73b78bc87a6p+798, chars_format::scientific, 240,
        "2."
        "2885616582924816530784070073813311039250987450317110713303432962050972937344928770752692668293089194605529"
        "0608211137899351314019622136717256892539500984709059963064994229906613395884507758858205052191954459822151"
        "1781291374084313853894590464e+240"},
    {0x1.b69a2039b5067p+799, chars_format::scientific, 239,
        "5."
        "7121188043661456678328008872506093548138903663377281285041608520095637609485982476407075424240402729445877"
        "4339604678663923908333018208735883952749660808133865118239612527062177749104161441575379075297379081293147"
        "900960085778554829588660224e+240"},
    {0x1.c9318f56346cep+800, chars_format::scientific, 241,
        "1."
        "1908490153821644619283158093528109987426655170996365765458354656665026592260831211660273736320197228824006"
        "8807963045425342397876010784789085355187514744433409506006637286593902764710295855833163921908212729191008"
        "90475871653745707435922817024e+241"},
    {0x1.3401abd9cab1ap+801, chars_format::scientific, 241,
        "1."
        "6045249823083895881361713712860563391171156578164991575414289295334729737454938352044948456680926597969686"
        "3050925745120889688762125639047773240430867525918502288211250081770600066608865761538925445119403248848218"
        "31835718200815935339827822592e+241"},
    {0x1.9451509f4d594p+802, chars_format::scientific, 241,
        "4."
        "2124934926639872820698705164077561033150645322246951472983374360250084754509456140452771893891811650082700"
        "8476703202083427652946465999321227644609061896995232601668165659507537285142883393178871950813985101339523"
        "80834671272890871310960295936e+241"},
    {0x1.693311304ae2fp+803, chars_format::scientific, 241,
        "7."
        "5265104770080295332178367065129652045456275043609132847824336608669067826017952400204955940094293124054257"
        "4852475785253445301600099905150226104745436671874010092945098510190008435762604016218987540554515377647101"
        "33944076096837889877193261056e+241"},
    {0x1.df089519e462bp+804, chars_format::scientific, 242,
        "1."
        "9963765370119968481634926026034374951277940085239248593420718947575091589129383509024279171159858004359286"
        "3504688558306636678159262921707469490960871925725729662377046505733704375416744931077775146683786618929534"
        "332115383984329784377263259648e+242"},
    {0x1.ab89beb8aabe9p+805, chars_format::scientific, 242,
        "3."
        "5635374969254025430568585517027217792799444908420355818342861726178161794532723410749195781712690824031079"
        "4310017343869812907100148774183849097884081288715289464770501559880487864305271735159038213120854399040209"
        "060513455780040766296470585344e+242"},
    {0x1.46cc5273da02bp+806, chars_format::scientific, 242,
        "5."
        "4477366708058466566655134611672790509037546172460934890613623870129442401676517206783993128970039181958036"
        "2426384544674351131359326804752571414576642144329305895853634962921675886002767155811657977044320345585688"
        "095697352462571132700896264192e+242"},
    {0x1.4ea090983d564p+807, chars_format::scientific, 243,
        "1."
        "1156495207540661418253164809185472162272891713234991494380662613296616531540865244596484276497868309719437"
        "3617177643665645519840787000240301424692793361517832839191225386853868937776276743037203564445163231623308"
        "9241962428253771093052393259008e+243"},
    {0x1.629961b8658adp+808, chars_format::scientific, 242,
        "2."
        "3644722323729202530632376908724461464007109597368741902538920716759797234401817824648073587323994699955712"
        "5648264452732032858395869340884384877054134253129761707648394212187240812816821311542228673662308704897899"
        "583239538170340844922017415168e+243"},
    {0x1.6fa68b72c2677p+809, chars_format::scientific, 241,
        "4."
        "9029985515120054991219793866924216920750872251953397307190125386871656376547215435820610121121629918570469"
        "2932229965036512490045144581731082612773985577453660692576488506973338654493547303963526703015702844647889"
        "92102255616474420568439914496e+243"},
    {0x1.1d5ddcb816159p+810, chars_format::scientific, 243,
        "7."
        "6113157409388193238729532718952114744786351715842762343118286303360666708027503785066003043952596584492730"
        "8041709547073320956899512551777237915036724122719137575454507464793196061695217074073096327096395937968822"
        "3847143281208387082485955035136e+243"},
    {0x1.19fad786740bfp+811, chars_format::scientific, 244,
        "1."
        "5041965738192946200722212939761911313149957245913376893384443835763146165414530116096641460821289392931044"
        "0630078704558810797169674663860330303705781820921368183064402339199493404910007111083399854517304573251517"
        "69785159894859363338510334427136e+244"},
    {0x1.3ae2c0e08d1efp+812, chars_format::scientific, 244,
        "3."
        "3594604205776399571547735562723174528528296198287880206491449261321063694267756459118569069896694466315807"
        "9060394196735833929677656923702443863850476515869528665652443334766758399236901631693454061508781940650430"
        "83480115234578972233121652539392e+244"},
    {0x1.07a5540e2223ap+813, chars_format::scientific, 242,
        "5."
        "6255810937325722364168544190599919919944988115599126260371359454766948641453922395581588351836311443942717"
        "0074877286708288570679911572171655245727999618768162781235182605194711519538182992458325101322631274257458"
        "626935171995388819171019063296e+244"},
    {0x1.956e83e8c51e2p+814, chars_format::scientific, 245,
        "1."
        "7301916345499639352289638577061978996058784043095091824698294699979622683284037830111746691503650855841047"
        "6999939726846771500166314131694028889035553778607001781013613472061022354416879057893328192437062066419536"
        "392847325840865191718208676036608e+245"},
    {0x1.b8b498637dbdap+815, chars_format::scientific, 244,
        "3."
        "7614467878694320040847306920809823505948332555470424652166458420295692303534588660807141398391045858309584"
        "1413967874817042173260887173028178444373791701703929714447150030566240591625957163983380294595179856309594"
        "72307970883902414984099829645312e+245"},
    {0x1.f84238ea4240fp+816, chars_format::scientific, 244,
        "8."
        "6077546560347295614272909918464340647673924012472192336720324021049311703284577534957499927813020888938512"
        "8773917946855872595697344028186679078946097028129784645488986749964802103215644921535921267141777871369472"
        "69800165590575130107216339664896e+245"},
    {0x1.52ad71035d8cbp+817, chars_format::scientific, 246,
        "1."
        "1562529259815605130236730296100290106123624875586685093423585578874668718454767210057255513612992306754618"
        "7342013693230898318163998173292325928633817009622432686125928501176669069326632568840932966409440904636285"
        "6182501376346373114543815180419072e+246"},
    {0x1.48fec7d03fd3dp+818, chars_format::scientific, 246,
        "2."
        "2463948643754039805273266514856692451977272866202583855569230043159032686041759389714588747353194691583147"
        "4452902908475707849749179375503315481022788227755493105616171789512052603092214593918819436824445346786518"
        "3485659375409167115085108199030784e+246"},
    {0x1.cf3c351de21d2p+819, chars_format::scientific, 246,
        "6."
        "3259830327537269189044662519669296931261791172364221329361593637019414071398195080337671514053830368262017"
        "9485254074733712535986358581460970535047746807357544820196076947637608204117489620214881737780122049288515"
        "5229266752654874064585229395296256e+246"},
    {0x1.04cfee010a1b0p+820, chars_format::scientific, 246,
        "7."
        "1233523026483118129409774865992293632616547759253418297613685912737518499550086903830721434337398871647481"
        "6681062540280955271611695843215620922951427058580870118796718799201266852043478989988290818085278143313409"
        "0565968448841286218356104624078848e+246"},
    {0x1.16ff034ddceb6p+821, chars_format::scientific, 247,
        "1."
        "5239989788883321238503418080232313766405266685350202354474518823147319501930684180240795371555272910032577"
        "9049954354848675448536122534205586842891052665122265107971822539494506600965187819614128128697568579627352"
        "33879680013030703241961011578667008e+247"},
    {0x1.87edf8de5b8c5p+822, chars_format::scientific, 247,
        "4."
        "2817815958852792009690939837540692667657942500261648858225755618432069627819656317285479347915329201974236"
        "1774090371005988644354729115809575512603753519692608035351355704445179917631181514402455534288096929879543"
        "01004090162477967508729042667831296e+247"},
    {0x1.669c114e230f8p+823, chars_format::scientific, 247,
        "7."
        "8355308511237709530930810281471556447977784106662035440600564389370223232176896921185631429562490325760418"
        "4040678795337449978775441323897003748541667506968239033335149617631780016082197756792118648804974130157841"
        "59154833577142573195961256835547136e+247"},
    {0x1.58d031c626c98p+824, chars_format::scientific, 248,
        "1."
        "5068166821885369761241532108175293171326902216427944067512350661456054766473593312346835595474357273106155"
        "0443352975975022048534417756037602834654175485189498865510882476319162081279903462387165411735576127964682"
        "682475050190476626348021385449701376e+248"},
    {0x1.e34e95fb1fd7cp+825, chars_format::scientific, 248,
        "4."
        "2240545805625662788005553229538307210864857630306634011231079027836776827258668243309661298916332821350400"
        "9899722075244068756374649547572873002969477945909958513824369325732383525908290312550258447997151554563028"
        "850116547816966945718645194204643328e+248"},
    {0x1.63711d42e8969p+826, chars_format::scientific, 248,
        "6."
        "2130524104674504312709824639557523483551730337458850149335416915855240137673709836071529680319293067420338"
        "4312317758999145612684331260582769097598430580201878319065162034573403657954549033776399570698036990728014"
        "309370022216068485544971660370640896e+248"},
    {0x1.badc307c28bf7p+827, chars_format::scientific, 249,
        "1."
        "5482212253078290137323515076998672008506438386926224329269661187742030679492468266492921375476288647815377"
        "0979107822881541818928344505816759457570487597227978430112594020575530604815278455258654123939844316414811"
        "2432800361003761689682808487570046976e+249"},
    {0x1.0a9ffb84993f8p+828, chars_format::scientific, 249,
        "1."
        "8642201656825735032487045445737131264202090391740882730526180997719415020580181710931406700397570032582529"
        "1725810794370004636502368683142428033504081712262310941760777903706494337172156236906134798389170572882188"
        "1800728029892690586075143474451054592e+249"},
    {0x1.b4b37e4289e69p+829, chars_format::scientific, 249,
        "6."
        "1067588584012951929907635132587529022793422163084759285705466684191965135342417650787056752222825478137672"
        "2272607455634492474756781990175669040977221401874388780115943698876864915101026751851198210499562900472675"
        "3068810448767555137722058562680651776e+249"},
    {0x1.cb3dec22a459bp+830, chars_format::scientific, 250,
        "1."
        "2843929885114427205223509904897308175928651557268642545106012550730315214169113727124053496729076859906621"
        "7058048465589552560767724767960979474433908542662650232168843419395326916423547105760665888316678476707804"
        "15959665868837863306341265182751195136e+250"},
    {0x1.540046039353bp+831, chars_format::scientific, 250,
        "1."
        "9018081890692326060832549932962923793803050200930597137121291666343311907659231774649708656240141439885377"
        "2995852889168534092009700171523193933546858525442546217623145476647138397975513103720466511762535730409839"
        "44733060790144155006131906575106834432e+250"},
    {0x1.ba087c8abd72fp+832, chars_format::scientific, 248,
        "4."
        "9450566101263624434421552691226627188006160690582878226879528430254220763518819638978711170059796369024989"
        "9822324647556645340449063345238710759902438168656167462547098730749436504815208438476002132344287060560190"
        "686566675986547104771240121885261824e+250"},
    {0x1.c630424f784bfp+833, chars_format::scientific, 251,
        "1."
        "0162079024060941902752986278592898244854037810570970835536347253884184405811222585986918355510523699760710"
        "8720562738620020129036885402684555944864458354638982574226703061602498417867883983480388401527947236142554"
        "900694304483602071758702926508016533504e+251"},
    {0x1.85e91d57faa7fp+834, chars_format::scientific, 250,
        "1."
        "7447831757371135971868471755808753449591436173823296107480817640339909863589495003745228117499203382520206"
        "9539324151967771977343828509557409552448094340742113501911628551355358681804381630523888669439044433379659"
        "77036968476816664586097351991475830784e+251"},
    {0x1.dd2774ff825b7p+835, chars_format::scientific, 250,
        "4."
        "2703660170962130244303048163026444835147574558041973970175978956362702386703322527155179489291238033872231"
        "9202066539552047310868912136192587125219809728800730236760671881009425615956313883933879641516247520243538"
        "50540715761104916193393419547242921984e+251"},
    {0x1.7fb49456f0d6fp+836, chars_format::scientific, 251,
        "6."
        "8680635961010054778547732613484647985247018036381086963058134686484342338181759398735578464286990961512242"
        "3860524082353077746568202335565206880392172011863842924238725950600524821099164719063099983937577502742978"
        "451517889868589043980171636988524363776e+251"},
    {0x1.fd01873113f1bp+837, chars_format::scientific, 251,
        "1."
        "8221716304153650272213764159000693884485126489166324070442650059724346984915036736532717255211886200617045"
        "1559140970097704185891051060148919646916253880568664978507007421126009924560566886603966798872120047504227"
        "498682957727850164695377954464654688256e+252"},
    {0x1.16ae49bfdd770p+838, chars_format::scientific, 252,
        "1."
        "9952782556234112235618388114000024419696976918884012985196883706080092405613980858524205835778745894133321"
        "0868285436775919750725736172285506109646439824434030650330008589013231883176343982203914391073596652430291"
        "7790375371341763162002626475342277115904e+252"},
    {0x1.f3ef2c4210cacp+839, chars_format::scientific, 252,
        "7."
        "1587847487893079499698458355959164784160549019709356298631985163802186160082258587785870869537220428341295"
        "9154953762325391374645796181723015336842060030080570448235415608409317273087473499964688536725010673884928"
        "8705506701643342594415108812000139935744e+252"},
    {0x1.ad8a77a22e9ccp+840, chars_format::scientific, 253,
        "1."
        "2301580219420288258750710073967242803603244157181759807205724391294942735957066782958529919353781927634981"
        "0332178857663060811072852430571703413531625861496620272515219238779208406942710051992836031567349036998627"
        "60042508068641111106629716312501667233792e+253"},
    {0x1.ee0e5ceddd957p+841, chars_format::scientific, 253,
        "2."
        "8298450670726808039569020713611370769752247693265877738977218776671815871966890797048229309787176096732913"
        "1557575024724858315121232799546498374424641272691542726135168215216303393892641064985962692205494753902395"
        "25928386877340201687282618195535303016448e+253"},
    {0x1.5b0d6e76dda47p+842, chars_format::scientific, 252,
        "3."
        "9756809005620167673963500063290061375743826936924843916067298983960768988309298922372333125861749340072060"
        "3193814599385110267978592875000662237114376052227737122342324525293468477254761924145161645921032961639161"
        "0300989215056042850046033283650733211648e+253"},
    {0x1.7c22aee81fa83p+843, chars_format::scientific, 253,
        "8."
        "7093308214511152528107680123068762354482351630940844953037898917744938205727100690119337533031598012932830"
        "5899183516041902309269864529394908188602588257391769221874838167307939441021963369847794051919452848913192"
        "07064962654856171425270750844538014662656e+253"},
    {0x1.b84441e72b707p+844, chars_format::scientific, 254,
        "2."
        "0174005971626055001082205847662126781792713876424713491426107135200153377636963327796919425670606854013876"
        "9188228169130929018386056603499673065740489029850179269264269221606509548886182752766216275942511240393316"
        "495487843867292364651919029871904141869056e+254"},
    {0x1.0552b62c8e128p+845, chars_format::scientific, 254,
        "2."
        "3948822178489890559980219012723484849467341938240490533083040081270350965283979484566831974206206564200097"
        "7813391908034755444058999987765739175366039266476547129613207191807837450381143027634960650298481158853128"
        "823296817588537874887085684399549987160064e+254"},
    {0x1.81940cda93532p+846, chars_format::scientific, 253,
        "7."
        "0672259148746032781953096787839027889529056934666995406469164252062383501495468316183615878862193250089894"
        "2824729667688989026764849833220049830460614235982996258221917434939821706769386936014308325931527289971326"
        "51595911203444205265762564863624413708288e+254"},
    {0x1.feca14e0d5431p+847, chars_format::scientific, 255,
        "1."
        "8724413449264554000912479366013655429391738786825257650857219360436405508576111348384928174760062323641767"
        "8355963928202928363122166407384529802017781834605348048825483579470507214795788114765647102370549369679820"
        "3822670734824380038945947831900155722858496e+255"},
    {0x1.8827ec23206d4p+848, chars_format::scientific, 255,
        "2."
        "8751146201193473147511048914580957805762968774039920973219195905081640980452976049063596877710504384456337"
        "8942133482080646288612528269588423761555820470966805352165440971982693782996962226116197358314589774284203"
        "1555441896836579508527488730801254267092992e+255"},
    {0x1.b5f64571e8768p+849, chars_format::scientific, 255,
        "6."
        "4218887967767973147050111402854431025976259585437744180673244997762152424757771170884317557489625383493538"
        "8361393226475356050594915067079552993583324564851489103509456327285189214338400599281283635090488306320315"
        "4505532895528456078517711521452946616221696e+255"},
    {0x1.008a415b3183ap+850, chars_format::scientific, 254,
        "7."
        "5233547495587533813215041264189804683273644679977334152418586391745637517690648136494502205349178507544930"
        "4982226958672016967506014326702860578746451776174964112417893379382667476706170679989555178879302805753091"
        "108683336905960853244568321779433883041792e+255"},
    {0x1.80ce08985395dp+851, chars_format::scientific, 254,
        "2."
        "2569755092325086975203493724033279385000107408412293275710347345297410075316635764407052156717311305034067"
        "6514647322222782299508751884380960970986935005936264995993547014912920456411557793138937542233075945826841"
        "792852744388221269309269296056441948340224e+256"},
    {0x1.c93e2e3575dd3p+852, chars_format::scientific, 256,
        "5."
        "3636854859010334156927466175684003738394714128573400526327089603309985356772629772564613094187950836011490"
        "7981918758305409650123299920242433241170318463532135276196145928454218679932889499527926234187310919488675"
        "05567571032101385441229409672592337764614144e+256"},
    {0x1.3585fd503289fp+853, chars_format::scientific, 256,
        "7."
        "2617253380026673444035579620762527314882508741575498105068925220256457780553521247639040403375622083543231"
        "6486550264499628730776026761628843667046600384317735951023059613456072596871655802663640764044923285549142"
        "62493008301528885911022370188177304688001024e+256"},
    {0x1.9437b5f9e6b1dp+854, chars_format::scientific, 257,
        "1."
        "8966691176866934017770214207713233840154439494884324292130780115404111263157917885413943878915831820762225"
        "0583303348187654531921298414600764621002789059760464627013274391530347087973710882160208775617821106882488"
        "293831053109873906677004142654823373750665216e+257"},
    {0x1.da62d2c072d77p+855, chars_format::scientific, 256,
        "4."
        "4518263636702483965495053856865406170236863462890282079194516118432973996711016751060886266308495383903464"
        "2746150586093362335739021603552694829648595836492021186657012662450405162755427498833201023318739340117695"
        "42527011418624873181894562270229605954617344e+257"},
    {0x1.ed1dc3f094314p+856, chars_format::scientific, 257,
        "9."
        "2551967587286591706284322222810649405226651345273042856895913250378153451345197355495763043221473190696946"
        "0611860955463662896675534000088606972814085114676199268097264054120326412981252636237720041559537499349640"
        "773600892533856516647510713166368494906769408e+257"},
    {0x1.ef52edd00039ap+857, chars_format::scientific, 258,
        "1."
        "8593264122501495174403183867678233836361455504181472606197270931819321323497564161749153365807154991322567"
        "2390476030417331932845704484326216214934527954763403077000110171731127369920811460830859516485802752602017"
        "3336192319696495016121803920946730655041978368e+258"},
    {0x1.e3bb125744a76p+858, chars_format::scientific, 258,
        "3."
        "6316167357983087714844824037018917492844360826517442957456966973425494059948116922878230830137295968794133"
        "6015957431917607400275062474387002683489057752768415445554866083398760065152355237788926587402650325283626"
        "7137258982023926052809172133449146986873749504e+258"},
    {0x1.ca0a9344ec42dp+859, chars_format::scientific, 258,
        "6."
        "8775056809719936773562239947664051518174519882815181477860548157748963568061643541510085655252472888900274"
        "6169928864401679954432098644991193402932567830206563234050230289011829876954220287981867426303858627431151"
        "5637490526902098135179090001625391964633432064e+258"},
    {0x1.2411970d3d9abp+860, chars_format::scientific, 258,
        "8."
        "7708430554932495543370037977511351939308693383512112665323264941874463770609190130161570455198577258604133"
        "4636679907937258218577041989632331153050988708602551653751196950259687810167099278093778665549710623277951"
        "8706602377059819914819060153907843977606856704e+258"},
    {0x1.1ec5847492eb6p+861, chars_format::scientific, 259,
        "1."
        "7223538042831239341548853561863193983642495213487394348170048026198592090336204240078770738165496044637111"
        "2342217250321051024454736362963000514473798185873133075921137741486035081623276812829601351743319683570519"
        "09828327505871566528836256883770889417414148096e+259"},
    {0x1.1cea572360825p+862, chars_format::scientific, 259,
        "3."
        "4224113618416387660983968909127780621102150832355912954774258704013837006241377937016098367433894097044239"
        "9548559312156546552455940215868211600940072182151265581465924724472562938954641277540870592656137399445957"
        "77869883504853717504448659641688579757020545024e+259"},
    {0x1.24cde6b8208dep+863, chars_format::scientific, 259,
        "7."
        "0343463133020690622080363520915250368134172380431222412466942091558376798359445012434068235562476291266919"
        "2263483493964563327850244971569130974664971468010256534095152179979912990687755183256723803192619430204631"
        "97815031497056680470826442214372237094403702784e+259"},
    {0x1.b585d7749984ep+864, chars_format::scientific, 258,
        "2."
        "1022143522712642534927702470363833595361742788098251565939808660957882314655047911950792006855166244834767"
        "9742384528807478336575531155237574537062478111192313055661179917070288035713865139698150878247481139550834"
        "5057190337375468415342190739196099429459296256e+260"},
    {0x1.9d037445325cdp+865, chars_format::scientific, 260,
        "3."
        "9689033579839333586087273329545497202552025223101557954368170073685594346508353881665191789733101162600963"
        "3832666126630950368714500596474244775837396509928744970487499110108854614051229977132244291177899594800898"
        "868953265027415713662233602012993288552077852672e+260"},
    {0x1.164c006e21d01p+866, chars_format::scientific, 260,
        "5."
        "3486554156761041122966272313360276147722474552229895173187242042125351415357870740578477470191391604587784"
        "7544762046104950012172421985090219541563083951673230860935981090927118350656495882735065989904791768286592"
        "793842156241914783340450390835867251603190841344e+260"},
    {0x1.b1ad1c32ca51ep+867, chars_format::scientific, 261,
        "1."
        "6669857056073904295877757328423769453449385938496074603048454391418528215175463715315403787528483878921026"
        "9734985247684352986127262307989667303704374626967638897389849285583351959286670587460222313677004843462283"
        "3020129626133155057078829236175711168725220589568e+261"},
    {0x1.48aec4c5297d8p+868, chars_format::scientific, 261,
        "2."
        "5268130061515183896672541083193819962814958369017161861916462692004818230105550952960108454257383922547725"
        "9430047285044243142322797421645388825477485111128620457670266244438408508981040669938314329656372612659262"
        "6063461209454637519696384115499033283572944338944e+261"},
    {0x1.c82791a9d61b3p+869, chars_format::scientific, 261,
        "7."
        "0135563955506447327134376779608858242321794549199409417336758439247473329704075211614864504298236856709108"
        "9491580123853294665804589087607528139845738395671479742204503115659932020873035669822478208917777517363066"
        "9756457138689042468036550644721521533789925277696e+261"},
    {0x1.6aa8c3fa4676cp+870, chars_format::scientific, 261,
        "1."
        "1152057754767969643018536779865322527240533916315230067839324867956406896271582112257557870903391509215809"
        "1956327894126813093730344747664064030616933374758815912702205423104102393081857574217568447918712081463529"
        "1478507530630185498829253348514286180823709253632e+262"},
    {0x1.283c03e3922cap+871, chars_format::scientific, 262,
        "1."
        "8218885128879403050907701841700254353705385323409708627633550805724582437371113678359942756580855059619909"
        "5387096660000020113210681570207177994891885681937114934287699917995965873657954921553898263299260585869319"
        "43076794661977482279539782871784104567717178114048e+262"},
    {0x1.8cea9120f82c5p+872, chars_format::scientific, 262,
        "4."
        "8821954627592468297034144101052902316423641419746580555012088510975847917374634573939724055978958532505445"
        "8910824834864704440551871917541689058272749866358635949227602996538977376206298893196919077990415442432746"
        "80302980924347818100188562495929432829251712712704e+262"},
    {0x1.d973ddd6f5b77p+873, chars_format::scientific, 263,
        "1."
        "1647232869439797144128612526951735538946998095578708442740497215499916303005982058096215134648677496022778"
        "3588644046610606860532249494006024946027982640278803787353469535819812520682463463954423986471436740424759"
        "351730369993756319745282998559730184772104807776256e+263"},
    {0x1.f6b246aa65daap+874, chars_format::scientific, 263,
        "2."
        "4733296974221883796778661362827342887970759082625185925539120429912050329008686714438091418672145986492174"
        "7123831207566139995773072740794784173590930118904914778018952948323351202355867513511555638275356370863058"
        "697535795005475738555744173010248664718303031197696e+263"},
    {0x1.84c43fcdfd3c9p+875, chars_format::scientific, 263,
        "3."
        "8255614772231619409090663562751720549695664441740645381704259047208036365622208250797489037403777801687502"
        "1251820705911738604051395984150068267867571861969188371719006695794892970741841549480519926689507865382895"
        "043590951293226573743254266501415406206108651487232e+263"},
    {0x1.0d0cf61c34917p+876, chars_format::scientific, 263,
        "5."
        "2950522530435664148148531050362284907601275172048568844087760323458796487612851879945690043513677305823631"
        "1027963509478254881181136917908166870711973901108220565960964083875886854518680826821014422246633900470942"
        "204464313973177246167132074412483179319922517868544e+263"},
    {0x1.b7470f572ca34p+877, chars_format::scientific, 264,
        "1."
        "7290409059596491160392660629780224120987670924600492127521833122544559638181938355651161578571122937908200"
        "4736562726151156355066947256957893503527892947890490864878566555947580613942211204717040529195486299636201"
        "4302506768477688217193036724104566863122371314712576e+264"},
    {0x1.6f579373cf416p+878, chars_format::scientific, 264,
        "2."
        "8917911522817363012645491894345880877959140658748164626457215144933567697478848748246557694041140147148397"
        "3773154689131883953422212476453709028316632368941627329032791514854112432586368236522512126676854020608788"
        "8147820900177311817262558184006103887903947191484416e+264"},
    {0x1.53e61c25b3dd6p+879, chars_format::scientific, 263,
        "5."
        "3515050581631755036520580325118687673947236845337125650051164727089722015319573279603673205642180581633918"
        "2827247492806189852021233450786795459652269420367267283626129052088926393182523919980423037030122018430228"
        "265381645243737717520975191570311770107321052561408e+264"},
    {0x1.58f3a1aff6692p+880, chars_format::scientific, 265,
        "1."
        "0862117360156828711782018083715567701140855006689768849211310756691923390150596155361509757423012122662014"
        "7543606621525575325168914047694766792472765528962462244301048456879469093164518615503952892850670680855784"
        "38933939908261673483684160060573765056449123499114496e+265"},
    {0x1.6f410a840c9f6p+881, chars_format::scientific, 265,
        "2."
        "3128785488546931489272260574369394166074818677610901547355806177242180002180697086090725045491064466731356"
        "0127553031593838481376225630920940311878815089733830843845396846155751065465312595061542938566927311228508"
        "35008617650833500338712484495998333181450026401923072e+265"},
    {0x1.c55ec45991240p+882, chars_format::scientific, 265,
        "5."
        "7104346407744366879442524026328321873829311834849605463322151469516209295387639527101327649590792421651782"
        "9514315747910569800251356318437826344953522781497302877730755704197328949288706415489347212482536070831297"
        "69835264604896319470976595601519978424881761413496832e+265"},
    {0x1.c4390577e353fp+883, chars_format::scientific, 266,
        "1."
        "1391963969865947573314488432655043746990076042479005580857991691371729105469208930334011603031931765527660"
        "0917805873430073523272197714955603390704189230682334970513371435191967474393169903239028641874533354488266"
        "172291445223237400317190676258012429832003316365656064e+266"},
    {0x1.80024108442cep+884, chars_format::scientific, 265,
        "1."
        "9347167157285601303774915232697415595562286652874494078992920448925138324939113354855246958541500385382314"
        "1416650002056326762170466471434812679273445318398594637346034345659552218437003750926311120682080530960525"
        "91460233395247230558816996364387719414973408389103616e+266"},
    {0x1.d3b49d281769fp+885, chars_format::scientific, 266,
        "4."
        "7127965925819099014644056539795354030893985157309915619565784136091723470489083161162051111812262902453425"
        "2262801742043035998900246742774977786010211977964487997955922525106556091069988389010083332747065934945098"
        "638325018724512951515441851702692596765254267021819904e+266"},
    {0x1.e1d71a9ff3f96p+886, chars_format::scientific, 266,
        "9."
        "7104480347680526724388655440563722229957272133761493078196799014479854048146499410022289577832223787658711"
        "0622082427832522414467935051386635148225548368445563790964504191323587209199839274129077851038873657848234"
        "049424161572976854377951240964017540898697569732919296e+266"},
    {0x1.a7027ae520191p+887, chars_format::scientific, 267,
        "1."
        "7049690600947821370125168065492658748824492222019128137338447696856596238790064614116696201248482964846722"
        "5184628076677445407056663027092528425760141456580472815946048919674298043627948451671861971785724528256343"
        "9952765212043058091006226485989331945084763383877599232e+267"},
    {0x1.07cadff975a25p+888, chars_format::scientific, 267,
        "2."
        "1264667446960466843185764124801368452628993903514278513168587197748772998239803298839293111491786165979697"
        "6630982545509082578930304252710488146559865458098358329640035523049333552971483963136440119661263615817430"
        "8868271748374352726432722496121159510184514510133395456e+267"},
    {0x1.cae05e4bb900cp+889, chars_format::scientific, 267,
        "7."
        "3981296724233212368915462203134618633827781348288599081204473928605382035734896070754821747025697168204777"
        "5831164644939498894759068631892579557932411831268566497011835763566862033238415369736821458656129565314617"
        "8255710476500506024135400500117736967485460947838959616e+267"},
    {0x1.2eca1796b7a01p+890, chars_format::scientific, 267,
        "9."
        "7633054173860787578411930441342299812581938383096906442189245136120952178871210673264010432571176704977342"
        "5144875507166490525658553295176797506420287263697491032818297518673506315051096497540547092110494724301159"
        "8819166228787969713283529575588634229583035259655553024e+267"},
    {0x1.406a4282d1f80p+891, chars_format::scientific, 268,
        "2."
        "0663273080075777668338994648180231590952022821837453038885287279067698313592069654163912058841010723048508"
        "4956016466783712260016983074067762455585111313554422858547193254983943038061713540787691125397501471732455"
        "71337587193911747858038040870387038252781816931388751872e+268"},
    {0x1.c19ff8bce5676p+892, chars_format::scientific, 268,
        "5."
        "7991789555885803138323063424220372329352634074389977280603810320972219404232779295106348205917934689394522"
        "6968684544645340888018484272478339697145259214282893355358872397623678216624402157855548818728918426167134"
        "32471899850352776136551900415744006197797151659494735872e+268"},
    {0x1.1fe38d5e73e29p+893, chars_format::scientific, 268,
        "7."
        "4262753269739863071097258410894263038106306114820869566206729774587639804770146725844918946518744734031143"
        "0212086497566770910828541707679614353259556721899264745050804359726236597577003220048795740807701689255561"
        "62933649281172853594080068740031755532479512733798105088e+268"},
    {0x1.9c33b1b47ba39p+894, chars_format::scientific, 268,
        "2."
        "1266018116022865411879381930967069790650798465621914648129213144859095777763598456618525330801709641460962"
        "0283984888529353757272520111093436834836026317167197256918208615548851093068000261067283457692229986020108"
        "92382509460090260457040044765667150887352245110542696448e+269"},
    {0x1.a26d55f602cabp+895, chars_format::scientific, 269,
        "4."
        "3174364231170401202551735299747722543232356757700271552533167886073035283977844894207602162776571084158010"
        "6637487827981321272123315762352293798979542062159013795203284222229869402422626555139587775055186134834731"
        "324943467913151240603384480045011193118883243399917338624e+269"},
    {0x1.9dbb95083d899p+896, chars_format::scientific, 269,
        "8."
        "5379978661479379320868346870429258696342415203889512925623464380466473704249833165653284702162353335262430"
        "2307718738124555968647710529467983770429635871301993423689601725064452486406011335898739997113633529929962"
        "577600432036682866890623144100588419524680589002758160384e+269"},
    {0x1.6af76358f5a1dp+897, chars_format::scientific, 268,
        "1."
        "4980714281344640077800324391631747631672023321820143802880940360267132634221480283784766939394893412549743"
        "3151756991181766902713336944094229312003649709735112045122838057934124138596703039110082058592770254239274"
        "54742902981302864610102076457909707158804960722041176064e+270"},
    {0x1.158ee8ababa48p+898, chars_format::scientific, 269,
        "2."
        "2911327982233443224255282606251683954818178224101142096814170593799078226053624816860825230410849307401794"
        "9387270640396091306344102882935763609967168275344632506117759911529139873832889312080415806425530984667493"
        "141882202135810556985477247500496099082247955662411661312e+270"},
    {0x1.e6e6e63b2d752p+899, chars_format::scientific, 270,
        "8."
        "0383636773183965563279950292424708434270709791957562856743978678069397060540636573407544654392197003659831"
        "0384498916233030138783388753183256314274108920183065336069113265406239709403032217045311711966041684929643"
        "7886880687688620940240142624597135728868058798902940270592e+270"},
    {0x1.efb1c88f1b917p+900, chars_format::scientific, 271,
        "1."
        "6367042236629718729268402905374296656046770255365947397612805585584577853260684216085805613577865939803054"
        "0017828458853352846712273689458592461038336716933341640440422893827137366319492868172331188522757035612448"
        "66825763146062984617418588471703105453076171109553535975424e+271"},
    {0x1.09f8f19708f4bp+901, chars_format::scientific, 271,
        "1."
        "7563972945923824150525176891612462671316782210660684679553841323870503209610405498092263311262830620848698"
        "1665909632003524215493513538752535250736701221979553770233146160642843021918667772131483618387627906645341"
        "51448437648021580687531829596950159719152557277080794955776e+271"},
    {0x1.4baeba8c6048ap+902, chars_format::scientific, 271,
        "4."
        "3806517196597018427536671187880965481198827304651513198477564882433011473589151224194298825916010573320122"
        "5609468413588284017169338273312525874904100588433697308517750041713396596008724468325763195854907398850846"
        "27694863349688275377814547997028444578550781519051836358656e+271"},
    {0x1.8cd2d20b35045p+903, chars_format::scientific, 272,
        "1."
        "0481984706425230890135303927487114643980806409793254758292517423408650454004004690410386164020024921406758"
        "0233261931631992081782639072972543258522686672291340682053372574758989506104340886674614134885461225788767"
        "794959454342911064675144442738585353876408558614225881137152e+272"},
    {0x1.8d927eecfed2cp+904, chars_format::scientific, 272,
        "2."
        "1003524500133662840062505751219054791731938233584420309293263329740744737213481017895065823059205657074688"
        "0495003915982871650202221554392121175674180533011917736497246381453282842769636604896153823898456077059993"
        "174472058950185123299125702872712090700453722243307694718976e+272"},
    {0x1.de6575ee0f842p+905, chars_format::scientific, 272,
        "5."
        "0546833046720616928644353045604638530577598414714986252992662226709325284346824803889505568642104307349610"
        "7456864923351748471226817911054373931071993953305772937720049829944021694539009473977809362995695360293075"
        "326737012260339556128535967312245217254998376141704004632576e+272"},
    {0x1.02c1c5af5c860p+906, chars_format::scientific, 272,
        "5."
        "4679946858938374499976093477651454227758162651854337179090133937645556976337514121554834083379163511523367"
        "8815555279040921759101244136392626043168966853295239988637028313028438110232397895920842852413186318437631"
        "699837025581837989426185144833604274121548536678718694752256e+272"},
    {0x1.2768e4c0016e5p+907, chars_format::scientific, 272,
        "1."
        "2485068025844775960002963813255958238990842988066318183410805756654220701045964459693999153819613426900795"
        "3835901620646121933168654246197946439033027346268505733120081821047015798725629926657488742079842818172233"
        "730531858978327745494162155720720998081562069703878674219008e+273"},
    {0x1.4e3237606f16cp+908, chars_format::scientific, 272,
        "2."
        "8248640371828672657868329395057769266301903582528250762504229181498738699765492883442629604378488105536677"
        "3049664084859301174542831369333256493187132550588644734495208565407517304624328179771024064881746101714668"
        "858926752177144909757882154154206792562438451054311169327104e+273"},
    {0x1.f05eff930a17ep+909, chars_format::scientific, 273,
        "8."
        "3913641859492810787304674784341053014693270446678981564276345206432838412584894683772323627106734331361054"
        "1416581936570159334220486914190086840257940612625606332369702794070260260363486788238523036201758835057677"
        "5298560150181764281568949818405610899480408885000428278775808e+273"},
    {0x1.a23308e004343p+910, chars_format::scientific, 273,
        "1."
        "4139675630970964068757427171450653642480984699223731129945891669323413302498586940624987482328347106006806"
        "4846263217980807891598990769975307425626751189318159967805770045501337306828952847948820905736086031581277"
        "8238270061183253086797412098465350022320714292528734678286336e+274"},
    {0x1.adec4218e0233p+911, chars_format::scientific, 274,
        "2."
        "9072116249125091042939641046412524813869995898197412985742610942841277694000191408581191975005336470406860"
        "8670999527092918316192574758132203457803702842095218262638389308959004912152377412018312352260096133426289"
        "29616172359221046711196391821853929650939211266126599721844736e+274"},
    {0x1.43575d8295151p+912, chars_format::scientific, 274,
        "4."
        "3729772786894278772365021639725627716998749940973044545992005554096377244645619407904548756693601776261605"
        "6152952004922597898719595364079241320185751107634778684879091923536788821539360129388400052441674499939002"
        "25872455306119622800921723936421051368987504900833416633647104e+274"},
    {0x1.be237fd05844bp+913, chars_format::scientific, 275,
        "1."
        "2067462091729204821705996332843518364549184819962054996414528185176897061805656617790934688110747687253529"
        "5544306710936939451090047765146059368821612654865459656462252966998392455236514266859434922735356209088047"
        "813317803540270554003913049746492043246213723402668101888638976e+275"},
    {0x1.9b2ed63fe7c22p+914, chars_format::scientific, 275,
        "2."
        "2243912429104520893942654928612862245652916790922677520426543135574633357874274265454057414544428592629568"
        "3796964658643810060103302362801047962335174283932176205460605605005617307935818958118860615338703168794392"
        "925077735391135331507600083390485205139796785562476991788089344e+275"},
    {0x1.8f0f2f60d3781p+915, chars_format::scientific, 275,
        "4."
        "3176111022712280167867660225316851001302201103025801779751953430446989655794342643320229462126147375696598"
        "6057754614071827730076422192135164453903891238489923349099709102388438790681497597224304990926662001012579"
        "367979653974531063520144552196830827397549438193507868325445632e+275"},
    {0x1.0f15d62fc5633p+916, chars_format::scientific, 275,
        "5."
        "8659996133632342527001688155338604828401105070265177949168444721384708318888625799190903763436682845675922"
        "7306284715963508222892046333736999261786975277280777429050552743479409111642363144164702524788373433324848"
        "215428458862120335468197775176023691718933345373884546130378752e+275"},
    {0x1.a13ca388420aep+917, chars_format::scientific, 276,
        "1."
        "8057130538588834061048515934756534390995822489129192711153743070686906337113213930488158590783023451845083"
        "4651614746589574435978102564052687814920235501288032606984645988911873437050795965137276804729122742273770"
        "9200512048695849494656431906847973487558358759169627465021652992e+276"},
    {0x1.362f096e14122p+918, chars_format::scientific, 276,
        "2."
        "6848194108224777937082562383506307368133432936919747599586612304240456657094417970576945341505202731025352"
        "0632752982342719728088743709847151084657234962263380932275542718077487586432626777649283951018672398397489"
        "3363047437618046657896564635520646493576084143889699133523492864e+276"},
    {0x1.8fa644035b86cp+919, chars_format::scientific, 276,
        "6."
        "9183940909811462267856874429532960053214473707563125892325174523868752693267436284447579323441695765517285"
        "6461752013313380421614617466134738839127312838144728166026552309098455007679065231380711981036221944925591"
        "6170496306109571246026337759461802379014512053313539039259787264e+276"},
    {0x1.15b58f82ad041p+920, chars_format::scientific, 276,
        "9."
        "6149348499063526743580344354791228259201017811104329003387392966700402965231618105168720685759553521422977"
        "2969122421092284303078177102786518853954107198000838782620800583313899806099610317077183204555144851614542"
        "1691615264016637411219377961498887240480935611881565575031291904e+276"},
    {0x1.f7e12b4722058p+921, chars_format::scientific, 277,
        "3."
        "4890949511765381917564489227625018979093213131187560258974574296412643868128154485421838312923799775150875"
        "9003316961232195921638521029189519961907126691803128371022641904028323108603719958360190246770869300997950"
        "38164349707939106070027734238634052910612717651260495359532597248e+277"},
    {0x1.b833396267bb9p+922, chars_format::scientific, 276,
        "6."
        "0962977207855186085746743770786866262858276275147849851959864674542242692534585216614320573201966495522684"
        "4025068473917567647785710745382815112116621538896778982052242681474360748602092434215393751764209878376730"
        "6117947376901223073177337953389454932670330342413819437144604672e+277"},
    {0x1.14ff9cd90c1c8p+923, chars_format::scientific, 277,
        "7."
        "6722620777448847130061796967153409035280000143520385310098455611892015953736303672977253557984136122161764"
        "1855280039261746154536109173275027345666993959003781623111625182923681709420935853242720927515701234022138"
        "97816199751137235767500308035447734094150706669707498282849140736e+277"},
    {0x1.3b1721167a5c2p+924, chars_format::scientific, 278,
        "1."
        "7454649363112346458114019774333177916866258109488378818436939429302078045906152707336731339732354531371694"
        "1228055475050043477580785364864935817555122130690642448975527407028574117711690510070820468159098253463861"
        "923710066771866278518787343952413380888028548678629320352600162304e+278"},
    {0x1.8a85c622c377ep+925, chars_format::scientific, 278,
        "4."
        "3709703490882645460547143745214997008005362476756005415933050867512306390155350060744401126622118183385628"
        "8935916341301053038413513553972091488238540498015095359572244498057448525080787377489166010463475091450891"
        "077867871890421144700651238367267845567414870002937756298860560384e+278"},
    {0x1.e4116b8770eb9p+926, chars_format::scientific, 279,
        "1."
        "0726114671866102551956995063181805410834259689461649311344404290995629835609285447093274145176968382209577"
        "6917302675169618383427699560030805008762564142832457663950285524391007167921681697164854346295152420849109"
        "2988143024833061601691689500187256255660717629109506653574802702336e+279"},
    {0x1.2a7f9aaaa274cp+927, chars_format::scientific, 279,
        "1."
        "3228423831361687349286227308475220689391231854842087295811247105913948608236089430096611789280877039362419"
        "3685744676257728697617300128153225560718497346830092449123962427997239392877784320723478193203713049316253"
        "3391015168714982268831422978156810759831148502703022726522467254272e+279"},
    {0x1.a112cefbcbd73p+928, chars_format::scientific, 279,
        "3."
        "6966520737709448562733517100815008461375735122478974319844006900499629823014306882648742396218913673903183"
        "5461596068574474985809396613938975088998218789612590775661930938869393235058776456670475387448381842545651"
        "4513165432860037804808051299109674905178839116525770357448709767168e+279"},
    {0x1.36a61081043f2p+929, chars_format::scientific, 278,
        "5."
        "5067521766553316365405027111879142061254413625271933177107069898070693174397408489738092892207866286482884"
        "5554683734104354555516180291558086314950736248180147530492954485185572182609677010072096843339571865071862"
        "178828666956936942499956139255069398138943922537089722379860443136e+279"},
    {0x1.98a5de28ff8fbp+930, chars_format::scientific, 280,
        "1."
        "4487895211141177065279488132777108116369718048416908124269709876510583237549918320826970379166384928483716"
        "1019967289695505122642072428382029305751309173352444213166148718207712764857116771438695299098448134310869"
        "65217307420056734039126102817769912404692662944189803753694493147136e+280"},
    {0x1.a53cb3ab922ddp+931, chars_format::scientific, 279,
        "2."
        "9868446101560017108642363680724015778812195311497478659672452525980171949720889266701711072171369061987837"
        "0719397873902392998888281790588552992933134932269907085753375411494921811461160297454476748326154204304000"
        "2632972792550636638956325947677509230573449759918627641766761725952e+280"},
    {0x1.6b6f105002edfp+932, chars_format::scientific, 280,
        "5."
        "1539637484359395145169998086608752414201287314052389550098572221666968199721428219163097111568025636009928"
        "9868974947747462738997782687742154327301151940704590687700939863040862556558535022961081423132129579761964"
        "34291429763959675488362249598031403354267911828901663515648043515904e+280"},
    {0x1.e1d1de4ed51d6p+933, chars_format::scientific, 281,
        "1."
        "3665660611345062300699415815156476698279049368362851304007368637846199054342285443988800802553372187636752"
        "3248917337453828432049841686697470139687419077855970402061884421298998636269755090181183266935109407044815"
        "321573786764986943900426058733725257337715070032077314544904538423296e+281"},
    {0x1.e13c425396dcfp+934, chars_format::scientific, 280,
        "2."
        "7298170376572543250595176058691059999798358983466020300175306241793194709984671670486033298460259585304738"
        "5017283331124297567037148310322911306994303912107766046694422982692238154811689038581436612976816696375957"
        "55239772226573822083165523805843885336942248086072157383512333221888e+281"},
    {0x1.68969e0aaf976p+935, chars_format::scientific, 280,
        "4."
        "0908887634365658052312311982281239969243017093157788635282062623784275846881594265651752794514038606902310"
        "6800674077822316855396294054170407702247910519199947866095197666860418768314483510897116866758790077807822"
        "28895035770669972426241339275644547073552005426085299679806831460352e+281"},
    {0x1.3b22da0fe1911p+936, chars_format::scientific, 281,
        "7."
        "1504633857438940571491623978721892914354286180332274833165835417359788838288174535897662032205925659473829"
        "1254467838197118759246342696315600723602737684766259628091374865649497230897798288966582459879507593177766"
        "553940950035435273202528651698676033968867504991057070045076471676928e+281"},
    {0x1.4e66e432f39f8p+937, chars_format::scientific, 282,
        "1."
        "5175210833272951397317171771093120533028700691071470081130010387044118657798964008191234121591053953108259"
        "6955862088695509774556450307706532410525408486178691764933071097832767619332513618102282556325062955506942"
        "7362782422201363564357317874795808595718985906746009234596759127195648e+282"},
    {0x1.cd42a1d8134ddp+938, chars_format::scientific, 282,
        "4."
        "1864125891654217678987160154326130560240863001735941095698054511092958063809530574780247432322632198663136"
        "5418302622171023894401032790833087273703184694721039596481868281280184720918524292021207074674806905103125"
        "4669662460887222261960281257747458512455969074216563763504450258337792e+282"},
    {0x1.5f2cf251a2c3cp+939, chars_format::scientific, 282,
        "6."
        "3745607194970414607011473297486321194408851855271826405209841375673158509178230157700838425649741315965153"
        "1787490773156272736941819746003947498415541918165918216258592523898070563734402123829915274799568966211125"
        "1632663075464418798824836792784408317689148157466121016089825903640576e+282"},
    {0x1.adc9e02b49a66p+940, chars_format::scientific, 283,
        "1."
        "5603097675062574896758887904284580014666588747292929902329386364783921519940435619097399070201464392502002"
        "5028890715059060477997149439060211939278134179325873422500374642911646757317084990080920453639258554845618"
        "13254903791863073045978225400887637841137225271718710407150443264212992e+283"},
    {0x1.3d3363cbf2d84p+941, chars_format::scientific, 283,
        "2."
        "3031389942941909352268527198234496379577068396336203317744876815161576479976171983520659455831024723099078"
        "3953912653441338360925646235294520011231816869933421886686303955035200196869516409069207975791230779110053"
        "11195074484622555449838749756095271033619639701182005144598929173643264e+283"},
    {0x1.d766f62bf7f84p+942, chars_format::scientific, 283,
        "6."
        "8455374301622028192436355472823846238656305230521706558129242344936800002020518868868064296400530352191789"
        "1034466226790547106518246010636997952128991451178947162684434339703836656537748396801799020313050219717687"
        "76346231778021269958063780588872346431583200394283187585456728088510464e+283"},
    {0x1.184991c55d18cp+943, chars_format::scientific, 283,
        "8."
        "1404701971339317344287383067486540221247016756955967093290383812811465088446107352280408680080482428195443"
        "2859846301022972599343792584032105393017442786371538959565030349794777528390097804778412027245663634510470"
        "78458089708094639868097495758509389693820290367400727907449779154583552e+283"},
    {0x1.e8b3dcebeba57p+944, chars_format::scientific, 284,
        "2."
        "8387070865957636043552264602157883541550621494567563701536179579776139163837320944226018566214448421682813"
        "9146714994229625209180111000906234680917576834864249534875261446994701128847388085608386018003065108691566"
        "848732851954616351985795075190456971406831718621827217641148650350444544e+284"},
    {0x1.967cd81cba730p+945, chars_format::scientific, 283,
        "4."
        "7222972051563224519350338009022716573803303881667812490788444725311840770556623092940989186835112772635211"
        "2743224783831438285150919074036999996137779134053001098115781992438186495543489249860281381207407832543648"
        "17662303876106820974135357911697797680185476906504157324030340042326016e+284"},
    {0x1.4cf2067674a05p+946, chars_format::scientific, 284,
        "7."
        "7358664988354629632820980491003531438355880596056791221819587355464733593010437851133428000986535843768202"
        "8813397315792428439760217722967556525317392550436423184707427411650596408077787470781836258444845657566221"
        "704456125209427655591152156570845479024339183607328000005037882486030336e+284"},
    {0x1.396e85b33c0bdp+947, chars_format::scientific, 285,
        "1."
        "4564946206181580844592084594207704222149275365767779002797711189323700501615565216897882479344696601965798"
        "7214001805314729196086011578252425814811977188275322843971098040849936431617543662738225046601518261128113"
        "2374308583508656325781250344038137418380156687680087240907535210346708992e+285"},
    {0x1.95206484ce576p+948, chars_format::scientific, 285,
        "3."
        "7651875364112937676079826373638285134656210548344094794627244719878759497617868910191518550757132648757165"
        "9033638473170496163259718929694674503055426759572449412069792075432533362901496572181167769653683164853916"
        "6571141383041739341196077037239708754641370459694088122009910159310061568e+285"},
    {0x1.22e9ba39c791ap+949, chars_format::scientific, 284,
        "5."
        "4074068333403965226750981237644983456668479689930940152267176801225028318769667357940376329074605916431061"
        "4179228438454115201658468909272669836435242142312208547792943910580280672735394813258979591343794568202162"
        "709802027713568619488866942294475102931728455399763827049938587391885312e+285"},
    {0x1.c10015e885bf5p+950, chars_format::scientific, 286,
        "1."
        "6691777225183442734155493695184638662590904633258100472470488533590977930515304351989064823049973327477126"
        "1895692018476435316799054399140695210497503507401916469005762783991428636380155890236982018335960721659795"
        "82528813031375076284990869886696245331704707225600453047248955585985511424e+286"},
    {0x1.7e47eb8f41b03p+951, chars_format::scientific, 285,
        "2."
        "8422910937483828159205881733190611988529916891665780536131260943457118685939406072581634351428299546320576"
        "0396749473544096221941676146479809429276884413946649887699651566840160395628585821920358023898327822565882"
        "8951550681268637687054413812030526818138559282485013293056231248488300544e+286"},
    {0x1.09d0d2a526197p+952, chars_format::scientific, 286,
        "3."
        "9527246153864665566951087294778578304623889883636970224893978854523038111797720316090827413947493083212896"
        "7844722249273717902614128985252239037734888348980268366864611317692974660014186053407372696445748574503415"
        "78296133621137927482641494123749218905855394522144524531019546018141175808e+286"},
    {0x1.329393888f7bep+953, chars_format::scientific, 286,
        "9."
        "1176878905953285118279701136005401786587902760102270865436829998885338329626092321640853120778010712669451"
        "0373698460188081841557295489700487987719867168096915145773718173158124223634025462177100914945077372091161"
        "00467436142545614804211132806327613747648211271222880398152942507767365632e+286"},
    {0x1.bbe7721540300p+954, chars_format::scientific, 287,
        "2."
        "6403715176860095022699449053141968576100424161884093294931549571262319776369831347356407500008594345868578"
        "3886670603935896834566016848681232358712602776606616349498486554151807746433631049948801957261905070980866"
        "218863512709255609194971921954793897583681193907186498977864992248177885184e+287"},
    {0x1.88cbea96e97dbp+955, chars_format::scientific, 287,
        "4."
        "6727608713307191811731595008960375298221325983796687233226799622196366586451734089583832057742414188524729"
        "9790823561171069651344832529105954322176333404979396460587010550966330585217753352905079690163268052230294"
        "873047744394947965285062467179754729677808277337626448692513961219618504704e+287"},
    {0x1.92de904946e55p+956, chars_format::scientific, 285,
        "9."
        "5851774967886283871424703550157422124862389173600706586104269250302149909771530581521764503566496817903367"
        "9520425155234935074360538133315694704204458222491239262475671332493078637032333046742899762907560886122978"
        "5621372421990248839692190711668885475704463446705424081679053506515828736e+287"},
    {0x1.7f42451f5dfadp+957, chars_format::scientific, 287,
        "1."
        "8237197308454679352521332889696823507212561832000261520249663849022474903193953062064507777750007282782305"
        "5844688987995889659167464398927070015579969304644214140035552340033653858384364990460291650066492163131472"
        "465999824312979406250066151215209790239504641334422284329371377930367664128e+288"},
    {0x1.5bcb0fe12ff45p+958, chars_format::scientific, 288,
        "3."
        "3099160671433535093084224672514360647394401123276052039350234673929255835025285679433814704400572813252037"
        "6316165403379745915463564399008817557713505803494239077292826673093202008184035941299826077797306915047648"
        "4721278024806918523029143876241835657869581941341018295520569998556732063744e+288"},
    {0x1.b90465a9c592cp+959, chars_format::scientific, 287,
        "8."
        "3942399746957991372869078281942404020217477793793748903487486836539875121518532182385048730991315535450129"
        "6066292673473655572134735382616456106780997318254265930532381881591026489637996542676756178814917207512248"
        "505680859658549636395147348969378726384175323964145648049041264030901075968e+288"},
    {0x1.69983d358fd5ep+960, chars_format::scientific, 289,
        "1."
        "3765053672754182859184546827995562817441803667851159142923805357904082337163005923613594490300620268879646"
        "4427657272680934322903126085125682986499564607354990434217242316960377563197108819664566707746439333948168"
        "39437145361195475585915790038086938448416859756069308137927266057545163210752e+289"},
    {0x1.de946c1935bebp+961, chars_format::scientific, 289,
        "3."
        "6436798293267568549903218347518137574726651717741644105751763536191250266712661451258775255635605998228834"
        "2012901246006434091445910044776272477500560046621628838893089250628068867605857325914011568299359415141634"
        "37151042307371112230166232390702102964620484295971653304142427375365317984256e+289"},
    {0x1.b5842f82a9de7p+962, chars_format::scientific, 289,
        "6."
        "6620847115568887370739473756442065065681196769911331682611092496715336718715155596977883617162878523841449"
        "1195244228805399554716468352898840685630426142198562600629075173101466368672042990656845441262776494523381"
        "27010045221858188132828582061277352981469985490408290156135533130942236327936e+289"},
    {0x1.e8b22ed3af96bp+963, chars_format::scientific, 290,
        "1."
        "4882800748283324399977058469272645928472632851629916206349194579268135708884744967243751899545815918258106"
        "3564764212811724201905328910445324121906120166169993601247788259189151502783772871311029419856354319292938"
        "359404923519710627910962261670847242925348963282404187971202996261023196905472e+290"},
    {0x1.29a2da729cdddp+964, chars_format::scientific, 290,
        "1."
        "8128485634074353186651032710851418799765830191648044920796289939797839866554628583160057708287641508147835"
        "3416991660757155282539462744077357077960029596847454004479999761152595114534845500036614198015631414265590"
        "188431157433539282197161887547513163560678186514777300223161756952567350296576e+290"},
    {0x1.276a30d060d86p+965, chars_format::scientific, 289,
        "3."
        "5986375764585901118401173857435431665393344228134043195993090267211557335482517408403998911271835938466563"
        "4578973486033515015557618769168149115430241202530067649619624893103124735795226961094794333422439468435787"
        "86100004426152086227134028234892112366944314773819711221653221244284711206912e+290"},
    {0x1.d01246917497dp+966, chars_format::scientific, 291,
        "1."
        "1306303530723757551379347540230283878801067046195789878544591357589053690252198317196318305608292471048042"
        "6573510425649333447216391174783435354024431883709870993191165042801828493609577800703214958208640517708896"
        "5595898416550699038646583977157339794314844188021211564490649717795032156602368e+291"},
    {0x1.980e6a27628afp+967, chars_format::scientific, 291,
        "1."
        "9883184243838976730410932296903215043773257347722139793282731020043769627897711427696892214094944056155874"
        "5773532880255610721204868508010113425199198024425077564874975290911000083831287880616319091923858196094459"
        "8491001794144386958052292241630342045252697101128134565354695877741983337283584e+291"},
    {0x1.437c0e85d91f7p+968, chars_format::scientific, 291,
        "3."
        "1524589717279720882715225845768415950174764083504840242130204263516013060098749586913055034958731403449344"
        "1208372093650396142197066540459113834187404379707141906158973632298825086025212231018442536491262443437671"
        "2560730512038580641775599869341924017562703624377521765695489143064395748737024e+291"},
    {0x1.1ceddebc11368p+969, chars_format::scientific, 289,
        "5."
        "5534486584838894985815395255332155554599222908321054704554473957783188087561644658289781622997765571377498"
        "0254860361303679922893002057120030214741484590883308892758826467544136194783289890892705217436463378669760"
        "85508090123985182923026778461906662147231685595323631215481030751756287475712e+291"},
    {0x1.f13408b3aaf95p+970, chars_format::scientific, 291,
        "1."
        "9381607498203373586175696557817944812659064403065108683262190633961372055872685840153949035085668045580572"
        "7271684831698888135449531590096565801574266515822704900761718432653313668573988087518548683433349503352718"
        "6285257259315270330716435545570478575822448445079861238076872636591806374477824e+292"},
    {0x1.af9922dbfa336p+971, chars_format::scientific, 292,
        "3."
        "3648478963002968698620423749283072504492485899019735249110361788561863970431143842896181333838683458814612"
        "4598595569278258609624938998649618367547993361532806816462567203005806179903282570174127495161186670335196"
        "17412877924128534588246437115544693678681843960583893836646823695670362570227712e+292"},
    {0x1.b6d988f35196fp+972, chars_format::scientific, 291,
        "6."
        "8427657249419059479161154927363270143292784372199950777274871522771499071305503708562954470769408862138873"
        "1474802374325885362173627703481269107443722893324474773474281616910266293515997961386896447706754207733557"
        "5352545540331475643945411254688238428244331792556297094231236390216163573891072e+292"},
    {0x1.90c721972c4a2p+973, chars_format::scientific, 293,
        "1."
        "2498259387089929987544604729229201047461183081001696695911791985667564169201445962180218662664297173257224"
        "0783416001704506170068124680312031816753145674679063100504319414514800555672293921190439313027282851410416"
        "527131226964653068028871701489323868875661390179301613620908627438519900539191296e+293"},
    {0x1.7fa5032ebc8e7p+974, chars_format::scientific, 293,
        "2."
        "3927916153858261394393006439111464375589591262939067880984703699387029997954416886187764975960375716663774"
        "7324929334133616973952797666607621630538557419287541059322652029872252214901040277415927729164527443341573"
        "258308076333446631106547639938187560726465677882789688970890598968747947810881536e+293"},
    {0x1.4ce903c008152p+975, chars_format::scientific, 293,
        "4."
        "1527226468994149805883120008216062805649376308762924758560595432241225459535095755829722726323538761681810"
        "0109244911505753906925022700052492277437591209390165152181173369747026248798037383291310666381029548454305"
        "977457986611411122735356736460608954225433970661515041585228932440487179403132928e+293"},
    {0x1.1033cfd825bfep+976, chars_format::scientific, 293,
        "6."
        "7909062839788017161866710428443273408843243572583256912137828809643937252536360566057575321962392476516410"
        "9295373824489237150025478824159009080880441253418086991920551877762452038557858218260332182171547242362745"
        "152998922247516579175346880356048429165046724254554702021353471037187691525439488e+293"},
    {0x1.0fcd0f994c6c3p+977, chars_format::scientific, 294,
        "1."
        "3561785760749323678669787265688365565689640949708619714054160129767110601805174279033805933291173229630234"
        "9694534389824422263920901953135120658800068583587102352433525536899095571443676695780068738425864348615998"
        "0898573992763548701523679724999841102526974236295406990913753746951524692055293952e+294"},
    {0x1.4ecd6004d6052p+978, chars_format::scientific, 293,
        "3."
        "3410590952598420317059089548905939025834628916093972522457623516814235244321423895949768406189130633668431"
        "7368760484815919204021605264468860090297189981381875925188997129387661959794324528266148926422168602715973"
        "167909073172803760343055337031341509508280546224566941805289330430780015789473792e+294"},
    {0x1.f3efb39a62b6fp+979, chars_format::scientific, 294,
        "9."
        "9779308814775026726545238938108225391742620151815475280043733999141726516502805101140500365178512807293103"
        "4832702879081724884796354724298523912059135271846012848441298235332887232423280512468585693898553460251806"
        "5129004909212362943512437101234020643757629011735714458250584381888822081044348928e+294"},
    {0x1.7b90e1f7acd5fp+980, chars_format::scientific, 294,
        "1."
        "5151060382509119303230072696616085397824006138244852698231578717068386499638092085604311976614167334172105"
        "9067485352359019807084574101981846207880933834777632827789527523390586536598629711121476163740733404587356"
        "2403590243000174027968021709791613049945818271254046076631622631725402432573800448e+295"},
    {0x1.780e24e541603p+981, chars_format::scientific, 295,
        "3."
        "0021849100893520243358225574670889620815156554449574573250051912654326113987284835353145201676673525718887"
        "5042697881806641218419106412453534354493043518552141426433358045973160321134894604670081881182357987680597"
        "51952649200503215287587191207086694028505970883124170608147640357927402985570172928e+295"},
    {0x1.700d3d3809014p+982, chars_format::scientific, 295,
        "5."
        "8765795963279930227848103637865601003943787056531376360036302905273752521105567528286745985028255384875457"
        "1490356367965241471404199068974466219719536013881180506072840356357417288376476202174117730455929024377704"
        "51522858269571663877746249378744932425279354599869012839882446798078904889967116288e+295"},
    {0x1.b688d558b5f6cp+983, chars_format::scientific, 296,
        "1."
        "4003917488295084275613719898286286543900946543796852786205748340103098176869027454271933921365124713506242"
        "4840043468664495636032046706208223098253951876889452581163756835639997767859551976134817039860523484461440"
        "124895585825179963559084955205686769325898379507940166327523415178499971301572083712e+296"},
    {0x1.f01912b454894p+984, chars_format::scientific, 296,
        "3."
        "1684232621942047385277264101507039556067440169362731047612881416017992423437710611846555322044158342722398"
        "8915277579013362002270444501078942736494131042992360048146233701817979552518486745549641868940508520247278"
        "182505289084695487280862714932759338066051522762627957622658669625057321641956081664e+296"},
    {0x1.1006d98e085bcp+985, chars_format::scientific, 296,
        "3."
        "4747005896842154056766241710224939253278957494279764707850526147334614495212661112229513392271233912156854"
        "4761851073506353853083647800598515099405732155724640228045952982796489208783132715430406627983166405192131"
        "258940257292542957476413248506076428650670534137201954640611227376407648222278844416e+296"},
    {0x1.2c3916e2ff373p+986, chars_format::scientific, 296,
        "7."
        "6697238550212685960832609911276146098915770657253390727731460462378114517962252738218713388984402744753410"
        "0644055244350474871367482438375619745138608308231095636232712461705478444271712793592166311581253206635330"
        "061153560207434566610596179623433497342212224379877437918600098792472693553791762432e+296"},
    {0x1.0a7487f857db1p+987, chars_format::scientific, 297,
        "1."
        "3614131925096533227358277304297327605620010964674273390519175146101981086716462390034963821779924748785739"
        "5620080532481805188047066315188930747903484713798353770585361867802872024778497522376969002439422146205889"
        "8780565314051488693571227506727823926105057168671455333801700670110926825836349751296e+297"},
    {0x1.3857c488fe8b8p+988, chars_format::scientific, 297,
        "3."
        "1917385509472622401741963902741798316020842891467372871639114279968501540720074385793183473550289230847540"
        "6531346952631945194501572201677681050736517236364445893621440519858256212122392536962698668571902046039673"
        "8617495507842843305566526087166039077960918279884459165757255575108034221542182223872e+297"},
    {0x1.b2e84c3dce473p+989, chars_format::scientific, 297,
        "8."
        "8883788439875624185164207745360558758802155875037125198532849056736078250163752904409270711399254253418185"
        "9444469734700030661866983137618978336282843998992322962605942456269502254865698961974528361768428078473937"
        "6094743421421524562002257540912448826271782010926639892392033944710549976982451388416e+297"},
    {0x1.71b76b7215201p+990, chars_format::scientific, 298,
        "1."
        "5112090835975456482691048470324136676461824411038137830875000839223319169242464768082370414035660254169158"
        "8669702780170871475227529225060662017601645192869668212722869526766762356560983217401072411526986055426607"
        "99442146505061129659657887076900042124590387275392937317008374397153245502302047961088e+298"},
    {0x1.21b184ed36242p+991, chars_format::scientific, 298,
        "2."
        "3682327923940455929074855404731835885200530396635967368041051592757206624858645698626710713225571745269233"
        "5729523644634975306222812534323302164949695407936710130084944345102224029476194227517181154705890457539653"
        "96355529469848408434057376579487220386627111660172302509770187382123275691926545760256e+298"},
    {0x1.37ea2520488ccp+992, chars_format::scientific, 298,
        "5."
        "0997804211457324301727969780021784932196577737124651974461574335281416292911140537078513800349516058166230"
        "6651023989265093968050976665439213325512154024914749918341591104687603878557877081517277860278457895962747"
        "15728449794070641109346128933556201664107191668445099152331696871514428213048815648768e+298"},
    {0x1.4664dbcd00eb0p+993, chars_format::scientific, 298,
        "1."
        "0673033377644725582076128279562256890020762752598912707261862612904605628388963403061314485035461507019337"
        "4438490926195154270158138687327359040657179392440930707711924166182794806470598924879805421312001727703958"
        "91921169134687535785461810688709659897643411981471381983104303837230721690128649027584e+299"},
    {0x1.6b9cbc489e09ap+994, chars_format::scientific, 299,
        "2."
        "3780130211770008635428798028054955143428405559792922085924082125222001207510564662620683226057796019174145"
        "2640417453863555219098122994555479241353169993047264294675297170597532090280617800437689617268886207229285"
        "482891877778657703920272278134074512640642342772726595535234502682602103798938923433984e+299"},
    {0x1.f513bbd25d6dep+995, chars_format::scientific, 299,
        "6."
        "5540577282820882734089899386704195345627846540047499645059907995983845109119849454543083195868777805712470"
        "7092461551987548003257290398700713345661594829621158366035617643372206998716563232961936757003882276959122"
        "708936001833829616557908400458109782703568488107962693518959628276723172599697604870144e+299"},
    {0x1.3e00e64a007e5p+996, chars_format::scientific, 299,
        "8."
        "3189331614742082391382447830313932954296861496924533518176874062021378195713696724616314709052435687480452"
        "3449453858407989081548890726447004714405286583963998060346441841261849601799117052047643487147092979557556"
        "891805175387244452772540164096096030738843539931931830599736589422869440330138761822208e+299"},
    {0x1.04358f2000393p+997, chars_format::scientific, 300,
        "1."
        "3614082701057758282991605516975489579288117474695742577033267689441829157997449528962630396276072567771846"
        "6563277978974992105381629734827673730338773434105077041481826605239116869440810337790164272971883723549343"
        "4622743766811503326558480996563151364510469225186261976905322157612487935439550111809536e+300"},
    {0x1.ff5ca45dac07fp+998, chars_format::scientific, 300,
        "5."
        "3508658110149902849421928428493905625870487322421898497682154406090765637213244572176099715326655431494367"
        "6929591673829631099980279628704586394230462593528555533852816968992662893077336730158326155001020626526239"
        "8738807874995959199986290114910339936114860975870138690918797206511003398780232983904256e+300"},
    {0x1.95dfb7963208bp+999, chars_format::scientific, 299,
        "8."
        "4940892966758526585494849182126227433166616658121716121221756680064677734611539033378080479693086528432595"
        "4264187555897655767726624817103774897165687722073995863869146194224654264271815412764432183860307112674231"
        "109279315205969947330246145602344386623802171762035716381797595664546003263242377363456e+300"},
    {0x1.042ea27af2ccfp+1000, chars_format::scientific, 301,
        "1."
        "0890134027784214313930348009402099228804786388308427577549589000490524838171536880083316594376503360923820"
        "3927956167113377874488765241234494902547691411017945498443986695825206736398283043101155534160891992194911"
        "53554556979108530787196381372092387340130982723560970359575450657479047437786029202866176e+301"},
    {0x1.19cacda6d507cp+1001, chars_format::scientific, 301,
        "2."
        "3589278771025920045285827982461236796817036300877185977488554279335842158782244191985990632926121503077907"
        "6520003666559211241592367336689930498536187798295766946194279734738125370727052729831736723306360154337779"
        "50412177760641174727204088780046261172088405036986621286405986734378144157024874903109632e+301"},
    {0x1.e4dc48c30aebdp+1002, chars_format::scientific, 301,
        "8."
        "1176903631052648655337080884157138757428798522929058319900963020890052053982712181300446346333787829121700"
        "3535527368462203251795552837011494935291596633256317483032620863293740739496732466044546947952666250308674"
        "72373502272570181905030453820398128968285453872513665526905113335684193781314404248190976e+301"},
    {0x1.16fa9da90f9d8p+1003, chars_format::scientific, 301,
        "9."
        "3415114267945876208367248131098341912085530505203943017270044503863132197893962771450745275333290347854810"
        "9960600140509742566153709652479468336022888542206366778998821244811822003682844389359377244112197477553800"
        "16760116417262780962600310403215068957481809727018548258602677622354836648271052026150912e+301"},
    {0x1.8a86318c46281p+1004, chars_format::scientific, 302,
        "2."
        "6421004320193599222220643359148420883281556097189074913758318124048616315511138834598140417187849490396791"
        "2440800658786078681336731143970379155380439690121456355674188789241410064996533294508126717933561959185778"
        "192754757376080092862115085847862393689963492786526884623762776875632820851286300067627008e+302"},
    {0x1.ff462fd806bd7p+1005, chars_format::scientific, 302,
        "6."
        "8479333893788643349951954373428706271337676580677545656111124234548678899530140198122640316703808141324695"
        "4111790004996031828015000205150715078148983240637243871500082888421342977620123039374551681737977878655788"
        "295179567168650606205377274978890097754212420262333936960341237630114805596678852383342592e+302"},
    {0x1.9abb3e1c6258dp+1006, chars_format::scientific, 303,
        "1."
        "1002556200184007023081438741792890947080762576000821563629014332834749679952244487757753483300298253507845"
        "5879206419534204227221954043005542510983229083842379647414279802190829035747238306982534802408454663553709"
        "1282385282353501007663737911321641626869306594390707034645320031413007213532753781288075264e+303"},
    {0x1.de0bd3c1f52abp+1007, chars_format::scientific, 303,
        "2."
        "5611530892094994514501088831871358384319448903452892325625676707904740327849930775175514338249741969657883"
        "8592308971003886423987684696984845619865591327523895036972469545643509680781096997879244741733146429164959"
        "3820790500115221658520513179659203340914713114632244088248136782610390183342216645609259008e+303"},
    {0x1.d9c1bbc9b76a1p+1008, chars_format::scientific, 303,
        "5."
        "0763445855374758137611513292718315449629948838655962307071284681337573494863787181114031880088015506956421"
        "0919814812869947242304860161660008686121237187656925137779489232921913748608997417433611598970782898218677"
        "0681263550628277966122021347502889218558140981978778760709565257654468755221733041969823744e+303"},
    {0x1.838389973dca2p+1009, chars_format::scientific, 303,
        "8."
        "3044878325009487636657872605880027931451341062254646176493301760411427870881245765778811788634335139822887"
        "7791768181558515981788246801785667173521110223595293418389986293158864840334067858751178794788759593463864"
        "3446637560952598376682571125723765484978607914917947356221830413431528356893552064082214912e+303"},
    {0x1.060853e168c00p+1010, chars_format::scientific, 304,
        "1."
        "1230804446665463017778789639347990996643965714634023343815009161240780246270947713147897725931947017335623"
        "7630191092159383150643994991146787024266771551963955625126256769736294908917256990486304395382712939541329"
        "44471985636790260821195763195960709126795406948190820263635402442656971341237103098326941696e+304"},
    {0x1.f308c45ea73d7p+1011, chars_format::scientific, 304,
        "4."
        "2777559220816042653857310038704146366752118155285251665154411932831735245152145261165776711742388354156016"
        "9871993219430699069531917092009858059914736544226777968630260462041311221406320891386198960782539433597799"
        "67819804460846041770466218522657499957662378458077745646242495542457900501384540282123452416e+304"},
    {0x1.6e7f0598d9a7ap+1012, chars_format::scientific, 304,
        "6."
        "2832609674393123217939414786004721368347810148169532603823847060388742916702683157570030369865385378061695"
        "0423422570163256408545609818970072287306016643092924903391807737646611595942820189227413388395855318648545"
        "96993614806461429966237140466546002145002610631737886461529165004165330118612673778600116224e+304"},
    {0x1.90ee34c61a4e4p+1013, chars_format::scientific, 305,
        "1."
        "3747215164191864557360328902417183080909502773980053305016024875594667249734748345961089521445251491076760"
        "1613710309461048505454382577543819736591536450997080647994948699299372710947086154466989750285286987223010"
        "010358709717485396216234719231061846048602963736424188145247774330747094015196695990582116352e+305"},
    {0x1.e2a0a3d09f949p+1014, chars_format::scientific, 305,
        "3."
        "3096929273918683614869679916049042345119516535338947195012264325212922683474532459406639062854253866258135"
        "7719151111687362183898117765879272408632912053460554027589018196032181403643752217046446854545876459118270"
        "311328170300273241053563917737426045554632200608705001740820709150305846610578306477689143296e+305"},
    {0x1.c1f1e31fb56a1p+1015, chars_format::scientific, 305,
        "6."
        "1711334781978492823905176274313064600948013598950259705624044810976578137635336099364396791518714662842370"
        "9280516241948225398658063408258944026475600604367395551060529895388440736389998513454247897588963927412199"
        "886596463797584431228714343905526280539044788020033342657437500226579170692177128139530436608e+305"},
    {0x1.c021a05af3889p+1016, chars_format::scientific, 306,
        "1."
        "2292521010494213202208392120910347371974932861996362652215354683626354286778450977056457988823406607851862"
        "6637132565769582888977482809648230361989943269158655634268614343814815368836427061857244021348551127969781"
        "1055580445126773330393578734970725834547100511308555559785816417647601996123490828625750523904e+306"},
    {0x1.a0ba4fb02d02bp+1017, chars_format::scientific, 305,
        "2."
        "2862202954633178261723536509649685641707279850300290869803982420258862461647313576454922281065116456219182"
        "9590977426811173756270658087196535714508685519454569812805651039956703238427854607968636622055258647292634"
        "684121390540222150085347564627967335399432454801846311963425999483985877313898405284846501888e+306"},
    {0x1.3f966b0ddcfd7p+1018, chars_format::scientific, 306,
        "3."
        "5065941308845354984753464542431391007674227604335612148522065748017825104538844307057550895580408416179424"
        "7118416307944385786855208364451666760483209546178608196510513690039018180918045791524606584522427293544334"
        "6243739881419482228334516326372503115386643937845878401903583322133727281304761523559911653376e+306"},
    {0x1.f28cb9c6710a9p+1019, chars_format::scientific, 307,
        "1."
        "0940422247589227743316285257523446771149121608626559253104638931006152289125664762418837487890517285868544"
        "1970842686935351143015218862511720392429343778632449186329279729720913087020406559756094832031600186601946"
        "42090669215782471906632775672148557149263319590356475272060941885997193903260433671483161575424e+307"},
    {0x1.c941430ebe2afp+1020, chars_format::scientific, 306,
        "2."
        "0068458193014485659233690965046541577150222922448876802079698749594927659484925364079051863693079922549962"
        "3702340752679075101040300153750541846589137823389048924711303393882024589282733583930812172225616249563429"
        "7868168967936674133963531031634950024920744675243356304584274649234115658663895314346773839872e+307"},
    {0x1.3e04900b4e89ep+1021, chars_format::scientific, 307,
        "2."
        "7914963723745636433327098668092909811147302243780506069948228182283265947810001627803239111045172778906393"
        "0987072447572980908861942482392189431390905934840154072184967491283583766051866632563025027572585713651756"
        "30215388510334525743239925811352693280111872637884811742138711874263709333351600610928924557312e+307"},
    {0x1.5cd1470a36d2ep+1022, chars_format::scientific, 307,
        "6."
        "1236992921041949817714041891928528839786938336942322084137095186042961819813936048028926723548660468971278"
        "4969654586939917432251493887838173965737887781285740992515883352944011799461643423393002121460091055587179"
        "85452576260185887979241983673503558946414035103004649802078842226017422195444929429676453003264e+307"},
    {0x1.e4ed787bb244bp+1023, chars_format::scientific, 308,
        "1."
        "7026387749989901049352803345551957967504365590849171315485933257848664869760810216798351071186594668551262"
        "9849272947937037080011581203332426168619415862460756069100292337181478478510557557506918137532825769631310"
        "693972479511748662180221113394836543075210717029725044946195117678217681054268005181200990732288e+308"},
};

inline constexpr double_to_chars_testcase double_scientific_precision_to_chars_test_cases_4[] = {
    // Test the maximum mantissa, which generates the most digits for each exponent.
    {0x0.fffffffffffffp-1022, chars_format::scientific, 766,
        "2."
        "2250738585072008890245868760858598876504231122409594654935248025624400092282356951787758888037591552642309"
        "7809504343120858773871583572918219930202943792242235598198275012420417889695713117910822610439719796040004"
        "5489739193807919893608152561311337614984204327175103362739154978273159414382813627511383860409424946494228"
        "6316695429105080201815926642134996606517803095075913058719846423906068637102005108723282784678843631944515"
        "8661350412234790147923695852083215976210663754016137365830441936037147783553066828345356340050740730401356"
        "0296804637591858316312422452159926254649430083685186171942241764645513713542013221703137049658321015465406"
        "8035397417906022589503023501937519773030945763173210852507299305089761582519159720757232455434770912461317"
        "493580281734466552734375e-308"},
    {0x1.fffffffffffffp-1022, chars_format::scientific, 766,
        "4."
        "4501477170144022721148195934182639518696390927032912960468522194496444440421538910330590478162701758282983"
        "1782607924221374017287738918929105531441481564124348675997628212653465850710457376274429802596224490290377"
        "9698114444614570510266311510031828794952795966823603998647925096578034214163701381261333311989876551545144"
        "0315261253813266652951306000184917766328660755595837392240989947807556594098101021612198814605258742579179"
        "0000716759993441450860872056815779154359230189103349648694206140521828924314457976051636509036065141403772"
        "1744226256159024466852576737244643007551333245007965068671949137768847800530996396770975896584413789443379"
        "6621993967316936280457084866613206797017728916080020698679408551343728867675409720757232455434770912461317"
        "493580281734466552734375e-308"},
    {0x1.fffffffffffffp-1021, chars_format::scientific, 765,
        "8."
        "9002954340288045442296391868365279037392781854065825920937044388992888880843077820661180956325403516565966"
        "3565215848442748034575477837858211062882963128248697351995256425306931701420914752548859605192448980580755"
        "9396228889229141020532623020063657589905591933647207997295850193156068428327402762522666623979753103090288"
        "0630522507626533305902612000369835532657321511191674784481979895615113188196202043224397629210517485158358"
        "0001433519986882901721744113631558308718460378206699297388412281043657848628915952103273018072130282807544"
        "3488452512318048933705153474489286015102666490015930137343898275537695601061992793541951793168827578886759"
        "3243987934633872560914169733226413594035457832160041397358817102687457735350819441514464910869541824922634"
        "98716056346893310546875e-308"},
    {0x1.fffffffffffffp-1020, chars_format::scientific, 765,
        "1."
        "7800590868057609088459278373673055807478556370813165184187408877798577776168615564132236191265080703313193"
        "2713043169688549606915095567571642212576592625649739470399051285061386340284182950509771921038489796116151"
        "1879245777845828204106524604012731517981118386729441599459170038631213685665480552504533324795950620618057"
        "6126104501525306661180522400073967106531464302238334956896395979123022637639240408644879525842103497031671"
        "6000286703997376580344348822726311661743692075641339859477682456208731569725783190420654603614426056561508"
        "8697690502463609786741030694897857203020533298003186027468779655107539120212398558708390358633765515777351"
        "8648797586926774512182833946645282718807091566432008279471763420537491547070163888302892982173908364984526"
        "99743211269378662109375e-307"},
    {0x1.fffffffffffffp-1019, chars_format::scientific, 764,
        "3."
        "5601181736115218176918556747346111614957112741626330368374817755597155552337231128264472382530161406626386"
        "5426086339377099213830191135143284425153185251299478940798102570122772680568365901019543842076979592232302"
        "3758491555691656408213049208025463035962236773458883198918340077262427371330961105009066649591901241236115"
        "2252209003050613322361044800147934213062928604476669913792791958246045275278480817289759051684206994063343"
        "2000573407994753160688697645452623323487384151282679718955364912417463139451566380841309207228852113123017"
        "7395381004927219573482061389795714406041066596006372054937559310215078240424797117416780717267531031554703"
        "7297595173853549024365667893290565437614183132864016558943526841074983094140327776605785964347816729969053"
        "9948642253875732421875e-307"},
    {0x1.fffffffffffffp-1018, chars_format::scientific, 763,
        "7."
        "1202363472230436353837113494692223229914225483252660736749635511194311104674462256528944765060322813252773"
        "0852172678754198427660382270286568850306370502598957881596205140245545361136731802039087684153959184464604"
        "7516983111383312816426098416050926071924473546917766397836680154524854742661922210018133299183802482472230"
        "4504418006101226644722089600295868426125857208953339827585583916492090550556961634579518103368413988126686"
        "4001146815989506321377395290905246646974768302565359437910729824834926278903132761682618414457704226246035"
        "4790762009854439146964122779591428812082133192012744109875118620430156480849594234833561434535062063109407"
        "4595190347707098048731335786581130875228366265728033117887053682149966188280655553211571928695633459938107"
        "989728450775146484375e-307"},
    {0x1.fffffffffffffp-1017, chars_format::scientific, 763,
        "1."
        "4240472694446087270767422698938444645982845096650532147349927102238862220934892451305788953012064562650554"
        "6170434535750839685532076454057313770061274100519791576319241028049109072227346360407817536830791836892920"
        "9503396622276662563285219683210185214384894709383553279567336030904970948532384442003626659836760496494446"
        "0900883601220245328944417920059173685225171441790667965517116783298418110111392326915903620673682797625337"
        "2800229363197901264275479058181049329394953660513071887582145964966985255780626552336523682891540845249207"
        "0958152401970887829392824555918285762416426638402548821975023724086031296169918846966712286907012412621881"
        "4919038069541419609746267157316226175045673253145606623577410736429993237656131110642314385739126691987621"
        "597945690155029296875e-306"},
    {0x1.fffffffffffffp-1016, chars_format::scientific, 762,
        "2."
        "8480945388892174541534845397876889291965690193301064294699854204477724441869784902611577906024129125301109"
        "2340869071501679371064152908114627540122548201039583152638482056098218144454692720815635073661583673785841"
        "9006793244553325126570439366420370428769789418767106559134672061809941897064768884007253319673520992988892"
        "1801767202440490657888835840118347370450342883581335931034233566596836220222784653831807241347365595250674"
        "5600458726395802528550958116362098658789907321026143775164291929933970511561253104673047365783081690498414"
        "1916304803941775658785649111836571524832853276805097643950047448172062592339837693933424573814024825243762"
        "9838076139082839219492534314632452350091346506291213247154821472859986475312262221284628771478253383975243"
        "19589138031005859375e-306"},
    {0x1.fffffffffffffp-1015, chars_format::scientific, 761,
        "5."
        "6961890777784349083069690795753778583931380386602128589399708408955448883739569805223155812048258250602218"
        "4681738143003358742128305816229255080245096402079166305276964112196436288909385441631270147323167347571683"
        "8013586489106650253140878732840740857539578837534213118269344123619883794129537768014506639347041985977784"
        "3603534404880981315777671680236694740900685767162671862068467133193672440445569307663614482694731190501349"
        "1200917452791605057101916232724197317579814642052287550328583859867941023122506209346094731566163380996828"
        "3832609607883551317571298223673143049665706553610195287900094896344125184679675387866849147628049650487525"
        "9676152278165678438985068629264904700182693012582426494309642945719972950624524442569257542956506767950486"
        "3917827606201171875e-306"},
    {0x1.fffffffffffffp-1014, chars_format::scientific, 761,
        "1."
        "1392378155556869816613938159150755716786276077320425717879941681791089776747913961044631162409651650120443"
        "6936347628600671748425661163245851016049019280415833261055392822439287257781877088326254029464633469514336"
        "7602717297821330050628175746568148171507915767506842623653868824723976758825907553602901327869408397195556"
        "8720706880976196263155534336047338948180137153432534372413693426638734488089113861532722896538946238100269"
        "8240183490558321011420383246544839463515962928410457510065716771973588204624501241869218946313232676199365"
        "6766521921576710263514259644734628609933141310722039057580018979268825036935935077573369829525609930097505"
        "1935230455633135687797013725852980940036538602516485298861928589143994590124904888513851508591301353590097"
        "2783565521240234375e-305"},
    {0x1.fffffffffffffp-1013, chars_format::scientific, 760,
        "2."
        "2784756311113739633227876318301511433572552154640851435759883363582179553495827922089262324819303300240887"
        "3872695257201343496851322326491702032098038560831666522110785644878574515563754176652508058929266939028673"
        "5205434595642660101256351493136296343015831535013685247307737649447953517651815107205802655738816794391113"
        "7441413761952392526311068672094677896360274306865068744827386853277468976178227723065445793077892476200539"
        "6480366981116642022840766493089678927031925856820915020131433543947176409249002483738437892626465352398731"
        "3533043843153420527028519289469257219866282621444078115160037958537650073871870155146739659051219860195010"
        "3870460911266271375594027451705961880073077205032970597723857178287989180249809777027703017182602707180194"
        "556713104248046875e-305"},
    {0x1.fffffffffffffp-1012, chars_format::scientific, 759,
        "4."
        "5569512622227479266455752636603022867145104309281702871519766727164359106991655844178524649638606600481774"
        "7745390514402686993702644652983404064196077121663333044221571289757149031127508353305016117858533878057347"
        "0410869191285320202512702986272592686031663070027370494615475298895907035303630214411605311477633588782227"
        "4882827523904785052622137344189355792720548613730137489654773706554937952356455446130891586155784952401079"
        "2960733962233284045681532986179357854063851713641830040262867087894352818498004967476875785252930704797462"
        "7066087686306841054057038578938514439732565242888156230320075917075300147743740310293479318102439720390020"
        "7740921822532542751188054903411923760146154410065941195447714356575978360499619554055406034365205414360389"
        "11342620849609375e-305"},
    {0x1.fffffffffffffp-1011, chars_format::scientific, 758,
        "9."
        "1139025244454958532911505273206045734290208618563405743039533454328718213983311688357049299277213200963549"
        "5490781028805373987405289305966808128392154243326666088443142579514298062255016706610032235717067756114694"
        "0821738382570640405025405972545185372063326140054740989230950597791814070607260428823210622955267177564454"
        "9765655047809570105244274688378711585441097227460274979309547413109875904712910892261783172311569904802158"
        "5921467924466568091363065972358715708127703427283660080525734175788705636996009934953751570505861409594925"
        "4132175372613682108114077157877028879465130485776312460640151834150600295487480620586958636204879440780041"
        "5481843645065085502376109806823847520292308820131882390895428713151956720999239108110812068730410828720778"
        "2268524169921875e-305"},
    {0x1.fffffffffffffp-1010, chars_format::scientific, 758,
        "1."
        "8227805048890991706582301054641209146858041723712681148607906690865743642796662337671409859855442640192709"
        "9098156205761074797481057861193361625678430848665333217688628515902859612451003341322006447143413551222938"
        "8164347676514128081005081194509037074412665228010948197846190119558362814121452085764642124591053435512890"
        "9953131009561914021048854937675742317088219445492054995861909482621975180942582178452356634462313980960431"
        "7184293584893313618272613194471743141625540685456732016105146835157741127399201986990750314101172281918985"
        "0826435074522736421622815431575405775893026097155262492128030366830120059097496124117391727240975888156008"
        "3096368729013017100475221961364769504058461764026376478179085742630391344199847821622162413746082165744155"
        "6453704833984375e-304"},
    {0x1.fffffffffffffp-1009, chars_format::scientific, 757,
        "3."
        "6455610097781983413164602109282418293716083447425362297215813381731487285593324675342819719710885280385419"
        "8196312411522149594962115722386723251356861697330666435377257031805719224902006682644012894286827102445877"
        "6328695353028256162010162389018074148825330456021896395692380239116725628242904171529284249182106871025781"
        "9906262019123828042097709875351484634176438890984109991723818965243950361885164356904713268924627961920863"
        "4368587169786627236545226388943486283251081370913464032210293670315482254798403973981500628202344563837970"
        "1652870149045472843245630863150811551786052194310524984256060733660240118194992248234783454481951776312016"
        "6192737458026034200950443922729539008116923528052752956358171485260782688399695643244324827492164331488311"
        "290740966796875e-304"},
    {0x1.fffffffffffffp-1008, chars_format::scientific, 756,
        "7."
        "2911220195563966826329204218564836587432166894850724594431626763462974571186649350685639439421770560770839"
        "6392624823044299189924231444773446502713723394661332870754514063611438449804013365288025788573654204891755"
        "2657390706056512324020324778036148297650660912043792791384760478233451256485808343058568498364213742051563"
        "9812524038247656084195419750702969268352877781968219983447637930487900723770328713809426537849255923841726"
        "8737174339573254473090452777886972566502162741826928064420587340630964509596807947963001256404689127675940"
        "3305740298090945686491261726301623103572104388621049968512121467320480236389984496469566908963903552624033"
        "2385474916052068401900887845459078016233847056105505912716342970521565376799391286488649654984328662976622"
        "58148193359375e-304"},
    {0x1.fffffffffffffp-1007, chars_format::scientific, 756,
        "1."
        "4582244039112793365265840843712967317486433378970144918886325352692594914237329870137127887884354112154167"
        "9278524964608859837984846288954689300542744678932266574150902812722287689960802673057605157714730840978351"
        "0531478141211302464804064955607229659530132182408758558276952095646690251297161668611713699672842748410312"
        "7962504807649531216839083950140593853670575556393643996689527586097580144754065742761885307569851184768345"
        "3747434867914650894618090555577394513300432548365385612884117468126192901919361589592600251280937825535188"
        "0661148059618189137298252345260324620714420877724209993702424293464096047277996899293913381792780710524806"
        "6477094983210413680380177569091815603246769411221101182543268594104313075359878257297729930996865732595324"
        "51629638671875e-303"},
    {0x1.fffffffffffffp-1006, chars_format::scientific, 755,
        "2."
        "9164488078225586730531681687425934634972866757940289837772650705385189828474659740274255775768708224308335"
        "8557049929217719675969692577909378601085489357864533148301805625444575379921605346115210315429461681956702"
        "1062956282422604929608129911214459319060264364817517116553904191293380502594323337223427399345685496820625"
        "5925009615299062433678167900281187707341151112787287993379055172195160289508131485523770615139702369536690"
        "7494869735829301789236181111154789026600865096730771225768234936252385803838723179185200502561875651070376"
        "1322296119236378274596504690520649241428841755448419987404848586928192094555993798587826763585561421049613"
        "2954189966420827360760355138183631206493538822442202365086537188208626150719756514595459861993731465190649"
        "0325927734375e-303"},
    {0x1.fffffffffffffp-1005, chars_format::scientific, 754,
        "5."
        "8328976156451173461063363374851869269945733515880579675545301410770379656949319480548511551537416448616671"
        "7114099858435439351939385155818757202170978715729066296603611250889150759843210692230420630858923363913404"
        "2125912564845209859216259822428918638120528729635034233107808382586761005188646674446854798691370993641251"
        "1850019230598124867356335800562375414682302225574575986758110344390320579016262971047541230279404739073381"
        "4989739471658603578472362222309578053201730193461542451536469872504771607677446358370401005123751302140752"
        "2644592238472756549193009381041298482857683510896839974809697173856384189111987597175653527171122842099226"
        "5908379932841654721520710276367262412987077644884404730173074376417252301439513029190919723987462930381298"
        "065185546875e-303"},
    {0x1.fffffffffffffp-1004, chars_format::scientific, 754,
        "1."
        "1665795231290234692212672674970373853989146703176115935109060282154075931389863896109702310307483289723334"
        "3422819971687087870387877031163751440434195743145813259320722250177830151968642138446084126171784672782680"
        "8425182512969041971843251964485783727624105745927006846621561676517352201037729334889370959738274198728250"
        "2370003846119624973471267160112475082936460445114915197351622068878064115803252594209508246055880947814676"
        "2997947894331720715694472444461915610640346038692308490307293974500954321535489271674080201024750260428150"
        "4528918447694551309838601876208259696571536702179367994961939434771276837822397519435130705434224568419845"
        "3181675986568330944304142055273452482597415528976880946034614875283450460287902605838183944797492586076259"
        "613037109375e-302"},
    {0x1.fffffffffffffp-1003, chars_format::scientific, 753,
        "2."
        "3331590462580469384425345349940747707978293406352231870218120564308151862779727792219404620614966579446668"
        "6845639943374175740775754062327502880868391486291626518641444500355660303937284276892168252343569345565361"
        "6850365025938083943686503928971567455248211491854013693243123353034704402075458669778741919476548397456500"
        "4740007692239249946942534320224950165872920890229830394703244137756128231606505188419016492111761895629352"
        "5995895788663441431388944888923831221280692077384616980614587949001908643070978543348160402049500520856300"
        "9057836895389102619677203752416519393143073404358735989923878869542553675644795038870261410868449136839690"
        "6363351973136661888608284110546904965194831057953761892069229750566900920575805211676367889594985172152519"
        "22607421875e-302"},
    {0x1.fffffffffffffp-1002, chars_format::scientific, 752,
        "4."
        "6663180925160938768850690699881495415956586812704463740436241128616303725559455584438809241229933158893337"
        "3691279886748351481551508124655005761736782972583253037282889000711320607874568553784336504687138691130723"
        "3700730051876167887373007857943134910496422983708027386486246706069408804150917339557483838953096794913000"
        "9480015384478499893885068640449900331745841780459660789406488275512256463213010376838032984223523791258705"
        "1991791577326882862777889777847662442561384154769233961229175898003817286141957086696320804099001041712601"
        "8115673790778205239354407504833038786286146808717471979847757739085107351289590077740522821736898273679381"
        "2726703946273323777216568221093809930389662115907523784138459501133801841151610423352735779189970344305038"
        "4521484375e-302"},
    {0x1.fffffffffffffp-1001, chars_format::scientific, 751,
        "9."
        "3326361850321877537701381399762990831913173625408927480872482257232607451118911168877618482459866317786674"
        "7382559773496702963103016249310011523473565945166506074565778001422641215749137107568673009374277382261446"
        "7401460103752335774746015715886269820992845967416054772972493412138817608301834679114967677906193589826001"
        "8960030768956999787770137280899800663491683560919321578812976551024512926426020753676065968447047582517410"
        "3983583154653765725555779555695324885122768309538467922458351796007634572283914173392641608198002083425203"
        "6231347581556410478708815009666077572572293617434943959695515478170214702579180155481045643473796547358762"
        "5453407892546647554433136442187619860779324231815047568276919002267603682303220846705471558379940688610076"
        "904296875e-302"},
    {0x1.fffffffffffffp-1000, chars_format::scientific, 751,
        "1."
        "8665272370064375507540276279952598166382634725081785496174496451446521490223782233775523696491973263557334"
        "9476511954699340592620603249862002304694713189033301214913155600284528243149827421513734601874855476452289"
        "3480292020750467154949203143177253964198569193483210954594498682427763521660366935822993535581238717965200"
        "3792006153791399957554027456179960132698336712183864315762595310204902585285204150735213193689409516503482"
        "0796716630930753145111155911139064977024553661907693584491670359201526914456782834678528321639600416685040"
        "7246269516311282095741763001933215514514458723486988791939103095634042940515836031096209128694759309471752"
        "5090681578509329510886627288437523972155864846363009513655383800453520736460644169341094311675988137722015"
        "380859375e-301"},
    {0x1.fffffffffffffp-999, chars_format::scientific, 750,
        "3."
        "7330544740128751015080552559905196332765269450163570992348992902893042980447564467551047392983946527114669"
        "8953023909398681185241206499724004609389426378066602429826311200569056486299654843027469203749710952904578"
        "6960584041500934309898406286354507928397138386966421909188997364855527043320733871645987071162477435930400"
        "7584012307582799915108054912359920265396673424367728631525190620409805170570408301470426387378819033006964"
        "1593433261861506290222311822278129954049107323815387168983340718403053828913565669357056643279200833370081"
        "4492539032622564191483526003866431029028917446973977583878206191268085881031672062192418257389518618943505"
        "0181363157018659021773254576875047944311729692726019027310767600907041472921288338682188623351976275444030"
        "76171875e-301"},
    {0x1.fffffffffffffp-998, chars_format::scientific, 749,
        "7."
        "4661089480257502030161105119810392665530538900327141984697985805786085960895128935102094785967893054229339"
        "7906047818797362370482412999448009218778852756133204859652622401138112972599309686054938407499421905809157"
        "3921168083001868619796812572709015856794276773932843818377994729711054086641467743291974142324954871860801"
        "5168024615165599830216109824719840530793346848735457263050381240819610341140816602940852774757638066013928"
        "3186866523723012580444623644556259908098214647630774337966681436806107657827131338714113286558401666740162"
        "8985078065245128382967052007732862058057834893947955167756412382536171762063344124384836514779037237887010"
        "0362726314037318043546509153750095888623459385452038054621535201814082945842576677364377246703952550888061"
        "5234375e-301"},
    {0x1.fffffffffffffp-997, chars_format::scientific, 749,
        "1."
        "4932217896051500406032221023962078533106107780065428396939597161157217192179025787020418957193578610845867"
        "9581209563759472474096482599889601843755770551226640971930524480227622594519861937210987681499884381161831"
        "4784233616600373723959362514541803171358855354786568763675598945942210817328293548658394828464990974372160"
        "3033604923033119966043221964943968106158669369747091452610076248163922068228163320588170554951527613202785"
        "6637373304744602516088924728911251981619642929526154867593336287361221531565426267742822657311680333348032"
        "5797015613049025676593410401546572411611566978789591033551282476507234352412668824876967302955807447577402"
        "0072545262807463608709301830750019177724691877090407610924307040362816589168515335472875449340790510177612"
        "3046875e-300"},
    {0x1.fffffffffffffp-996, chars_format::scientific, 748,
        "2."
        "9864435792103000812064442047924157066212215560130856793879194322314434384358051574040837914387157221691735"
        "9162419127518944948192965199779203687511541102453281943861048960455245189039723874421975362999768762323662"
        "9568467233200747447918725029083606342717710709573137527351197891884421634656587097316789656929981948744320"
        "6067209846066239932086443929887936212317338739494182905220152496327844136456326641176341109903055226405571"
        "3274746609489205032177849457822503963239285859052309735186672574722443063130852535485645314623360666696065"
        "1594031226098051353186820803093144823223133957579182067102564953014468704825337649753934605911614895154804"
        "0145090525614927217418603661500038355449383754180815221848614080725633178337030670945750898681581020355224"
        "609375e-300"},
    {0x1.fffffffffffffp-995, chars_format::scientific, 747,
        "5."
        "9728871584206001624128884095848314132424431120261713587758388644628868768716103148081675828774314443383471"
        "8324838255037889896385930399558407375023082204906563887722097920910490378079447748843950725999537524647325"
        "9136934466401494895837450058167212685435421419146275054702395783768843269313174194633579313859963897488641"
        "2134419692132479864172887859775872424634677478988365810440304992655688272912653282352682219806110452811142"
        "6549493218978410064355698915645007926478571718104619470373345149444886126261705070971290629246721333392130"
        "3188062452196102706373641606186289646446267915158364134205129906028937409650675299507869211823229790309608"
        "0290181051229854434837207323000076710898767508361630443697228161451266356674061341891501797363162040710449"
        "21875e-300"},
    {0x1.fffffffffffffp-994, chars_format::scientific, 747,
        "1."
        "1945774316841200324825776819169662826484886224052342717551677728925773753743220629616335165754862888676694"
        "3664967651007577979277186079911681475004616440981312777544419584182098075615889549768790145199907504929465"
        "1827386893280298979167490011633442537087084283829255010940479156753768653862634838926715862771992779497728"
        "2426883938426495972834577571955174484926935495797673162088060998531137654582530656470536443961222090562228"
        "5309898643795682012871139783129001585295714343620923894074669029888977225252341014194258125849344266678426"
        "0637612490439220541274728321237257929289253583031672826841025981205787481930135059901573842364645958061921"
        "6058036210245970886967441464600015342179753501672326088739445632290253271334812268378300359472632408142089"
        "84375e-299"},
    {0x1.fffffffffffffp-993, chars_format::scientific, 746,
        "2."
        "3891548633682400649651553638339325652969772448104685435103355457851547507486441259232670331509725777353388"
        "7329935302015155958554372159823362950009232881962625555088839168364196151231779099537580290399815009858930"
        "3654773786560597958334980023266885074174168567658510021880958313507537307725269677853431725543985558995456"
        "4853767876852991945669155143910348969853870991595346324176121997062275309165061312941072887922444181124457"
        "0619797287591364025742279566258003170591428687241847788149338059777954450504682028388516251698688533356852"
        "1275224980878441082549456642474515858578507166063345653682051962411574963860270119803147684729291916123843"
        "2116072420491941773934882929200030684359507003344652177478891264580506542669624536756600718945264816284179"
        "6875e-299"},
    {0x1.fffffffffffffp-992, chars_format::scientific, 745,
        "4."
        "7783097267364801299303107276678651305939544896209370870206710915703095014972882518465340663019451554706777"
        "4659870604030311917108744319646725900018465763925251110177678336728392302463558199075160580799630019717860"
        "7309547573121195916669960046533770148348337135317020043761916627015074615450539355706863451087971117990912"
        "9707535753705983891338310287820697939707741983190692648352243994124550618330122625882145775844888362248914"
        "1239594575182728051484559132516006341182857374483695576298676119555908901009364056777032503397377066713704"
        "2550449961756882165098913284949031717157014332126691307364103924823149927720540239606295369458583832247686"
        "4232144840983883547869765858400061368719014006689304354957782529161013085339249073513201437890529632568359"
        "375e-299"},
    {0x1.fffffffffffffp-991, chars_format::scientific, 744,
        "9."
        "5566194534729602598606214553357302611879089792418741740413421831406190029945765036930681326038903109413554"
        "9319741208060623834217488639293451800036931527850502220355356673456784604927116398150321161599260039435721"
        "4619095146242391833339920093067540296696674270634040087523833254030149230901078711413726902175942235981825"
        "9415071507411967782676620575641395879415483966381385296704487988249101236660245251764291551689776724497828"
        "2479189150365456102969118265032012682365714748967391152597352239111817802018728113554065006794754133427408"
        "5100899923513764330197826569898063434314028664253382614728207849646299855441080479212590738917167664495372"
        "8464289681967767095739531716800122737438028013378608709915565058322026170678498147026402875781059265136718"
        "75e-299"},
    {0x1.fffffffffffffp-990, chars_format::scientific, 744,
        "1."
        "9113238906945920519721242910671460522375817958483748348082684366281238005989153007386136265207780621882710"
        "9863948241612124766843497727858690360007386305570100444071071334691356920985423279630064232319852007887144"
        "2923819029248478366667984018613508059339334854126808017504766650806029846180215742282745380435188447196365"
        "1883014301482393556535324115128279175883096793276277059340897597649820247332049050352858310337955344899565"
        "6495837830073091220593823653006402536473142949793478230519470447822363560403745622710813001358950826685481"
        "7020179984702752866039565313979612686862805732850676522945641569929259971088216095842518147783433532899074"
        "5692857936393553419147906343360024547487605602675721741983113011664405234135699629405280575156211853027343"
        "75e-298"},
    {0x1.fffffffffffffp-989, chars_format::scientific, 743,
        "3."
        "8226477813891841039442485821342921044751635916967496696165368732562476011978306014772272530415561243765421"
        "9727896483224249533686995455717380720014772611140200888142142669382713841970846559260128464639704015774288"
        "5847638058496956733335968037227016118678669708253616035009533301612059692360431484565490760870376894392730"
        "3766028602964787113070648230256558351766193586552554118681795195299640494664098100705716620675910689799131"
        "2991675660146182441187647306012805072946285899586956461038940895644727120807491245421626002717901653370963"
        "4040359969405505732079130627959225373725611465701353045891283139858519942176432191685036295566867065798149"
        "1385715872787106838295812686720049094975211205351443483966226023328810468271399258810561150312423706054687"
        "5e-298"},
    {0x1.fffffffffffffp-988, chars_format::scientific, 742,
        "7."
        "6452955627783682078884971642685842089503271833934993392330737465124952023956612029544545060831122487530843"
        "9455792966448499067373990911434761440029545222280401776284285338765427683941693118520256929279408031548577"
        "1695276116993913466671936074454032237357339416507232070019066603224119384720862969130981521740753788785460"
        "7532057205929574226141296460513116703532387173105108237363590390599280989328196201411433241351821379598262"
        "5983351320292364882375294612025610145892571799173912922077881791289454241614982490843252005435803306741926"
        "8080719938811011464158261255918450747451222931402706091782566279717039884352864383370072591133734131596298"
        "2771431745574213676591625373440098189950422410702886967932452046657620936542798517621122300624847412109375"
        "e-298"},
    {0x1.fffffffffffffp-987, chars_format::scientific, 742,
        "1."
        "5290591125556736415776994328537168417900654366786998678466147493024990404791322405908909012166224497506168"
        "7891158593289699813474798182286952288005909044456080355256857067753085536788338623704051385855881606309715"
        "4339055223398782693334387214890806447471467883301446414003813320644823876944172593826196304348150757757092"
        "1506411441185914845228259292102623340706477434621021647472718078119856197865639240282286648270364275919652"
        "5196670264058472976475058922405122029178514359834782584415576358257890848322996498168650401087160661348385"
        "3616143987762202292831652251183690149490244586280541218356513255943407976870572876674014518226746826319259"
        "6554286349114842735318325074688019637990084482140577393586490409331524187308559703524224460124969482421875"
        "e-297"},
    {0x1.fffffffffffffp-986, chars_format::scientific, 741,
        "3."
        "0581182251113472831553988657074336835801308733573997356932294986049980809582644811817818024332448995012337"
        "5782317186579399626949596364573904576011818088912160710513714135506171073576677247408102771711763212619430"
        "8678110446797565386668774429781612894942935766602892828007626641289647753888345187652392608696301515514184"
        "3012822882371829690456518584205246681412954869242043294945436156239712395731278480564573296540728551839305"
        "0393340528116945952950117844810244058357028719669565168831152716515781696645992996337300802174321322696770"
        "7232287975524404585663304502367380298980489172561082436713026511886815953741145753348029036453493652638519"
        "310857269822968547063665014937603927598016896428115478717298081866304837461711940704844892024993896484375e"
        "-297"},
    {0x1.fffffffffffffp-985, chars_format::scientific, 740,
        "6."
        "1162364502226945663107977314148673671602617467147994713864589972099961619165289623635636048664897990024675"
        "1564634373158799253899192729147809152023636177824321421027428271012342147153354494816205543423526425238861"
        "7356220893595130773337548859563225789885871533205785656015253282579295507776690375304785217392603031028368"
        "6025645764743659380913037168410493362825909738484086589890872312479424791462556961129146593081457103678610"
        "0786681056233891905900235689620488116714057439339130337662305433031563393291985992674601604348642645393541"
        "4464575951048809171326609004734760597960978345122164873426053023773631907482291506696058072906987305277038"
        "62171453964593709412733002987520785519603379285623095743459616373260967492342388140968978404998779296875e-"
        "297"},
    {0x1.fffffffffffffp-984, chars_format::scientific, 740,
        "1."
        "2232472900445389132621595462829734734320523493429598942772917994419992323833057924727127209732979598004935"
        "0312926874631759850779838545829561830404727235564864284205485654202468429430670898963241108684705285047772"
        "3471244178719026154667509771912645157977174306641157131203050656515859101555338075060957043478520606205673"
        "7205129152948731876182607433682098672565181947696817317978174462495884958292511392225829318616291420735722"
        "0157336211246778381180047137924097623342811487867826067532461086606312678658397198534920320869728529078708"
        "2892915190209761834265321800946952119592195669024432974685210604754726381496458301339211614581397461055407"
        "72434290792918741882546600597504157103920675857124619148691923274652193498468477628193795680999755859375e-"
        "296"},
    {0x1.fffffffffffffp-983, chars_format::scientific, 739,
        "2."
        "4464945800890778265243190925659469468641046986859197885545835988839984647666115849454254419465959196009870"
        "0625853749263519701559677091659123660809454471129728568410971308404936858861341797926482217369410570095544"
        "6942488357438052309335019543825290315954348613282314262406101313031718203110676150121914086957041212411347"
        "4410258305897463752365214867364197345130363895393634635956348924991769916585022784451658637232582841471444"
        "0314672422493556762360094275848195246685622975735652135064922173212625357316794397069840641739457058157416"
        "5785830380419523668530643601893904239184391338048865949370421209509452762992916602678423229162794922110815"
        "4486858158583748376509320119500831420784135171424923829738384654930438699693695525638759136199951171875e-"
        "296"},
    {0x1.fffffffffffffp-982, chars_format::scientific, 738,
        "4."
        "8929891601781556530486381851318938937282093973718395771091671977679969295332231698908508838931918392019740"
        "1251707498527039403119354183318247321618908942259457136821942616809873717722683595852964434738821140191089"
        "3884976714876104618670039087650580631908697226564628524812202626063436406221352300243828173914082424822694"
        "8820516611794927504730429734728394690260727790787269271912697849983539833170045568903317274465165682942888"
        "0629344844987113524720188551696390493371245951471304270129844346425250714633588794139681283478914116314833"
        "1571660760839047337061287203787808478368782676097731898740842419018905525985833205356846458325589844221630"
        "897371631716749675301864023900166284156827034284984765947676930986087739938739105127751827239990234375e-"
        "296"},
    {0x1.fffffffffffffp-981, chars_format::scientific, 737,
        "9."
        "7859783203563113060972763702637877874564187947436791542183343955359938590664463397817017677863836784039480"
        "2503414997054078806238708366636494643237817884518914273643885233619747435445367191705928869477642280382178"
        "7769953429752209237340078175301161263817394453129257049624405252126872812442704600487656347828164849645389"
        "7641033223589855009460859469456789380521455581574538543825395699967079666340091137806634548930331365885776"
        "1258689689974227049440377103392780986742491902942608540259688692850501429267177588279362566957828232629666"
        "3143321521678094674122574407575616956737565352195463797481684838037811051971666410713692916651179688443261"
        "79474326343349935060372804780033256831365406856996953189535386197217547987747821025550365447998046875e-"
        "296"},
    {0x1.fffffffffffffp-980, chars_format::scientific, 737,
        "1."
        "9571956640712622612194552740527575574912837589487358308436668791071987718132892679563403535572767356807896"
        "0500682999410815761247741673327298928647563576903782854728777046723949487089073438341185773895528456076435"
        "7553990685950441847468015635060232252763478890625851409924881050425374562488540920097531269565632969929077"
        "9528206644717971001892171893891357876104291116314907708765079139993415933268018227561326909786066273177155"
        "2251737937994845409888075420678556197348498380588521708051937738570100285853435517655872513391565646525933"
        "2628664304335618934824514881515123391347513070439092759496336967607562210394333282142738583330235937688652"
        "35894865268669987012074560956006651366273081371399390637907077239443509597549564205110073089599609375e-"
        "295"},
    {0x1.fffffffffffffp-979, chars_format::scientific, 736,
        "3."
        "9143913281425245224389105481055151149825675178974716616873337582143975436265785359126807071145534713615792"
        "1001365998821631522495483346654597857295127153807565709457554093447898974178146876682371547791056912152871"
        "5107981371900883694936031270120464505526957781251702819849762100850749124977081840195062539131265939858155"
        "9056413289435942003784343787782715752208582232629815417530158279986831866536036455122653819572132546354310"
        "4503475875989690819776150841357112394696996761177043416103875477140200571706871035311745026783131293051866"
        "5257328608671237869649029763030246782695026140878185518992673935215124420788666564285477166660471875377304"
        "7178973053733997402414912191201330273254616274279878127581415447888701919509912841022014617919921875e-"
        "295"},
    {0x1.fffffffffffffp-978, chars_format::scientific, 735,
        "7."
        "8287826562850490448778210962110302299651350357949433233746675164287950872531570718253614142291069427231584"
        "2002731997643263044990966693309195714590254307615131418915108186895797948356293753364743095582113824305743"
        "0215962743801767389872062540240929011053915562503405639699524201701498249954163680390125078262531879716311"
        "8112826578871884007568687575565431504417164465259630835060316559973663733072072910245307639144265092708620"
        "9006951751979381639552301682714224789393993522354086832207750954280401143413742070623490053566262586103733"
        "0514657217342475739298059526060493565390052281756371037985347870430248841577333128570954333320943750754609"
        "435794610746799480482982438240266054650923254855975625516283089577740383901982568204402923583984375e-295"},
    {0x1.fffffffffffffp-977, chars_format::scientific, 735,
        "1."
        "5657565312570098089755642192422060459930270071589886646749335032857590174506314143650722828458213885446316"
        "8400546399528652608998193338661839142918050861523026283783021637379159589671258750672948619116422764861148"
        "6043192548760353477974412508048185802210783112500681127939904840340299649990832736078025015652506375943262"
        "3622565315774376801513737515113086300883432893051926167012063311994732746614414582049061527828853018541724"
        "1801390350395876327910460336542844957878798704470817366441550190856080228682748414124698010713252517220746"
        "6102931443468495147859611905212098713078010456351274207597069574086049768315466625714190866664188750150921"
        "887158922149359896096596487648053210930184650971195125103256617915548076780396513640880584716796875e-294"},
    {0x1.fffffffffffffp-976, chars_format::scientific, 734,
        "3."
        "1315130625140196179511284384844120919860540143179773293498670065715180349012628287301445656916427770892633"
        "6801092799057305217996386677323678285836101723046052567566043274758319179342517501345897238232845529722297"
        "2086385097520706955948825016096371604421566225001362255879809680680599299981665472156050031305012751886524"
        "7245130631548753603027475030226172601766865786103852334024126623989465493228829164098123055657706037083448"
        "3602780700791752655820920673085689915757597408941634732883100381712160457365496828249396021426505034441493"
        "2205862886936990295719223810424197426156020912702548415194139148172099536630933251428381733328377500301843"
        "77431784429871979219319297529610642186036930194239025020651323583109615356079302728176116943359375e-294"},
    {0x1.fffffffffffffp-975, chars_format::scientific, 733,
        "6."
        "2630261250280392359022568769688241839721080286359546586997340131430360698025256574602891313832855541785267"
        "3602185598114610435992773354647356571672203446092105135132086549516638358685035002691794476465691059444594"
        "4172770195041413911897650032192743208843132450002724511759619361361198599963330944312100062610025503773049"
        "4490261263097507206054950060452345203533731572207704668048253247978930986457658328196246111315412074166896"
        "7205561401583505311641841346171379831515194817883269465766200763424320914730993656498792042853010068882986"
        "4411725773873980591438447620848394852312041825405096830388278296344199073261866502856763466656755000603687"
        "5486356885974395843863859505922128437207386038847805004130264716621923071215860545635223388671875e-294"},
    {0x1.fffffffffffffp-974, chars_format::scientific, 733,
        "1."
        "2526052250056078471804513753937648367944216057271909317399468026286072139605051314920578262766571108357053"
        "4720437119622922087198554670929471314334440689218421027026417309903327671737007000538358895293138211888918"
        "8834554039008282782379530006438548641768626490000544902351923872272239719992666188862420012522005100754609"
        "8898052252619501441210990012090469040706746314441540933609650649595786197291531665639249222263082414833379"
        "3441112280316701062328368269234275966303038963576653893153240152684864182946198731299758408570602013776597"
        "2882345154774796118287689524169678970462408365081019366077655659268839814652373300571352693331351000120737"
        "5097271377194879168772771901184425687441477207769561000826052943324384614243172109127044677734375e-293"},
    {0x1.fffffffffffffp-973, chars_format::scientific, 732,
        "2."
        "5052104500112156943609027507875296735888432114543818634798936052572144279210102629841156525533142216714106"
        "9440874239245844174397109341858942628668881378436842054052834619806655343474014001076717790586276423777837"
        "7669108078016565564759060012877097283537252980001089804703847744544479439985332377724840025044010201509219"
        "7796104505239002882421980024180938081413492628883081867219301299191572394583063331278498444526164829666758"
        "6882224560633402124656736538468551932606077927153307786306480305369728365892397462599516817141204027553194"
        "5764690309549592236575379048339357940924816730162038732155311318537679629304746601142705386662702000241475"
        "019454275438975833754554380236885137488295441553912200165210588664876922848634421825408935546875e-293"},
    {0x1.fffffffffffffp-972, chars_format::scientific, 731,
        "5."
        "0104209000224313887218055015750593471776864229087637269597872105144288558420205259682313051066284433428213"
        "8881748478491688348794218683717885257337762756873684108105669239613310686948028002153435581172552847555675"
        "5338216156033131129518120025754194567074505960002179609407695489088958879970664755449680050088020403018439"
        "5592209010478005764843960048361876162826985257766163734438602598383144789166126662556996889052329659333517"
        "3764449121266804249313473076937103865212155854306615572612960610739456731784794925199033634282408055106389"
        "1529380619099184473150758096678715881849633460324077464310622637075359258609493202285410773325404000482950"
        "03890855087795166750910876047377027497659088310782440033042117732975384569726884365081787109375e-293"},
    {0x1.fffffffffffffp-971, chars_format::scientific, 731,
        "1."
        "0020841800044862777443611003150118694355372845817527453919574421028857711684041051936462610213256886685642"
        "7776349695698337669758843736743577051467552551374736821621133847922662137389605600430687116234510569511135"
        "1067643231206626225903624005150838913414901192000435921881539097817791775994132951089936010017604080603687"
        "9118441802095601152968792009672375232565397051553232746887720519676628957833225332511399377810465931866703"
        "4752889824253360849862694615387420773042431170861323114522592122147891346356958985039806726856481611021277"
        "8305876123819836894630151619335743176369926692064815492862124527415071851721898640457082154665080800096590"
        "00778171017559033350182175209475405499531817662156488006608423546595076913945376873016357421875e-292"},
    {0x1.fffffffffffffp-970, chars_format::scientific, 730,
        "2."
        "0041683600089725554887222006300237388710745691635054907839148842057715423368082103872925220426513773371285"
        "5552699391396675339517687473487154102935105102749473643242267695845324274779211200861374232469021139022270"
        "2135286462413252451807248010301677826829802384000871843763078195635583551988265902179872020035208161207375"
        "8236883604191202305937584019344750465130794103106465493775441039353257915666450665022798755620931863733406"
        "9505779648506721699725389230774841546084862341722646229045184244295782692713917970079613453712963222042555"
        "6611752247639673789260303238671486352739853384129630985724249054830143703443797280914164309330161600193180"
        "0155634203511806670036435041895081099906363532431297601321684709319015382789075374603271484375e-292"},
    {0x1.fffffffffffffp-969, chars_format::scientific, 729,
        "4."
        "0083367200179451109774444012600474777421491383270109815678297684115430846736164207745850440853027546742571"
        "1105398782793350679035374946974308205870210205498947286484535391690648549558422401722748464938042278044540"
        "4270572924826504903614496020603355653659604768001743687526156391271167103976531804359744040070416322414751"
        "6473767208382404611875168038689500930261588206212930987550882078706515831332901330045597511241863727466813"
        "9011559297013443399450778461549683092169724683445292458090368488591565385427835940159226907425926444085111"
        "3223504495279347578520606477342972705479706768259261971448498109660287406887594561828328618660323200386360"
        "031126840702361334007287008379016219981272706486259520264336941863803076557815074920654296875e-292"},
    {0x1.fffffffffffffp-968, chars_format::scientific, 728,
        "8."
        "0166734400358902219548888025200949554842982766540219631356595368230861693472328415491700881706055093485142"
        "2210797565586701358070749893948616411740420410997894572969070783381297099116844803445496929876084556089080"
        "8541145849653009807228992041206711307319209536003487375052312782542334207953063608719488080140832644829503"
        "2947534416764809223750336077379001860523176412425861975101764157413031662665802660091195022483727454933627"
        "8023118594026886798901556923099366184339449366890584916180736977183130770855671880318453814851852888170222"
        "6447008990558695157041212954685945410959413536518523942896996219320574813775189123656657237320646400772720"
        "06225368140472266801457401675803243996254541297251904052867388372760615311563014984130859375e-292"},
    {0x1.fffffffffffffp-967, chars_format::scientific, 728,
        "1."
        "6033346880071780443909777605040189910968596553308043926271319073646172338694465683098340176341211018697028"
        "4442159513117340271614149978789723282348084082199578914593814156676259419823368960689099385975216911217816"
        "1708229169930601961445798408241342261463841907200697475010462556508466841590612721743897616028166528965900"
        "6589506883352961844750067215475800372104635282485172395020352831482606332533160532018239004496745490986725"
        "5604623718805377359780311384619873236867889873378116983236147395436626154171134376063690762970370577634044"
        "5289401798111739031408242590937189082191882707303704788579399243864114962755037824731331447464129280154544"
        "01245073628094453360291480335160648799250908259450380810573477674552123062312602996826171875e-291"},
    {0x1.fffffffffffffp-966, chars_format::scientific, 727,
        "3."
        "2066693760143560887819555210080379821937193106616087852542638147292344677388931366196680352682422037394056"
        "8884319026234680543228299957579446564696168164399157829187628313352518839646737921378198771950433822435632"
        "3416458339861203922891596816482684522927683814401394950020925113016933683181225443487795232056333057931801"
        "3179013766705923689500134430951600744209270564970344790040705662965212665066321064036478008993490981973451"
        "1209247437610754719560622769239746473735779746756233966472294790873252308342268752127381525940741155268089"
        "0578803596223478062816485181874378164383765414607409577158798487728229925510075649462662894928258560309088"
        "0249014725618890672058296067032129759850181651890076162114695534910424612462520599365234375e-291"},
    {0x1.fffffffffffffp-965, chars_format::scientific, 726,
        "6."
        "4133387520287121775639110420160759643874386213232175705085276294584689354777862732393360705364844074788113"
        "7768638052469361086456599915158893129392336328798315658375256626705037679293475842756397543900867644871264"
        "6832916679722407845783193632965369045855367628802789900041850226033867366362450886975590464112666115863602"
        "6358027533411847379000268861903201488418541129940689580081411325930425330132642128072956017986981963946902"
        "2418494875221509439121245538479492947471559493512467932944589581746504616684537504254763051881482310536178"
        "1157607192446956125632970363748756328767530829214819154317596975456459851020151298925325789856517120618176"
        "049802945123778134411659213406425951970036330378015232422939106982084922492504119873046875e-291"},
    {0x1.fffffffffffffp-964, chars_format::scientific, 726,
        "1."
        "2826677504057424355127822084032151928774877242646435141017055258916937870955572546478672141072968814957622"
        "7553727610493872217291319983031778625878467265759663131675051325341007535858695168551279508780173528974252"
        "9366583335944481569156638726593073809171073525760557980008370045206773473272490177395118092822533223172720"
        "5271605506682369475800053772380640297683708225988137916016282265186085066026528425614591203597396392789380"
        "4483698975044301887824249107695898589494311898702493586588917916349300923336907500850952610376296462107235"
        "6231521438489391225126594072749751265753506165842963830863519395091291970204030259785065157971303424123635"
        "209960589024755626882331842681285190394007266075603046484587821396416984498500823974609375e-290"},
    {0x1.fffffffffffffp-963, chars_format::scientific, 725,
        "2."
        "5653355008114848710255644168064303857549754485292870282034110517833875741911145092957344282145937629915245"
        "5107455220987744434582639966063557251756934531519326263350102650682015071717390337102559017560347057948505"
        "8733166671888963138313277453186147618342147051521115960016740090413546946544980354790236185645066446345441"
        "0543211013364738951600107544761280595367416451976275832032564530372170132053056851229182407194792785578760"
        "8967397950088603775648498215391797178988623797404987173177835832698601846673815001701905220752592924214471"
        "2463042876978782450253188145499502531507012331685927661727038790182583940408060519570130315942606848247270"
        "41992117804951125376466368536257038078801453215120609296917564279283396899700164794921875e-290"},
    {0x1.fffffffffffffp-962, chars_format::scientific, 724,
        "5."
        "1306710016229697420511288336128607715099508970585740564068221035667751483822290185914688564291875259830491"
        "0214910441975488869165279932127114503513869063038652526700205301364030143434780674205118035120694115897011"
        "7466333343777926276626554906372295236684294103042231920033480180827093893089960709580472371290132892690882"
        "1086422026729477903200215089522561190734832903952551664065129060744340264106113702458364814389585571157521"
        "7934795900177207551296996430783594357977247594809974346355671665397203693347630003403810441505185848428942"
        "4926085753957564900506376290999005063014024663371855323454077580365167880816121039140260631885213696494540"
        "8398423560990225075293273707251407615760290643024121859383512855856679379940032958984375e-290"},
    {0x1.fffffffffffffp-961, chars_format::scientific, 724,
        "1."
        "0261342003245939484102257667225721543019901794117148112813644207133550296764458037182937712858375051966098"
        "2042982088395097773833055986425422900702773812607730505340041060272806028686956134841023607024138823179402"
        "3493266668755585255325310981274459047336858820608446384006696036165418778617992141916094474258026578538176"
        "4217284405345895580640043017904512238146966580790510332813025812148868052821222740491672962877917114231504"
        "3586959180035441510259399286156718871595449518961994869271134333079440738669526000680762088301037169685788"
        "4985217150791512980101275258199801012602804932674371064690815516073033576163224207828052126377042739298908"
        "1679684712198045015058654741450281523152058128604824371876702571171335875988006591796875e-289"},
    {0x1.fffffffffffffp-960, chars_format::scientific, 723,
        "2."
        "0522684006491878968204515334451443086039803588234296225627288414267100593528916074365875425716750103932196"
        "4085964176790195547666111972850845801405547625215461010680082120545612057373912269682047214048277646358804"
        "6986533337511170510650621962548918094673717641216892768013392072330837557235984283832188948516053157076352"
        "8434568810691791161280086035809024476293933161581020665626051624297736105642445480983345925755834228463008"
        "7173918360070883020518798572313437743190899037923989738542268666158881477339052001361524176602074339371576"
        "9970434301583025960202550516399602025205609865348742129381631032146067152326448415656104252754085478597816"
        "335936942439609003011730948290056304630411625720964874375340514234267175197601318359375e-289"},
    {0x1.fffffffffffffp-959, chars_format::scientific, 722,
        "4."
        "1045368012983757936409030668902886172079607176468592451254576828534201187057832148731750851433500207864392"
        "8171928353580391095332223945701691602811095250430922021360164241091224114747824539364094428096555292717609"
        "3973066675022341021301243925097836189347435282433785536026784144661675114471968567664377897032106314152705"
        "6869137621383582322560172071618048952587866323162041331252103248595472211284890961966691851511668456926017"
        "4347836720141766041037597144626875486381798075847979477084537332317762954678104002723048353204148678743153"
        "9940868603166051920405101032799204050411219730697484258763262064292134304652896831312208505508170957195632"
        "67187388487921800602346189658011260926082325144192974875068102846853435039520263671875e-289"},
    {0x1.fffffffffffffp-958, chars_format::scientific, 721,
        "8."
        "2090736025967515872818061337805772344159214352937184902509153657068402374115664297463501702867000415728785"
        "6343856707160782190664447891403383205622190500861844042720328482182448229495649078728188856193110585435218"
        "7946133350044682042602487850195672378694870564867571072053568289323350228943937135328755794064212628305411"
        "3738275242767164645120344143236097905175732646324082662504206497190944422569781923933383703023336913852034"
        "8695673440283532082075194289253750972763596151695958954169074664635525909356208005446096706408297357486307"
        "9881737206332103840810202065598408100822439461394968517526524128584268609305793662624417011016341914391265"
        "3437477697584360120469237931602252185216465028838594975013620569370687007904052734375e-289"},
    {0x1.fffffffffffffp-957, chars_format::scientific, 721,
        "1."
        "6418147205193503174563612267561154468831842870587436980501830731413680474823132859492700340573400083145757"
        "1268771341432156438132889578280676641124438100172368808544065696436489645899129815745637771238622117087043"
        "7589226670008936408520497570039134475738974112973514214410713657864670045788787427065751158812842525661082"
        "2747655048553432929024068828647219581035146529264816532500841299438188884513956384786676740604667382770406"
        "9739134688056706416415038857850750194552719230339191790833814932927105181871241601089219341281659471497261"
        "5976347441266420768162040413119681620164487892278993703505304825716853721861158732524883402203268382878253"
        "0687495539516872024093847586320450437043293005767718995002724113874137401580810546875e-288"},
    {0x1.fffffffffffffp-956, chars_format::scientific, 720,
        "3."
        "2836294410387006349127224535122308937663685741174873961003661462827360949646265718985400681146800166291514"
        "2537542682864312876265779156561353282248876200344737617088131392872979291798259631491275542477244234174087"
        "5178453340017872817040995140078268951477948225947028428821427315729340091577574854131502317625685051322164"
        "5495310097106865858048137657294439162070293058529633065001682598876377769027912769573353481209334765540813"
        "9478269376113412832830077715701500389105438460678383581667629865854210363742483202178438682563318942994523"
        "1952694882532841536324080826239363240328975784557987407010609651433707443722317465049766804406536765756506"
        "137499107903374404818769517264090087408658601153543799000544822774827480316162109375e-288"},
    {0x1.fffffffffffffp-955, chars_format::scientific, 719,
        "6."
        "5672588820774012698254449070244617875327371482349747922007322925654721899292531437970801362293600332583028"
        "5075085365728625752531558313122706564497752400689475234176262785745958583596519262982551084954488468348175"
        "0356906680035745634081990280156537902955896451894056857642854631458680183155149708263004635251370102644329"
        "0990620194213731716096275314588878324140586117059266130003365197752755538055825539146706962418669531081627"
        "8956538752226825665660155431403000778210876921356767163335259731708420727484966404356877365126637885989046"
        "3905389765065683072648161652478726480657951569115974814021219302867414887444634930099533608813073531513012"
        "27499821580674880963753903452818017481731720230708759800108964554965496063232421875e-288"},
    {0x1.fffffffffffffp-954, chars_format::scientific, 719,
        "1."
        "3134517764154802539650889814048923575065474296469949584401464585130944379858506287594160272458720066516605"
        "7015017073145725150506311662624541312899550480137895046835252557149191716719303852596510216990897693669635"
        "0071381336007149126816398056031307580591179290378811371528570926291736036631029941652600927050274020528865"
        "8198124038842746343219255062917775664828117223411853226000673039550551107611165107829341392483733906216325"
        "5791307750445365133132031086280600155642175384271353432667051946341684145496993280871375473025327577197809"
        "2781077953013136614529632330495745296131590313823194962804243860573482977488926986019906721762614706302602"
        "45499964316134976192750780690563603496346344046141751960021792910993099212646484375e-287"},
    {0x1.fffffffffffffp-953, chars_format::scientific, 718,
        "2."
        "6269035528309605079301779628097847150130948592939899168802929170261888759717012575188320544917440133033211"
        "4030034146291450301012623325249082625799100960275790093670505114298383433438607705193020433981795387339270"
        "0142762672014298253632796112062615161182358580757622743057141852583472073262059883305201854100548041057731"
        "6396248077685492686438510125835551329656234446823706452001346079101102215222330215658682784967467812432651"
        "1582615500890730266264062172561200311284350768542706865334103892683368290993986561742750946050655154395618"
        "5562155906026273229059264660991490592263180627646389925608487721146965954977853972039813443525229412605204"
        "9099992863226995238550156138112720699269268809228350392004358582198619842529296875e-287"},
    {0x1.fffffffffffffp-952, chars_format::scientific, 717,
        "5."
        "2538071056619210158603559256195694300261897185879798337605858340523777519434025150376641089834880266066422"
        "8060068292582900602025246650498165251598201920551580187341010228596766866877215410386040867963590774678540"
        "0285525344028596507265592224125230322364717161515245486114283705166944146524119766610403708201096082115463"
        "2792496155370985372877020251671102659312468893647412904002692158202204430444660431317365569934935624865302"
        "3165231001781460532528124345122400622568701537085413730668207785366736581987973123485501892101310308791237"
        "1124311812052546458118529321982981184526361255292779851216975442293931909955707944079626887050458825210409"
        "819998572645399047710031227622544139853853761845670078400871716439723968505859375e-287"},
    {0x1.fffffffffffffp-951, chars_format::scientific, 717,
        "1."
        "0507614211323842031720711851239138860052379437175959667521171668104755503886805030075328217966976053213284"
        "5612013658516580120405049330099633050319640384110316037468202045719353373375443082077208173592718154935708"
        "0057105068805719301453118444825046064472943432303049097222856741033388829304823953322080741640219216423092"
        "6558499231074197074575404050334220531862493778729482580800538431640440886088932086263473113986987124973060"
        "4633046200356292106505624869024480124513740307417082746133641557073347316397594624697100378420262061758247"
        "4224862362410509291623705864396596236905272251058555970243395088458786381991141588815925377410091765042081"
        "963999714529079809542006245524508827970770752369134015680174343287944793701171875e-286"},
    {0x1.fffffffffffffp-950, chars_format::scientific, 716,
        "2."
        "1015228422647684063441423702478277720104758874351919335042343336209511007773610060150656435933952106426569"
        "1224027317033160240810098660199266100639280768220632074936404091438706746750886164154416347185436309871416"
        "0114210137611438602906236889650092128945886864606098194445713482066777658609647906644161483280438432846185"
        "3116998462148394149150808100668441063724987557458965161601076863280881772177864172526946227973974249946120"
        "9266092400712584213011249738048960249027480614834165492267283114146694632795189249394200756840524123516494"
        "8449724724821018583247411728793192473810544502117111940486790176917572763982283177631850754820183530084163"
        "92799942905815961908401249104901765594154150473826803136034868657588958740234375e-286"},
    {0x1.fffffffffffffp-949, chars_format::scientific, 715,
        "4."
        "2030456845295368126882847404956555440209517748703838670084686672419022015547220120301312871867904212853138"
        "2448054634066320481620197320398532201278561536441264149872808182877413493501772328308832694370872619742832"
        "0228420275222877205812473779300184257891773729212196388891426964133555317219295813288322966560876865692370"
        "6233996924296788298301616201336882127449975114917930323202153726561763544355728345053892455947948499892241"
        "8532184801425168426022499476097920498054961229668330984534566228293389265590378498788401513681048247032989"
        "6899449449642037166494823457586384947621089004234223880973580353835145527964566355263701509640367060168327"
        "8559988581163192381680249820980353118830830094765360627206973731517791748046875e-286"},
    {0x1.fffffffffffffp-948, chars_format::scientific, 714,
        "8."
        "4060913690590736253765694809913110880419035497407677340169373344838044031094440240602625743735808425706276"
        "4896109268132640963240394640797064402557123072882528299745616365754826987003544656617665388741745239485664"
        "0456840550445754411624947558600368515783547458424392777782853928267110634438591626576645933121753731384741"
        "2467993848593576596603232402673764254899950229835860646404307453123527088711456690107784911895896999784483"
        "7064369602850336852044998952195840996109922459336661969069132456586778531180756997576803027362096494065979"
        "3798898899284074332989646915172769895242178008468447761947160707670291055929132710527403019280734120336655"
        "711997716232638476336049964196070623766166018953072125441394746303558349609375e-286"},
    {0x1.fffffffffffffp-947, chars_format::scientific, 714,
        "1."
        "6812182738118147250753138961982622176083807099481535468033874668967608806218888048120525148747161685141255"
        "2979221853626528192648078928159412880511424614576505659949123273150965397400708931323533077748349047897132"
        "8091368110089150882324989511720073703156709491684878555556570785653422126887718325315329186624350746276948"
        "2493598769718715319320646480534752850979990045967172129280861490624705417742291338021556982379179399956896"
        "7412873920570067370408999790439168199221984491867332393813826491317355706236151399515360605472419298813195"
        "8759779779856814866597929383034553979048435601693689552389432141534058211185826542105480603856146824067331"
        "142399543246527695267209992839214124753233203790614425088278949260711669921875e-285"},
    {0x1.fffffffffffffp-946, chars_format::scientific, 713,
        "3."
        "3624365476236294501506277923965244352167614198963070936067749337935217612437776096241050297494323370282510"
        "5958443707253056385296157856318825761022849229153011319898246546301930794801417862647066155496698095794265"
        "6182736220178301764649979023440147406313418983369757111113141571306844253775436650630658373248701492553896"
        "4987197539437430638641292961069505701959980091934344258561722981249410835484582676043113964758358799913793"
        "4825747841140134740817999580878336398443968983734664787627652982634711412472302799030721210944838597626391"
        "7519559559713629733195858766069107958096871203387379104778864283068116422371653084210961207712293648134662"
        "28479908649305539053441998567842824950646640758122885017655789852142333984375e-285"},
    {0x1.fffffffffffffp-945, chars_format::scientific, 712,
        "6."
        "7248730952472589003012555847930488704335228397926141872135498675870435224875552192482100594988646740565021"
        "1916887414506112770592315712637651522045698458306022639796493092603861589602835725294132310993396191588531"
        "2365472440356603529299958046880294812626837966739514222226283142613688507550873301261316746497402985107792"
        "9974395078874861277282585922139011403919960183868688517123445962498821670969165352086227929516717599827586"
        "9651495682280269481635999161756672796887937967469329575255305965269422824944605598061442421889677195252783"
        "5039119119427259466391717532138215916193742406774758209557728566136232844743306168421922415424587296269324"
        "5695981729861107810688399713568564990129328151624577003531157970428466796875e-285"},
    {0x1.fffffffffffffp-944, chars_format::scientific, 712,
        "1."
        "3449746190494517800602511169586097740867045679585228374427099735174087044975110438496420118997729348113004"
        "2383377482901222554118463142527530304409139691661204527959298618520772317920567145058826462198679238317706"
        "2473094488071320705859991609376058962525367593347902844445256628522737701510174660252263349299480597021558"
        "5994879015774972255456517184427802280783992036773737703424689192499764334193833070417245585903343519965517"
        "3930299136456053896327199832351334559377587593493865915051061193053884564988921119612288484377935439050556"
        "7007823823885451893278343506427643183238748481354951641911545713227246568948661233684384483084917459253864"
        "9139196345972221562137679942713712998025865630324915400706231594085693359375e-284"},
    {0x1.fffffffffffffp-943, chars_format::scientific, 711,
        "2."
        "6899492380989035601205022339172195481734091359170456748854199470348174089950220876992840237995458696226008"
        "4766754965802445108236926285055060608818279383322409055918597237041544635841134290117652924397358476635412"
        "4946188976142641411719983218752117925050735186695805688890513257045475403020349320504526698598961194043117"
        "1989758031549944510913034368855604561567984073547475406849378384999528668387666140834491171806687039931034"
        "7860598272912107792654399664702669118755175186987731830102122386107769129977842239224576968755870878101113"
        "4015647647770903786556687012855286366477496962709903283823091426454493137897322467368768966169834918507729"
        "827839269194444312427535988542742599605173126064983080141246318817138671875e-284"},
    {0x1.fffffffffffffp-942, chars_format::scientific, 710,
        "5."
        "3798984761978071202410044678344390963468182718340913497708398940696348179900441753985680475990917392452016"
        "9533509931604890216473852570110121217636558766644818111837194474083089271682268580235305848794716953270824"
        "9892377952285282823439966437504235850101470373391611377781026514090950806040698641009053397197922388086234"
        "3979516063099889021826068737711209123135968147094950813698756769999057336775332281668982343613374079862069"
        "5721196545824215585308799329405338237510350373975463660204244772215538259955684478449153937511741756202226"
        "8031295295541807573113374025710572732954993925419806567646182852908986275794644934737537932339669837015459"
        "65567853838888862485507197708548519921034625212996616028249263763427734375e-284"},
    {0x1.fffffffffffffp-941, chars_format::scientific, 710,
        "1."
        "0759796952395614240482008935668878192693636543668182699541679788139269635980088350797136095198183478490403"
        "3906701986320978043294770514022024243527311753328963622367438894816617854336453716047061169758943390654164"
        "9978475590457056564687993287500847170020294074678322275556205302818190161208139728201810679439584477617246"
        "8795903212619977804365213747542241824627193629418990162739751353999811467355066456333796468722674815972413"
        "9144239309164843117061759865881067647502070074795092732040848954443107651991136895689830787502348351240445"
        "3606259059108361514622674805142114546590998785083961313529236570581797255158928986947507586467933967403091"
        "93113570767777772497101439541709703984206925042599323205649852752685546875e-283"},
    {0x1.fffffffffffffp-940, chars_format::scientific, 709,
        "2."
        "1519593904791228480964017871337756385387273087336365399083359576278539271960176701594272190396366956980806"
        "7813403972641956086589541028044048487054623506657927244734877789633235708672907432094122339517886781308329"
        "9956951180914113129375986575001694340040588149356644551112410605636380322416279456403621358879168955234493"
        "7591806425239955608730427495084483649254387258837980325479502707999622934710132912667592937445349631944827"
        "8288478618329686234123519731762135295004140149590185464081697908886215303982273791379661575004696702480890"
        "7212518118216723029245349610284229093181997570167922627058473141163594510317857973895015172935867934806183"
        "8622714153555554499420287908341940796841385008519864641129970550537109375e-283"},
    {0x1.fffffffffffffp-939, chars_format::scientific, 708,
        "4."
        "3039187809582456961928035742675512770774546174672730798166719152557078543920353403188544380792733913961613"
        "5626807945283912173179082056088096974109247013315854489469755579266471417345814864188244679035773562616659"
        "9913902361828226258751973150003388680081176298713289102224821211272760644832558912807242717758337910468987"
        "5183612850479911217460854990168967298508774517675960650959005415999245869420265825335185874890699263889655"
        "6576957236659372468247039463524270590008280299180370928163395817772430607964547582759323150009393404961781"
        "4425036236433446058490699220568458186363995140335845254116946282327189020635715947790030345871735869612367"
        "724542830711110899884057581668388159368277001703972928225994110107421875e-283"},
    {0x1.fffffffffffffp-938, chars_format::scientific, 707,
        "8."
        "6078375619164913923856071485351025541549092349345461596333438305114157087840706806377088761585467827923227"
        "1253615890567824346358164112176193948218494026631708978939511158532942834691629728376489358071547125233319"
        "9827804723656452517503946300006777360162352597426578204449642422545521289665117825614485435516675820937975"
        "0367225700959822434921709980337934597017549035351921301918010831998491738840531650670371749781398527779311"
        "3153914473318744936494078927048541180016560598360741856326791635544861215929095165518646300018786809923562"
        "8850072472866892116981398441136916372727990280671690508233892564654378041271431895580060691743471739224735"
        "44908566142222179976811516333677631873655400340794585645198822021484375e-283"},
    {0x1.fffffffffffffp-937, chars_format::scientific, 707,
        "1."
        "7215675123832982784771214297070205108309818469869092319266687661022831417568141361275417752317093565584645"
        "4250723178113564869271632822435238789643698805326341795787902231706588566938325945675297871614309425046663"
        "9965560944731290503500789260001355472032470519485315640889928484509104257933023565122897087103335164187595"
        "0073445140191964486984341996067586919403509807070384260383602166399698347768106330134074349956279705555862"
        "2630782894663748987298815785409708236003312119672148371265358327108972243185819033103729260003757361984712"
        "5770014494573378423396279688227383274545598056134338101646778512930875608254286379116012138348694347844947"
        "08981713228444435995362303266735526374731080068158917129039764404296875e-282"},
    {0x1.fffffffffffffp-936, chars_format::scientific, 706,
        "3."
        "4431350247665965569542428594140410216619636939738184638533375322045662835136282722550835504634187131169290"
        "8501446356227129738543265644870477579287397610652683591575804463413177133876651891350595743228618850093327"
        "9931121889462581007001578520002710944064941038970631281779856969018208515866047130245794174206670328375190"
        "0146890280383928973968683992135173838807019614140768520767204332799396695536212660268148699912559411111724"
        "5261565789327497974597631570819416472006624239344296742530716654217944486371638066207458520007514723969425"
        "1540028989146756846792559376454766549091196112268676203293557025861751216508572758232024276697388695689894"
        "1796342645688887199072460653347105274946216013631783425807952880859375e-282"},
    {0x1.fffffffffffffp-935, chars_format::scientific, 705,
        "6."
        "8862700495331931139084857188280820433239273879476369277066750644091325670272565445101671009268374262338581"
        "7002892712454259477086531289740955158574795221305367183151608926826354267753303782701191486457237700186655"
        "9862243778925162014003157040005421888129882077941262563559713938036417031732094260491588348413340656750380"
        "0293780560767857947937367984270347677614039228281537041534408665598793391072425320536297399825118822223449"
        "0523131578654995949195263141638832944013248478688593485061433308435888972743276132414917040015029447938850"
        "3080057978293513693585118752909533098182392224537352406587114051723502433017145516464048553394777391379788"
        "359268529137777439814492130669421054989243202726356685161590576171875e-282"},
    {0x1.fffffffffffffp-934, chars_format::scientific, 705,
        "1."
        "3772540099066386227816971437656164086647854775895273855413350128818265134054513089020334201853674852467716"
        "3400578542490851895417306257948191031714959044261073436630321785365270853550660756540238297291447540037331"
        "1972448755785032402800631408001084377625976415588252512711942787607283406346418852098317669682668131350076"
        "0058756112153571589587473596854069535522807845656307408306881733119758678214485064107259479965023764444689"
        "8104626315730999189839052628327766588802649695737718697012286661687177794548655226482983408003005889587770"
        "0616011595658702738717023750581906619636478444907470481317422810344700486603429103292809710678955478275957"
        "671853705827555487962898426133884210997848640545271337032318115234375e-281"},
    {0x1.fffffffffffffp-933, chars_format::scientific, 704,
        "2."
        "7545080198132772455633942875312328173295709551790547710826700257636530268109026178040668403707349704935432"
        "6801157084981703790834612515896382063429918088522146873260643570730541707101321513080476594582895080074662"
        "3944897511570064805601262816002168755251952831176505025423885575214566812692837704196635339365336262700152"
        "0117512224307143179174947193708139071045615691312614816613763466239517356428970128214518959930047528889379"
        "6209252631461998379678105256655533177605299391475437394024573323374355589097310452965966816006011779175540"
        "1232023191317405477434047501163813239272956889814940962634845620689400973206858206585619421357910956551915"
        "34370741165511097592579685226776842199569728109054267406463623046875e-281"},
    {0x1.fffffffffffffp-932, chars_format::scientific, 703,
        "5."
        "5090160396265544911267885750624656346591419103581095421653400515273060536218052356081336807414699409870865"
        "3602314169963407581669225031792764126859836177044293746521287141461083414202643026160953189165790160149324"
        "7889795023140129611202525632004337510503905662353010050847771150429133625385675408393270678730672525400304"
        "0235024448614286358349894387416278142091231382625229633227526932479034712857940256429037919860095057778759"
        "2418505262923996759356210513311066355210598782950874788049146646748711178194620905931933632012023558351080"
        "2464046382634810954868095002327626478545913779629881925269691241378801946413716413171238842715821913103830"
        "6874148233102219518515937045355368439913945621810853481292724609375e-281"},
    {0x1.fffffffffffffp-931, chars_format::scientific, 703,
        "1."
        "1018032079253108982253577150124931269318283820716219084330680103054612107243610471216267361482939881974173"
        "0720462833992681516333845006358552825371967235408858749304257428292216682840528605232190637833158032029864"
        "9577959004628025922240505126400867502100781132470602010169554230085826725077135081678654135746134505080060"
        "8047004889722857271669978877483255628418246276525045926645505386495806942571588051285807583972019011555751"
        "8483701052584799351871242102662213271042119756590174957609829329349742235638924181186386726402404711670216"
        "0492809276526962190973619000465525295709182755925976385053938248275760389282743282634247768543164382620766"
        "1374829646620443903703187409071073687982789124362170696258544921875e-280"},
    {0x1.fffffffffffffp-930, chars_format::scientific, 702,
        "2."
        "2036064158506217964507154300249862538636567641432438168661360206109224214487220942432534722965879763948346"
        "1440925667985363032667690012717105650743934470817717498608514856584433365681057210464381275666316064059729"
        "9155918009256051844481010252801735004201562264941204020339108460171653450154270163357308271492269010160121"
        "6094009779445714543339957754966511256836492553050091853291010772991613885143176102571615167944038023111503"
        "6967402105169598703742484205324426542084239513180349915219658658699484471277848362372773452804809423340432"
        "0985618553053924381947238000931050591418365511851952770107876496551520778565486565268495537086328765241532"
        "274965929324088780740637481814214737596557824872434139251708984375e-280"},
    {0x1.fffffffffffffp-929, chars_format::scientific, 701,
        "4."
        "4072128317012435929014308600499725077273135282864876337322720412218448428974441884865069445931759527896692"
        "2881851335970726065335380025434211301487868941635434997217029713168866731362114420928762551332632128119459"
        "8311836018512103688962020505603470008403124529882408040678216920343306900308540326714616542984538020320243"
        "2188019558891429086679915509933022513672985106100183706582021545983227770286352205143230335888076046223007"
        "3934804210339197407484968410648853084168479026360699830439317317398968942555696724745546905609618846680864"
        "1971237106107848763894476001862101182836731023703905540215752993103041557130973130536991074172657530483064"
        "54993185864817756148127496362842947519311564974486827850341796875e-280"},
    {0x1.fffffffffffffp-928, chars_format::scientific, 700,
        "8."
        "8144256634024871858028617200999450154546270565729752674645440824436896857948883769730138891863519055793384"
        "5763702671941452130670760050868422602975737883270869994434059426337733462724228841857525102665264256238919"
        "6623672037024207377924041011206940016806249059764816081356433840686613800617080653429233085969076040640486"
        "4376039117782858173359831019866045027345970212200367413164043091966455540572704410286460671776152092446014"
        "7869608420678394814969936821297706168336958052721399660878634634797937885111393449491093811219237693361728"
        "3942474212215697527788952003724202365673462047407811080431505986206083114261946261073982148345315060966129"
        "0998637172963551229625499272568589503862312994897365570068359375e-280"},
    {0x1.fffffffffffffp-927, chars_format::scientific, 700,
        "1."
        "7628851326804974371605723440199890030909254113145950534929088164887379371589776753946027778372703811158676"
        "9152740534388290426134152010173684520595147576654173998886811885267546692544845768371505020533052851247783"
        "9324734407404841475584808202241388003361249811952963216271286768137322760123416130685846617193815208128097"
        "2875207823556571634671966203973209005469194042440073482632808618393291108114540882057292134355230418489202"
        "9573921684135678962993987364259541233667391610544279932175726926959587577022278689898218762243847538672345"
        "6788494842443139505557790400744840473134692409481562216086301197241216622852389252214796429669063012193225"
        "8199727434592710245925099854513717900772462598979473114013671875e-279"},
    {0x1.fffffffffffffp-926, chars_format::scientific, 699,
        "3."
        "5257702653609948743211446880399780061818508226291901069858176329774758743179553507892055556745407622317353"
        "8305481068776580852268304020347369041190295153308347997773623770535093385089691536743010041066105702495567"
        "8649468814809682951169616404482776006722499623905926432542573536274645520246832261371693234387630416256194"
        "5750415647113143269343932407946418010938388084880146965265617236786582216229081764114584268710460836978405"
        "9147843368271357925987974728519082467334783221088559864351453853919175154044557379796437524487695077344691"
        "3576989684886279011115580801489680946269384818963124432172602394482433245704778504429592859338126024386451"
        "639945486918542049185019970902743580154492519795894622802734375e-279"},
    {0x1.fffffffffffffp-925, chars_format::scientific, 698,
        "7."
        "0515405307219897486422893760799560123637016452583802139716352659549517486359107015784111113490815244634707"
        "6610962137553161704536608040694738082380590306616695995547247541070186770179383073486020082132211404991135"
        "7298937629619365902339232808965552013444999247811852865085147072549291040493664522743386468775260832512389"
        "1500831294226286538687864815892836021876776169760293930531234473573164432458163528229168537420921673956811"
        "8295686736542715851975949457038164934669566442177119728702907707838350308089114759592875048975390154689382"
        "7153979369772558022231161602979361892538769637926248864345204788964866491409557008859185718676252048772903"
        "27989097383708409837003994180548716030898503959178924560546875e-279"},
    {0x1.fffffffffffffp-924, chars_format::scientific, 698,
        "1."
        "4103081061443979497284578752159912024727403290516760427943270531909903497271821403156822222698163048926941"
        "5322192427510632340907321608138947616476118061323339199109449508214037354035876614697204016426442280998227"
        "1459787525923873180467846561793110402688999849562370573017029414509858208098732904548677293755052166502477"
        "8300166258845257307737572963178567204375355233952058786106246894714632886491632705645833707484184334791362"
        "3659137347308543170395189891407632986933913288435423945740581541567670061617822951918575009795078030937876"
        "5430795873954511604446232320595872378507753927585249772869040957792973298281911401771837143735250409754580"
        "65597819476741681967400798836109743206179700791835784912109375e-278"},
    {0x1.fffffffffffffp-923, chars_format::scientific, 697,
        "2."
        "8206162122887958994569157504319824049454806581033520855886541063819806994543642806313644445396326097853883"
        "0644384855021264681814643216277895232952236122646678398218899016428074708071753229394408032852884561996454"
        "2919575051847746360935693123586220805377999699124741146034058829019716416197465809097354587510104333004955"
        "6600332517690514615475145926357134408750710467904117572212493789429265772983265411291667414968368669582724"
        "7318274694617086340790379782815265973867826576870847891481163083135340123235645903837150019590156061875753"
        "0861591747909023208892464641191744757015507855170499545738081915585946596563822803543674287470500819509161"
        "3119563895348336393480159767221948641235940158367156982421875e-278"},
    {0x1.fffffffffffffp-922, chars_format::scientific, 696,
        "5."
        "6412324245775917989138315008639648098909613162067041711773082127639613989087285612627288890792652195707766"
        "1288769710042529363629286432555790465904472245293356796437798032856149416143506458788816065705769123992908"
        "5839150103695492721871386247172441610755999398249482292068117658039432832394931618194709175020208666009911"
        "3200665035381029230950291852714268817501420935808235144424987578858531545966530822583334829936737339165449"
        "4636549389234172681580759565630531947735653153741695782962326166270680246471291807674300039180312123751506"
        "1723183495818046417784929282383489514031015710340999091476163831171893193127645607087348574941001639018322"
        "623912779069667278696031953444389728247188031673431396484375e-278"},
    {0x1.fffffffffffffp-921, chars_format::scientific, 696,
        "1."
        "1282464849155183597827663001727929619781922632413408342354616425527922797817457122525457778158530439141553"
        "2257753942008505872725857286511158093180894449058671359287559606571229883228701291757763213141153824798581"
        "7167830020739098544374277249434488322151199879649896458413623531607886566478986323638941835004041733201982"
        "2640133007076205846190058370542853763500284187161647028884997515771706309193306164516666965987347467833089"
        "8927309877846834536316151913126106389547130630748339156592465233254136049294258361534860007836062424750301"
        "2344636699163609283556985856476697902806203142068199818295232766234378638625529121417469714988200327803664"
        "524782555813933455739206390688877945649437606334686279296875e-277"},
    {0x1.fffffffffffffp-920, chars_format::scientific, 695,
        "2."
        "2564929698310367195655326003455859239563845264826816684709232851055845595634914245050915556317060878283106"
        "4515507884017011745451714573022316186361788898117342718575119213142459766457402583515526426282307649597163"
        "4335660041478197088748554498868976644302399759299792916827247063215773132957972647277883670008083466403964"
        "5280266014152411692380116741085707527000568374323294057769995031543412618386612329033333931974694935666179"
        "7854619755693669072632303826252212779094261261496678313184930466508272098588516723069720015672124849500602"
        "4689273398327218567113971712953395805612406284136399636590465532468757277251058242834939429976400655607329"
        "04956511162786691147841278137775589129887521266937255859375e-277"},
    {0x1.fffffffffffffp-919, chars_format::scientific, 694,
        "4."
        "5129859396620734391310652006911718479127690529653633369418465702111691191269828490101831112634121756566212"
        "9031015768034023490903429146044632372723577796234685437150238426284919532914805167031052852564615299194326"
        "8671320082956394177497108997737953288604799518599585833654494126431546265915945294555767340016166932807929"
        "0560532028304823384760233482171415054001136748646588115539990063086825236773224658066667863949389871332359"
        "5709239511387338145264607652504425558188522522993356626369860933016544197177033446139440031344249699001204"
        "9378546796654437134227943425906791611224812568272799273180931064937514554502116485669878859952801311214658"
        "0991302232557338229568255627555117825977504253387451171875e-277"},
    {0x1.fffffffffffffp-918, chars_format::scientific, 693,
        "9."
        "0259718793241468782621304013823436958255381059307266738836931404223382382539656980203662225268243513132425"
        "8062031536068046981806858292089264745447155592469370874300476852569839065829610334062105705129230598388653"
        "7342640165912788354994217995475906577209599037199171667308988252863092531831890589111534680032333865615858"
        "1121064056609646769520466964342830108002273497293176231079980126173650473546449316133335727898779742664719"
        "1418479022774676290529215305008851116377045045986713252739721866033088394354066892278880062688499398002409"
        "8757093593308874268455886851813583222449625136545598546361862129875029109004232971339757719905602622429316"
        "198260446511467645913651125511023565195500850677490234375e-277"},
    {0x1.fffffffffffffp-917, chars_format::scientific, 693,
        "1."
        "8051943758648293756524260802764687391651076211861453347767386280844676476507931396040732445053648702626485"
        "1612406307213609396361371658417852949089431118493874174860095370513967813165922066812421141025846119677730"
        "7468528033182557670998843599095181315441919807439834333461797650572618506366378117822306936006466773123171"
        "6224212811321929353904093392868566021600454699458635246215996025234730094709289863226667145579755948532943"
        "8283695804554935258105843061001770223275409009197342650547944373206617678870813378455776012537699879600481"
        "9751418718661774853691177370362716644489925027309119709272372425975005821800846594267951543981120524485863"
        "239652089302293529182730225102204713039100170135498046875e-276"},
    {0x1.fffffffffffffp-916, chars_format::scientific, 692,
        "3."
        "6103887517296587513048521605529374783302152423722906695534772561689352953015862792081464890107297405252970"
        "3224812614427218792722743316835705898178862236987748349720190741027935626331844133624842282051692239355461"
        "4937056066365115341997687198190362630883839614879668666923595301145237012732756235644613872012933546246343"
        "2448425622643858707808186785737132043200909398917270492431992050469460189418579726453334291159511897065887"
        "6567391609109870516211686122003540446550818018394685301095888746413235357741626756911552025075399759200963"
        "9502837437323549707382354740725433288979850054618239418544744851950011643601693188535903087962241048971726"
        "47930417860458705836546045020440942607820034027099609375e-276"},
    {0x1.fffffffffffffp-915, chars_format::scientific, 691,
        "7."
        "2207775034593175026097043211058749566604304847445813391069545123378705906031725584162929780214594810505940"
        "6449625228854437585445486633671411796357724473975496699440381482055871252663688267249684564103384478710922"
        "9874112132730230683995374396380725261767679229759337333847190602290474025465512471289227744025867092492686"
        "4896851245287717415616373571474264086401818797834540984863984100938920378837159452906668582319023794131775"
        "3134783218219741032423372244007080893101636036789370602191777492826470715483253513823104050150799518401927"
        "9005674874647099414764709481450866577959700109236478837089489703900023287203386377071806175924482097943452"
        "9586083572091741167309209004088188521564006805419921875e-276"},
    {0x1.fffffffffffffp-914, chars_format::scientific, 691,
        "1."
        "4441555006918635005219408642211749913320860969489162678213909024675741181206345116832585956042918962101188"
        "1289925045770887517089097326734282359271544894795099339888076296411174250532737653449936912820676895742184"
        "5974822426546046136799074879276145052353535845951867466769438120458094805093102494257845548805173418498537"
        "2979370249057543483123274714294852817280363759566908196972796820187784075767431890581333716463804758826355"
        "0626956643643948206484674448801416178620327207357874120438355498565294143096650702764620810030159903680385"
        "5801134974929419882952941896290173315591940021847295767417897940780004657440677275414361235184896419588690"
        "5917216714418348233461841800817637704312801361083984375e-275"},
    {0x1.fffffffffffffp-913, chars_format::scientific, 690,
        "2."
        "8883110013837270010438817284423499826641721938978325356427818049351482362412690233665171912085837924202376"
        "2579850091541775034178194653468564718543089789590198679776152592822348501065475306899873825641353791484369"
        "1949644853092092273598149758552290104707071691903734933538876240916189610186204988515691097610346836997074"
        "5958740498115086966246549428589705634560727519133816393945593640375568151534863781162667432927609517652710"
        "1253913287287896412969348897602832357240654414715748240876710997130588286193301405529241620060319807360771"
        "1602269949858839765905883792580346631183880043694591534835795881560009314881354550828722470369792839177381"
        "183443342883669646692368360163527540862560272216796875e-275"},
    {0x1.fffffffffffffp-912, chars_format::scientific, 689,
        "5."
        "7766220027674540020877634568846999653283443877956650712855636098702964724825380467330343824171675848404752"
        "5159700183083550068356389306937129437086179579180397359552305185644697002130950613799747651282707582968738"
        "3899289706184184547196299517104580209414143383807469867077752481832379220372409977031382195220693673994149"
        "1917480996230173932493098857179411269121455038267632787891187280751136303069727562325334865855219035305420"
        "2507826574575792825938697795205664714481308829431496481753421994261176572386602811058483240120639614721542"
        "3204539899717679531811767585160693262367760087389183069671591763120018629762709101657444940739585678354762"
        "36688668576733929338473672032705508172512054443359375e-275"},
    {0x1.fffffffffffffp-911, chars_format::scientific, 689,
        "1."
        "1553244005534908004175526913769399930656688775591330142571127219740592944965076093466068764834335169680950"
        "5031940036616710013671277861387425887417235915836079471910461037128939400426190122759949530256541516593747"
        "6779857941236836909439259903420916041882828676761493973415550496366475844074481995406276439044138734798829"
        "8383496199246034786498619771435882253824291007653526557578237456150227260613945512465066973171043807061084"
        "0501565314915158565187739559041132942896261765886299296350684398852235314477320562211696648024127922944308"
        "4640907979943535906362353517032138652473552017477836613934318352624003725952541820331488988147917135670952"
        "47337733715346785867694734406541101634502410888671875e-274"},
    {0x1.fffffffffffffp-910, chars_format::scientific, 688,
        "2."
        "3106488011069816008351053827538799861313377551182660285142254439481185889930152186932137529668670339361901"
        "0063880073233420027342555722774851774834471831672158943820922074257878800852380245519899060513083033187495"
        "3559715882473673818878519806841832083765657353522987946831100992732951688148963990812552878088277469597659"
        "6766992398492069572997239542871764507648582015307053115156474912300454521227891024930133946342087614122168"
        "1003130629830317130375479118082265885792523531772598592701368797704470628954641124423393296048255845888616"
        "9281815959887071812724707034064277304947104034955673227868636705248007451905083640662977976295834271341904"
        "9467546743069357173538946881308220326900482177734375e-274"},
    {0x1.fffffffffffffp-909, chars_format::scientific, 687,
        "4."
        "6212976022139632016702107655077599722626755102365320570284508878962371779860304373864275059337340678723802"
        "0127760146466840054685111445549703549668943663344317887641844148515757601704760491039798121026166066374990"
        "7119431764947347637757039613683664167531314707045975893662201985465903376297927981625105756176554939195319"
        "3533984796984139145994479085743529015297164030614106230312949824600909042455782049860267892684175228244336"
        "2006261259660634260750958236164531771585047063545197185402737595408941257909282248846786592096511691777233"
        "8563631919774143625449414068128554609894208069911346455737273410496014903810167281325955952591668542683809"
        "893509348613871434707789376261644065380096435546875e-274"},
    {0x1.fffffffffffffp-908, chars_format::scientific, 686,
        "9."
        "2425952044279264033404215310155199445253510204730641140569017757924743559720608747728550118674681357447604"
        "0255520292933680109370222891099407099337887326688635775283688297031515203409520982079596242052332132749981"
        "4238863529894695275514079227367328335062629414091951787324403970931806752595855963250211512353109878390638"
        "7067969593968278291988958171487058030594328061228212460625899649201818084911564099720535785368350456488672"
        "4012522519321268521501916472329063543170094127090394370805475190817882515818564497693573184193023383554467"
        "7127263839548287250898828136257109219788416139822692911474546820992029807620334562651911905183337085367619"
        "78701869722774286941557875252328813076019287109375e-274"},
    {0x1.fffffffffffffp-907, chars_format::scientific, 686,
        "1."
        "8485190408855852806680843062031039889050702040946128228113803551584948711944121749545710023734936271489520"
        "8051104058586736021874044578219881419867577465337727155056737659406303040681904196415919248410466426549996"
        "2847772705978939055102815845473465667012525882818390357464880794186361350519171192650042302470621975678127"
        "7413593918793655658397791634297411606118865612245642492125179929840363616982312819944107157073670091297734"
        "4802504503864253704300383294465812708634018825418078874161095038163576503163712899538714636838604676710893"
        "5425452767909657450179765627251421843957683227964538582294909364198405961524066912530382381036667417073523"
        "95740373944554857388311575050465762615203857421875e-273"},
    {0x1.fffffffffffffp-906, chars_format::scientific, 685,
        "3."
        "6970380817711705613361686124062079778101404081892256456227607103169897423888243499091420047469872542979041"
        "6102208117173472043748089156439762839735154930675454310113475318812606081363808392831838496820932853099992"
        "5695545411957878110205631690946931334025051765636780714929761588372722701038342385300084604941243951356255"
        "4827187837587311316795583268594823212237731224491284984250359859680727233964625639888214314147340182595468"
        "9605009007728507408600766588931625417268037650836157748322190076327153006327425799077429273677209353421787"
        "0850905535819314900359531254502843687915366455929077164589818728396811923048133825060764762073334834147047"
        "9148074788910971477662315010093152523040771484375e-273"},
    {0x1.fffffffffffffp-905, chars_format::scientific, 684,
        "7."
        "3940761635423411226723372248124159556202808163784512912455214206339794847776486998182840094939745085958083"
        "2204416234346944087496178312879525679470309861350908620226950637625212162727616785663676993641865706199985"
        "1391090823915756220411263381893862668050103531273561429859523176745445402076684770600169209882487902712510"
        "9654375675174622633591166537189646424475462448982569968500719719361454467929251279776428628294680365190937"
        "9210018015457014817201533177863250834536075301672315496644380152654306012654851598154858547354418706843574"
        "1701811071638629800719062509005687375830732911858154329179637456793623846096267650121529524146669668294095"
        "829614957782194295532463002018630504608154296875e-273"},
    {0x1.fffffffffffffp-904, chars_format::scientific, 684,
        "1."
        "4788152327084682245344674449624831911240561632756902582491042841267958969555297399636568018987949017191616"
        "6440883246869388817499235662575905135894061972270181724045390127525042432545523357132735398728373141239997"
        "0278218164783151244082252676378772533610020706254712285971904635349089080415336954120033841976497580542502"
        "1930875135034924526718233307437929284895092489796513993700143943872290893585850255955285725658936073038187"
        "5842003603091402963440306635572650166907215060334463099328876030530861202530970319630971709470883741368714"
        "8340362214327725960143812501801137475166146582371630865835927491358724769219253530024305904829333933658819"
        "165922991556438859106492600403726100921630859375e-272"},
    {0x1.fffffffffffffp-903, chars_format::scientific, 683,
        "2."
        "9576304654169364490689348899249663822481123265513805164982085682535917939110594799273136037975898034383233"
        "2881766493738777634998471325151810271788123944540363448090780255050084865091046714265470797456746282479994"
        "0556436329566302488164505352757545067220041412509424571943809270698178160830673908240067683952995161085004"
        "3861750270069849053436466614875858569790184979593027987400287887744581787171700511910571451317872146076375"
        "1684007206182805926880613271145300333814430120668926198657752061061722405061940639261943418941767482737429"
        "6680724428655451920287625003602274950332293164743261731671854982717449538438507060048611809658667867317638"
        "33184598311287771821298520080745220184326171875e-272"},
    {0x1.fffffffffffffp-902, chars_format::scientific, 682,
        "5."
        "9152609308338728981378697798499327644962246531027610329964171365071835878221189598546272075951796068766466"
        "5763532987477555269996942650303620543576247889080726896181560510100169730182093428530941594913492564959988"
        "1112872659132604976329010705515090134440082825018849143887618541396356321661347816480135367905990322170008"
        "7723500540139698106872933229751717139580369959186055974800575775489163574343401023821142902635744292152750"
        "3368014412365611853761226542290600667628860241337852397315504122123444810123881278523886837883534965474859"
        "3361448857310903840575250007204549900664586329486523463343709965434899076877014120097223619317335734635276"
        "6636919662257554364259704016149044036865234375e-272"},
    {0x1.fffffffffffffp-901, chars_format::scientific, 682,
        "1."
        "1830521861667745796275739559699865528992449306205522065992834273014367175644237919709254415190359213753293"
        "3152706597495511053999388530060724108715249577816145379236312102020033946036418685706188318982698512991997"
        "6222574531826520995265802141103018026888016565003769828777523708279271264332269563296027073581198064434001"
        "7544700108027939621374586645950343427916073991837211194960115155097832714868680204764228580527148858430550"
        "0673602882473122370752245308458120133525772048267570479463100824424688962024776255704777367576706993094971"
        "8672289771462180768115050001440909980132917265897304692668741993086979815375402824019444723863467146927055"
        "3327383932451510872851940803229808807373046875e-271"},
    {0x1.fffffffffffffp-900, chars_format::scientific, 681,
        "2."
        "3661043723335491592551479119399731057984898612411044131985668546028734351288475839418508830380718427506586"
        "6305413194991022107998777060121448217430499155632290758472624204040067892072837371412376637965397025983995"
        "2445149063653041990531604282206036053776033130007539657555047416558542528664539126592054147162396128868003"
        "5089400216055879242749173291900686855832147983674422389920230310195665429737360409528457161054297716861100"
        "1347205764946244741504490616916240267051544096535140958926201648849377924049552511409554735153413986189943"
        "7344579542924361536230100002881819960265834531794609385337483986173959630750805648038889447726934293854110"
        "665476786490302174570388160645961761474609375e-271"},
    {0x1.fffffffffffffp-899, chars_format::scientific, 680,
        "4."
        "7322087446670983185102958238799462115969797224822088263971337092057468702576951678837017660761436855013173"
        "2610826389982044215997554120242896434860998311264581516945248408080135784145674742824753275930794051967990"
        "4890298127306083981063208564412072107552066260015079315110094833117085057329078253184108294324792257736007"
        "0178800432111758485498346583801373711664295967348844779840460620391330859474720819056914322108595433722200"
        "2694411529892489483008981233832480534103088193070281917852403297698755848099105022819109470306827972379887"
        "4689159085848723072460200005763639920531669063589218770674967972347919261501611296077778895453868587708221"
        "33095357298060434914077632129192352294921875e-271"},
    {0x1.fffffffffffffp-898, chars_format::scientific, 679,
        "9."
        "4644174893341966370205916477598924231939594449644176527942674184114937405153903357674035321522873710026346"
        "5221652779964088431995108240485792869721996622529163033890496816160271568291349485649506551861588103935980"
        "9780596254612167962126417128824144215104132520030158630220189666234170114658156506368216588649584515472014"
        "0357600864223516970996693167602747423328591934697689559680921240782661718949441638113828644217190867444400"
        "5388823059784978966017962467664961068206176386140563835704806595397511696198210045638218940613655944759774"
        "9378318171697446144920400011527279841063338127178437541349935944695838523003222592155557790907737175416442"
        "6619071459612086982815526425838470458984375e-271"},
    {0x1.fffffffffffffp-897, chars_format::scientific, 679,
        "1."
        "8928834978668393274041183295519784846387918889928835305588534836822987481030780671534807064304574742005269"
        "3044330555992817686399021648097158573944399324505832606778099363232054313658269897129901310372317620787196"
        "1956119250922433592425283425764828843020826504006031726044037933246834022931631301273643317729916903094402"
        "8071520172844703394199338633520549484665718386939537911936184248156532343789888327622765728843438173488880"
        "1077764611956995793203592493532992213641235277228112767140961319079502339239642009127643788122731188951954"
        "9875663634339489228984080002305455968212667625435687508269987188939167704600644518431111558181547435083288"
        "5323814291922417396563105285167694091796875e-270"},
    {0x1.fffffffffffffp-896, chars_format::scientific, 678,
        "3."
        "7857669957336786548082366591039569692775837779857670611177069673645974962061561343069614128609149484010538"
        "6088661111985635372798043296194317147888798649011665213556198726464108627316539794259802620744635241574392"
        "3912238501844867184850566851529657686041653008012063452088075866493668045863262602547286635459833806188805"
        "6143040345689406788398677267041098969331436773879075823872368496313064687579776655245531457686876346977760"
        "2155529223913991586407184987065984427282470554456225534281922638159004678479284018255287576245462377903909"
        "9751327268678978457968160004610911936425335250871375016539974377878335409201289036862223116363094870166577"
        "064762858384483479312621057033538818359375e-270"},
    {0x1.fffffffffffffp-895, chars_format::scientific, 677,
        "7."
        "5715339914673573096164733182079139385551675559715341222354139347291949924123122686139228257218298968021077"
        "2177322223971270745596086592388634295777597298023330427112397452928217254633079588519605241489270483148784"
        "7824477003689734369701133703059315372083306016024126904176151732987336091726525205094573270919667612377611"
        "2286080691378813576797354534082197938662873547758151647744736992626129375159553310491062915373752693955520"
        "4311058447827983172814369974131968854564941108912451068563845276318009356958568036510575152490924755807819"
        "9502654537357956915936320009221823872850670501742750033079948755756670818402578073724446232726189740333154"
        "12952571676896695862524211406707763671875e-270"},
    {0x1.fffffffffffffp-894, chars_format::scientific, 677,
        "1."
        "5143067982934714619232946636415827877110335111943068244470827869458389984824624537227845651443659793604215"
        "4435464444794254149119217318477726859155519459604666085422479490585643450926615917703921048297854096629756"
        "9564895400737946873940226740611863074416661203204825380835230346597467218345305041018914654183933522475522"
        "2457216138275762715359470906816439587732574709551630329548947398525225875031910662098212583074750538791104"
        "0862211689565596634562873994826393770912988221782490213712769055263601871391713607302115030498184951161563"
        "9900530907471591383187264001844364774570134100348550006615989751151334163680515614744889246545237948066630"
        "82590514335379339172504842281341552734375e-269"},
    {0x1.fffffffffffffp-893, chars_format::scientific, 676,
        "3."
        "0286135965869429238465893272831655754220670223886136488941655738916779969649249074455691302887319587208430"
        "8870928889588508298238434636955453718311038919209332170844958981171286901853231835407842096595708193259513"
        "9129790801475893747880453481223726148833322406409650761670460693194934436690610082037829308367867044951044"
        "4914432276551525430718941813632879175465149419103260659097894797050451750063821324196425166149501077582208"
        "1724423379131193269125747989652787541825976443564980427425538110527203742783427214604230060996369902323127"
        "9801061814943182766374528003688729549140268200697100013231979502302668327361031229489778493090475896133261"
        "6518102867075867834500968456268310546875e-269"},
    {0x1.fffffffffffffp-892, chars_format::scientific, 675,
        "6."
        "0572271931738858476931786545663311508441340447772272977883311477833559939298498148911382605774639174416861"
        "7741857779177016596476869273910907436622077838418664341689917962342573803706463670815684193191416386519027"
        "8259581602951787495760906962447452297666644812819301523340921386389868873381220164075658616735734089902088"
        "9828864553103050861437883627265758350930298838206521318195789594100903500127642648392850332299002155164416"
        "3448846758262386538251495979305575083651952887129960854851076221054407485566854429208460121992739804646255"
        "9602123629886365532749056007377459098280536401394200026463959004605336654722062458979556986180951792266523"
        "303620573415173566900193691253662109375e-269"},
    {0x1.fffffffffffffp-891, chars_format::scientific, 675,
        "1."
        "2114454386347771695386357309132662301688268089554454595576662295566711987859699629782276521154927834883372"
        "3548371555835403319295373854782181487324415567683732868337983592468514760741292734163136838638283277303805"
        "5651916320590357499152181392489490459533328962563860304668184277277973774676244032815131723347146817980417"
        "7965772910620610172287576725453151670186059767641304263639157918820180700025528529678570066459800431032883"
        "2689769351652477307650299195861115016730390577425992170970215244210881497113370885841692024398547960929251"
        "1920424725977273106549811201475491819656107280278840005292791800921067330944412491795911397236190358453304"
        "660724114683034713380038738250732421875e-268"},
    {0x1.fffffffffffffp-890, chars_format::scientific, 674,
        "2."
        "4228908772695543390772714618265324603376536179108909191153324591133423975719399259564553042309855669766744"
        "7096743111670806638590747709564362974648831135367465736675967184937029521482585468326273677276566554607611"
        "1303832641180714998304362784978980919066657925127720609336368554555947549352488065630263446694293635960835"
        "5931545821241220344575153450906303340372119535282608527278315837640361400051057059357140132919600862065766"
        "5379538703304954615300598391722230033460781154851984341940430488421762994226741771683384048797095921858502"
        "3840849451954546213099622402950983639312214560557680010585583601842134661888824983591822794472380716906609"
        "32144822936606942676007747650146484375e-268"},
    {0x1.fffffffffffffp-889, chars_format::scientific, 673,
        "4."
        "8457817545391086781545429236530649206753072358217818382306649182266847951438798519129106084619711339533489"
        "4193486223341613277181495419128725949297662270734931473351934369874059042965170936652547354553133109215222"
        "2607665282361429996608725569957961838133315850255441218672737109111895098704976131260526893388587271921671"
        "1863091642482440689150306901812606680744239070565217054556631675280722800102114118714280265839201724131533"
        "0759077406609909230601196783444460066921562309703968683880860976843525988453483543366768097594191843717004"
        "7681698903909092426199244805901967278624429121115360021171167203684269323777649967183645588944761433813218"
        "6428964587321388535201549530029296875e-268"},
    {0x1.fffffffffffffp-888, chars_format::scientific, 672,
        "9."
        "6915635090782173563090858473061298413506144716435636764613298364533695902877597038258212169239422679066978"
        "8386972446683226554362990838257451898595324541469862946703868739748118085930341873305094709106266218430444"
        "5215330564722859993217451139915923676266631700510882437345474218223790197409952262521053786777174543843342"
        "3726183284964881378300613803625213361488478141130434109113263350561445600204228237428560531678403448263066"
        "1518154813219818461202393566888920133843124619407937367761721953687051976906967086733536195188383687434009"
        "5363397807818184852398489611803934557248858242230720042342334407368538647555299934367291177889522867626437"
        "285792917464277707040309906005859375e-268"},
    {0x1.fffffffffffffp-887, chars_format::scientific, 672,
        "1."
        "9383127018156434712618171694612259682701228943287127352922659672906739180575519407651642433847884535813395"
        "7677394489336645310872598167651490379719064908293972589340773747949623617186068374661018941821253243686088"
        "9043066112944571998643490227983184735253326340102176487469094843644758039481990452504210757355434908768668"
        "4745236656992976275660122760725042672297695628226086821822652670112289120040845647485712106335680689652613"
        "2303630962643963692240478713377784026768624923881587473552344390737410395381393417346707239037676737486801"
        "9072679561563636970479697922360786911449771648446144008468466881473707729511059986873458235577904573525287"
        "457158583492855541408061981201171875e-267"},
    {0x1.fffffffffffffp-886, chars_format::scientific, 671,
        "3."
        "8766254036312869425236343389224519365402457886574254705845319345813478361151038815303284867695769071626791"
        "5354788978673290621745196335302980759438129816587945178681547495899247234372136749322037883642506487372177"
        "8086132225889143997286980455966369470506652680204352974938189687289516078963980905008421514710869817537336"
        "9490473313985952551320245521450085344595391256452173643645305340224578240081691294971424212671361379305226"
        "4607261925287927384480957426755568053537249847763174947104688781474820790762786834693414478075353474973603"
        "8145359123127273940959395844721573822899543296892288016936933762947415459022119973746916471155809147050574"
        "91431716698571108281612396240234375e-267"},
    {0x1.fffffffffffffp-885, chars_format::scientific, 670,
        "7."
        "7532508072625738850472686778449038730804915773148509411690638691626956722302077630606569735391538143253583"
        "0709577957346581243490392670605961518876259633175890357363094991798494468744273498644075767285012974744355"
        "6172264451778287994573960911932738941013305360408705949876379374579032157927961810016843029421739635074673"
        "8980946627971905102640491042900170689190782512904347287290610680449156480163382589942848425342722758610452"
        "9214523850575854768961914853511136107074499695526349894209377562949641581525573669386828956150706949947207"
        "6290718246254547881918791689443147645799086593784576033873867525894830918044239947493832942311618294101149"
        "8286343339714221656322479248046875e-267"},
    {0x1.fffffffffffffp-884, chars_format::scientific, 670,
        "1."
        "5506501614525147770094537355689807746160983154629701882338127738325391344460415526121313947078307628650716"
        "6141915591469316248698078534121192303775251926635178071472618998359698893748854699728815153457002594948871"
        "1234452890355657598914792182386547788202661072081741189975275874915806431585592362003368605884347927014934"
        "7796189325594381020528098208580034137838156502580869457458122136089831296032676517988569685068544551722090"
        "5842904770115170953792382970702227221414899939105269978841875512589928316305114733877365791230141389989441"
        "5258143649250909576383758337888629529159817318756915206774773505178966183608847989498766588462323658820229"
        "9657268667942844331264495849609375e-266"},
    {0x1.fffffffffffffp-883, chars_format::scientific, 669,
        "3."
        "1013003229050295540189074711379615492321966309259403764676255476650782688920831052242627894156615257301433"
        "2283831182938632497396157068242384607550503853270356142945237996719397787497709399457630306914005189897742"
        "2468905780711315197829584364773095576405322144163482379950551749831612863171184724006737211768695854029869"
        "5592378651188762041056196417160068275676313005161738914916244272179662592065353035977139370137089103444181"
        "1685809540230341907584765941404454442829799878210539957683751025179856632610229467754731582460282779978883"
        "0516287298501819152767516675777259058319634637513830413549547010357932367217695978997533176924647317640459"
        "931453733588568866252899169921875e-266"},
    {0x1.fffffffffffffp-882, chars_format::scientific, 668,
        "6."
        "2026006458100591080378149422759230984643932618518807529352510953301565377841662104485255788313230514602866"
        "4567662365877264994792314136484769215101007706540712285890475993438795574995418798915260613828010379795484"
        "4937811561422630395659168729546191152810644288326964759901103499663225726342369448013474423537391708059739"
        "1184757302377524082112392834320136551352626010323477829832488544359325184130706071954278740274178206888362"
        "3371619080460683815169531882808908885659599756421079915367502050359713265220458935509463164920565559957766"
        "1032574597003638305535033351554518116639269275027660827099094020715864734435391957995066353849294635280919"
        "86290746717713773250579833984375e-266"},
    {0x1.fffffffffffffp-881, chars_format::scientific, 668,
        "1."
        "2405201291620118216075629884551846196928786523703761505870502190660313075568332420897051157662646102920573"
        "2913532473175452998958462827296953843020201541308142457178095198687759114999083759783052122765602075959096"
        "8987562312284526079131833745909238230562128857665392951980220699932645145268473889602694884707478341611947"
        "8236951460475504816422478566864027310270525202064695565966497708871865036826141214390855748054835641377672"
        "4674323816092136763033906376561781777131919951284215983073500410071942653044091787101892632984113111991553"
        "2206514919400727661107006670310903623327853855005532165419818804143172946887078391599013270769858927056183"
        "97258149343542754650115966796875e-265"},
    {0x1.fffffffffffffp-880, chars_format::scientific, 667,
        "2."
        "4810402583240236432151259769103692393857573047407523011741004381320626151136664841794102315325292205841146"
        "5827064946350905997916925654593907686040403082616284914356190397375518229998167519566104245531204151918193"
        "7975124624569052158263667491818476461124257715330785903960441399865290290536947779205389769414956683223895"
        "6473902920951009632844957133728054620541050404129391131932995417743730073652282428781711496109671282755344"
        "9348647632184273526067812753123563554263839902568431966147000820143885306088183574203785265968226223983106"
        "4413029838801455322214013340621807246655707710011064330839637608286345893774156783198026541539717854112367"
        "9451629868708550930023193359375e-265"},
    {0x1.fffffffffffffp-879, chars_format::scientific, 666,
        "4."
        "9620805166480472864302519538207384787715146094815046023482008762641252302273329683588204630650584411682293"
        "1654129892701811995833851309187815372080806165232569828712380794751036459996335039132208491062408303836387"
        "5950249249138104316527334983636952922248515430661571807920882799730580581073895558410779538829913366447791"
        "2947805841902019265689914267456109241082100808258782263865990835487460147304564857563422992219342565510689"
        "8697295264368547052135625506247127108527679805136863932294001640287770612176367148407570531936452447966212"
        "8826059677602910644428026681243614493311415420022128661679275216572691787548313566396053083079435708224735"
        "890325973741710186004638671875e-265"},
    {0x1.fffffffffffffp-878, chars_format::scientific, 665,
        "9."
        "9241610332960945728605039076414769575430292189630092046964017525282504604546659367176409261301168823364586"
        "3308259785403623991667702618375630744161612330465139657424761589502072919992670078264416982124816607672775"
        "1900498498276208633054669967273905844497030861323143615841765599461161162147791116821559077659826732895582"
        "5895611683804038531379828534912218482164201616517564527731981670974920294609129715126845984438685131021379"
        "7394590528737094104271251012494254217055359610273727864588003280575541224352734296815141063872904895932425"
        "7652119355205821288856053362487228986622830840044257323358550433145383575096627132792106166158871416449471"
        "78065194748342037200927734375e-265"},
    {0x1.fffffffffffffp-877, chars_format::scientific, 665,
        "1."
        "9848322066592189145721007815282953915086058437926018409392803505056500920909331873435281852260233764672917"
        "2661651957080724798333540523675126148832322466093027931484952317900414583998534015652883396424963321534555"
        "0380099699655241726610933993454781168899406172264628723168353119892232232429558223364311815531965346579116"
        "5179122336760807706275965706982443696432840323303512905546396334194984058921825943025369196887737026204275"
        "9478918105747418820854250202498850843411071922054745572917600656115108244870546859363028212774580979186485"
        "1530423871041164257771210672497445797324566168008851464671710086629076715019325426558421233231774283289894"
        "35613038949668407440185546875e-264"},
    {0x1.fffffffffffffp-876, chars_format::scientific, 664,
        "3."
        "9696644133184378291442015630565907830172116875852036818785607010113001841818663746870563704520467529345834"
        "5323303914161449596667081047350252297664644932186055862969904635800829167997068031305766792849926643069110"
        "0760199399310483453221867986909562337798812344529257446336706239784464464859116446728623631063930693158233"
        "0358244673521615412551931413964887392865680646607025811092792668389968117843651886050738393775474052408551"
        "8957836211494837641708500404997701686822143844109491145835201312230216489741093718726056425549161958372970"
        "3060847742082328515542421344994891594649132336017702929343420173258153430038650853116842466463548566579788"
        "7122607789933681488037109375e-264"},
    {0x1.fffffffffffffp-875, chars_format::scientific, 663,
        "7."
        "9393288266368756582884031261131815660344233751704073637571214020226003683637327493741127409040935058691669"
        "0646607828322899193334162094700504595329289864372111725939809271601658335994136062611533585699853286138220"
        "1520398798620966906443735973819124675597624689058514892673412479568928929718232893457247262127861386316466"
        "0716489347043230825103862827929774785731361293214051622185585336779936235687303772101476787550948104817103"
        "7915672422989675283417000809995403373644287688218982291670402624460432979482187437452112851098323916745940"
        "6121695484164657031084842689989783189298264672035405858686840346516306860077301706233684932927097133159577"
        "424521557986736297607421875e-264"},
    {0x1.fffffffffffffp-874, chars_format::scientific, 663,
        "1."
        "5878657653273751316576806252226363132068846750340814727514242804045200736727465498748225481808187011738333"
        "8129321565664579838666832418940100919065857972874422345187961854320331667198827212522306717139970657227644"
        "0304079759724193381288747194763824935119524937811702978534682495913785785943646578691449452425572277263293"
        "2143297869408646165020772565585954957146272258642810324437117067355987247137460754420295357510189620963420"
        "7583134484597935056683400161999080674728857537643796458334080524892086595896437487490422570219664783349188"
        "1224339096832931406216968537997956637859652934407081171737368069303261372015460341246736986585419426631915"
        "484904311597347259521484375e-263"},
    {0x1.fffffffffffffp-873, chars_format::scientific, 662,
        "3."
        "1757315306547502633153612504452726264137693500681629455028485608090401473454930997496450963616374023476667"
        "6258643131329159677333664837880201838131715945748844690375923708640663334397654425044613434279941314455288"
        "0608159519448386762577494389527649870239049875623405957069364991827571571887293157382898904851144554526586"
        "4286595738817292330041545131171909914292544517285620648874234134711974494274921508840590715020379241926841"
        "5166268969195870113366800323998161349457715075287592916668161049784173191792874974980845140439329566698376"
        "2448678193665862812433937075995913275719305868814162343474736138606522744030920682493473973170838853263830"
        "96980862319469451904296875e-263"},
    {0x1.fffffffffffffp-872, chars_format::scientific, 661,
        "6."
        "3514630613095005266307225008905452528275387001363258910056971216180802946909861994992901927232748046953335"
        "2517286262658319354667329675760403676263431891497689380751847417281326668795308850089226868559882628910576"
        "1216319038896773525154988779055299740478099751246811914138729983655143143774586314765797809702289109053172"
        "8573191477634584660083090262343819828585089034571241297748468269423948988549843017681181430040758483853683"
        "0332537938391740226733600647996322698915430150575185833336322099568346383585749949961690280878659133396752"
        "4897356387331725624867874151991826551438611737628324686949472277213045488061841364986947946341677706527661"
        "9396172463893890380859375e-263"},
    {0x1.fffffffffffffp-871, chars_format::scientific, 661,
        "1."
        "2702926122619001053261445001781090505655077400272651782011394243236160589381972398998580385446549609390667"
        "0503457252531663870933465935152080735252686378299537876150369483456265333759061770017845373711976525782115"
        "2243263807779354705030997755811059948095619950249362382827745996731028628754917262953159561940457821810634"
        "5714638295526916932016618052468763965717017806914248259549693653884789797709968603536236286008151696770736"
        "6066507587678348045346720129599264539783086030115037166667264419913669276717149989992338056175731826679350"
        "4979471277466345124973574830398365310287722347525664937389894455442609097612368272997389589268335541305532"
        "3879234492778778076171875e-262"},
    {0x1.fffffffffffffp-870, chars_format::scientific, 660,
        "2."
        "5405852245238002106522890003562181011310154800545303564022788486472321178763944797997160770893099218781334"
        "1006914505063327741866931870304161470505372756599075752300738966912530667518123540035690747423953051564230"
        "4486527615558709410061995511622119896191239900498724765655491993462057257509834525906319123880915643621269"
        "1429276591053833864033236104937527931434035613828496519099387307769579595419937207072472572016303393541473"
        "2133015175356696090693440259198529079566172060230074333334528839827338553434299979984676112351463653358700"
        "9958942554932690249947149660796730620575444695051329874779788910885218195224736545994779178536671082611064"
        "775846898555755615234375e-262"},
    {0x1.fffffffffffffp-869, chars_format::scientific, 659,
        "5."
        "0811704490476004213045780007124362022620309601090607128045576972944642357527889595994321541786198437562668"
        "2013829010126655483733863740608322941010745513198151504601477933825061335036247080071381494847906103128460"
        "8973055231117418820123991023244239792382479800997449531310983986924114515019669051812638247761831287242538"
        "2858553182107667728066472209875055862868071227656993038198774615539159190839874414144945144032606787082946"
        "4266030350713392181386880518397058159132344120460148666669057679654677106868599959969352224702927306717401"
        "9917885109865380499894299321593461241150889390102659749559577821770436390449473091989558357073342165222129"
        "55169379711151123046875e-262"},
    {0x1.fffffffffffffp-868, chars_format::scientific, 659,
        "1."
        "0162340898095200842609156001424872404524061920218121425609115394588928471505577919198864308357239687512533"
        "6402765802025331096746772748121664588202149102639630300920295586765012267007249416014276298969581220625692"
        "1794611046223483764024798204648847958476495960199489906262196797384822903003933810362527649552366257448507"
        "6571710636421533545613294441975011172573614245531398607639754923107831838167974882828989028806521357416589"
        "2853206070142678436277376103679411631826468824092029733333811535930935421373719991993870444940585461343480"
        "3983577021973076099978859864318692248230177878020531949911915564354087278089894618397911671414668433044425"
        "91033875942230224609375e-261"},
    {0x1.fffffffffffffp-867, chars_format::scientific, 658,
        "2."
        "0324681796190401685218312002849744809048123840436242851218230789177856943011155838397728616714479375025067"
        "2805531604050662193493545496243329176404298205279260601840591173530024534014498832028552597939162441251384"
        "3589222092446967528049596409297695916952991920398979812524393594769645806007867620725055299104732514897015"
        "3143421272843067091226588883950022345147228491062797215279509846215663676335949765657978057613042714833178"
        "5706412140285356872554752207358823263652937648184059466667623071861870842747439983987740889881170922686960"
        "7967154043946152199957719728637384496460355756041063899823831128708174556179789236795823342829336866088851"
        "8206775188446044921875e-261"},
    {0x1.fffffffffffffp-866, chars_format::scientific, 657,
        "4."
        "0649363592380803370436624005699489618096247680872485702436461578355713886022311676795457233428958750050134"
        "5611063208101324386987090992486658352808596410558521203681182347060049068028997664057105195878324882502768"
        "7178444184893935056099192818595391833905983840797959625048787189539291612015735241450110598209465029794030"
        "6286842545686134182453177767900044690294456982125594430559019692431327352671899531315956115226085429666357"
        "1412824280570713745109504414717646527305875296368118933335246143723741685494879967975481779762341845373921"
        "5934308087892304399915439457274768992920711512082127799647662257416349112359578473591646685658673732177703"
        "641355037689208984375e-261"},
    {0x1.fffffffffffffp-865, chars_format::scientific, 656,
        "8."
        "1298727184761606740873248011398979236192495361744971404872923156711427772044623353590914466857917500100269"
        "1222126416202648773974181984973316705617192821117042407362364694120098136057995328114210391756649765005537"
        "4356888369787870112198385637190783667811967681595919250097574379078583224031470482900221196418930059588061"
        "2573685091372268364906355535800089380588913964251188861118039384862654705343799062631912230452170859332714"
        "2825648561141427490219008829435293054611750592736237866670492287447483370989759935950963559524683690747843"
        "1868616175784608799830878914549537985841423024164255599295324514832698224719156947183293371317347464355407"
        "28271007537841796875e-261"},
    {0x1.fffffffffffffp-864, chars_format::scientific, 656,
        "1."
        "6259745436952321348174649602279795847238499072348994280974584631342285554408924670718182893371583500020053"
        "8244425283240529754794836396994663341123438564223408481472472938824019627211599065622842078351329953001107"
        "4871377673957574022439677127438156733562393536319183850019514875815716644806294096580044239283786011917612"
        "2514737018274453672981271107160017876117782792850237772223607876972530941068759812526382446090434171866542"
        "8565129712228285498043801765887058610922350118547247573334098457489496674197951987190192711904936738149568"
        "6373723235156921759966175782909907597168284604832851119859064902966539644943831389436658674263469492871081"
        "45654201507568359375e-260"},
    {0x1.fffffffffffffp-863, chars_format::scientific, 655,
        "3."
        "2519490873904642696349299204559591694476998144697988561949169262684571108817849341436365786743167000040107"
        "6488850566481059509589672793989326682246877128446816962944945877648039254423198131245684156702659906002214"
        "9742755347915148044879354254876313467124787072638367700039029751631433289612588193160088478567572023835224"
        "5029474036548907345962542214320035752235565585700475544447215753945061882137519625052764892180868343733085"
        "7130259424456570996087603531774117221844700237094495146668196914978993348395903974380385423809873476299137"
        "2747446470313843519932351565819815194336569209665702239718129805933079289887662778873317348526938985742162"
        "9130840301513671875e-260"},
    {0x1.fffffffffffffp-862, chars_format::scientific, 654,
        "6."
        "5038981747809285392698598409119183388953996289395977123898338525369142217635698682872731573486334000080215"
        "2977701132962119019179345587978653364493754256893633925889891755296078508846396262491368313405319812004429"
        "9485510695830296089758708509752626934249574145276735400078059503262866579225176386320176957135144047670449"
        "0058948073097814691925084428640071504471131171400951088894431507890123764275039250105529784361736687466171"
        "4260518848913141992175207063548234443689400474188990293336393829957986696791807948760770847619746952598274"
        "5494892940627687039864703131639630388673138419331404479436259611866158579775325557746634697053877971484325"
        "826168060302734375e-260"},
    {0x1.fffffffffffffp-861, chars_format::scientific, 654,
        "1."
        "3007796349561857078539719681823836677790799257879195424779667705073828443527139736574546314697266800016043"
        "0595540226592423803835869117595730672898750851378726785177978351059215701769279252498273662681063962400885"
        "9897102139166059217951741701950525386849914829055347080015611900652573315845035277264035391427028809534089"
        "8011789614619562938385016885728014300894226234280190217778886301578024752855007850021105956872347337493234"
        "2852103769782628398435041412709646888737880094837798058667278765991597339358361589752154169523949390519654"
        "9098978588125537407972940626327926077734627683866280895887251922373231715955065111549326939410775594296865"
        "165233612060546875e-259"},
    {0x1.fffffffffffffp-860, chars_format::scientific, 653,
        "2."
        "6015592699123714157079439363647673355581598515758390849559335410147656887054279473149092629394533600032086"
        "1191080453184847607671738235191461345797501702757453570355956702118431403538558504996547325362127924801771"
        "9794204278332118435903483403901050773699829658110694160031223801305146631690070554528070782854057619068179"
        "6023579229239125876770033771456028601788452468560380435557772603156049505710015700042211913744694674986468"
        "5704207539565256796870082825419293777475760189675596117334557531983194678716723179504308339047898781039309"
        "8197957176251074815945881252655852155469255367732561791774503844746463431910130223098653878821551188593730"
        "33046722412109375e-259"},
    {0x1.fffffffffffffp-859, chars_format::scientific, 652,
        "5."
        "2031185398247428314158878727295346711163197031516781699118670820295313774108558946298185258789067200064172"
        "2382160906369695215343476470382922691595003405514907140711913404236862807077117009993094650724255849603543"
        "9588408556664236871806966807802101547399659316221388320062447602610293263380141109056141565708115238136359"
        "2047158458478251753540067542912057203576904937120760871115545206312099011420031400084423827489389349972937"
        "1408415079130513593740165650838587554951520379351192234669115063966389357433446359008616678095797562078619"
        "6395914352502149631891762505311704310938510735465123583549007689492926863820260446197307757643102377187460"
        "6609344482421875e-259"},
    {0x1.fffffffffffffp-858, chars_format::scientific, 652,
        "1."
        "0406237079649485662831775745459069342232639406303356339823734164059062754821711789259637051757813440012834"
        "4476432181273939043068695294076584538319000681102981428142382680847372561415423401998618930144851169920708"
        "7917681711332847374361393361560420309479931863244277664012489520522058652676028221811228313141623047627271"
        "8409431691695650350708013508582411440715380987424152174223109041262419802284006280016884765497877869994587"
        "4281683015826102718748033130167717510990304075870238446933823012793277871486689271801723335619159512415723"
        "9279182870500429926378352501062340862187702147093024716709801537898585372764052089239461551528620475437492"
        "1321868896484375e-258"},
    {0x1.fffffffffffffp-857, chars_format::scientific, 651,
        "2."
        "0812474159298971325663551490918138684465278812606712679647468328118125509643423578519274103515626880025668"
        "8952864362547878086137390588153169076638001362205962856284765361694745122830846803997237860289702339841417"
        "5835363422665694748722786723120840618959863726488555328024979041044117305352056443622456626283246095254543"
        "6818863383391300701416027017164822881430761974848304348446218082524839604568012560033769530995755739989174"
        "8563366031652205437496066260335435021980608151740476893867646025586555742973378543603446671238319024831447"
        "8558365741000859852756705002124681724375404294186049433419603075797170745528104178478923103057240950874984"
        "264373779296875e-258"},
    {0x1.fffffffffffffp-856, chars_format::scientific, 650,
        "4."
        "1624948318597942651327102981836277368930557625213425359294936656236251019286847157038548207031253760051337"
        "7905728725095756172274781176306338153276002724411925712569530723389490245661693607994475720579404679682835"
        "1670726845331389497445573446241681237919727452977110656049958082088234610704112887244913252566492190509087"
        "3637726766782601402832054034329645762861523949696608696892436165049679209136025120067539061991511479978349"
        "7126732063304410874992132520670870043961216303480953787735292051173111485946757087206893342476638049662895"
        "7116731482001719705513410004249363448750808588372098866839206151594341491056208356957846206114481901749968"
        "52874755859375e-258"},
    {0x1.fffffffffffffp-855, chars_format::scientific, 649,
        "8."
        "3249896637195885302654205963672554737861115250426850718589873312472502038573694314077096414062507520102675"
        "5811457450191512344549562352612676306552005448823851425139061446778980491323387215988951441158809359365670"
        "3341453690662778994891146892483362475839454905954221312099916164176469221408225774489826505132984381018174"
        "7275453533565202805664108068659291525723047899393217393784872330099358418272050240135078123983022959956699"
        "4253464126608821749984265041341740087922432606961907575470584102346222971893514174413786684953276099325791"
        "4233462964003439411026820008498726897501617176744197733678412303188682982112416713915692412228963803499937"
        "0574951171875e-258"},
    {0x1.fffffffffffffp-854, chars_format::scientific, 649,
        "1."
        "6649979327439177060530841192734510947572223050085370143717974662494500407714738862815419282812501504020535"
        "1162291490038302468909912470522535261310401089764770285027812289355796098264677443197790288231761871873134"
        "0668290738132555798978229378496672495167890981190844262419983232835293844281645154897965301026596876203634"
        "9455090706713040561132821613731858305144609579878643478756974466019871683654410048027015624796604591991339"
        "8850692825321764349996853008268348017584486521392381515094116820469244594378702834882757336990655219865158"
        "2846692592800687882205364001699745379500323435348839546735682460637736596422483342783138482445792760699987"
        "4114990234375e-257"},
    {0x1.fffffffffffffp-853, chars_format::scientific, 648,
        "3."
        "3299958654878354121061682385469021895144446100170740287435949324989000815429477725630838565625003008041070"
        "2324582980076604937819824941045070522620802179529540570055624578711592196529354886395580576463523743746268"
        "1336581476265111597956458756993344990335781962381688524839966465670587688563290309795930602053193752407269"
        "8910181413426081122265643227463716610289219159757286957513948932039743367308820096054031249593209183982679"
        "7701385650643528699993706016536696035168973042784763030188233640938489188757405669765514673981310439730316"
        "5693385185601375764410728003399490759000646870697679093471364921275473192844966685566276964891585521399974"
        "822998046875e-257"},
    {0x1.fffffffffffffp-852, chars_format::scientific, 647,
        "6."
        "6599917309756708242123364770938043790288892200341480574871898649978001630858955451261677131250006016082140"
        "4649165960153209875639649882090141045241604359059081140111249157423184393058709772791161152927047487492536"
        "2673162952530223195912917513986689980671563924763377049679932931341175377126580619591861204106387504814539"
        "7820362826852162244531286454927433220578438319514573915027897864079486734617640192108062499186418367965359"
        "5402771301287057399987412033073392070337946085569526060376467281876978377514811339531029347962620879460633"
        "1386770371202751528821456006798981518001293741395358186942729842550946385689933371132553929783171042799949"
        "64599609375e-257"},
    {0x1.fffffffffffffp-851, chars_format::scientific, 647,
        "1."
        "3319983461951341648424672954187608758057778440068296114974379729995600326171791090252335426250001203216428"
        "0929833192030641975127929976418028209048320871811816228022249831484636878611741954558232230585409497498507"
        "2534632590506044639182583502797337996134312784952675409935986586268235075425316123918372240821277500962907"
        "9564072565370432448906257290985486644115687663902914783005579572815897346923528038421612499837283673593071"
        "9080554260257411479997482406614678414067589217113905212075293456375395675502962267906205869592524175892126"
        "6277354074240550305764291201359796303600258748279071637388545968510189277137986674226510785956634208559989"
        "92919921875e-256"},
    {0x1.fffffffffffffp-850, chars_format::scientific, 646,
        "2."
        "6639966923902683296849345908375217516115556880136592229948759459991200652343582180504670852500002406432856"
        "1859666384061283950255859952836056418096641743623632456044499662969273757223483909116464461170818994997014"
        "5069265181012089278365167005594675992268625569905350819871973172536470150850632247836744481642555001925815"
        "9128145130740864897812514581970973288231375327805829566011159145631794693847056076843224999674567347186143"
        "8161108520514822959994964813229356828135178434227810424150586912750791351005924535812411739185048351784253"
        "2554708148481100611528582402719592607200517496558143274777091937020378554275973348453021571913268417119979"
        "8583984375e-256"},
    {0x1.fffffffffffffp-849, chars_format::scientific, 645,
        "5."
        "3279933847805366593698691816750435032231113760273184459897518919982401304687164361009341705000004812865712"
        "3719332768122567900511719905672112836193283487247264912088999325938547514446967818232928922341637989994029"
        "0138530362024178556730334011189351984537251139810701639743946345072940301701264495673488963285110003851631"
        "8256290261481729795625029163941946576462750655611659132022318291263589387694112153686449999349134694372287"
        "6322217041029645919989929626458713656270356868455620848301173825501582702011849071624823478370096703568506"
        "5109416296962201223057164805439185214401034993116286549554183874040757108551946696906043143826536834239959"
        "716796875e-256"},
    {0x1.fffffffffffffp-848, chars_format::scientific, 645,
        "1."
        "0655986769561073318739738363350087006446222752054636891979503783996480260937432872201868341000000962573142"
        "4743866553624513580102343981134422567238656697449452982417799865187709502889393563646585784468327597998805"
        "8027706072404835711346066802237870396907450227962140327948789269014588060340252899134697792657022000770326"
        "3651258052296345959125005832788389315292550131122331826404463658252717877538822430737289999869826938874457"
        "5264443408205929183997985925291742731254071373691124169660234765100316540402369814324964695674019340713701"
        "3021883259392440244611432961087837042880206998623257309910836774808151421710389339381208628765307366847991"
        "943359375e-255"},
    {0x1.fffffffffffffp-847, chars_format::scientific, 644,
        "2."
        "1311973539122146637479476726700174012892445504109273783959007567992960521874865744403736682000001925146284"
        "9487733107249027160204687962268845134477313394898905964835599730375419005778787127293171568936655195997611"
        "6055412144809671422692133604475740793814900455924280655897578538029176120680505798269395585314044001540652"
        "7302516104592691918250011665576778630585100262244663652808927316505435755077644861474579999739653877748915"
        "0528886816411858367995971850583485462508142747382248339320469530200633080804739628649929391348038681427402"
        "6043766518784880489222865922175674085760413997246514619821673549616302843420778678762417257530614733695983"
        "88671875e-255"},
    {0x1.fffffffffffffp-846, chars_format::scientific, 643,
        "4."
        "2623947078244293274958953453400348025784891008218547567918015135985921043749731488807473364000003850292569"
        "8975466214498054320409375924537690268954626789797811929671199460750838011557574254586343137873310391995223"
        "2110824289619342845384267208951481587629800911848561311795157076058352241361011596538791170628088003081305"
        "4605032209185383836500023331153557261170200524489327305617854633010871510155289722949159999479307755497830"
        "1057773632823716735991943701166970925016285494764496678640939060401266161609479257299858782696077362854805"
        "2087533037569760978445731844351348171520827994493029239643347099232605686841557357524834515061229467391967"
        "7734375e-255"},
    {0x1.fffffffffffffp-845, chars_format::scientific, 642,
        "8."
        "5247894156488586549917906906800696051569782016437095135836030271971842087499462977614946728000007700585139"
        "7950932428996108640818751849075380537909253579595623859342398921501676023115148509172686275746620783990446"
        "4221648579238685690768534417902963175259601823697122623590314152116704482722023193077582341256176006162610"
        "9210064418370767673000046662307114522340401048978654611235709266021743020310579445898319998958615510995660"
        "2115547265647433471983887402333941850032570989528993357281878120802532323218958514599717565392154725709610"
        "4175066075139521956891463688702696343041655988986058479286694198465211373683114715049669030122458934783935"
        "546875e-255"},
    {0x1.fffffffffffffp-844, chars_format::scientific, 642,
        "1."
        "7049578831297717309983581381360139210313956403287419027167206054394368417499892595522989345600001540117027"
        "9590186485799221728163750369815076107581850715919124771868479784300335204623029701834537255149324156798089"
        "2844329715847737138153706883580592635051920364739424524718062830423340896544404638615516468251235201232522"
        "1842012883674153534600009332461422904468080209795730922247141853204348604062115889179663999791723102199132"
        "0423109453129486694396777480466788370006514197905798671456375624160506464643791702919943513078430945141922"
        "0835013215027904391378292737740539268608331197797211695857338839693042274736622943009933806024491786956787"
        "109375e-254"},
    {0x1.fffffffffffffp-843, chars_format::scientific, 641,
        "3."
        "4099157662595434619967162762720278420627912806574838054334412108788736834999785191045978691200003080234055"
        "9180372971598443456327500739630152215163701431838249543736959568600670409246059403669074510298648313596178"
        "5688659431695474276307413767161185270103840729478849049436125660846681793088809277231032936502470402465044"
        "3684025767348307069200018664922845808936160419591461844494283706408697208124231778359327999583446204398264"
        "0846218906258973388793554960933576740013028395811597342912751248321012929287583405839887026156861890283844"
        "1670026430055808782756585475481078537216662395594423391714677679386084549473245886019867612048983573913574"
        "21875e-254"},
    {0x1.fffffffffffffp-842, chars_format::scientific, 640,
        "6."
        "8198315325190869239934325525440556841255825613149676108668824217577473669999570382091957382400006160468111"
        "8360745943196886912655001479260304430327402863676499087473919137201340818492118807338149020597296627192357"
        "1377318863390948552614827534322370540207681458957698098872251321693363586177618554462065873004940804930088"
        "7368051534696614138400037329845691617872320839182923688988567412817394416248463556718655999166892408796528"
        "1692437812517946777587109921867153480026056791623194685825502496642025858575166811679774052313723780567688"
        "3340052860111617565513170950962157074433324791188846783429355358772169098946491772039735224097967147827148"
        "4375e-254"},
    {0x1.fffffffffffffp-841, chars_format::scientific, 640,
        "1."
        "3639663065038173847986865105088111368251165122629935221733764843515494733999914076418391476480001232093622"
        "3672149188639377382531000295852060886065480572735299817494783827440268163698423761467629804119459325438471"
        "4275463772678189710522965506864474108041536291791539619774450264338672717235523710892413174600988160986017"
        "7473610306939322827680007465969138323574464167836584737797713482563478883249692711343731199833378481759305"
        "6338487562503589355517421984373430696005211358324638937165100499328405171715033362335954810462744756113537"
        "6668010572022323513102634190192431414886664958237769356685871071754433819789298354407947044819593429565429"
        "6875e-253"},
    {0x1.fffffffffffffp-840, chars_format::scientific, 639,
        "2."
        "7279326130076347695973730210176222736502330245259870443467529687030989467999828152836782952960002464187244"
        "7344298377278754765062000591704121772130961145470599634989567654880536327396847522935259608238918650876942"
        "8550927545356379421045931013728948216083072583583079239548900528677345434471047421784826349201976321972035"
        "4947220613878645655360014931938276647148928335673169475595426965126957766499385422687462399666756963518611"
        "2676975125007178711034843968746861392010422716649277874330200998656810343430066724671909620925489512227075"
        "3336021144044647026205268380384862829773329916475538713371742143508867639578596708815894089639186859130859"
        "375e-253"},
    {0x1.fffffffffffffp-839, chars_format::scientific, 638,
        "5."
        "4558652260152695391947460420352445473004660490519740886935059374061978935999656305673565905920004928374489"
        "4688596754557509530124001183408243544261922290941199269979135309761072654793695045870519216477837301753885"
        "7101855090712758842091862027457896432166145167166158479097801057354690868942094843569652698403952643944070"
        "9894441227757291310720029863876553294297856671346338951190853930253915532998770845374924799333513927037222"
        "5353950250014357422069687937493722784020845433298555748660401997313620686860133449343819241850979024454150"
        "6672042288089294052410536760769725659546659832951077426743484287017735279157193417631788179278373718261718"
        "75e-253"},
    {0x1.fffffffffffffp-838, chars_format::scientific, 638,
        "1."
        "0911730452030539078389492084070489094600932098103948177387011874812395787199931261134713181184000985674897"
        "8937719350911501906024800236681648708852384458188239853995827061952214530958739009174103843295567460350777"
        "1420371018142551768418372405491579286433229033433231695819560211470938173788418968713930539680790528788814"
        "1978888245551458262144005972775310658859571334269267790238170786050783106599754169074984959866702785407444"
        "5070790050002871484413937587498744556804169086659711149732080399462724137372026689868763848370195804890830"
        "1334408457617858810482107352153945131909331966590215485348696857403547055831438683526357635855674743652343"
        "75e-252"},
    {0x1.fffffffffffffp-837, chars_format::scientific, 637,
        "2."
        "1823460904061078156778984168140978189201864196207896354774023749624791574399862522269426362368001971349795"
        "7875438701823003812049600473363297417704768916376479707991654123904429061917478018348207686591134920701554"
        "2840742036285103536836744810983158572866458066866463391639120422941876347576837937427861079361581057577628"
        "3957776491102916524288011945550621317719142668538535580476341572101566213199508338149969919733405570814889"
        "0141580100005742968827875174997489113608338173319422299464160798925448274744053379737527696740391609781660"
        "2668816915235717620964214704307890263818663933180430970697393714807094111662877367052715271711349487304687"
        "5e-252"},
    {0x1.fffffffffffffp-836, chars_format::scientific, 636,
        "4."
        "3646921808122156313557968336281956378403728392415792709548047499249583148799725044538852724736003942699591"
        "5750877403646007624099200946726594835409537832752959415983308247808858123834956036696415373182269841403108"
        "5681484072570207073673489621966317145732916133732926783278240845883752695153675874855722158723162115155256"
        "7915552982205833048576023891101242635438285337077071160952683144203132426399016676299939839466811141629778"
        "0283160200011485937655750349994978227216676346638844598928321597850896549488106759475055393480783219563320"
        "5337633830471435241928429408615780527637327866360861941394787429614188223325754734105430543422698974609375"
        "e-252"},
    {0x1.fffffffffffffp-835, chars_format::scientific, 635,
        "8."
        "7293843616244312627115936672563912756807456784831585419096094998499166297599450089077705449472007885399183"
        "1501754807292015248198401893453189670819075665505918831966616495617716247669912073392830746364539682806217"
        "1362968145140414147346979243932634291465832267465853566556481691767505390307351749711444317446324230310513"
        "5831105964411666097152047782202485270876570674154142321905366288406264852798033352599879678933622283259556"
        "0566320400022971875311500699989956454433352693277689197856643195701793098976213518950110786961566439126641"
        "067526766094287048385685881723156105527465573272172388278957485922837644665150946821086108684539794921875e"
        "-252"},
    {0x1.fffffffffffffp-834, chars_format::scientific, 635,
        "1."
        "7458768723248862525423187334512782551361491356966317083819218999699833259519890017815541089894401577079836"
        "6300350961458403049639680378690637934163815133101183766393323299123543249533982414678566149272907936561243"
        "4272593629028082829469395848786526858293166453493170713311296338353501078061470349942288863489264846062102"
        "7166221192882333219430409556440497054175314134830828464381073257681252970559606670519975935786724456651911"
        "2113264080004594375062300139997991290886670538655537839571328639140358619795242703790022157392313287825328"
        "213505353218857409677137176344631221105493114654434477655791497184567528933030189364217221736907958984375e"
        "-251"},
    {0x1.fffffffffffffp-833, chars_format::scientific, 634,
        "3."
        "4917537446497725050846374669025565102722982713932634167638437999399666519039780035631082179788803154159673"
        "2600701922916806099279360757381275868327630266202367532786646598247086499067964829357132298545815873122486"
        "8545187258056165658938791697573053716586332906986341426622592676707002156122940699884577726978529692124205"
        "4332442385764666438860819112880994108350628269661656928762146515362505941119213341039951871573448913303822"
        "4226528160009188750124600279995982581773341077311075679142657278280717239590485407580044314784626575650656"
        "42701070643771481935427435268926244221098622930886895531158299436913505786606037872843444347381591796875e-"
        "251"},
    {0x1.fffffffffffffp-832, chars_format::scientific, 633,
        "6."
        "9835074892995450101692749338051130205445965427865268335276875998799333038079560071262164359577606308319346"
        "5201403845833612198558721514762551736655260532404735065573293196494172998135929658714264597091631746244973"
        "7090374516112331317877583395146107433172665813972682853245185353414004312245881399769155453957059384248410"
        "8664884771529332877721638225761988216701256539323313857524293030725011882238426682079903743146897826607644"
        "8453056320018377500249200559991965163546682154622151358285314556561434479180970815160088629569253151301312"
        "8540214128754296387085487053785248844219724586177379106231659887382701157321207574568688869476318359375e-"
        "251"},
    {0x1.fffffffffffffp-831, chars_format::scientific, 633,
        "1."
        "3967014978599090020338549867610226041089193085573053667055375199759866607615912014252432871915521261663869"
        "3040280769166722439711744302952510347331052106480947013114658639298834599627185931742852919418326349248994"
        "7418074903222466263575516679029221486634533162794536570649037070682800862449176279953831090791411876849682"
        "1732976954305866575544327645152397643340251307864662771504858606145002376447685336415980748629379565321528"
        "9690611264003675500049840111998393032709336430924430271657062911312286895836194163032017725913850630260262"
        "5708042825750859277417097410757049768843944917235475821246331977476540231464241514913737773895263671875e-"
        "250"},
    {0x1.fffffffffffffp-830, chars_format::scientific, 632,
        "2."
        "7934029957198180040677099735220452082178386171146107334110750399519733215231824028504865743831042523327738"
        "6080561538333444879423488605905020694662104212961894026229317278597669199254371863485705838836652698497989"
        "4836149806444932527151033358058442973269066325589073141298074141365601724898352559907662181582823753699364"
        "3465953908611733151088655290304795286680502615729325543009717212290004752895370672831961497258759130643057"
        "9381222528007351000099680223996786065418672861848860543314125822624573791672388326064035451827701260520525"
        "141608565150171855483419482151409953768788983447095164249266395495308046292848302982747554779052734375e-"
        "250"},
    {0x1.fffffffffffffp-829, chars_format::scientific, 631,
        "5."
        "5868059914396360081354199470440904164356772342292214668221500799039466430463648057009731487662085046655477"
        "2161123076666889758846977211810041389324208425923788052458634557195338398508743726971411677673305396995978"
        "9672299612889865054302066716116885946538132651178146282596148282731203449796705119815324363165647507398728"
        "6931907817223466302177310580609590573361005231458651086019434424580009505790741345663922994517518261286115"
        "8762445056014702000199360447993572130837345723697721086628251645249147583344776652128070903655402521041050"
        "28321713030034371096683896430281990753757796689419032849853279099061609258569660596549510955810546875e-"
        "250"},
    {0x1.fffffffffffffp-828, chars_format::scientific, 631,
        "1."
        "1173611982879272016270839894088180832871354468458442933644300159807893286092729611401946297532417009331095"
        "4432224615333377951769395442362008277864841685184757610491726911439067679701748745394282335534661079399195"
        "7934459922577973010860413343223377189307626530235629256519229656546240689959341023963064872633129501479745"
        "7386381563444693260435462116121918114672201046291730217203886884916001901158148269132784598903503652257223"
        "1752489011202940400039872089598714426167469144739544217325650329049829516668955330425614180731080504208210"
        "05664342606006874219336779286056398150751559337883806569970655819812321851713932119309902191162109375e-"
        "249"},
    {0x1.fffffffffffffp-827, chars_format::scientific, 630,
        "2."
        "2347223965758544032541679788176361665742708936916885867288600319615786572185459222803892595064834018662190"
        "8864449230666755903538790884724016555729683370369515220983453822878135359403497490788564671069322158798391"
        "5868919845155946021720826686446754378615253060471258513038459313092481379918682047926129745266259002959491"
        "4772763126889386520870924232243836229344402092583460434407773769832003802316296538265569197807007304514446"
        "3504978022405880800079744179197428852334938289479088434651300658099659033337910660851228361462161008416420"
        "1132868521201374843867355857211279630150311867576761313994131163962464370342786423861980438232421875e-"
        "249"},
    {0x1.fffffffffffffp-826, chars_format::scientific, 629,
        "4."
        "4694447931517088065083359576352723331485417873833771734577200639231573144370918445607785190129668037324381"
        "7728898461333511807077581769448033111459366740739030441966907645756270718806994981577129342138644317596783"
        "1737839690311892043441653372893508757230506120942517026076918626184962759837364095852259490532518005918982"
        "9545526253778773041741848464487672458688804185166920868815547539664007604632593076531138395614014609028892"
        "7009956044811761600159488358394857704669876578958176869302601316199318066675821321702456722924322016832840"
        "226573704240274968773471171442255926030062373515352262798826232792492874068557284772396087646484375e-249"},
    {0x1.fffffffffffffp-825, chars_format::scientific, 628,
        "8."
        "9388895863034176130166719152705446662970835747667543469154401278463146288741836891215570380259336074648763"
        "5457796922667023614155163538896066222918733481478060883933815291512541437613989963154258684277288635193566"
        "3475679380623784086883306745787017514461012241885034052153837252369925519674728191704518981065036011837965"
        "9091052507557546083483696928975344917377608370333841737631095079328015209265186153062276791228029218057785"
        "4019912089623523200318976716789715409339753157916353738605202632398636133351642643404913445848644033665680"
        "45314740848054993754694234288451185206012474703070452559765246558498574813711456954479217529296875e-249"},
    {0x1.fffffffffffffp-824, chars_format::scientific, 628,
        "1."
        "7877779172606835226033343830541089332594167149533508693830880255692629257748367378243114076051867214929752"
        "7091559384533404722831032707779213244583746696295612176786763058302508287522797992630851736855457727038713"
        "2695135876124756817376661349157403502892202448377006810430767450473985103934945638340903796213007202367593"
        "1818210501511509216696739385795068983475521674066768347526219015865603041853037230612455358245605843611557"
        "0803982417924704640063795343357943081867950631583270747721040526479727226670328528680982689169728806733136"
        "09062948169610998750938846857690237041202494940614090511953049311699714962742291390895843505859375e-248"},
    {0x1.fffffffffffffp-823, chars_format::scientific, 627,
        "3."
        "5755558345213670452066687661082178665188334299067017387661760511385258515496734756486228152103734429859505"
        "4183118769066809445662065415558426489167493392591224353573526116605016575045595985261703473710915454077426"
        "5390271752249513634753322698314807005784404896754013620861534900947970207869891276681807592426014404735186"
        "3636421003023018433393478771590137966951043348133536695052438031731206083706074461224910716491211687223114"
        "1607964835849409280127590686715886163735901263166541495442081052959454453340657057361965378339457613466272"
        "1812589633922199750187769371538047408240498988122818102390609862339942992548458278179168701171875e-248"},
    {0x1.fffffffffffffp-822, chars_format::scientific, 626,
        "7."
        "1511116690427340904133375322164357330376668598134034775323521022770517030993469512972456304207468859719010"
        "8366237538133618891324130831116852978334986785182448707147052233210033150091191970523406947421830908154853"
        "0780543504499027269506645396629614011568809793508027241723069801895940415739782553363615184852028809470372"
        "7272842006046036866786957543180275933902086696267073390104876063462412167412148922449821432982423374446228"
        "3215929671698818560255181373431772327471802526333082990884162105918908906681314114723930756678915226932544"
        "362517926784439950037553874307609481648099797624563620478121972467988598509691655635833740234375e-248"},
    {0x1.fffffffffffffp-821, chars_format::scientific, 626,
        "1."
        "4302223338085468180826675064432871466075333719626806955064704204554103406198693902594491260841493771943802"
        "1673247507626723778264826166223370595666997357036489741429410446642006630018238394104681389484366181630970"
        "6156108700899805453901329079325922802313761958701605448344613960379188083147956510672723036970405761894074"
        "5454568401209207373357391508636055186780417339253414678020975212692482433482429784489964286596484674889245"
        "6643185934339763712051036274686354465494360505266616598176832421183781781336262822944786151335783045386508"
        "872503585356887990007510774861521896329619959524912724095624394493597719701938331127166748046875e-247"},
    {0x1.fffffffffffffp-820, chars_format::scientific, 625,
        "2."
        "8604446676170936361653350128865742932150667439253613910129408409108206812397387805188982521682987543887604"
        "3346495015253447556529652332446741191333994714072979482858820893284013260036476788209362778968732363261941"
        "2312217401799610907802658158651845604627523917403210896689227920758376166295913021345446073940811523788149"
        "0909136802418414746714783017272110373560834678506829356041950425384964866964859568979928573192969349778491"
        "3286371868679527424102072549372708930988721010533233196353664842367563562672525645889572302671566090773017"
        "74500717071377598001502154972304379265923991904982544819124878898719543940387666225433349609375e-247"},
    {0x1.fffffffffffffp-819, chars_format::scientific, 624,
        "5."
        "7208893352341872723306700257731485864301334878507227820258816818216413624794775610377965043365975087775208"
        "6692990030506895113059304664893482382667989428145958965717641786568026520072953576418725557937464726523882"
        "4624434803599221815605316317303691209255047834806421793378455841516752332591826042690892147881623047576298"
        "1818273604836829493429566034544220747121669357013658712083900850769929733929719137959857146385938699556982"
        "6572743737359054848204145098745417861977442021066466392707329684735127125345051291779144605343132181546035"
        "4900143414275519600300430994460875853184798380996508963824975779743908788077533245086669921875e-247"},
    {0x1.fffffffffffffp-818, chars_format::scientific, 624,
        "1."
        "1441778670468374544661340051546297172860266975701445564051763363643282724958955122075593008673195017555041"
        "7338598006101379022611860932978696476533597885629191793143528357313605304014590715283745111587492945304776"
        "4924886960719844363121063263460738241851009566961284358675691168303350466518365208538178429576324609515259"
        "6363654720967365898685913206908844149424333871402731742416780170153985946785943827591971429277187739911396"
        "5314548747471810969640829019749083572395488404213293278541465936947025425069010258355828921068626436309207"
        "0980028682855103920060086198892175170636959676199301792764995155948781757615506649017333984375e-246"},
    {0x1.fffffffffffffp-817, chars_format::scientific, 623,
        "2."
        "2883557340936749089322680103092594345720533951402891128103526727286565449917910244151186017346390035110083"
        "4677196012202758045223721865957392953067195771258383586287056714627210608029181430567490223174985890609552"
        "9849773921439688726242126526921476483702019133922568717351382336606700933036730417076356859152649219030519"
        "2727309441934731797371826413817688298848667742805463484833560340307971893571887655183942858554375479822793"
        "0629097494943621939281658039498167144790976808426586557082931873894050850138020516711657842137252872618414"
        "196005736571020784012017239778435034127391935239860358552999031189756351523101329803466796875e-246"},
    {0x1.fffffffffffffp-816, chars_format::scientific, 622,
        "4."
        "5767114681873498178645360206185188691441067902805782256207053454573130899835820488302372034692780070220166"
        "9354392024405516090447443731914785906134391542516767172574113429254421216058362861134980446349971781219105"
        "9699547842879377452484253053842952967404038267845137434702764673213401866073460834152713718305298438061038"
        "5454618883869463594743652827635376597697335485610926969667120680615943787143775310367885717108750959645586"
        "1258194989887243878563316078996334289581953616853173114165863747788101700276041033423315684274505745236828"
        "39201147314204156802403447955687006825478387047972071710599806237951270304620265960693359375e-246"},
    {0x1.fffffffffffffp-815, chars_format::scientific, 621,
        "9."
        "1534229363746996357290720412370377382882135805611564512414106909146261799671640976604744069385560140440333"
        "8708784048811032180894887463829571812268783085033534345148226858508842432116725722269960892699943562438211"
        "9399095685758754904968506107685905934808076535690274869405529346426803732146921668305427436610596876122077"
        "0909237767738927189487305655270753195394670971221853939334241361231887574287550620735771434217501919291172"
        "2516389979774487757126632157992668579163907233706346228331727495576203400552082066846631368549011490473656"
        "7840229462840831360480689591137401365095677409594414342119961247590254060924053192138671875e-246"},
    {0x1.fffffffffffffp-814, chars_format::scientific, 621,
        "1."
        "8306845872749399271458144082474075476576427161122312902482821381829252359934328195320948813877112028088066"
        "7741756809762206436178977492765914362453756617006706869029645371701768486423345144453992178539988712487642"
        "3879819137151750980993701221537181186961615307138054973881105869285360746429384333661085487322119375224415"
        "4181847553547785437897461131054150639078934194244370787866848272246377514857510124147154286843500383858234"
        "4503277995954897551425326431598533715832781446741269245666345499115240680110416413369326273709802298094731"
        "3568045892568166272096137918227480273019135481918882868423992249518050812184810638427734375e-245"},
    {0x1.fffffffffffffp-813, chars_format::scientific, 620,
        "3."
        "6613691745498798542916288164948150953152854322244625804965642763658504719868656390641897627754224056176133"
        "5483513619524412872357954985531828724907513234013413738059290743403536972846690288907984357079977424975284"
        "7759638274303501961987402443074362373923230614276109947762211738570721492858768667322170974644238750448830"
        "8363695107095570875794922262108301278157868388488741575733696544492755029715020248294308573687000767716468"
        "9006555991909795102850652863197067431665562893482538491332690998230481360220832826738652547419604596189462"
        "713609178513633254419227583645496054603827096383776573684798449903610162436962127685546875e-245"},
    {0x1.fffffffffffffp-812, chars_format::scientific, 619,
        "7."
        "3227383490997597085832576329896301906305708644489251609931285527317009439737312781283795255508448112352267"
        "0967027239048825744715909971063657449815026468026827476118581486807073945693380577815968714159954849950569"
        "5519276548607003923974804886148724747846461228552219895524423477141442985717537334644341949288477500897661"
        "6727390214191141751589844524216602556315736776977483151467393088985510059430040496588617147374001535432937"
        "8013111983819590205701305726394134863331125786965076982665381996460962720441665653477305094839209192378925"
        "42721835702726650883845516729099210920765419276755314736959689980722032487392425537109375e-245"},
    {0x1.fffffffffffffp-811, chars_format::scientific, 619,
        "1."
        "4645476698199519417166515265979260381261141728897850321986257105463401887947462556256759051101689622470453"
        "4193405447809765148943181994212731489963005293605365495223716297361414789138676115563193742831990969990113"
        "9103855309721400784794960977229744949569292245710443979104884695428288597143507466928868389857695500179532"
        "3345478042838228350317968904843320511263147355395496630293478617797102011886008099317723429474800307086587"
        "5602622396763918041140261145278826972666225157393015396533076399292192544088333130695461018967841838475785"
        "08544367140545330176769103345819842184153083855351062947391937996144406497478485107421875e-244"},
    {0x1.fffffffffffffp-810, chars_format::scientific, 618,
        "2."
        "9290953396399038834333030531958520762522283457795700643972514210926803775894925112513518102203379244940906"
        "8386810895619530297886363988425462979926010587210730990447432594722829578277352231126387485663981939980227"
        "8207710619442801569589921954459489899138584491420887958209769390856577194287014933857736779715391000359064"
        "6690956085676456700635937809686641022526294710790993260586957235594204023772016198635446858949600614173175"
        "1205244793527836082280522290557653945332450314786030793066152798584385088176666261390922037935683676951570"
        "1708873428109066035353820669163968436830616771070212589478387599228881299495697021484375e-244"},
    {0x1.fffffffffffffp-809, chars_format::scientific, 617,
        "5."
        "8581906792798077668666061063917041525044566915591401287945028421853607551789850225027036204406758489881813"
        "6773621791239060595772727976850925959852021174421461980894865189445659156554704462252774971327963879960455"
        "6415421238885603139179843908918979798277168982841775916419538781713154388574029867715473559430782000718129"
        "3381912171352913401271875619373282045052589421581986521173914471188408047544032397270893717899201228346350"
        "2410489587055672164561044581115307890664900629572061586132305597168770176353332522781844075871367353903140"
        "341774685621813207070764133832793687366123354214042517895677519845776259899139404296875e-244"},
    {0x1.fffffffffffffp-808, chars_format::scientific, 617,
        "1."
        "1716381358559615533733212212783408305008913383118280257589005684370721510357970045005407240881351697976362"
        "7354724358247812119154545595370185191970404234884292396178973037889131831310940892450554994265592775992091"
        "1283084247777120627835968781783795959655433796568355183283907756342630877714805973543094711886156400143625"
        "8676382434270582680254375123874656409010517884316397304234782894237681609508806479454178743579840245669270"
        "0482097917411134432912208916223061578132980125914412317226461119433754035270666504556368815174273470780628"
        "068354937124362641414152826766558737473224670842808503579135503969155251979827880859375e-243"},
    {0x1.fffffffffffffp-807, chars_format::scientific, 616,
        "2."
        "3432762717119231067466424425566816610017826766236560515178011368741443020715940090010814481762703395952725"
        "4709448716495624238309091190740370383940808469768584792357946075778263662621881784901109988531185551984182"
        "2566168495554241255671937563567591919310867593136710366567815512685261755429611947086189423772312800287251"
        "7352764868541165360508750247749312818021035768632794608469565788475363219017612958908357487159680491338540"
        "0964195834822268865824417832446123156265960251828824634452922238867508070541333009112737630348546941561256"
        "13670987424872528282830565353311747494644934168561700715827100793831050395965576171875e-243"},
    {0x1.fffffffffffffp-806, chars_format::scientific, 615,
        "4."
        "6865525434238462134932848851133633220035653532473121030356022737482886041431880180021628963525406791905450"
        "9418897432991248476618182381480740767881616939537169584715892151556527325243763569802219977062371103968364"
        "5132336991108482511343875127135183838621735186273420733135631025370523510859223894172378847544625600574503"
        "4705529737082330721017500495498625636042071537265589216939131576950726438035225917816714974319360982677080"
        "1928391669644537731648835664892246312531920503657649268905844477735016141082666018225475260697093883122512"
        "2734197484974505656566113070662349498928986833712340143165420158766210079193115234375e-243"},
    {0x1.fffffffffffffp-805, chars_format::scientific, 614,
        "9."
        "3731050868476924269865697702267266440071307064946242060712045474965772082863760360043257927050813583810901"
        "8837794865982496953236364762961481535763233879074339169431784303113054650487527139604439954124742207936729"
        "0264673982216965022687750254270367677243470372546841466271262050741047021718447788344757695089251201149006"
        "9411059474164661442035000990997251272084143074531178433878263153901452876070451835633429948638721965354160"
        "3856783339289075463297671329784492625063841007315298537811688955470032282165332036450950521394187766245024"
        "546839496994901131313222614132469899785797366742468028633084031753242015838623046875e-243"},
    {0x1.fffffffffffffp-804, chars_format::scientific, 614,
        "1."
        "8746210173695384853973139540453453288014261412989248412142409094993154416572752072008651585410162716762180"
        "3767558973196499390647272952592296307152646775814867833886356860622610930097505427920887990824948441587345"
        "8052934796443393004537550050854073535448694074509368293254252410148209404343689557668951539017850240229801"
        "3882211894832932288407000198199450254416828614906235686775652630780290575214090367126685989727744393070832"
        "0771356667857815092659534265956898525012768201463059707562337791094006456433066407290190104278837553249004"
        "909367899398980226262644522826493979957159473348493605726616806350648403167724609375e-242"},
    {0x1.fffffffffffffp-803, chars_format::scientific, 613,
        "3."
        "7492420347390769707946279080906906576028522825978496824284818189986308833145504144017303170820325433524360"
        "7535117946392998781294545905184592614305293551629735667772713721245221860195010855841775981649896883174691"
        "6105869592886786009075100101708147070897388149018736586508504820296418808687379115337903078035700480459602"
        "7764423789665864576814000396398900508833657229812471373551305261560581150428180734253371979455488786141664"
        "1542713335715630185319068531913797050025536402926119415124675582188012912866132814580380208557675106498009"
        "81873579879796045252528904565298795991431894669698721145323361270129680633544921875e-242"},
    {0x1.fffffffffffffp-802, chars_format::scientific, 612,
        "7."
        "4984840694781539415892558161813813152057045651956993648569636379972617666291008288034606341640650867048721"
        "5070235892785997562589091810369185228610587103259471335545427442490443720390021711683551963299793766349383"
        "2211739185773572018150200203416294141794776298037473173017009640592837617374758230675806156071400960919205"
        "5528847579331729153628000792797801017667314459624942747102610523121162300856361468506743958910977572283328"
        "3085426671431260370638137063827594100051072805852238830249351164376025825732265629160760417115350212996019"
        "6374715975959209050505780913059759198286378933939744229064672254025936126708984375e-242"},
    {0x1.fffffffffffffp-801, chars_format::scientific, 612,
        "1."
        "4996968138956307883178511632362762630411409130391398729713927275994523533258201657606921268328130173409744"
        "3014047178557199512517818362073837045722117420651894267109085488498088744078004342336710392659958753269876"
        "6442347837154714403630040040683258828358955259607494634603401928118567523474951646135161231214280192183841"
        "1105769515866345830725600158559560203533462891924988549420522104624232460171272293701348791782195514456665"
        "6617085334286252074127627412765518820010214561170447766049870232875205165146453125832152083423070042599203"
        "9274943195191841810101156182611951839657275786787948845812934450805187225341796875e-241"},
    {0x1.fffffffffffffp-800, chars_format::scientific, 611,
        "2."
        "9993936277912615766357023264725525260822818260782797459427854551989047066516403315213842536656260346819488"
        "6028094357114399025035636724147674091444234841303788534218170976996177488156008684673420785319917506539753"
        "2884695674309428807260080081366517656717910519214989269206803856237135046949903292270322462428560384367682"
        "2211539031732691661451200317119120407066925783849977098841044209248464920342544587402697583564391028913331"
        "3234170668572504148255254825531037640020429122340895532099740465750410330292906251664304166846140085198407"
        "854988639038368362020231236522390367931455157357589769162586890161037445068359375e-241"},
    {0x1.fffffffffffffp-799, chars_format::scientific, 610,
        "5."
        "9987872555825231532714046529451050521645636521565594918855709103978094133032806630427685073312520693638977"
        "2056188714228798050071273448295348182888469682607577068436341953992354976312017369346841570639835013079506"
        "5769391348618857614520160162733035313435821038429978538413607712474270093899806584540644924857120768735364"
        "4423078063465383322902400634238240814133851567699954197682088418496929840685089174805395167128782057826662"
        "6468341337145008296510509651062075280040858244681791064199480931500820660585812503328608333692280170396815"
        "70997727807673672404046247304478073586291031471517953832517378032207489013671875e-241"},
    {0x1.fffffffffffffp-798, chars_format::scientific, 610,
        "1."
        "1997574511165046306542809305890210104329127304313118983771141820795618826606561326085537014662504138727795"
        "4411237742845759610014254689659069636577693936521515413687268390798470995262403473869368314127967002615901"
        "3153878269723771522904032032546607062687164207685995707682721542494854018779961316908128984971424153747072"
        "8884615612693076664580480126847648162826770313539990839536417683699385968137017834961079033425756411565332"
        "5293668267429001659302101930212415056008171648936358212839896186300164132117162500665721666738456034079363"
        "14199545561534734480809249460895614717258206294303590766503475606441497802734375e-240"},
    {0x1.fffffffffffffp-797, chars_format::scientific, 609,
        "2."
        "3995149022330092613085618611780420208658254608626237967542283641591237653213122652171074029325008277455590"
        "8822475485691519220028509379318139273155387873043030827374536781596941990524806947738736628255934005231802"
        "6307756539447543045808064065093214125374328415371991415365443084989708037559922633816257969942848307494145"
        "7769231225386153329160960253695296325653540627079981679072835367398771936274035669922158066851512823130665"
        "0587336534858003318604203860424830112016343297872716425679792372600328264234325001331443333476912068158726"
        "2839909112306946896161849892179122943451641258860718153300695121288299560546875e-240"},
    {0x1.fffffffffffffp-796, chars_format::scientific, 608,
        "4."
        "7990298044660185226171237223560840417316509217252475935084567283182475306426245304342148058650016554911181"
        "7644950971383038440057018758636278546310775746086061654749073563193883981049613895477473256511868010463605"
        "2615513078895086091616128130186428250748656830743982830730886169979416075119845267632515939885696614988291"
        "5538462450772306658321920507390592651307081254159963358145670734797543872548071339844316133703025646261330"
        "1174673069716006637208407720849660224032686595745432851359584745200656528468650002662886666953824136317452"
        "567981822461389379232369978435824588690328251772143630660139024257659912109375e-240"},
    {0x1.fffffffffffffp-795, chars_format::scientific, 607,
        "9."
        "5980596089320370452342474447121680834633018434504951870169134566364950612852490608684296117300033109822363"
        "5289901942766076880114037517272557092621551492172123309498147126387767962099227790954946513023736020927210"
        "5231026157790172183232256260372856501497313661487965661461772339958832150239690535265031879771393229976583"
        "1076924901544613316643841014781185302614162508319926716291341469595087745096142679688632267406051292522660"
        "2349346139432013274416815441699320448065373191490865702719169490401313056937300005325773333907648272634905"
        "13596364492277875846473995687164917738065650354428726132027804851531982421875e-240"},
    {0x1.fffffffffffffp-794, chars_format::scientific, 607,
        "1."
        "9196119217864074090468494889424336166926603686900990374033826913272990122570498121736859223460006621964472"
        "7057980388553215376022807503454511418524310298434424661899629425277553592419845558190989302604747204185442"
        "1046205231558034436646451252074571300299462732297593132292354467991766430047938107053006375954278645995316"
        "6215384980308922663328768202956237060522832501663985343258268293919017549019228535937726453481210258504532"
        "0469869227886402654883363088339864089613074638298173140543833898080262611387460001065154666781529654526981"
        "02719272898455575169294799137432983547613130070885745226405560970306396484375e-239"},
    {0x1.fffffffffffffp-793, chars_format::scientific, 606,
        "3."
        "8392238435728148180936989778848672333853207373801980748067653826545980245140996243473718446920013243928945"
        "4115960777106430752045615006909022837048620596868849323799258850555107184839691116381978605209494408370884"
        "2092410463116068873292902504149142600598925464595186264584708935983532860095876214106012751908557291990633"
        "2430769960617845326657536405912474121045665003327970686516536587838035098038457071875452906962420517009064"
        "0939738455772805309766726176679728179226149276596346281087667796160525222774920002130309333563059309053962"
        "0543854579691115033858959827486596709522626014177149045281112194061279296875e-239"},
    {0x1.fffffffffffffp-792, chars_format::scientific, 605,
        "7."
        "6784476871456296361873979557697344667706414747603961496135307653091960490281992486947436893840026487857890"
        "8231921554212861504091230013818045674097241193737698647598517701110214369679382232763957210418988816741768"
        "4184820926232137746585805008298285201197850929190372529169417871967065720191752428212025503817114583981266"
        "4861539921235690653315072811824948242091330006655941373033073175676070196076914143750905813924841034018128"
        "1879476911545610619533452353359456358452298553192692562175335592321050445549840004260618667126118618107924"
        "108770915938223006771791965497319341904525202835429809056222438812255859375e-239"},
    {0x1.fffffffffffffp-791, chars_format::scientific, 605,
        "1."
        "5356895374291259272374795911539468933541282949520792299227061530618392098056398497389487378768005297571578"
        "1646384310842572300818246002763609134819448238747539729519703540222042873935876446552791442083797763348353"
        "6836964185246427549317161001659657040239570185838074505833883574393413144038350485642405100763422916796253"
        "2972307984247138130663014562364989648418266001331188274606614635135214039215382828750181162784968206803625"
        "6375895382309122123906690470671891271690459710638538512435067118464210089109968000852123733425223723621584"
        "821754183187644601354358393099463868380905040567085961811244487762451171875e-238"},
    {0x1.fffffffffffffp-790, chars_format::scientific, 604,
        "3."
        "0713790748582518544749591823078937867082565899041584598454123061236784196112796994778974757536010595143156"
        "3292768621685144601636492005527218269638896477495079459039407080444085747871752893105582884167595526696707"
        "3673928370492855098634322003319314080479140371676149011667767148786826288076700971284810201526845833592506"
        "5944615968494276261326029124729979296836532002662376549213229270270428078430765657500362325569936413607251"
        "2751790764618244247813380941343782543380919421277077024870134236928420178219936001704247466850447447243169"
        "64350836637528920270871678619892773676181008113417192362248897552490234375e-238"},
    {0x1.fffffffffffffp-789, chars_format::scientific, 603,
        "6."
        "1427581497165037089499183646157875734165131798083169196908246122473568392225593989557949515072021190286312"
        "6585537243370289203272984011054436539277792954990158918078814160888171495743505786211165768335191053393414"
        "7347856740985710197268644006638628160958280743352298023335534297573652576153401942569620403053691667185013"
        "1889231936988552522652058249459958593673064005324753098426458540540856156861531315000724651139872827214502"
        "5503581529236488495626761882687565086761838842554154049740268473856840356439872003408494933700894894486339"
        "2870167327505784054174335723978554735236201622683438472449779510498046875e-238"},
    {0x1.fffffffffffffp-788, chars_format::scientific, 603,
        "1."
        "2285516299433007417899836729231575146833026359616633839381649224494713678445118797911589903014404238057262"
        "5317107448674057840654596802210887307855558590998031783615762832177634299148701157242233153667038210678682"
        "9469571348197142039453728801327725632191656148670459604667106859514730515230680388513924080610738333437002"
        "6377846387397710504530411649891991718734612801064950619685291708108171231372306263000144930227974565442900"
        "5100716305847297699125352376537513017352367768510830809948053694771368071287974400681698986740178978897267"
        "8574033465501156810834867144795710947047240324536687694489955902099609375e-237"},
    {0x1.fffffffffffffp-787, chars_format::scientific, 602,
        "2."
        "4571032598866014835799673458463150293666052719233267678763298448989427356890237595823179806028808476114525"
        "0634214897348115681309193604421774615711117181996063567231525664355268598297402314484466307334076421357365"
        "8939142696394284078907457602655451264383312297340919209334213719029461030461360777027848161221476666874005"
        "2755692774795421009060823299783983437469225602129901239370583416216342462744612526000289860455949130885801"
        "0201432611694595398250704753075026034704735537021661619896107389542736142575948801363397973480357957794535"
        "714806693100231362166973428959142189409448064907337538897991180419921875e-237"},
    {0x1.fffffffffffffp-786, chars_format::scientific, 601,
        "4."
        "9142065197732029671599346916926300587332105438466535357526596897978854713780475191646359612057616952229050"
        "1268429794696231362618387208843549231422234363992127134463051328710537196594804628968932614668152842714731"
        "7878285392788568157814915205310902528766624594681838418668427438058922060922721554055696322442953333748010"
        "5511385549590842018121646599567966874938451204259802478741166832432684925489225052000579720911898261771602"
        "0402865223389190796501409506150052069409471074043323239792214779085472285151897602726795946960715915589071"
        "42961338620046272433394685791828437881889612981467507779598236083984375e-237"},
    {0x1.fffffffffffffp-785, chars_format::scientific, 600,
        "9."
        "8284130395464059343198693833852601174664210876933070715053193795957709427560950383292719224115233904458100"
        "2536859589392462725236774417687098462844468727984254268926102657421074393189609257937865229336305685429463"
        "5756570785577136315629830410621805057533249189363676837336854876117844121845443108111392644885906667496021"
        "1022771099181684036243293199135933749876902408519604957482333664865369850978450104001159441823796523543204"
        "0805730446778381593002819012300104138818942148086646479584429558170944570303795205453591893921431831178142"
        "8592267724009254486678937158365687576377922596293501555919647216796875e-237"},
    {0x1.fffffffffffffp-784, chars_format::scientific, 600,
        "1."
        "9656826079092811868639738766770520234932842175386614143010638759191541885512190076658543844823046780891620"
        "0507371917878492545047354883537419692568893745596850853785220531484214878637921851587573045867261137085892"
        "7151314157115427263125966082124361011506649837872735367467370975223568824369088621622278528977181333499204"
        "2204554219836336807248658639827186749975380481703920991496466732973073970195690020800231888364759304708640"
        "8161146089355676318600563802460020827763788429617329295916885911634188914060759041090718378784286366235628"
        "5718453544801850897335787431673137515275584519258700311183929443359375e-236"},
    {0x1.fffffffffffffp-783, chars_format::scientific, 599,
        "3."
        "9313652158185623737279477533541040469865684350773228286021277518383083771024380153317087689646093561783240"
        "1014743835756985090094709767074839385137787491193701707570441062968429757275843703175146091734522274171785"
        "4302628314230854526251932164248722023013299675745470734934741950447137648738177243244557057954362666998408"
        "4409108439672673614497317279654373499950760963407841982992933465946147940391380041600463776729518609417281"
        "6322292178711352637201127604920041655527576859234658591833771823268377828121518082181436757568572732471257"
        "143690708960370179467157486334627503055116903851740062236785888671875e-236"},
    {0x1.fffffffffffffp-782, chars_format::scientific, 598,
        "7."
        "8627304316371247474558955067082080939731368701546456572042555036766167542048760306634175379292187123566480"
        "2029487671513970180189419534149678770275574982387403415140882125936859514551687406350292183469044548343570"
        "8605256628461709052503864328497444046026599351490941469869483900894275297476354486489114115908725333996816"
        "8818216879345347228994634559308746999901521926815683965985866931892295880782760083200927553459037218834563"
        "2644584357422705274402255209840083311055153718469317183667543646536755656243036164362873515137145464942514"
        "28738141792074035893431497266925500611023380770348012447357177734375e-236"},
    {0x1.fffffffffffffp-781, chars_format::scientific, 598,
        "1."
        "5725460863274249494911791013416416187946273740309291314408511007353233508409752061326835075858437424713296"
        "0405897534302794036037883906829935754055114996477480683028176425187371902910337481270058436693808909668714"
        "1721051325692341810500772865699488809205319870298188293973896780178855059495270897297822823181745066799363"
        "3763643375869069445798926911861749399980304385363136793197173386378459176156552016640185510691807443766912"
        "6528916871484541054880451041968016662211030743693863436733508729307351131248607232872574703027429092988502"
        "85747628358414807178686299453385100122204676154069602489471435546875e-235"},
    {0x1.fffffffffffffp-780, chars_format::scientific, 597,
        "3."
        "1450921726548498989823582026832832375892547480618582628817022014706467016819504122653670151716874849426592"
        "0811795068605588072075767813659871508110229992954961366056352850374743805820674962540116873387617819337428"
        "3442102651384683621001545731398977618410639740596376587947793560357710118990541794595645646363490133598726"
        "7527286751738138891597853823723498799960608770726273586394346772756918352313104033280371021383614887533825"
        "3057833742969082109760902083936033324422061487387726873467017458614702262497214465745149406054858185977005"
        "7149525671682961435737259890677020024440935230813920497894287109375e-235"},
    {0x1.fffffffffffffp-779, chars_format::scientific, 596,
        "6."
        "2901843453096997979647164053665664751785094961237165257634044029412934033639008245307340303433749698853184"
        "1623590137211176144151535627319743016220459985909922732112705700749487611641349925080233746775235638674856"
        "6884205302769367242003091462797955236821279481192753175895587120715420237981083589191291292726980267197453"
        "5054573503476277783195707647446997599921217541452547172788693545513836704626208066560742042767229775067650"
        "6115667485938164219521804167872066648844122974775453746934034917229404524994428931490298812109716371954011"
        "429905134336592287147451978135404004888187046162784099578857421875e-235"},
    {0x1.fffffffffffffp-778, chars_format::scientific, 596,
        "1."
        "2580368690619399595929432810733132950357018992247433051526808805882586806727801649061468060686749939770636"
        "8324718027442235228830307125463948603244091997181984546422541140149897522328269985016046749355047127734971"
        "3376841060553873448400618292559591047364255896238550635179117424143084047596216717838258258545396053439490"
        "7010914700695255556639141529489399519984243508290509434557738709102767340925241613312148408553445955013530"
        "1223133497187632843904360833574413329768824594955090749386806983445880904998885786298059762421943274390802"
        "285981026867318457429490395627080800977637409232556819915771484375e-234"},
    {0x1.fffffffffffffp-777, chars_format::scientific, 595,
        "2."
        "5160737381238799191858865621466265900714037984494866103053617611765173613455603298122936121373499879541273"
        "6649436054884470457660614250927897206488183994363969092845082280299795044656539970032093498710094255469942"
        "6753682121107746896801236585119182094728511792477101270358234848286168095192433435676516517090792106878981"
        "4021829401390511113278283058978799039968487016581018869115477418205534681850483226624296817106891910027060"
        "2446266994375265687808721667148826659537649189910181498773613966891761809997771572596119524843886548781604"
        "57196205373463691485898079125416160195527481846511363983154296875e-234"},
    {0x1.fffffffffffffp-776, chars_format::scientific, 594,
        "5."
        "0321474762477598383717731242932531801428075968989732206107235223530347226911206596245872242746999759082547"
        "3298872109768940915321228501855794412976367988727938185690164560599590089313079940064186997420188510939885"
        "3507364242215493793602473170238364189457023584954202540716469696572336190384866871353033034181584213757962"
        "8043658802781022226556566117957598079936974033162037738230954836411069363700966453248593634213783820054120"
        "4892533988750531375617443334297653319075298379820362997547227933783523619995543145192239049687773097563209"
        "1439241074692738297179615825083232039105496369302272796630859375e-234"},
    {0x1.fffffffffffffp-775, chars_format::scientific, 594,
        "1."
        "0064294952495519676743546248586506360285615193797946441221447044706069445382241319249174448549399951816509"
        "4659774421953788183064245700371158882595273597745587637138032912119918017862615988012837399484037702187977"
        "0701472848443098758720494634047672837891404716990840508143293939314467238076973374270606606836316842751592"
        "5608731760556204445311313223591519615987394806632407547646190967282213872740193290649718726842756764010824"
        "0978506797750106275123488666859530663815059675964072599509445586756704723999108629038447809937554619512641"
        "8287848214938547659435923165016646407821099273860454559326171875e-233"},
    {0x1.fffffffffffffp-774, chars_format::scientific, 593,
        "2."
        "0128589904991039353487092497173012720571230387595892882442894089412138890764482638498348897098799903633018"
        "9319548843907576366128491400742317765190547195491175274276065824239836035725231976025674798968075404375954"
        "1402945696886197517440989268095345675782809433981681016286587878628934476153946748541213213672633685503185"
        "1217463521112408890622626447183039231974789613264815095292381934564427745480386581299437453685513528021648"
        "1957013595500212550246977333719061327630119351928145199018891173513409447998217258076895619875109239025283"
        "657569642987709531887184633003329281564219854772090911865234375e-233"},
    {0x1.fffffffffffffp-773, chars_format::scientific, 592,
        "4."
        "0257179809982078706974184994346025441142460775191785764885788178824277781528965276996697794197599807266037"
        "8639097687815152732256982801484635530381094390982350548552131648479672071450463952051349597936150808751908"
        "2805891393772395034881978536190691351565618867963362032573175757257868952307893497082426427345267371006370"
        "2434927042224817781245252894366078463949579226529630190584763869128855490960773162598874907371027056043296"
        "3914027191000425100493954667438122655260238703856290398037782347026818895996434516153791239750218478050567"
        "31513928597541906377436926600665856312843970954418182373046875e-233"},
    {0x1.fffffffffffffp-772, chars_format::scientific, 591,
        "8."
        "0514359619964157413948369988692050882284921550383571529771576357648555563057930553993395588395199614532075"
        "7278195375630305464513965602969271060762188781964701097104263296959344142900927904102699195872301617503816"
        "5611782787544790069763957072381382703131237735926724065146351514515737904615786994164852854690534742012740"
        "4869854084449635562490505788732156927899158453059260381169527738257710981921546325197749814742054112086592"
        "7828054382000850200987909334876245310520477407712580796075564694053637791992869032307582479500436956101134"
        "6302785719508381275487385320133171262568794190883636474609375e-233"},
    {0x1.fffffffffffffp-771, chars_format::scientific, 591,
        "1."
        "6102871923992831482789673997738410176456984310076714305954315271529711112611586110798679117679039922906415"
        "1455639075126061092902793120593854212152437756392940219420852659391868828580185580820539839174460323500763"
        "3122356557508958013952791414476276540626247547185344813029270302903147580923157398832970570938106948402548"
        "0973970816889927112498101157746431385579831690611852076233905547651542196384309265039549962948410822417318"
        "5565610876400170040197581866975249062104095481542516159215112938810727558398573806461516495900087391220226"
        "9260557143901676255097477064026634252513758838176727294921875e-232"},
    {0x1.fffffffffffffp-770, chars_format::scientific, 590,
        "3."
        "2205743847985662965579347995476820352913968620153428611908630543059422225223172221597358235358079845812830"
        "2911278150252122185805586241187708424304875512785880438841705318783737657160371161641079678348920647001526"
        "6244713115017916027905582828952553081252495094370689626058540605806295161846314797665941141876213896805096"
        "1947941633779854224996202315492862771159663381223704152467811095303084392768618530079099925896821644834637"
        "1131221752800340080395163733950498124208190963085032318430225877621455116797147612923032991800174782440453"
        "852111428780335251019495412805326850502751767635345458984375e-232"},
    {0x1.fffffffffffffp-769, chars_format::scientific, 589,
        "6."
        "4411487695971325931158695990953640705827937240306857223817261086118844450446344443194716470716159691625660"
        "5822556300504244371611172482375416848609751025571760877683410637567475314320742323282159356697841294003053"
        "2489426230035832055811165657905106162504990188741379252117081211612590323692629595331882283752427793610192"
        "3895883267559708449992404630985725542319326762447408304935622190606168785537237060158199851793643289669274"
        "2262443505600680160790327467900996248416381926170064636860451755242910233594295225846065983600349564880907"
        "70422285756067050203899082561065370100550353527069091796875e-232"},
    {0x1.fffffffffffffp-768, chars_format::scientific, 589,
        "1."
        "2882297539194265186231739198190728141165587448061371444763452217223768890089268888638943294143231938325132"
        "1164511260100848874322234496475083369721950205114352175536682127513495062864148464656431871339568258800610"
        "6497885246007166411162233131581021232500998037748275850423416242322518064738525919066376456750485558722038"
        "4779176653511941689998480926197145108463865352489481660987124438121233757107447412031639970358728657933854"
        "8452488701120136032158065493580199249683276385234012927372090351048582046718859045169213196720069912976181"
        "54084457151213410040779816512213074020110070705413818359375e-231"},
    {0x1.fffffffffffffp-767, chars_format::scientific, 588,
        "2."
        "5764595078388530372463478396381456282331174896122742889526904434447537780178537777277886588286463876650264"
        "2329022520201697748644468992950166739443900410228704351073364255026990125728296929312863742679136517601221"
        "2995770492014332822324466263162042465001996075496551700846832484645036129477051838132752913500971117444076"
        "9558353307023883379996961852394290216927730704978963321974248876242467514214894824063279940717457315867709"
        "6904977402240272064316130987160398499366552770468025854744180702097164093437718090338426393440139825952363"
        "0816891430242682008155963302442614804022014141082763671875e-231"},
    {0x1.fffffffffffffp-766, chars_format::scientific, 587,
        "5."
        "1529190156777060744926956792762912564662349792245485779053808868895075560357075554555773176572927753300528"
        "4658045040403395497288937985900333478887800820457408702146728510053980251456593858625727485358273035202442"
        "5991540984028665644648932526324084930003992150993103401693664969290072258954103676265505827001942234888153"
        "9116706614047766759993923704788580433855461409957926643948497752484935028429789648126559881434914631735419"
        "3809954804480544128632261974320796998733105540936051709488361404194328186875436180676852786880279651904726"
        "163378286048536401631192660488522960804402828216552734375e-231"},
    {0x1.fffffffffffffp-765, chars_format::scientific, 587,
        "1."
        "0305838031355412148985391358552582512932469958449097155810761773779015112071415110911154635314585550660105"
        "6931609008080679099457787597180066695777560164091481740429345702010796050291318771725145497071654607040488"
        "5198308196805733128929786505264816986000798430198620680338732993858014451790820735253101165400388446977630"
        "7823341322809553351998784740957716086771092281991585328789699550496987005685957929625311976286982926347083"
        "8761990960896108825726452394864159399746621108187210341897672280838865637375087236135370557376055930380945"
        "232675657209707280326238532097704592160880565643310546875e-230"},
    {0x1.fffffffffffffp-764, chars_format::scientific, 586,
        "2."
        "0611676062710824297970782717105165025864939916898194311621523547558030224142830221822309270629171101320211"
        "3863218016161358198915575194360133391555120328182963480858691404021592100582637543450290994143309214080977"
        "0396616393611466257859573010529633972001596860397241360677465987716028903581641470506202330800776893955261"
        "5646682645619106703997569481915432173542184563983170657579399100993974011371915859250623952573965852694167"
        "7523981921792217651452904789728318799493242216374420683795344561677731274750174472270741114752111860761890"
        "46535131441941456065247706419540918432176113128662109375e-230"},
    {0x1.fffffffffffffp-763, chars_format::scientific, 585,
        "4."
        "1223352125421648595941565434210330051729879833796388623243047095116060448285660443644618541258342202640422"
        "7726436032322716397831150388720266783110240656365926961717382808043184201165275086900581988286618428161954"
        "0793232787222932515719146021059267944003193720794482721354931975432057807163282941012404661601553787910523"
        "1293365291238213407995138963830864347084369127966341315158798201987948022743831718501247905147931705388335"
        "5047963843584435302905809579456637598986484432748841367590689123355462549500348944541482229504223721523780"
        "9307026288388291213049541283908183686435222625732421875e-230"},
    {0x1.fffffffffffffp-762, chars_format::scientific, 584,
        "8."
        "2446704250843297191883130868420660103459759667592777246486094190232120896571320887289237082516684405280845"
        "5452872064645432795662300777440533566220481312731853923434765616086368402330550173801163976573236856323908"
        "1586465574445865031438292042118535888006387441588965442709863950864115614326565882024809323203107575821046"
        "2586730582476426815990277927661728694168738255932682630317596403975896045487663437002495810295863410776671"
        "0095927687168870605811619158913275197972968865497682735181378246710925099000697889082964459008447443047561"
        "861405257677658242609908256781636737287044525146484375e-230"},
    {0x1.fffffffffffffp-761, chars_format::scientific, 584,
        "1."
        "6489340850168659438376626173684132020691951933518555449297218838046424179314264177457847416503336881056169"
        "1090574412929086559132460155488106713244096262546370784686953123217273680466110034760232795314647371264781"
        "6317293114889173006287658408423707177601277488317793088541972790172823122865313176404961864640621515164209"
        "2517346116495285363198055585532345738833747651186536526063519280795179209097532687400499162059172682155334"
        "2019185537433774121162323831782655039594593773099536547036275649342185019800139577816592891801689488609512"
        "372281051535531648521981651356327347457408905029296875e-229"},
    {0x1.fffffffffffffp-760, chars_format::scientific, 583,
        "3."
        "2978681700337318876753252347368264041383903867037110898594437676092848358628528354915694833006673762112338"
        "2181148825858173118264920310976213426488192525092741569373906246434547360932220069520465590629294742529563"
        "2634586229778346012575316816847414355202554976635586177083945580345646245730626352809923729281243030328418"
        "5034692232990570726396111171064691477667495302373073052127038561590358418195065374800998324118345364310668"
        "4038371074867548242324647663565310079189187546199073094072551298684370039600279155633185783603378977219024"
        "74456210307106329704396330271265469491481781005859375e-229"},
    {0x1.fffffffffffffp-759, chars_format::scientific, 582,
        "6."
        "5957363400674637753506504694736528082767807734074221797188875352185696717257056709831389666013347524224676"
        "4362297651716346236529840621952426852976385050185483138747812492869094721864440139040931181258589485059126"
        "5269172459556692025150633633694828710405109953271172354167891160691292491461252705619847458562486060656837"
        "0069384465981141452792222342129382955334990604746146104254077123180716836390130749601996648236690728621336"
        "8076742149735096484649295327130620158378375092398146188145102597368740079200558311266371567206757954438049"
        "4891242061421265940879266054253093898296356201171875e-229"},
    {0x1.fffffffffffffp-758, chars_format::scientific, 582,
        "1."
        "3191472680134927550701300938947305616553561546814844359437775070437139343451411341966277933202669504844935"
        "2872459530343269247305968124390485370595277010037096627749562498573818944372888027808186236251717897011825"
        "3053834491911338405030126726738965742081021990654234470833578232138258498292250541123969491712497212131367"
        "4013876893196228290558444468425876591066998120949229220850815424636143367278026149920399329647338145724267"
        "3615348429947019296929859065426124031675675018479629237629020519473748015840111662253274313441351590887609"
        "8978248412284253188175853210850618779659271240234375e-228"},
    {0x1.fffffffffffffp-757, chars_format::scientific, 581,
        "2."
        "6382945360269855101402601877894611233107123093629688718875550140874278686902822683932555866405339009689870"
        "5744919060686538494611936248780970741190554020074193255499124997147637888745776055616372472503435794023650"
        "6107668983822676810060253453477931484162043981308468941667156464276516996584501082247938983424994424262734"
        "8027753786392456581116888936851753182133996241898458441701630849272286734556052299840798659294676291448534"
        "7230696859894038593859718130852248063351350036959258475258041038947496031680223324506548626882703181775219"
        "795649682456850637635170642170123755931854248046875e-228"},
    {0x1.fffffffffffffp-756, chars_format::scientific, 580,
        "5."
        "2765890720539710202805203755789222466214246187259377437751100281748557373805645367865111732810678019379741"
        "1489838121373076989223872497561941482381108040148386510998249994295275777491552111232744945006871588047301"
        "2215337967645353620120506906955862968324087962616937883334312928553033993169002164495877966849988848525469"
        "6055507572784913162233777873703506364267992483796916883403261698544573469112104599681597318589352582897069"
        "4461393719788077187719436261704496126702700073918516950516082077894992063360446649013097253765406363550439"
        "59129936491370127527034128434024751186370849609375e-228"},
    {0x1.fffffffffffffp-755, chars_format::scientific, 580,
        "1."
        "0553178144107942040561040751157844493242849237451875487550220056349711474761129073573022346562135603875948"
        "2297967624274615397844774499512388296476221608029677302199649998859055155498310422246548989001374317609460"
        "2443067593529070724024101381391172593664817592523387576666862585710606798633800432899175593369997769705093"
        "9211101514556982632446755574740701272853598496759383376680652339708914693822420919936319463717870516579413"
        "8892278743957615437543887252340899225340540014783703390103216415578998412672089329802619450753081272710087"
        "91825987298274025505406825686804950237274169921875e-227"},
    {0x1.fffffffffffffp-754, chars_format::scientific, 579,
        "2."
        "1106356288215884081122081502315688986485698474903750975100440112699422949522258147146044693124271207751896"
        "4595935248549230795689548999024776592952443216059354604399299997718110310996620844493097978002748635218920"
        "4886135187058141448048202762782345187329635185046775153333725171421213597267600865798351186739995539410187"
        "8422203029113965264893511149481402545707196993518766753361304679417829387644841839872638927435741033158827"
        "7784557487915230875087774504681798450681080029567406780206432831157996825344178659605238901506162545420175"
        "8365197459654805101081365137360990047454833984375e-227"},
    {0x1.fffffffffffffp-753, chars_format::scientific, 578,
        "4."
        "2212712576431768162244163004631377972971396949807501950200880225398845899044516294292089386248542415503792"
        "9191870497098461591379097998049553185904886432118709208798599995436220621993241688986195956005497270437840"
        "9772270374116282896096405525564690374659270370093550306667450342842427194535201731596702373479991078820375"
        "6844406058227930529787022298962805091414393987037533506722609358835658775289683679745277854871482066317655"
        "5569114975830461750175549009363596901362160059134813560412865662315993650688357319210477803012325090840351"
        "673039491930961020216273027472198009490966796875e-227"},
    {0x1.fffffffffffffp-752, chars_format::scientific, 577,
        "8."
        "4425425152863536324488326009262755945942793899615003900401760450797691798089032588584178772497084831007585"
        "8383740994196923182758195996099106371809772864237418417597199990872441243986483377972391912010994540875681"
        "9544540748232565792192811051129380749318540740187100613334900685684854389070403463193404746959982157640751"
        "3688812116455861059574044597925610182828787974075067013445218717671317550579367359490555709742964132635311"
        "1138229951660923500351098018727193802724320118269627120825731324631987301376714638420955606024650181680703"
        "34607898386192204043254605494439601898193359375e-227"},
    {0x1.fffffffffffffp-751, chars_format::scientific, 577,
        "1."
        "6885085030572707264897665201852551189188558779923000780080352090159538359617806517716835754499416966201517"
        "1676748198839384636551639199219821274361954572847483683519439998174488248797296675594478382402198908175136"
        "3908908149646513158438562210225876149863708148037420122666980137136970877814080692638680949391996431528150"
        "2737762423291172211914808919585122036565757594815013402689043743534263510115873471898111141948592826527062"
        "2227645990332184700070219603745438760544864023653925424165146264926397460275342927684191121204930036336140"
        "66921579677238440808650921098887920379638671875e-226"},
    {0x1.fffffffffffffp-750, chars_format::scientific, 576,
        "3."
        "3770170061145414529795330403705102378377117559846001560160704180319076719235613035433671508998833932403034"
        "3353496397678769273103278398439642548723909145694967367038879996348976497594593351188956764804397816350272"
        "7817816299293026316877124420451752299727416296074840245333960274273941755628161385277361898783992863056300"
        "5475524846582344423829617839170244073131515189630026805378087487068527020231746943796222283897185653054124"
        "4455291980664369400140439207490877521089728047307850848330292529852794920550685855368382242409860072672281"
        "3384315935447688161730184219777584075927734375e-226"},
    {0x1.fffffffffffffp-749, chars_format::scientific, 575,
        "6."
        "7540340122290829059590660807410204756754235119692003120321408360638153438471226070867343017997667864806068"
        "6706992795357538546206556796879285097447818291389934734077759992697952995189186702377913529608795632700545"
        "5635632598586052633754248840903504599454832592149680490667920548547883511256322770554723797567985726112601"
        "0951049693164688847659235678340488146263030379260053610756174974137054040463493887592444567794371306108248"
        "8910583961328738800280878414981755042179456094615701696660585059705589841101371710736764484819720145344562"
        "676863187089537632346036843955516815185546875e-226"},
    {0x1.fffffffffffffp-748, chars_format::scientific, 575,
        "1."
        "3508068024458165811918132161482040951350847023938400624064281672127630687694245214173468603599533572961213"
        "7341398559071507709241311359375857019489563658277986946815551998539590599037837340475582705921759126540109"
        "1127126519717210526750849768180700919890966518429936098133584109709576702251264554110944759513597145222520"
        "2190209938632937769531847135668097629252606075852010722151234994827410808092698777518488913558874261221649"
        "7782116792265747760056175682996351008435891218923140339332117011941117968220274342147352896963944029068912"
        "535372637417907526469207368791103363037109375e-225"},
    {0x1.fffffffffffffp-747, chars_format::scientific, 574,
        "2."
        "7016136048916331623836264322964081902701694047876801248128563344255261375388490428346937207199067145922427"
        "4682797118143015418482622718751714038979127316555973893631103997079181198075674680951165411843518253080218"
        "2254253039434421053501699536361401839781933036859872196267168219419153404502529108221889519027194290445040"
        "4380419877265875539063694271336195258505212151704021444302469989654821616185397555036977827117748522443299"
        "5564233584531495520112351365992702016871782437846280678664234023882235936440548684294705793927888058137825"
        "07074527483581505293841473758220672607421875e-225"},
    {0x1.fffffffffffffp-746, chars_format::scientific, 573,
        "5."
        "4032272097832663247672528645928163805403388095753602496257126688510522750776980856693874414398134291844854"
        "9365594236286030836965245437503428077958254633111947787262207994158362396151349361902330823687036506160436"
        "4508506078868842107003399072722803679563866073719744392534336438838306809005058216443779038054388580890080"
        "8760839754531751078127388542672390517010424303408042888604939979309643232370795110073955654235497044886599"
        "1128467169062991040224702731985404033743564875692561357328468047764471872881097368589411587855776116275650"
        "1414905496716301058768294751644134521484375e-225"},
    {0x1.fffffffffffffp-745, chars_format::scientific, 573,
        "1."
        "0806454419566532649534505729185632761080677619150720499251425337702104550155396171338774882879626858368970"
        "9873118847257206167393049087500685615591650926622389557452441598831672479230269872380466164737407301232087"
        "2901701215773768421400679814544560735912773214743948878506867287767661361801011643288755807610877716178016"
        "1752167950906350215625477708534478103402084860681608577720987995861928646474159022014791130847099408977319"
        "8225693433812598208044940546397080806748712975138512271465693609552894374576219473717882317571155223255130"
        "0282981099343260211753658950328826904296875e-224"},
    {0x1.fffffffffffffp-744, chars_format::scientific, 572,
        "2."
        "1612908839133065299069011458371265522161355238301440998502850675404209100310792342677549765759253716737941"
        "9746237694514412334786098175001371231183301853244779114904883197663344958460539744760932329474814602464174"
        "5803402431547536842801359629089121471825546429487897757013734575535322723602023286577511615221755432356032"
        "3504335901812700431250955417068956206804169721363217155441975991723857292948318044029582261694198817954639"
        "6451386867625196416089881092794161613497425950277024542931387219105788749152438947435764635142310446510260"
        "056596219868652042350731790065765380859375e-224"},
    {0x1.fffffffffffffp-743, chars_format::scientific, 571,
        "4."
        "3225817678266130598138022916742531044322710476602881997005701350808418200621584685355099531518507433475883"
        "9492475389028824669572196350002742462366603706489558229809766395326689916921079489521864658949629204928349"
        "1606804863095073685602719258178242943651092858975795514027469151070645447204046573155023230443510864712064"
        "7008671803625400862501910834137912413608339442726434310883951983447714585896636088059164523388397635909279"
        "2902773735250392832179762185588323226994851900554049085862774438211577498304877894871529270284620893020520"
        "11319243973730408470146358013153076171875e-224"},
    {0x1.fffffffffffffp-742, chars_format::scientific, 570,
        "8."
        "6451635356532261196276045833485062088645420953205763994011402701616836401243169370710199063037014866951767"
        "8984950778057649339144392700005484924733207412979116459619532790653379833842158979043729317899258409856698"
        "3213609726190147371205438516356485887302185717951591028054938302141290894408093146310046460887021729424129"
        "4017343607250801725003821668275824827216678885452868621767903966895429171793272176118329046776795271818558"
        "5805547470500785664359524371176646453989703801108098171725548876423154996609755789743058540569241786041040"
        "2263848794746081694029271602630615234375e-224"},
    {0x1.fffffffffffffp-741, chars_format::scientific, 570,
        "1."
        "7290327071306452239255209166697012417729084190641152798802280540323367280248633874142039812607402973390353"
        "5796990155611529867828878540001096984946641482595823291923906558130675966768431795808745863579851681971339"
        "6642721945238029474241087703271297177460437143590318205610987660428258178881618629262009292177404345884825"
        "8803468721450160345000764333655164965443335777090573724353580793379085834358654435223665809355359054363711"
        "7161109494100157132871904874235329290797940760221619634345109775284630999321951157948611708113848357208208"
        "0452769758949216338805854320526123046875e-223"},
    {0x1.fffffffffffffp-740, chars_format::scientific, 569,
        "3."
        "4580654142612904478510418333394024835458168381282305597604561080646734560497267748284079625214805946780707"
        "1593980311223059735657757080002193969893282965191646583847813116261351933536863591617491727159703363942679"
        "3285443890476058948482175406542594354920874287180636411221975320856516357763237258524018584354808691769651"
        "7606937442900320690001528667310329930886671554181147448707161586758171668717308870447331618710718108727423"
        "4322218988200314265743809748470658581595881520443239268690219550569261998643902315897223416227696714416416"
        "090553951789843267761170864105224609375e-223"},
    {0x1.fffffffffffffp-739, chars_format::scientific, 568,
        "6."
        "9161308285225808957020836666788049670916336762564611195209122161293469120994535496568159250429611893561414"
        "3187960622446119471315514160004387939786565930383293167695626232522703867073727183234983454319406727885358"
        "6570887780952117896964350813085188709841748574361272822443950641713032715526474517048037168709617383539303"
        "5213874885800641380003057334620659861773343108362294897414323173516343337434617740894663237421436217454846"
        "8644437976400628531487619496941317163191763040886478537380439101138523997287804631794446832455393428832832"
        "18110790357968653552234172821044921875e-223"},
    {0x1.fffffffffffffp-738, chars_format::scientific, 568,
        "1."
        "3832261657045161791404167333357609934183267352512922239041824432258693824198907099313631850085922378712282"
        "8637592124489223894263102832000877587957313186076658633539125246504540773414745436646996690863881345577071"
        "7314177556190423579392870162617037741968349714872254564488790128342606543105294903409607433741923476707860"
        "7042774977160128276000611466924131972354668621672458979482864634703268667486923548178932647484287243490969"
        "3728887595280125706297523899388263432638352608177295707476087820227704799457560926358889366491078685766566"
        "43622158071593730710446834564208984375e-222"},
    {0x1.fffffffffffffp-737, chars_format::scientific, 567,
        "2."
        "7664523314090323582808334666715219868366534705025844478083648864517387648397814198627263700171844757424565"
        "7275184248978447788526205664001755175914626372153317267078250493009081546829490873293993381727762691154143"
        "4628355112380847158785740325234075483936699429744509128977580256685213086210589806819214867483846953415721"
        "4085549954320256552001222933848263944709337243344917958965729269406537334973847096357865294968574486981938"
        "7457775190560251412595047798776526865276705216354591414952175640455409598915121852717778732982157371533132"
        "8724431614318746142089366912841796875e-222"},
    {0x1.fffffffffffffp-736, chars_format::scientific, 566,
        "5."
        "5329046628180647165616669333430439736733069410051688956167297729034775296795628397254527400343689514849131"
        "4550368497956895577052411328003510351829252744306634534156500986018163093658981746587986763455525382308286"
        "9256710224761694317571480650468150967873398859489018257955160513370426172421179613638429734967693906831442"
        "8171099908640513104002445867696527889418674486689835917931458538813074669947694192715730589937148973963877"
        "4915550381120502825190095597553053730553410432709182829904351280910819197830243705435557465964314743066265"
        "744886322863749228417873382568359375e-222"},
    {0x1.fffffffffffffp-735, chars_format::scientific, 566,
        "1."
        "1065809325636129433123333866686087947346613882010337791233459545806955059359125679450905480068737902969826"
        "2910073699591379115410482265600702070365850548861326906831300197203632618731796349317597352691105076461657"
        "3851342044952338863514296130093630193574679771897803651591032102674085234484235922727685946993538781366288"
        "5634219981728102620800489173539305577883734897337967183586291707762614933989538838543146117987429794792775"
        "4983110076224100565038019119510610746110682086541836565980870256182163839566048741087111493192862948613253"
        "148977264572749845683574676513671875e-221"},
    {0x1.fffffffffffffp-734, chars_format::scientific, 565,
        "2."
        "2131618651272258866246667733372175894693227764020675582466919091613910118718251358901810960137475805939652"
        "5820147399182758230820964531201404140731701097722653813662600394407265237463592698635194705382210152923314"
        "7702684089904677727028592260187260387149359543795607303182064205348170468968471845455371893987077562732577"
        "1268439963456205241600978347078611155767469794675934367172583415525229867979077677086292235974859589585550"
        "9966220152448201130076038239021221492221364173083673131961740512364327679132097482174222986385725897226506"
        "29795452914549969136714935302734375e-221"},
    {0x1.fffffffffffffp-733, chars_format::scientific, 564,
        "4."
        "4263237302544517732493335466744351789386455528041351164933838183227820237436502717803621920274951611879305"
        "1640294798365516461641929062402808281463402195445307627325200788814530474927185397270389410764420305846629"
        "5405368179809355454057184520374520774298719087591214606364128410696340937936943690910743787974155125465154"
        "2536879926912410483201956694157222311534939589351868734345166831050459735958155354172584471949719179171101"
        "9932440304896402260152076478042442984442728346167346263923481024728655358264194964348445972771451794453012"
        "5959090582909993827342987060546875e-221"},
    {0x1.fffffffffffffp-732, chars_format::scientific, 563,
        "8."
        "8526474605089035464986670933488703578772911056082702329867676366455640474873005435607243840549903223758610"
        "3280589596731032923283858124805616562926804390890615254650401577629060949854370794540778821528840611693259"
        "0810736359618710908114369040749041548597438175182429212728256821392681875873887381821487575948310250930308"
        "5073759853824820966403913388314444623069879178703737468690333662100919471916310708345168943899438358342203"
        "9864880609792804520304152956084885968885456692334692527846962049457310716528389928696891945542903588906025"
        "191818116581998765468597412109375e-221"},
    {0x1.fffffffffffffp-731, chars_format::scientific, 563,
        "1."
        "7705294921017807092997334186697740715754582211216540465973535273291128094974601087121448768109980644751722"
        "0656117919346206584656771624961123312585360878178123050930080315525812189970874158908155764305768122338651"
        "8162147271923742181622873808149808309719487635036485842545651364278536375174777476364297515189662050186061"
        "7014751970764964193280782677662888924613975835740747493738066732420183894383262141669033788779887671668440"
        "7972976121958560904060830591216977193777091338466938505569392409891462143305677985739378389108580717781205"
        "038363623316399753093719482421875e-220"},
    {0x1.fffffffffffffp-730, chars_format::scientific, 562,
        "3."
        "5410589842035614185994668373395481431509164422433080931947070546582256189949202174242897536219961289503444"
        "1312235838692413169313543249922246625170721756356246101860160631051624379941748317816311528611536244677303"
        "6324294543847484363245747616299616619438975270072971685091302728557072750349554952728595030379324100372123"
        "4029503941529928386561565355325777849227951671481494987476133464840367788766524283338067577559775343336881"
        "5945952243917121808121661182433954387554182676933877011138784819782924286611355971478756778217161435562410"
        "07672724663279950618743896484375e-220"},
    {0x1.fffffffffffffp-729, chars_format::scientific, 561,
        "7."
        "0821179684071228371989336746790962863018328844866161863894141093164512379898404348485795072439922579006888"
        "2624471677384826338627086499844493250341443512712492203720321262103248759883496635632623057223072489354607"
        "2648589087694968726491495232599233238877950540145943370182605457114145500699109905457190060758648200744246"
        "8059007883059856773123130710651555698455903342962989974952266929680735577533048566676135155119550686673763"
        "1891904487834243616243322364867908775108365353867754022277569639565848573222711942957513556434322871124820"
        "1534544932655990123748779296875e-220"},
    {0x1.fffffffffffffp-728, chars_format::scientific, 561,
        "1."
        "4164235936814245674397867349358192572603665768973232372778828218632902475979680869697159014487984515801377"
        "6524894335476965267725417299968898650068288702542498440744064252420649751976699327126524611444614497870921"
        "4529717817538993745298299046519846647775590108029188674036521091422829100139821981091438012151729640148849"
        "3611801576611971354624626142130311139691180668592597994990453385936147115506609713335227031023910137334752"
        "6378380897566848723248664472973581755021673070773550804455513927913169714644542388591502711286864574224964"
        "0306908986531198024749755859375e-219"},
    {0x1.fffffffffffffp-727, chars_format::scientific, 560,
        "2."
        "8328471873628491348795734698716385145207331537946464745557656437265804951959361739394318028975969031602755"
        "3049788670953930535450834599937797300136577405084996881488128504841299503953398654253049222889228995741842"
        "9059435635077987490596598093039693295551180216058377348073042182845658200279643962182876024303459280297698"
        "7223603153223942709249252284260622279382361337185195989980906771872294231013219426670454062047820274669505"
        "2756761795133697446497328945947163510043346141547101608911027855826339429289084777183005422573729148449928"
        "061381797306239604949951171875e-219"},
    {0x1.fffffffffffffp-726, chars_format::scientific, 559,
        "5."
        "6656943747256982697591469397432770290414663075892929491115312874531609903918723478788636057951938063205510"
        "6099577341907861070901669199875594600273154810169993762976257009682599007906797308506098445778457991483685"
        "8118871270155974981193196186079386591102360432116754696146084365691316400559287924365752048606918560595397"
        "4447206306447885418498504568521244558764722674370391979961813543744588462026438853340908124095640549339010"
        "5513523590267394892994657891894327020086692283094203217822055711652678858578169554366010845147458296899856"
        "12276359461247920989990234375e-219"},
    {0x1.fffffffffffffp-725, chars_format::scientific, 559,
        "1."
        "1331388749451396539518293879486554058082932615178585898223062574906321980783744695757727211590387612641102"
        "1219915468381572214180333839975118920054630962033998752595251401936519801581359461701219689155691598296737"
        "1623774254031194996238639237215877318220472086423350939229216873138263280111857584873150409721383712119079"
        "4889441261289577083699700913704248911752944534874078395992362708748917692405287770668181624819128109867802"
        "1102704718053478978598931578378865404017338456618840643564411142330535771715633910873202169029491659379971"
        "22455271892249584197998046875e-218"},
    {0x1.fffffffffffffp-724, chars_format::scientific, 558,
        "2."
        "2662777498902793079036587758973108116165865230357171796446125149812643961567489391515454423180775225282204"
        "2439830936763144428360667679950237840109261924067997505190502803873039603162718923402439378311383196593474"
        "3247548508062389992477278474431754636440944172846701878458433746276526560223715169746300819442767424238158"
        "9778882522579154167399401827408497823505889069748156791984725417497835384810575541336363249638256219735604"
        "2205409436106957957197863156757730808034676913237681287128822284661071543431267821746404338058983318759942"
        "4491054378449916839599609375e-218"},
    {0x1.fffffffffffffp-723, chars_format::scientific, 557,
        "4."
        "5325554997805586158073175517946216232331730460714343592892250299625287923134978783030908846361550450564408"
        "4879661873526288856721335359900475680218523848135995010381005607746079206325437846804878756622766393186948"
        "6495097016124779984954556948863509272881888345693403756916867492553053120447430339492601638885534848476317"
        "9557765045158308334798803654816995647011778139496313583969450834995670769621151082672726499276512439471208"
        "4410818872213915914395726313515461616069353826475362574257644569322143086862535643492808676117966637519884"
        "898210875689983367919921875e-218"},
    {0x1.fffffffffffffp-722, chars_format::scientific, 556,
        "9."
        "0651109995611172316146351035892432464663460921428687185784500599250575846269957566061817692723100901128816"
        "9759323747052577713442670719800951360437047696271990020762011215492158412650875693609757513245532786373897"
        "2990194032249559969909113897727018545763776691386807513833734985106106240894860678985203277771069696952635"
        "9115530090316616669597607309633991294023556278992627167938901669991341539242302165345452998553024878942416"
        "8821637744427831828791452627030923232138707652950725148515289138644286173725071286985617352235933275039769"
        "79642175137996673583984375e-218"},
    {0x1.fffffffffffffp-721, chars_format::scientific, 556,
        "1."
        "8130221999122234463229270207178486492932692184285737437156900119850115169253991513212363538544620180225763"
        "3951864749410515542688534143960190272087409539254398004152402243098431682530175138721951502649106557274779"
        "4598038806449911993981822779545403709152755338277361502766746997021221248178972135797040655554213939390527"
        "1823106018063323333919521461926798258804711255798525433587780333998268307848460433069090599710604975788483"
        "3764327548885566365758290525406184646427741530590145029703057827728857234745014257397123470447186655007953"
        "95928435027599334716796875e-217"},
    {0x1.fffffffffffffp-720, chars_format::scientific, 555,
        "3."
        "6260443998244468926458540414356972985865384368571474874313800239700230338507983026424727077089240360451526"
        "7903729498821031085377068287920380544174819078508796008304804486196863365060350277443903005298213114549558"
        "9196077612899823987963645559090807418305510676554723005533493994042442496357944271594081311108427878781054"
        "3646212036126646667839042923853596517609422511597050867175560667996536615696920866138181199421209951576966"
        "7528655097771132731516581050812369292855483061180290059406115655457714469490028514794246940894373310015907"
        "9185687005519866943359375e-217"},
    {0x1.fffffffffffffp-719, chars_format::scientific, 554,
        "7."
        "2520887996488937852917080828713945971730768737142949748627600479400460677015966052849454154178480720903053"
        "5807458997642062170754136575840761088349638157017592016609608972393726730120700554887806010596426229099117"
        "8392155225799647975927291118181614836611021353109446011066987988084884992715888543188162622216855757562108"
        "7292424072253293335678085847707193035218845023194101734351121335993073231393841732276362398842419903153933"
        "5057310195542265463033162101624738585710966122360580118812231310915428938980057029588493881788746620031815"
        "837137401103973388671875e-217"},
    {0x1.fffffffffffffp-718, chars_format::scientific, 554,
        "1."
        "4504177599297787570583416165742789194346153747428589949725520095880092135403193210569890830835696144180610"
        "7161491799528412434150827315168152217669927631403518403321921794478745346024140110977561202119285245819823"
        "5678431045159929595185458223636322967322204270621889202213397597616976998543177708637632524443371151512421"
        "7458484814450658667135617169541438607043769004638820346870224267198614646278768346455272479768483980630786"
        "7011462039108453092606632420324947717142193224472116023762446262183085787796011405917698776357749324006363"
        "167427480220794677734375e-216"},
    {0x1.fffffffffffffp-717, chars_format::scientific, 553,
        "2."
        "9008355198595575141166832331485578388692307494857179899451040191760184270806386421139781661671392288361221"
        "4322983599056824868301654630336304435339855262807036806643843588957490692048280221955122404238570491639647"
        "1356862090319859190370916447272645934644408541243778404426795195233953997086355417275265048886742303024843"
        "4916969628901317334271234339082877214087538009277640693740448534397229292557536692910544959536967961261573"
        "4022924078216906185213264840649895434284386448944232047524892524366171575592022811835397552715498648012726"
        "33485496044158935546875e-216"},
    {0x1.fffffffffffffp-716, chars_format::scientific, 552,
        "5."
        "8016710397191150282333664662971156777384614989714359798902080383520368541612772842279563323342784576722442"
        "8645967198113649736603309260672608870679710525614073613287687177914981384096560443910244808477140983279294"
        "2713724180639718380741832894545291869288817082487556808853590390467907994172710834550530097773484606049686"
        "9833939257802634668542468678165754428175076018555281387480897068794458585115073385821089919073935922523146"
        "8045848156433812370426529681299790868568772897888464095049785048732343151184045623670795105430997296025452"
        "6697099208831787109375e-216"},
    {0x1.fffffffffffffp-715, chars_format::scientific, 552,
        "1."
        "1603342079438230056466732932594231355476922997942871959780416076704073708322554568455912664668556915344488"
        "5729193439622729947320661852134521774135942105122814722657537435582996276819312088782048961695428196655858"
        "8542744836127943676148366578909058373857763416497511361770718078093581598834542166910106019554696921209937"
        "3966787851560526933708493735633150885635015203711056277496179413758891717023014677164217983814787184504629"
        "3609169631286762474085305936259958173713754579577692819009957009746468630236809124734159021086199459205090"
        "5339419841766357421875e-215"},
    {0x1.fffffffffffffp-714, chars_format::scientific, 551,
        "2."
        "3206684158876460112933465865188462710953845995885743919560832153408147416645109136911825329337113830688977"
        "1458386879245459894641323704269043548271884210245629445315074871165992553638624177564097923390856393311717"
        "7085489672255887352296733157818116747715526832995022723541436156187163197669084333820212039109393842419874"
        "7933575703121053867416987471266301771270030407422112554992358827517783434046029354328435967629574369009258"
        "7218339262573524948170611872519916347427509159155385638019914019492937260473618249468318042172398918410181"
        "067883968353271484375e-215"},
    {0x1.fffffffffffffp-713, chars_format::scientific, 550,
        "4."
        "6413368317752920225866931730376925421907691991771487839121664306816294833290218273823650658674227661377954"
        "2916773758490919789282647408538087096543768420491258890630149742331985107277248355128195846781712786623435"
        "4170979344511774704593466315636233495431053665990045447082872312374326395338168667640424078218787684839749"
        "5867151406242107734833974942532603542540060814844225109984717655035566868092058708656871935259148738018517"
        "4436678525147049896341223745039832694855018318310771276039828038985874520947236498936636084344797836820362"
        "13576793670654296875e-215"},
    {0x1.fffffffffffffp-712, chars_format::scientific, 549,
        "9."
        "2826736635505840451733863460753850843815383983542975678243328613632589666580436547647301317348455322755908"
        "5833547516981839578565294817076174193087536840982517781260299484663970214554496710256391693563425573246870"
        "8341958689023549409186932631272466990862107331980090894165744624748652790676337335280848156437575369679499"
        "1734302812484215469667949885065207085080121629688450219969435310071133736184117417313743870518297476037034"
        "8873357050294099792682447490079665389710036636621542552079656077971749041894472997873272168689595673640724"
        "2715358734130859375e-215"},
    {0x1.fffffffffffffp-711, chars_format::scientific, 549,
        "1."
        "8565347327101168090346772692150770168763076796708595135648665722726517933316087309529460263469691064551181"
        "7166709503396367915713058963415234838617507368196503556252059896932794042910899342051278338712685114649374"
        "1668391737804709881837386526254493398172421466396018178833148924949730558135267467056169631287515073935899"
        "8346860562496843093933589977013041417016024325937690043993887062014226747236823483462748774103659495207406"
        "9774671410058819958536489498015933077942007327324308510415931215594349808378894599574654433737919134728144"
        "8543071746826171875e-214"},
    {0x1.fffffffffffffp-710, chars_format::scientific, 548,
        "3."
        "7130694654202336180693545384301540337526153593417190271297331445453035866632174619058920526939382129102363"
        "4333419006792735831426117926830469677235014736393007112504119793865588085821798684102556677425370229298748"
        "3336783475609419763674773052508986796344842932792036357666297849899461116270534934112339262575030147871799"
        "6693721124993686187867179954026082834032048651875380087987774124028453494473646966925497548207318990414813"
        "9549342820117639917072978996031866155884014654648617020831862431188699616757789199149308867475838269456289"
        "708614349365234375e-214"},
    {0x1.fffffffffffffp-709, chars_format::scientific, 547,
        "7."
        "4261389308404672361387090768603080675052307186834380542594662890906071733264349238117841053878764258204726"
        "8666838013585471662852235853660939354470029472786014225008239587731176171643597368205113354850740458597496"
        "6673566951218839527349546105017973592689685865584072715332595699798922232541069868224678525150060295743599"
        "3387442249987372375734359908052165668064097303750760175975548248056906988947293933850995096414637980829627"
        "9098685640235279834145957992063732311768029309297234041663724862377399233515578398298617734951676538912579"
        "41722869873046875e-214"},
    {0x1.fffffffffffffp-708, chars_format::scientific, 547,
        "1."
        "4852277861680934472277418153720616135010461437366876108518932578181214346652869847623568210775752851640945"
        "3733367602717094332570447170732187870894005894557202845001647917546235234328719473641022670970148091719499"
        "3334713390243767905469909221003594718537937173116814543066519139959784446508213973644935705030012059148719"
        "8677488449997474475146871981610433133612819460750152035195109649611381397789458786770199019282927596165925"
        "5819737128047055966829191598412746462353605861859446808332744972475479846703115679659723546990335307782515"
        "88344573974609375e-213"},
    {0x1.fffffffffffffp-707, chars_format::scientific, 546,
        "2."
        "9704555723361868944554836307441232270020922874733752217037865156362428693305739695247136421551505703281890"
        "7466735205434188665140894341464375741788011789114405690003295835092470468657438947282045341940296183438998"
        "6669426780487535810939818442007189437075874346233629086133038279919568893016427947289871410060024118297439"
        "7354976899994948950293743963220866267225638921500304070390219299222762795578917573540398038565855192331851"
        "1639474256094111933658383196825492924707211723718893616665489944950959693406231359319447093980670615565031"
        "7668914794921875e-213"},
    {0x1.fffffffffffffp-706, chars_format::scientific, 545,
        "5."
        "9409111446723737889109672614882464540041845749467504434075730312724857386611479390494272843103011406563781"
        "4933470410868377330281788682928751483576023578228811380006591670184940937314877894564090683880592366877997"
        "3338853560975071621879636884014378874151748692467258172266076559839137786032855894579742820120048236594879"
        "4709953799989897900587487926441732534451277843000608140780438598445525591157835147080796077131710384663702"
        "3278948512188223867316766393650985849414423447437787233330979889901919386812462718638894187961341231130063"
        "533782958984375e-213"},
    {0x1.fffffffffffffp-705, chars_format::scientific, 545,
        "1."
        "1881822289344747577821934522976492908008369149893500886815146062544971477322295878098854568620602281312756"
        "2986694082173675466056357736585750296715204715645762276001318334036988187462975578912818136776118473375599"
        "4667770712195014324375927376802875774830349738493451634453215311967827557206571178915948564024009647318975"
        "8941990759997979580117497585288346506890255568600121628156087719689105118231567029416159215426342076932740"
        "4655789702437644773463353278730197169882884689487557446666195977980383877362492543727778837592268246226012"
        "706756591796875e-212"},
    {0x1.fffffffffffffp-704, chars_format::scientific, 544,
        "2."
        "3763644578689495155643869045952985816016738299787001773630292125089942954644591756197709137241204562625512"
        "5973388164347350932112715473171500593430409431291524552002636668073976374925951157825636273552236946751198"
        "9335541424390028648751854753605751549660699476986903268906430623935655114413142357831897128048019294637951"
        "7883981519995959160234995170576693013780511137200243256312175439378210236463134058832318430852684153865480"
        "9311579404875289546926706557460394339765769378975114893332391955960767754724985087455557675184536492452025"
        "41351318359375e-212"},
    {0x1.fffffffffffffp-703, chars_format::scientific, 543,
        "4."
        "7527289157378990311287738091905971632033476599574003547260584250179885909289183512395418274482409125251025"
        "1946776328694701864225430946343001186860818862583049104005273336147952749851902315651272547104473893502397"
        "8671082848780057297503709507211503099321398953973806537812861247871310228826284715663794256096038589275903"
        "5767963039991918320469990341153386027561022274400486512624350878756420472926268117664636861705368307730961"
        "8623158809750579093853413114920788679531538757950229786664783911921535509449970174911115350369072984904050"
        "8270263671875e-212"},
    {0x1.fffffffffffffp-702, chars_format::scientific, 542,
        "9."
        "5054578314757980622575476183811943264066953199148007094521168500359771818578367024790836548964818250502050"
        "3893552657389403728450861892686002373721637725166098208010546672295905499703804631302545094208947787004795"
        "7342165697560114595007419014423006198642797907947613075625722495742620457652569431327588512192077178551807"
        "1535926079983836640939980682306772055122044548800973025248701757512840945852536235329273723410736615461923"
        "7246317619501158187706826229841577359063077515900459573329567823843071018899940349822230700738145969808101"
        "654052734375e-212"},
    {0x1.fffffffffffffp-701, chars_format::scientific, 542,
        "1."
        "9010915662951596124515095236762388652813390639829601418904233700071954363715673404958167309792963650100410"
        "0778710531477880745690172378537200474744327545033219641602109334459181099940760926260509018841789557400959"
        "1468433139512022919001483802884601239728559581589522615125144499148524091530513886265517702438415435710361"
        "4307185215996767328187996136461354411024408909760194605049740351502568189170507247065854744682147323092384"
        "7449263523900231637541365245968315471812615503180091914665913564768614203779988069964446140147629193961620"
        "330810546875e-211"},
    {0x1.fffffffffffffp-700, chars_format::scientific, 541,
        "3."
        "8021831325903192249030190473524777305626781279659202837808467400143908727431346809916334619585927300200820"
        "1557421062955761491380344757074400949488655090066439283204218668918362199881521852521018037683579114801918"
        "2936866279024045838002967605769202479457119163179045230250288998297048183061027772531035404876830871420722"
        "8614370431993534656375992272922708822048817819520389210099480703005136378341014494131709489364294646184769"
        "4898527047800463275082730491936630943625231006360183829331827129537228407559976139928892280295258387923240"
        "66162109375e-211"},
    {0x1.fffffffffffffp-699, chars_format::scientific, 540,
        "7."
        "6043662651806384498060380947049554611253562559318405675616934800287817454862693619832669239171854600401640"
        "3114842125911522982760689514148801898977310180132878566408437337836724399763043705042036075367158229603836"
        "5873732558048091676005935211538404958914238326358090460500577996594096366122055545062070809753661742841445"
        "7228740863987069312751984545845417644097635639040778420198961406010272756682028988263418978728589292369538"
        "9797054095600926550165460983873261887250462012720367658663654259074456815119952279857784560590516775846481"
        "3232421875e-211"},
    {0x1.fffffffffffffp-698, chars_format::scientific, 540,
        "1."
        "5208732530361276899612076189409910922250712511863681135123386960057563490972538723966533847834370920080328"
        "0622968425182304596552137902829760379795462036026575713281687467567344879952608741008407215073431645920767"
        "3174746511609618335201187042307680991782847665271618092100115599318819273224411109012414161950732348568289"
        "1445748172797413862550396909169083528819527127808155684039792281202054551336405797652683795745717858473907"
        "7959410819120185310033092196774652377450092402544073531732730851814891363023990455971556912118103355169296"
        "2646484375e-210"},
    {0x1.fffffffffffffp-697, chars_format::scientific, 539,
        "3."
        "0417465060722553799224152378819821844501425023727362270246773920115126981945077447933067695668741840160656"
        "1245936850364609193104275805659520759590924072053151426563374935134689759905217482016814430146863291841534"
        "6349493023219236670402374084615361983565695330543236184200231198637638546448822218024828323901464697136578"
        "2891496345594827725100793818338167057639054255616311368079584562404109102672811595305367591491435716947815"
        "5918821638240370620066184393549304754900184805088147063465461703629782726047980911943113824236206710338592"
        "529296875e-210"},
    {0x1.fffffffffffffp-696, chars_format::scientific, 538,
        "6."
        "0834930121445107598448304757639643689002850047454724540493547840230253963890154895866135391337483680321312"
        "2491873700729218386208551611319041519181848144106302853126749870269379519810434964033628860293726583683069"
        "2698986046438473340804748169230723967131390661086472368400462397275277092897644436049656647802929394273156"
        "5782992691189655450201587636676334115278108511232622736159169124808218205345623190610735182982871433895631"
        "1837643276480741240132368787098609509800369610176294126930923407259565452095961823886227648472413420677185"
        "05859375e-210"},
    {0x1.fffffffffffffp-695, chars_format::scientific, 538,
        "1."
        "2166986024289021519689660951527928737800570009490944908098709568046050792778030979173227078267496736064262"
        "4498374740145843677241710322263808303836369628821260570625349974053875903962086992806725772058745316736613"
        "8539797209287694668160949633846144793426278132217294473680092479455055418579528887209931329560585878854631"
        "3156598538237931090040317527335266823055621702246524547231833824961643641069124638122147036596574286779126"
        "2367528655296148248026473757419721901960073922035258825386184681451913090419192364777245529694482684135437"
        "01171875e-209"},
    {0x1.fffffffffffffp-694, chars_format::scientific, 537,
        "2."
        "4333972048578043039379321903055857475601140018981889816197419136092101585556061958346454156534993472128524"
        "8996749480291687354483420644527616607672739257642521141250699948107751807924173985613451544117490633473227"
        "7079594418575389336321899267692289586852556264434588947360184958910110837159057774419862659121171757709262"
        "6313197076475862180080635054670533646111243404493049094463667649923287282138249276244294073193148573558252"
        "4735057310592296496052947514839443803920147844070517650772369362903826180838384729554491059388965368270874"
        "0234375e-209"},
    {0x1.fffffffffffffp-693, chars_format::scientific, 536,
        "4."
        "8667944097156086078758643806111714951202280037963779632394838272184203171112123916692908313069986944257049"
        "7993498960583374708966841289055233215345478515285042282501399896215503615848347971226903088234981266946455"
        "4159188837150778672643798535384579173705112528869177894720369917820221674318115548839725318242343515418525"
        "2626394152951724360161270109341067292222486808986098188927335299846574564276498552488588146386297147116504"
        "9470114621184592992105895029678887607840295688141035301544738725807652361676769459108982118777930736541748"
        "046875e-209"},
    {0x1.fffffffffffffp-692, chars_format::scientific, 535,
        "9."
        "7335888194312172157517287612223429902404560075927559264789676544368406342224247833385816626139973888514099"
        "5986997921166749417933682578110466430690957030570084565002799792431007231696695942453806176469962533892910"
        "8318377674301557345287597070769158347410225057738355789440739835640443348636231097679450636484687030837050"
        "5252788305903448720322540218682134584444973617972196377854670599693149128552997104977176292772594294233009"
        "8940229242369185984211790059357775215680591376282070603089477451615304723353538918217964237555861473083496"
        "09375e-209"},
    {0x1.fffffffffffffp-691, chars_format::scientific, 535,
        "1."
        "9467177638862434431503457522444685980480912015185511852957935308873681268444849566677163325227994777702819"
        "9197399584233349883586736515622093286138191406114016913000559958486201446339339188490761235293992506778582"
        "1663675534860311469057519414153831669482045011547671157888147967128088669727246219535890127296937406167410"
        "1050557661180689744064508043736426916888994723594439275570934119938629825710599420995435258554518858846601"
        "9788045848473837196842358011871555043136118275256414120617895490323060944670707783643592847511172294616699"
        "21875e-208"},
    {0x1.fffffffffffffp-690, chars_format::scientific, 534,
        "3."
        "8934355277724868863006915044889371960961824030371023705915870617747362536889699133354326650455989555405639"
        "8394799168466699767173473031244186572276382812228033826001119916972402892678678376981522470587985013557164"
        "3327351069720622938115038828307663338964090023095342315776295934256177339454492439071780254593874812334820"
        "2101115322361379488129016087472853833777989447188878551141868239877259651421198841990870517109037717693203"
        "9576091696947674393684716023743110086272236550512828241235790980646121889341415567287185695022344589233398"
        "4375e-208"},
    {0x1.fffffffffffffp-689, chars_format::scientific, 533,
        "7."
        "7868710555449737726013830089778743921923648060742047411831741235494725073779398266708653300911979110811279"
        "6789598336933399534346946062488373144552765624456067652002239833944805785357356753963044941175970027114328"
        "6654702139441245876230077656615326677928180046190684631552591868512354678908984878143560509187749624669640"
        "4202230644722758976258032174945707667555978894377757102283736479754519302842397683981741034218075435386407"
        "9152183393895348787369432047486220172544473101025656482471581961292243778682831134574371390044689178466796"
        "875e-208"},
    {0x1.fffffffffffffp-688, chars_format::scientific, 533,
        "1."
        "5573742111089947545202766017955748784384729612148409482366348247098945014755879653341730660182395822162255"
        "9357919667386679906869389212497674628910553124891213530400447966788961157071471350792608988235194005422865"
        "7330940427888249175246015531323065335585636009238136926310518373702470935781796975628712101837549924933928"
        "0840446128944551795251606434989141533511195778875551420456747295950903860568479536796348206843615087077281"
        "5830436678779069757473886409497244034508894620205131296494316392258448755736566226914874278008937835693359"
        "375e-207"},
    {0x1.fffffffffffffp-687, chars_format::scientific, 532,
        "3."
        "1147484222179895090405532035911497568769459224296818964732696494197890029511759306683461320364791644324511"
        "8715839334773359813738778424995349257821106249782427060800895933577922314142942701585217976470388010845731"
        "4661880855776498350492031062646130671171272018476273852621036747404941871563593951257424203675099849867856"
        "1680892257889103590503212869978283067022391557751102840913494591901807721136959073592696413687230174154563"
        "1660873357558139514947772818994488069017789240410262592988632784516897511473132453829748556017875671386718"
        "75e-207"},
    {0x1.fffffffffffffp-686, chars_format::scientific, 531,
        "6."
        "2294968444359790180811064071822995137538918448593637929465392988395780059023518613366922640729583288649023"
        "7431678669546719627477556849990698515642212499564854121601791867155844628285885403170435952940776021691462"
        "9323761711552996700984062125292261342342544036952547705242073494809883743127187902514848407350199699735712"
        "3361784515778207181006425739956566134044783115502205681826989183803615442273918147185392827374460348309126"
        "3321746715116279029895545637988976138035578480820525185977265569033795022946264907659497112035751342773437"
        "5e-207"},
    {0x1.fffffffffffffp-685, chars_format::scientific, 531,
        "1."
        "2458993688871958036162212814364599027507783689718727585893078597679156011804703722673384528145916657729804"
        "7486335733909343925495511369998139703128442499912970824320358373431168925657177080634087190588155204338292"
        "5864752342310599340196812425058452268468508807390509541048414698961976748625437580502969681470039939947142"
        "4672356903155641436201285147991313226808956623100441136365397836760723088454783629437078565474892069661825"
        "2664349343023255805979109127597795227607115696164105037195453113806759004589252981531899422407150268554687"
        "5e-206"},
    {0x1.fffffffffffffp-684, chars_format::scientific, 530,
        "2."
        "4917987377743916072324425628729198055015567379437455171786157195358312023609407445346769056291833315459609"
        "4972671467818687850991022739996279406256884999825941648640716746862337851314354161268174381176310408676585"
        "1729504684621198680393624850116904536937017614781019082096829397923953497250875161005939362940079879894284"
        "9344713806311282872402570295982626453617913246200882272730795673521446176909567258874157130949784139323650"
        "5328698686046511611958218255195590455214231392328210074390906227613518009178505963063798844814300537109375"
        "e-206"},
    {0x1.fffffffffffffp-683, chars_format::scientific, 529,
        "4."
        "9835974755487832144648851257458396110031134758874910343572314390716624047218814890693538112583666630919218"
        "9945342935637375701982045479992558812513769999651883297281433493724675702628708322536348762352620817353170"
        "3459009369242397360787249700233809073874035229562038164193658795847906994501750322011878725880159759788569"
        "8689427612622565744805140591965252907235826492401764545461591347042892353819134517748314261899568278647301"
        "065739737209302322391643651039118091042846278465642014878181245522703601835701192612759768962860107421875e"
        "-206"},
    {0x1.fffffffffffffp-682, chars_format::scientific, 528,
        "9."
        "9671949510975664289297702514916792220062269517749820687144628781433248094437629781387076225167333261838437"
        "9890685871274751403964090959985117625027539999303766594562866987449351405257416645072697524705241634706340"
        "6918018738484794721574499400467618147748070459124076328387317591695813989003500644023757451760319519577139"
        "7378855225245131489610281183930505814471652984803529090923182694085784707638269035496628523799136557294602"
        "13147947441860464478328730207823618208569255693128402975636249104540720367140238522551953792572021484375e-"
        "206"},
    {0x1.fffffffffffffp-681, chars_format::scientific, 528,
        "1."
        "9934389902195132857859540502983358444012453903549964137428925756286649618887525956277415245033466652367687"
        "5978137174254950280792818191997023525005507999860753318912573397489870281051483329014539504941048326941268"
        "1383603747696958944314899880093523629549614091824815265677463518339162797800700128804751490352063903915427"
        "9475771045049026297922056236786101162894330596960705818184636538817156941527653807099325704759827311458920"
        "42629589488372092895665746041564723641713851138625680595127249820908144073428047704510390758514404296875e-"
        "205"},
    {0x1.fffffffffffffp-680, chars_format::scientific, 527,
        "3."
        "9868779804390265715719081005966716888024907807099928274857851512573299237775051912554830490066933304735375"
        "1956274348509900561585636383994047050011015999721506637825146794979740562102966658029079009882096653882536"
        "2767207495393917888629799760187047259099228183649630531354927036678325595601400257609502980704127807830855"
        "8951542090098052595844112473572202325788661193921411636369273077634313883055307614198651409519654622917840"
        "8525917897674418579133149208312944728342770227725136119025449964181628814685609540902078151702880859375e-"
        "205"},
    {0x1.fffffffffffffp-679, chars_format::scientific, 526,
        "7."
        "9737559608780531431438162011933433776049815614199856549715703025146598475550103825109660980133866609470750"
        "3912548697019801123171272767988094100022031999443013275650293589959481124205933316058158019764193307765072"
        "5534414990787835777259599520374094518198456367299261062709854073356651191202800515219005961408255615661711"
        "7903084180196105191688224947144404651577322387842823272738546155268627766110615228397302819039309245835681"
        "705183579534883715826629841662588945668554045545027223805089992836325762937121908180415630340576171875e-"
        "205"},
    {0x1.fffffffffffffp-678, chars_format::scientific, 526,
        "1."
        "5947511921756106286287632402386686755209963122839971309943140605029319695110020765021932196026773321894150"
        "0782509739403960224634254553597618820004406399888602655130058717991896224841186663211631603952838661553014"
        "5106882998157567155451919904074818903639691273459852212541970814671330238240560103043801192281651123132342"
        "3580616836039221038337644989428880930315464477568564654547709231053725553222123045679460563807861849167136"
        "341036715906976743165325968332517789133710809109005444761017998567265152587424381636083126068115234375e-"
        "204"},
    {0x1.fffffffffffffp-677, chars_format::scientific, 525,
        "3."
        "1895023843512212572575264804773373510419926245679942619886281210058639390220041530043864392053546643788300"
        "1565019478807920449268509107195237640008812799777205310260117435983792449682373326423263207905677323106029"
        "0213765996315134310903839808149637807279382546919704425083941629342660476481120206087602384563302246264684"
        "7161233672078442076675289978857761860630928955137129309095418462107451106444246091358921127615723698334272"
        "68207343181395348633065193666503557826742161821801088952203599713453030517484876327216625213623046875e-"
        "204"},
    {0x1.fffffffffffffp-676, chars_format::scientific, 524,
        "6."
        "3790047687024425145150529609546747020839852491359885239772562420117278780440083060087728784107093287576600"
        "3130038957615840898537018214390475280017625599554410620520234871967584899364746652846526415811354646212058"
        "0427531992630268621807679616299275614558765093839408850167883258685320952962240412175204769126604492529369"
        "4322467344156884153350579957715523721261857910274258618190836924214902212888492182717842255231447396668545"
        "3641468636279069726613038733300711565348432364360217790440719942690606103496975265443325042724609375e-"
        "204"},
    {0x1.fffffffffffffp-675, chars_format::scientific, 524,
        "1."
        "2758009537404885029030105921909349404167970498271977047954512484023455756088016612017545756821418657515320"
        "0626007791523168179707403642878095056003525119910882124104046974393516979872949330569305283162270929242411"
        "6085506398526053724361535923259855122911753018767881770033576651737064190592448082435040953825320898505873"
        "8864493468831376830670115991543104744252371582054851723638167384842980442577698436543568451046289479333709"
        "0728293727255813945322607746660142313069686472872043558088143988538121220699395053088665008544921875e-"
        "203"},
    {0x1.fffffffffffffp-674, chars_format::scientific, 523,
        "2."
        "5516019074809770058060211843818698808335940996543954095909024968046911512176033224035091513642837315030640"
        "1252015583046336359414807285756190112007050239821764248208093948787033959745898661138610566324541858484823"
        "2171012797052107448723071846519710245823506037535763540067153303474128381184896164870081907650641797011747"
        "7728986937662753661340231983086209488504743164109703447276334769685960885155396873087136902092578958667418"
        "145658745451162789064521549332028462613937294574408711617628797707624244139879010617733001708984375e-203"},
    {0x1.fffffffffffffp-673, chars_format::scientific, 522,
        "5."
        "1032038149619540116120423687637397616671881993087908191818049936093823024352066448070183027285674630061280"
        "2504031166092672718829614571512380224014100479643528496416187897574067919491797322277221132649083716969646"
        "4342025594104214897446143693039420491647012075071527080134306606948256762369792329740163815301283594023495"
        "5457973875325507322680463966172418977009486328219406894552669539371921770310793746174273804185157917334836"
        "29131749090232557812904309866405692522787458914881742323525759541524848827975802123546600341796875e-203"},
    {0x1.fffffffffffffp-672, chars_format::scientific, 522,
        "1."
        "0206407629923908023224084737527479523334376398617581638363609987218764604870413289614036605457134926012256"
        "0500806233218534543765922914302476044802820095928705699283237579514813583898359464455444226529816743393929"
        "2868405118820842979489228738607884098329402415014305416026861321389651352473958465948032763060256718804699"
        "1091594775065101464536092793234483795401897265643881378910533907874384354062158749234854760837031583466967"
        "25826349818046511562580861973281138504557491782976348464705151908304969765595160424709320068359375e-202"},
    {0x1.fffffffffffffp-671, chars_format::scientific, 521,
        "2."
        "0412815259847816046448169475054959046668752797235163276727219974437529209740826579228073210914269852024512"
        "1001612466437069087531845828604952089605640191857411398566475159029627167796718928910888453059633486787858"
        "5736810237641685958978457477215768196658804830028610832053722642779302704947916931896065526120513437609398"
        "2183189550130202929072185586468967590803794531287762757821067815748768708124317498469709521674063166933934"
        "5165269963609302312516172394656227700911498356595269692941030381660993953119032084941864013671875e-202"},
    {0x1.fffffffffffffp-670, chars_format::scientific, 520,
        "4."
        "0825630519695632092896338950109918093337505594470326553454439948875058419481653158456146421828539704049024"
        "2003224932874138175063691657209904179211280383714822797132950318059254335593437857821776906119266973575717"
        "1473620475283371917956914954431536393317609660057221664107445285558605409895833863792131052241026875218796"
        "4366379100260405858144371172937935181607589062575525515642135631497537416248634996939419043348126333867869"
        "033053992721860462503234478931245540182299671319053938588206076332198790623806416988372802734375e-202"},
    {0x1.fffffffffffffp-669, chars_format::scientific, 519,
        "8."
        "1651261039391264185792677900219836186675011188940653106908879897750116838963306316912292843657079408098048"
        "4006449865748276350127383314419808358422560767429645594265900636118508671186875715643553812238533947151434"
        "2947240950566743835913829908863072786635219320114443328214890571117210819791667727584262104482053750437592"
        "8732758200520811716288742345875870363215178125151051031284271262995074832497269993878838086696252667735738"
        "06610798544372092500646895786249108036459934263810787717641215266439758124761283397674560546875e-202"},
    {0x1.fffffffffffffp-668, chars_format::scientific, 519,
        "1."
        "6330252207878252837158535580043967237335002237788130621381775979550023367792661263382458568731415881619609"
        "6801289973149655270025476662883961671684512153485929118853180127223701734237375143128710762447706789430286"
        "8589448190113348767182765981772614557327043864022888665642978114223442163958333545516852420896410750087518"
        "5746551640104162343257748469175174072643035625030210206256854252599014966499453998775767617339250533547147"
        "61322159708874418500129379157249821607291986852762157543528243053287951624952256679534912109375e-201"},
    {0x1.fffffffffffffp-667, chars_format::scientific, 518,
        "3."
        "2660504415756505674317071160087934474670004475576261242763551959100046735585322526764917137462831763239219"
        "3602579946299310540050953325767923343369024306971858237706360254447403468474750286257421524895413578860573"
        "7178896380226697534365531963545229114654087728045777331285956228446884327916667091033704841792821500175037"
        "1493103280208324686515496938350348145286071250060420412513708505198029932998907997551535234678501067094295"
        "2264431941774883700025875831449964321458397370552431508705648610657590324990451335906982421875e-201"},
    {0x1.fffffffffffffp-666, chars_format::scientific, 517,
        "6."
        "5321008831513011348634142320175868949340008951152522485527103918200093471170645053529834274925663526478438"
        "7205159892598621080101906651535846686738048613943716475412720508894806936949500572514843049790827157721147"
        "4357792760453395068731063927090458229308175456091554662571912456893768655833334182067409683585643000350074"
        "2986206560416649373030993876700696290572142500120840825027417010396059865997815995103070469357002134188590"
        "452886388354976740005175166289992864291679474110486301741129722131518064998090267181396484375e-201"},
    {0x1.fffffffffffffp-665, chars_format::scientific, 517,
        "1."
        "3064201766302602269726828464035173789868001790230504497105420783640018694234129010705966854985132705295687"
        "7441031978519724216020381330307169337347609722788743295082544101778961387389900114502968609958165431544229"
        "4871558552090679013746212785418091645861635091218310932514382491378753731166666836413481936717128600070014"
        "8597241312083329874606198775340139258114428500024168165005483402079211973199563199020614093871400426837718"
        "090577277670995348001035033257998572858335894822097260348225944426303612999618053436279296875e-200"},
    {0x1.fffffffffffffp-664, chars_format::scientific, 516,
        "2."
        "6128403532605204539453656928070347579736003580461008994210841567280037388468258021411933709970265410591375"
        "4882063957039448432040762660614338674695219445577486590165088203557922774779800229005937219916330863088458"
        "9743117104181358027492425570836183291723270182436621865028764982757507462333333672826963873434257200140029"
        "7194482624166659749212397550680278516228857000048336330010966804158423946399126398041228187742800853675436"
        "18115455534199069600207006651599714571667178964419452069645188885260722599923610687255859375e-200"},
    {0x1.fffffffffffffp-663, chars_format::scientific, 515,
        "5."
        "2256807065210409078907313856140695159472007160922017988421683134560074776936516042823867419940530821182750"
        "9764127914078896864081525321228677349390438891154973180330176407115845549559600458011874439832661726176917"
        "9486234208362716054984851141672366583446540364873243730057529965515014924666667345653927746868514400280059"
        "4388965248333319498424795101360557032457714000096672660021933608316847892798252796082456375485601707350872"
        "3623091106839813920041401330319942914333435792883890413929037777052144519984722137451171875e-200"},
    {0x1.fffffffffffffp-662, chars_format::scientific, 515,
        "1."
        "0451361413042081815781462771228139031894401432184403597684336626912014955387303208564773483988106164236550"
        "1952825582815779372816305064245735469878087778230994636066035281423169109911920091602374887966532345235383"
        "5897246841672543210996970228334473316689308072974648746011505993103002984933333469130785549373702880056011"
        "8877793049666663899684959020272111406491542800019334532004386721663369578559650559216491275097120341470174"
        "4724618221367962784008280266063988582866687158576778082785807555410428903996944427490234375e-199"},
    {0x1.fffffffffffffp-661, chars_format::scientific, 514,
        "2."
        "0902722826084163631562925542456278063788802864368807195368673253824029910774606417129546967976212328473100"
        "3905651165631558745632610128491470939756175556461989272132070562846338219823840183204749775933064690470767"
        "1794493683345086421993940456668946633378616145949297492023011986206005969866666938261571098747405760112023"
        "7755586099333327799369918040544222812983085600038669064008773443326739157119301118432982550194240682940348"
        "944923644273592556801656053212797716573337431715355616557161511082085780799388885498046875e-199"},
    {0x1.fffffffffffffp-660, chars_format::scientific, 513,
        "4."
        "1805445652168327263125851084912556127577605728737614390737346507648059821549212834259093935952424656946200"
        "7811302331263117491265220256982941879512351112923978544264141125692676439647680366409499551866129380941534"
        "3588987366690172843987880913337893266757232291898594984046023972412011939733333876523142197494811520224047"
        "5511172198666655598739836081088445625966171200077338128017546886653478314238602236865965100388481365880697"
        "88984728854718511360331210642559543314667486343071123311432302216417156159877777099609375e-199"},
    {0x1.fffffffffffffp-659, chars_format::scientific, 512,
        "8."
        "3610891304336654526251702169825112255155211457475228781474693015296119643098425668518187871904849313892401"
        "5622604662526234982530440513965883759024702225847957088528282251385352879295360732818999103732258761883068"
        "7177974733380345687975761826675786533514464583797189968092047944824023879466667753046284394989623040448095"
        "1022344397333311197479672162176891251932342400154676256035093773306956628477204473731930200776962731761395"
        "7796945770943702272066242128511908662933497268614224662286460443283431231975555419921875e-199"},
    {0x1.fffffffffffffp-658, chars_format::scientific, 512,
        "1."
        "6722178260867330905250340433965022451031042291495045756294938603059223928619685133703637574380969862778480"
        "3124520932505246996506088102793176751804940445169591417705656450277070575859072146563799820746451752376613"
        "7435594946676069137595152365335157306702892916759437993618409588964804775893333550609256878997924608089619"
        "0204468879466662239495934432435378250386468480030935251207018754661391325695440894746386040155392546352279"
        "1559389154188740454413248425702381732586699453722844932457292088656686246395111083984375e-198"},
    {0x1.fffffffffffffp-657, chars_format::scientific, 511,
        "3."
        "3444356521734661810500680867930044902062084582990091512589877206118447857239370267407275148761939725556960"
        "6249041865010493993012176205586353503609880890339182835411312900554141151718144293127599641492903504753227"
        "4871189893352138275190304730670314613405785833518875987236819177929609551786667101218513757995849216179238"
        "0408937758933324478991868864870756500772936960061870502414037509322782651390881789492772080310785092704558"
        "311877830837748090882649685140476346517339890744568986491458417731337249279022216796875e-198"},
    {0x1.fffffffffffffp-656, chars_format::scientific, 510,
        "6."
        "6888713043469323621001361735860089804124169165980183025179754412236895714478740534814550297523879451113921"
        "2498083730020987986024352411172707007219761780678365670822625801108282303436288586255199282985807009506454"
        "9742379786704276550380609461340629226811571667037751974473638355859219103573334202437027515991698432358476"
        "0817875517866648957983737729741513001545873920123741004828075018645565302781763578985544160621570185409116"
        "62375566167549618176529937028095269303467978148913797298291683546267449855804443359375e-198"},
    {0x1.fffffffffffffp-655, chars_format::scientific, 510,
        "1."
        "3377742608693864724200272347172017960824833833196036605035950882447379142895748106962910059504775890222784"
        "2499616746004197597204870482234541401443952356135673134164525160221656460687257717251039856597161401901290"
        "9948475957340855310076121892268125845362314333407550394894727671171843820714666840487405503198339686471695"
        "2163575103573329791596747545948302600309174784024748200965615003729113060556352715797108832124314037081823"
        "32475113233509923635305987405619053860693595629782759459658336709253489971160888671875e-197"},
    {0x1.fffffffffffffp-654, chars_format::scientific, 509,
        "2."
        "6755485217387729448400544694344035921649667666392073210071901764894758285791496213925820119009551780445568"
        "4999233492008395194409740964469082802887904712271346268329050320443312921374515434502079713194322803802581"
        "9896951914681710620152243784536251690724628666815100789789455342343687641429333680974811006396679372943390"
        "4327150207146659583193495091896605200618349568049496401931230007458226121112705431594217664248628074163646"
        "6495022646701984727061197481123810772138719125956551891931667341850697994232177734375e-197"},
    {0x1.fffffffffffffp-653, chars_format::scientific, 508,
        "5."
        "3510970434775458896801089388688071843299335332784146420143803529789516571582992427851640238019103560891136"
        "9998466984016790388819481928938165605775809424542692536658100640886625842749030869004159426388645607605163"
        "9793903829363421240304487569072503381449257333630201579578910684687375282858667361949622012793358745886780"
        "8654300414293319166386990183793210401236699136098992803862460014916452242225410863188435328497256148327293"
        "299004529340396945412239496224762154427743825191310378386333468370139598846435546875e-197"},
    {0x1.fffffffffffffp-652, chars_format::scientific, 508,
        "1."
        "0702194086955091779360217877737614368659867066556829284028760705957903314316598485570328047603820712178227"
        "3999693396803358077763896385787633121155161884908538507331620128177325168549806173800831885277729121521032"
        "7958780765872684248060897513814500676289851466726040315915782136937475056571733472389924402558671749177356"
        "1730860082858663833277398036758642080247339827219798560772492002983290448445082172637687065699451229665458"
        "659800905868079389082447899244952430885548765038262075677266693674027919769287109375e-196"},
    {0x1.fffffffffffffp-651, chars_format::scientific, 507,
        "2."
        "1404388173910183558720435755475228737319734133113658568057521411915806628633196971140656095207641424356454"
        "7999386793606716155527792771575266242310323769817077014663240256354650337099612347601663770555458243042065"
        "5917561531745368496121795027629001352579702933452080631831564273874950113143466944779848805117343498354712"
        "3461720165717327666554796073517284160494679654439597121544984005966580896890164345275374131398902459330917"
        "31960181173615877816489579848990486177109753007652415135453338734805583953857421875e-196"},
    {0x1.fffffffffffffp-650, chars_format::scientific, 506,
        "4."
        "2808776347820367117440871510950457474639468266227317136115042823831613257266393942281312190415282848712909"
        "5998773587213432311055585543150532484620647539634154029326480512709300674199224695203327541110916486084131"
        "1835123063490736992243590055258002705159405866904161263663128547749900226286933889559697610234686996709424"
        "6923440331434655333109592147034568320989359308879194243089968011933161793780328690550748262797804918661834"
        "6392036234723175563297915969798097235421950601530483027090667746961116790771484375e-196"},
    {0x1.fffffffffffffp-649, chars_format::scientific, 505,
        "8."
        "5617552695640734234881743021900914949278936532454634272230085647663226514532787884562624380830565697425819"
        "1997547174426864622111171086301064969241295079268308058652961025418601348398449390406655082221832972168262"
        "3670246126981473984487180110516005410318811733808322527326257095499800452573867779119395220469373993418849"
        "3846880662869310666219184294069136641978718617758388486179936023866323587560657381101496525595609837323669"
        "278407246944635112659583193959619447084390120306096605418133549392223358154296875e-196"},
    {0x1.fffffffffffffp-648, chars_format::scientific, 505,
        "1."
        "7123510539128146846976348604380182989855787306490926854446017129532645302906557576912524876166113139485163"
        "8399509434885372924422234217260212993848259015853661611730592205083720269679689878081331016444366594433652"
        "4734049225396294796897436022103201082063762346761664505465251419099960090514773555823879044093874798683769"
        "8769376132573862133243836858813827328395743723551677697235987204773264717512131476220299305119121967464733"
        "855681449388927022531916638791923889416878024061219321083626709878444671630859375e-195"},
    {0x1.fffffffffffffp-647, chars_format::scientific, 504,
        "3."
        "4247021078256293693952697208760365979711574612981853708892034259065290605813115153825049752332226278970327"
        "6799018869770745848844468434520425987696518031707323223461184410167440539359379756162662032888733188867304"
        "9468098450792589593794872044206402164127524693523329010930502838199920181029547111647758088187749597367539"
        "7538752265147724266487673717627654656791487447103355394471974409546529435024262952440598610238243934929467"
        "71136289877785404506383327758384777883375604812243864216725341975688934326171875e-195"},
    {0x1.fffffffffffffp-646, chars_format::scientific, 503,
        "6."
        "8494042156512587387905394417520731959423149225963707417784068518130581211626230307650099504664452557940655"
        "3598037739541491697688936869040851975393036063414646446922368820334881078718759512325324065777466377734609"
        "8936196901585179187589744088412804328255049387046658021861005676399840362059094223295516176375499194735079"
        "5077504530295448532975347435255309313582974894206710788943948819093058870048525904881197220476487869858935"
        "4227257975557080901276665551676955576675120962448772843345068395137786865234375e-195"},
    {0x1.fffffffffffffp-645, chars_format::scientific, 503,
        "1."
        "3698808431302517477581078883504146391884629845192741483556813703626116242325246061530019900932890511588131"
        "0719607547908298339537787373808170395078607212682929289384473764066976215743751902465064813155493275546921"
        "9787239380317035837517948817682560865651009877409331604372201135279968072411818844659103235275099838947015"
        "9015500906059089706595069487051061862716594978841342157788789763818611774009705180976239444095297573971787"
        "0845451595111416180255333110335391115335024192489754568669013679027557373046875e-194"},
    {0x1.fffffffffffffp-644, chars_format::scientific, 502,
        "2."
        "7397616862605034955162157767008292783769259690385482967113627407252232484650492123060039801865781023176262"
        "1439215095816596679075574747616340790157214425365858578768947528133952431487503804930129626310986551093843"
        "9574478760634071675035897635365121731302019754818663208744402270559936144823637689318206470550199677894031"
        "8031001812118179413190138974102123725433189957682684315577579527637223548019410361952478888190595147943574"
        "169090319022283236051066622067078223067004838497950913733802735805511474609375e-194"},
    {0x1.fffffffffffffp-643, chars_format::scientific, 501,
        "5."
        "4795233725210069910324315534016585567538519380770965934227254814504464969300984246120079603731562046352524"
        "2878430191633193358151149495232681580314428850731717157537895056267904862975007609860259252621973102187687"
        "9148957521268143350071795270730243462604039509637326417488804541119872289647275378636412941100399355788063"
        "6062003624236358826380277948204247450866379915365368631155159055274447096038820723904957776381190295887148"
        "33818063804456647210213324413415644613400967699590182746760547161102294921875e-194"},
    {0x1.fffffffffffffp-642, chars_format::scientific, 501,
        "1."
        "0959046745042013982064863106803317113507703876154193186845450962900892993860196849224015920746312409270504"
        "8575686038326638671630229899046536316062885770146343431507579011253580972595001521972051850524394620437537"
        "5829791504253628670014359054146048692520807901927465283497760908223974457929455075727282588220079871157612"
        "7212400724847271765276055589640849490173275983073073726231031811054889419207764144780991555276238059177429"
        "66763612760891329442042664882683128922680193539918036549352109432220458984375e-193"},
    {0x1.fffffffffffffp-641, chars_format::scientific, 500,
        "2."
        "1918093490084027964129726213606634227015407752308386373690901925801785987720393698448031841492624818541009"
        "7151372076653277343260459798093072632125771540292686863015158022507161945190003043944103701048789240875075"
        "1659583008507257340028718108292097385041615803854930566995521816447948915858910151454565176440159742315225"
        "4424801449694543530552111179281698980346551966146147452462063622109778838415528289561983110552476118354859"
        "3352722552178265888408532976536625784536038707983607309870421886444091796875e-193"},
    {0x1.fffffffffffffp-640, chars_format::scientific, 499,
        "4."
        "3836186980168055928259452427213268454030815504616772747381803851603571975440787396896063682985249637082019"
        "4302744153306554686520919596186145264251543080585373726030316045014323890380006087888207402097578481750150"
        "3319166017014514680057436216584194770083231607709861133991043632895897831717820302909130352880319484630450"
        "8849602899389087061104222358563397960693103932292294904924127244219557676831056579123966221104952236709718"
        "670544510435653177681706595307325156907207741596721461974084377288818359375e-193"},
    {0x1.fffffffffffffp-639, chars_format::scientific, 498,
        "8."
        "7672373960336111856518904854426536908061631009233545494763607703207143950881574793792127365970499274164038"
        "8605488306613109373041839192372290528503086161170747452060632090028647780760012175776414804195156963500300"
        "6638332034029029360114872433168389540166463215419722267982087265791795663435640605818260705760638969260901"
        "7699205798778174122208444717126795921386207864584589809848254488439115353662113158247932442209904473419437"
        "34108902087130635536341319061465031381441548319344292394816875457763671875e-193"},
    {0x1.fffffffffffffp-638, chars_format::scientific, 498,
        "1."
        "7534474792067222371303780970885307381612326201846709098952721540641428790176314958758425473194099854832807"
        "7721097661322621874608367838474458105700617232234149490412126418005729556152002435155282960839031392700060"
        "1327666406805805872022974486633677908033292643083944453596417453158359132687128121163652141152127793852180"
        "3539841159755634824441688943425359184277241572916917961969650897687823070732422631649586488441980894683887"
        "46821780417426127107268263812293006276288309663868858478963375091552734375e-192"},
    {0x1.fffffffffffffp-637, chars_format::scientific, 497,
        "3."
        "5068949584134444742607561941770614763224652403693418197905443081282857580352629917516850946388199709665615"
        "5442195322645243749216735676948916211401234464468298980824252836011459112304004870310565921678062785400120"
        "2655332813611611744045948973267355816066585286167888907192834906316718265374256242327304282304255587704360"
        "7079682319511269648883377886850718368554483145833835923939301795375646141464845263299172976883961789367774"
        "9364356083485225421453652762458601255257661932773771695792675018310546875e-192"},
    {0x1.fffffffffffffp-636, chars_format::scientific, 496,
        "7."
        "0137899168268889485215123883541229526449304807386836395810886162565715160705259835033701892776399419331231"
        "0884390645290487498433471353897832422802468928936597961648505672022918224608009740621131843356125570800240"
        "5310665627223223488091897946534711632133170572335777814385669812633436530748512484654608564608511175408721"
        "4159364639022539297766755773701436737108966291667671847878603590751292282929690526598345953767923578735549"
        "872871216697045084290730552491720251051532386554754339158535003662109375e-192"},
    {0x1.fffffffffffffp-635, chars_format::scientific, 496,
        "1."
        "4027579833653777897043024776708245905289860961477367279162177232513143032141051967006740378555279883866246"
        "2176878129058097499686694270779566484560493785787319592329701134404583644921601948124226368671225114160048"
        "1062133125444644697618379589306942326426634114467155562877133962526687306149702496930921712921702235081744"
        "2831872927804507859553351154740287347421793258333534369575720718150258456585938105319669190753584715747109"
        "974574243339409016858146110498344050210306477310950867831707000732421875e-191"},
    {0x1.fffffffffffffp-634, chars_format::scientific, 495,
        "2."
        "8055159667307555794086049553416491810579721922954734558324354465026286064282103934013480757110559767732492"
        "4353756258116194999373388541559132969120987571574639184659402268809167289843203896248452737342450228320096"
        "2124266250889289395236759178613884652853268228934311125754267925053374612299404993861843425843404470163488"
        "5663745855609015719106702309480574694843586516667068739151441436300516913171876210639338381507169431494219"
        "94914848667881803371629222099668810042061295462190173566341400146484375e-191"},
    {0x1.fffffffffffffp-633, chars_format::scientific, 494,
        "5."
        "6110319334615111588172099106832983621159443845909469116648708930052572128564207868026961514221119535464984"
        "8707512516232389998746777083118265938241975143149278369318804537618334579686407792496905474684900456640192"
        "4248532501778578790473518357227769305706536457868622251508535850106749224598809987723686851686808940326977"
        "1327491711218031438213404618961149389687173033334137478302882872601033826343752421278676763014338862988439"
        "8982969733576360674325844419933762008412259092438034713268280029296875e-191"},
    {0x1.fffffffffffffp-632, chars_format::scientific, 494,
        "1."
        "1222063866923022317634419821366596724231888769181893823329741786010514425712841573605392302844223907092996"
        "9741502503246477999749355416623653187648395028629855673863760907523666915937281558499381094936980091328038"
        "4849706500355715758094703671445553861141307291573724450301707170021349844919761997544737370337361788065395"
        "4265498342243606287642680923792229877937434606666827495660576574520206765268750484255735352602867772597687"
        "9796593946715272134865168883986752401682451818487606942653656005859375e-190"},
    {0x1.fffffffffffffp-631, chars_format::scientific, 493,
        "2."
        "2444127733846044635268839642733193448463777538363787646659483572021028851425683147210784605688447814185993"
        "9483005006492955999498710833247306375296790057259711347727521815047333831874563116998762189873960182656076"
        "9699413000711431516189407342891107722282614583147448900603414340042699689839523995089474740674723576130790"
        "8530996684487212575285361847584459755874869213333654991321153149040413530537500968511470705205735545195375"
        "959318789343054426973033776797350480336490363697521388530731201171875e-190"},
    {0x1.fffffffffffffp-630, chars_format::scientific, 492,
        "4."
        "4888255467692089270537679285466386896927555076727575293318967144042057702851366294421569211376895628371987"
        "8966010012985911998997421666494612750593580114519422695455043630094667663749126233997524379747920365312153"
        "9398826001422863032378814685782215444565229166294897801206828680085399379679047990178949481349447152261581"
        "7061993368974425150570723695168919511749738426667309982642306298080827061075001937022941410411471090390751"
        "91863757868610885394606755359470096067298072739504277706146240234375e-190"},
    {0x1.fffffffffffffp-629, chars_format::scientific, 491,
        "8."
        "9776510935384178541075358570932773793855110153455150586637934288084115405702732588843138422753791256743975"
        "7932020025971823997994843332989225501187160229038845390910087260189335327498252467995048759495840730624307"
        "8797652002845726064757629371564430889130458332589795602413657360170798759358095980357898962698894304523163"
        "4123986737948850301141447390337839023499476853334619965284612596161654122150003874045882820822942180781503"
        "8372751573722177078921351071894019213459614547900855541229248046875e-190"},
    {0x1.fffffffffffffp-628, chars_format::scientific, 491,
        "1."
        "7955302187076835708215071714186554758771022030691030117327586857616823081140546517768627684550758251348795"
        "1586404005194364799598968666597845100237432045807769078182017452037867065499650493599009751899168146124861"
        "5759530400569145212951525874312886177826091666517959120482731472034159751871619196071579792539778860904632"
        "6824797347589770060228289478067567804699895370666923993056922519232330824430000774809176564164588436156300"
        "7674550314744435415784270214378803842691922909580171108245849609375e-189"},
    {0x1.fffffffffffffp-627, chars_format::scientific, 490,
        "3."
        "5910604374153671416430143428373109517542044061382060234655173715233646162281093035537255369101516502697590"
        "3172808010388729599197937333195690200474864091615538156364034904075734130999300987198019503798336292249723"
        "1519060801138290425903051748625772355652183333035918240965462944068319503743238392143159585079557721809265"
        "3649594695179540120456578956135135609399790741333847986113845038464661648860001549618353128329176872312601"
        "534910062948887083156854042875760768538384581916034221649169921875e-189"},
    {0x1.fffffffffffffp-626, chars_format::scientific, 489,
        "7."
        "1821208748307342832860286856746219035084088122764120469310347430467292324562186071074510738203033005395180"
        "6345616020777459198395874666391380400949728183231076312728069808151468261998601974396039007596672584499446"
        "3038121602276580851806103497251544711304366666071836481930925888136639007486476784286319170159115443618530"
        "7299189390359080240913157912270271218799581482667695972227690076929323297720003099236706256658353744625203"
        "06982012589777416631370808575152153707676916383206844329833984375e-189"},
    {0x1.fffffffffffffp-625, chars_format::scientific, 489,
        "1."
        "4364241749661468566572057371349243807016817624552824093862069486093458464912437214214902147640606601079036"
        "1269123204155491839679174933278276080189945636646215262545613961630293652399720394879207801519334516899889"
        "2607624320455316170361220699450308942260873333214367296386185177627327801497295356857263834031823088723706"
        "1459837878071816048182631582454054243759916296533539194445538015385864659544000619847341251331670748925040"
        "61396402517955483326274161715030430741535383276641368865966796875e-188"},
    {0x1.fffffffffffffp-624, chars_format::scientific, 488,
        "2."
        "8728483499322937133144114742698487614033635249105648187724138972186916929824874428429804295281213202158072"
        "2538246408310983679358349866556552160379891273292430525091227923260587304799440789758415603038669033799778"
        "5215248640910632340722441398900617884521746666428734592772370355254655602994590713714527668063646177447412"
        "2919675756143632096365263164908108487519832593067078388891076030771729319088001239694682502663341497850081"
        "2279280503591096665254832343006086148307076655328273773193359375e-188"},
    {0x1.fffffffffffffp-623, chars_format::scientific, 487,
        "5."
        "7456966998645874266288229485396975228067270498211296375448277944373833859649748856859608590562426404316144"
        "5076492816621967358716699733113104320759782546584861050182455846521174609598881579516831206077338067599557"
        "0430497281821264681444882797801235769043493332857469185544740710509311205989181427429055336127292354894824"
        "5839351512287264192730526329816216975039665186134156777782152061543458638176002479389365005326682995700162"
        "455856100718219333050966468601217229661415331065654754638671875e-188"},
    {0x1.fffffffffffffp-622, chars_format::scientific, 487,
        "1."
        "1491393399729174853257645897079395045613454099642259275089655588874766771929949771371921718112485280863228"
        "9015298563324393471743339946622620864151956509316972210036491169304234921919776315903366241215467613519911"
        "4086099456364252936288976559560247153808698666571493837108948142101862241197836285485811067225458470978964"
        "9167870302457452838546105265963243395007933037226831355556430412308691727635200495877873001065336599140032"
        "491171220143643866610193293720243445932283066213130950927734375e-187"},
    {0x1.fffffffffffffp-621, chars_format::scientific, 486,
        "2."
        "2982786799458349706515291794158790091226908199284518550179311177749533543859899542743843436224970561726457"
        "8030597126648786943486679893245241728303913018633944420072982338608469843839552631806732482430935227039822"
        "8172198912728505872577953119120494307617397333142987674217896284203724482395672570971622134450916941957929"
        "8335740604914905677092210531926486790015866074453662711112860824617383455270400991755746002130673198280064"
        "98234244028728773322038658744048689186456613242626190185546875e-187"},
    {0x1.fffffffffffffp-620, chars_format::scientific, 485,
        "4."
        "5965573598916699413030583588317580182453816398569037100358622355499067087719799085487686872449941123452915"
        "6061194253297573886973359786490483456607826037267888840145964677216939687679105263613464964861870454079645"
        "6344397825457011745155906238240988615234794666285975348435792568407448964791345141943244268901833883915859"
        "6671481209829811354184421063852973580031732148907325422225721649234766910540801983511492004261346396560129"
        "9646848805745754664407731748809737837291322648525238037109375e-187"},
    {0x1.fffffffffffffp-619, chars_format::scientific, 484,
        "9."
        "1931147197833398826061167176635160364907632797138074200717244710998134175439598170975373744899882246905831"
        "2122388506595147773946719572980966913215652074535777680291929354433879375358210527226929929723740908159291"
        "2688795650914023490311812476481977230469589332571950696871585136814897929582690283886488537803667767831719"
        "3342962419659622708368842127705947160063464297814650844451443298469533821081603967022984008522692793120259"
        "929369761149150932881546349761947567458264529705047607421875e-187"},
    {0x1.fffffffffffffp-618, chars_format::scientific, 484,
        "1."
        "8386229439566679765212233435327032072981526559427614840143448942199626835087919634195074748979976449381166"
        "2424477701319029554789343914596193382643130414907155536058385870886775875071642105445385985944748181631858"
        "2537759130182804698062362495296395446093917866514390139374317027362979585916538056777297707560733553566343"
        "8668592483931924541673768425541189432012692859562930168890288659693906764216320793404596801704538558624051"
        "985873952229830186576309269952389513491652905941009521484375e-186"},
    {0x1.fffffffffffffp-617, chars_format::scientific, 483,
        "3."
        "6772458879133359530424466870654064145963053118855229680286897884399253670175839268390149497959952898762332"
        "4848955402638059109578687829192386765286260829814311072116771741773551750143284210890771971889496363263716"
        "5075518260365609396124724990592790892187835733028780278748634054725959171833076113554595415121467107132687"
        "7337184967863849083347536851082378864025385719125860337780577319387813528432641586809193603409077117248103"
        "97174790445966037315261853990477902698330581188201904296875e-186"},
    {0x1.fffffffffffffp-616, chars_format::scientific, 482,
        "7."
        "3544917758266719060848933741308128291926106237710459360573795768798507340351678536780298995919905797524664"
        "9697910805276118219157375658384773530572521659628622144233543483547103500286568421781543943778992726527433"
        "0151036520731218792249449981185581784375671466057560557497268109451918343666152227109190830242934214265375"
        "4674369935727698166695073702164757728050771438251720675561154638775627056865283173618387206818154234496207"
        "9434958089193207463052370798095580539666116237640380859375e-186"},
    {0x1.fffffffffffffp-615, chars_format::scientific, 482,
        "1."
        "4708983551653343812169786748261625658385221247542091872114759153759701468070335707356059799183981159504932"
        "9939582161055223643831475131676954706114504331925724428846708696709420700057313684356308788755798545305486"
        "6030207304146243758449889996237116356875134293211512111499453621890383668733230445421838166048586842853075"
        "0934873987145539633339014740432951545610154287650344135112230927755125411373056634723677441363630846899241"
        "5886991617838641492610474159619116107933223247528076171875e-185"},
    {0x1.fffffffffffffp-614, chars_format::scientific, 481,
        "2."
        "9417967103306687624339573496523251316770442495084183744229518307519402936140671414712119598367962319009865"
        "9879164322110447287662950263353909412229008663851448857693417393418841400114627368712617577511597090610973"
        "2060414608292487516899779992474232713750268586423024222998907243780767337466460890843676332097173685706150"
        "1869747974291079266678029480865903091220308575300688270224461855510250822746113269447354882727261693798483"
        "177398323567728298522094831923823221586644649505615234375e-185"},
    {0x1.fffffffffffffp-613, chars_format::scientific, 480,
        "5."
        "8835934206613375248679146993046502633540884990168367488459036615038805872281342829424239196735924638019731"
        "9758328644220894575325900526707818824458017327702897715386834786837682800229254737425235155023194181221946"
        "4120829216584975033799559984948465427500537172846048445997814487561534674932921781687352664194347371412300"
        "3739495948582158533356058961731806182440617150601376540448923711020501645492226538894709765454523387596966"
        "35479664713545659704418966384764644317328929901123046875e-185"},
    {0x1.fffffffffffffp-612, chars_format::scientific, 480,
        "1."
        "1767186841322675049735829398609300526708176998033673497691807323007761174456268565884847839347184927603946"
        "3951665728844178915065180105341563764891603465540579543077366957367536560045850947485047031004638836244389"
        "2824165843316995006759911996989693085500107434569209689199562897512306934986584356337470532838869474282460"
        "0747899189716431706671211792346361236488123430120275308089784742204100329098445307778941953090904677519393"
        "27095932942709131940883793276952928863465785980224609375e-184"},
    {0x1.fffffffffffffp-611, chars_format::scientific, 479,
        "2."
        "3534373682645350099471658797218601053416353996067346995383614646015522348912537131769695678694369855207892"
        "7903331457688357830130360210683127529783206931081159086154733914735073120091701894970094062009277672488778"
        "5648331686633990013519823993979386171000214869138419378399125795024613869973168712674941065677738948564920"
        "1495798379432863413342423584692722472976246860240550616179569484408200658196890615557883906181809355038786"
        "5419186588541826388176758655390585772693157196044921875e-184"},
    {0x1.fffffffffffffp-610, chars_format::scientific, 478,
        "4."
        "7068747365290700198943317594437202106832707992134693990767229292031044697825074263539391357388739710415785"
        "5806662915376715660260720421366255059566413862162318172309467829470146240183403789940188124018555344977557"
        "1296663373267980027039647987958772342000429738276838756798251590049227739946337425349882131355477897129840"
        "2991596758865726826684847169385444945952493720481101232359138968816401316393781231115767812363618710077573"
        "083837317708365277635351731078117154538631439208984375e-184"},
    {0x1.fffffffffffffp-609, chars_format::scientific, 477,
        "9."
        "4137494730581400397886635188874404213665415984269387981534458584062089395650148527078782714777479420831571"
        "1613325830753431320521440842732510119132827724324636344618935658940292480366807579880376248037110689955114"
        "2593326746535960054079295975917544684000859476553677513596503180098455479892674850699764262710955794259680"
        "5983193517731453653369694338770889891904987440962202464718277937632802632787562462231535624727237420155146"
        "16767463541673055527070346215623430907726287841796875e-184"},
    {0x1.fffffffffffffp-608, chars_format::scientific, 477,
        "1."
        "8827498946116280079577327037774880842733083196853877596306891716812417879130029705415756542955495884166314"
        "2322665166150686264104288168546502023826565544864927268923787131788058496073361515976075249607422137991022"
        "8518665349307192010815859195183508936800171895310735502719300636019691095978534970139952852542191158851936"
        "1196638703546290730673938867754177978380997488192440492943655587526560526557512492446307124945447484031029"
        "23353492708334611105414069243124686181545257568359375e-183"},
    {0x1.fffffffffffffp-607, chars_format::scientific, 476,
        "3."
        "7654997892232560159154654075549761685466166393707755192613783433624835758260059410831513085910991768332628"
        "4645330332301372528208576337093004047653131089729854537847574263576116992146723031952150499214844275982045"
        "7037330698614384021631718390367017873600343790621471005438601272039382191957069940279905705084382317703872"
        "2393277407092581461347877735508355956761994976384880985887311175053121053115024984892614249890894968062058"
        "4670698541666922221082813848624937236309051513671875e-183"},
    {0x1.fffffffffffffp-606, chars_format::scientific, 475,
        "7."
        "5309995784465120318309308151099523370932332787415510385227566867249671516520118821663026171821983536665256"
        "9290660664602745056417152674186008095306262179459709075695148527152233984293446063904300998429688551964091"
        "4074661397228768043263436780734035747200687581242942010877202544078764383914139880559811410168764635407744"
        "4786554814185162922695755471016711913523989952769761971774622350106242106230049969785228499781789936124116"
        "934139708333384444216562769724987447261810302734375e-183"},
    {0x1.fffffffffffffp-605, chars_format::scientific, 475,
        "1."
        "5061999156893024063661861630219904674186466557483102077045513373449934303304023764332605234364396707333051"
        "3858132132920549011283430534837201619061252435891941815139029705430446796858689212780860199685937710392818"
        "2814932279445753608652687356146807149440137516248588402175440508815752876782827976111962282033752927081548"
        "8957310962837032584539151094203342382704797990553952394354924470021248421246009993957045699956357987224823"
        "386827941666676888843312553944997489452362060546875e-182"},
    {0x1.fffffffffffffp-604, chars_format::scientific, 474,
        "3."
        "0123998313786048127323723260439809348372933114966204154091026746899868606608047528665210468728793414666102"
        "7716264265841098022566861069674403238122504871783883630278059410860893593717378425561720399371875420785636"
        "5629864558891507217305374712293614298880275032497176804350881017631505753565655952223924564067505854163097"
        "7914621925674065169078302188406684765409595981107904788709848940042496842492019987914091399912715974449646"
        "77365588333335377768662510788999497890472412109375e-182"},
    {0x1.fffffffffffffp-603, chars_format::scientific, 473,
        "6."
        "0247996627572096254647446520879618696745866229932408308182053493799737213216095057330420937457586829332205"
        "5432528531682196045133722139348806476245009743567767260556118821721787187434756851123440798743750841571273"
        "1259729117783014434610749424587228597760550064994353608701762035263011507131311904447849128135011708326195"
        "5829243851348130338156604376813369530819191962215809577419697880084993684984039975828182799825431948899293"
        "5473117666667075553732502157799899578094482421875e-182"},
    {0x1.fffffffffffffp-602, chars_format::scientific, 473,
        "1."
        "2049599325514419250929489304175923739349173245986481661636410698759947442643219011466084187491517365866441"
        "1086505706336439209026744427869761295249001948713553452111223764344357437486951370224688159748750168314254"
        "6251945823556602886922149884917445719552110012998870721740352407052602301426262380889569825627002341665239"
        "1165848770269626067631320875362673906163838392443161915483939576016998736996807995165636559965086389779858"
        "7094623533333415110746500431559979915618896484375e-181"},
    {0x1.fffffffffffffp-601, chars_format::scientific, 472,
        "2."
        "4099198651028838501858978608351847478698346491972963323272821397519894885286438022932168374983034731732882"
        "2173011412672878418053488855739522590498003897427106904222447528688714874973902740449376319497500336628509"
        "2503891647113205773844299769834891439104220025997741443480704814105204602852524761779139651254004683330478"
        "2331697540539252135262641750725347812327676784886323830967879152033997473993615990331273119930172779559717"
        "418924706666683022149300086311995983123779296875e-181"},
    {0x1.fffffffffffffp-600, chars_format::scientific, 471,
        "4."
        "8198397302057677003717957216703694957396692983945926646545642795039789770572876045864336749966069463465764"
        "4346022825345756836106977711479045180996007794854213808444895057377429749947805480898752638995000673257018"
        "5007783294226411547688599539669782878208440051995482886961409628210409205705049523558279302508009366660956"
        "4663395081078504270525283501450695624655353569772647661935758304067994947987231980662546239860345559119434"
        "83784941333336604429860017262399196624755859375e-181"},
    {0x1.fffffffffffffp-599, chars_format::scientific, 470,
        "9."
        "6396794604115354007435914433407389914793385967891853293091285590079579541145752091728673499932138926931528"
        "8692045650691513672213955422958090361992015589708427616889790114754859499895610961797505277990001346514037"
        "0015566588452823095377199079339565756416880103990965773922819256420818411410099047116558605016018733321912"
        "9326790162157008541050567002901391249310707139545295323871516608135989895974463961325092479720691118238869"
        "6756988266667320885972003452479839324951171875e-181"},
    {0x1.fffffffffffffp-598, chars_format::scientific, 470,
        "1."
        "9279358920823070801487182886681477982958677193578370658618257118015915908229150418345734699986427785386305"
        "7738409130138302734442791084591618072398403117941685523377958022950971899979122192359501055598000269302807"
        "4003113317690564619075439815867913151283376020798193154784563851284163682282019809423311721003203746664382"
        "5865358032431401708210113400580278249862141427909059064774303321627197979194892792265018495944138223647773"
        "9351397653333464177194400690495967864990234375e-180"},
    {0x1.fffffffffffffp-597, chars_format::scientific, 469,
        "3."
        "8558717841646141602974365773362955965917354387156741317236514236031831816458300836691469399972855570772611"
        "5476818260276605468885582169183236144796806235883371046755916045901943799958244384719002111196000538605614"
        "8006226635381129238150879631735826302566752041596386309569127702568327364564039618846623442006407493328765"
        "1730716064862803416420226801160556499724282855818118129548606643254395958389785584530036991888276447295547"
        "870279530666692835438880138099193572998046875e-180"},
    {0x1.fffffffffffffp-596, chars_format::scientific, 468,
        "7."
        "7117435683292283205948731546725911931834708774313482634473028472063663632916601673382938799945711141545223"
        "0953636520553210937771164338366472289593612471766742093511832091803887599916488769438004222392001077211229"
        "6012453270762258476301759263471652605133504083192772619138255405136654729128079237693246884012814986657530"
        "3461432129725606832840453602321112999448565711636236259097213286508791916779571169060073983776552894591095"
        "74055906133338567087776027619838714599609375e-180"},
    {0x1.fffffffffffffp-595, chars_format::scientific, 468,
        "1."
        "5423487136658456641189746309345182386366941754862696526894605694412732726583320334676587759989142228309044"
        "6190727304110642187554232867673294457918722494353348418702366418360777519983297753887600844478400215442245"
        "9202490654152451695260351852694330521026700816638554523827651081027330945825615847538649376802562997331506"
        "0692286425945121366568090720464222599889713142327247251819442657301758383355914233812014796755310578918219"
        "14811181226667713417555205523967742919921875e-179"},
    {0x1.fffffffffffffp-594, chars_format::scientific, 467,
        "3."
        "0846974273316913282379492618690364772733883509725393053789211388825465453166640669353175519978284456618089"
        "2381454608221284375108465735346588915837444988706696837404732836721555039966595507775201688956800430884491"
        "8404981308304903390520703705388661042053401633277109047655302162054661891651231695077298753605125994663012"
        "1384572851890242733136181440928445199779426284654494503638885314603516766711828467624029593510621157836438"
        "2962236245333542683511041104793548583984375e-179"},
    {0x1.fffffffffffffp-593, chars_format::scientific, 466,
        "6."
        "1693948546633826564758985237380729545467767019450786107578422777650930906333281338706351039956568913236178"
        "4762909216442568750216931470693177831674889977413393674809465673443110079933191015550403377913600861768983"
        "6809962616609806781041407410777322084106803266554218095310604324109323783302463390154597507210251989326024"
        "2769145703780485466272362881856890399558852569308989007277770629207033533423656935248059187021242315672876"
        "592447249066708536702208220958709716796875e-179"},
    {0x1.fffffffffffffp-592, chars_format::scientific, 466,
        "1."
        "2338789709326765312951797047476145909093553403890157221515684555530186181266656267741270207991313782647235"
        "6952581843288513750043386294138635566334977995482678734961893134688622015986638203110080675582720172353796"
        "7361992523321961356208281482155464416821360653310843619062120864821864756660492678030919501442050397865204"
        "8553829140756097093254472576371378079911770513861797801455554125841406706684731387049611837404248463134575"
        "318489449813341707340441644191741943359375e-178"},
    {0x1.fffffffffffffp-591, chars_format::scientific, 465,
        "2."
        "4677579418653530625903594094952291818187106807780314443031369111060372362533312535482540415982627565294471"
        "3905163686577027500086772588277271132669955990965357469923786269377244031973276406220161351165440344707593"
        "4723985046643922712416562964310928833642721306621687238124241729643729513320985356061839002884100795730409"
        "7107658281512194186508945152742756159823541027723595602911108251682813413369462774099223674808496926269150"
        "63697889962668341468088328838348388671875e-178"},
    {0x1.fffffffffffffp-590, chars_format::scientific, 464,
        "4."
        "9355158837307061251807188189904583636374213615560628886062738222120744725066625070965080831965255130588942"
        "7810327373154055000173545176554542265339911981930714939847572538754488063946552812440322702330880689415186"
        "9447970093287845424833125928621857667285442613243374476248483459287459026641970712123678005768201591460819"
        "4215316563024388373017890305485512319647082055447191205822216503365626826738925548198447349616993852538301"
        "2739577992533668293617665767669677734375e-178"},
    {0x1.fffffffffffffp-589, chars_format::scientific, 463,
        "9."
        "8710317674614122503614376379809167272748427231121257772125476444241489450133250141930161663930510261177885"
        "5620654746308110000347090353109084530679823963861429879695145077508976127893105624880645404661761378830373"
        "8895940186575690849666251857243715334570885226486748952496966918574918053283941424247356011536403182921638"
        "8430633126048776746035780610971024639294164110894382411644433006731253653477851096396894699233987705076602"
        "547915598506733658723533153533935546875e-178"},
    {0x1.fffffffffffffp-588, chars_format::scientific, 463,
        "1."
        "9742063534922824500722875275961833454549685446224251554425095288848297890026650028386032332786102052235577"
        "1124130949261622000069418070621816906135964792772285975939029015501795225578621124976129080932352275766074"
        "7779188037315138169933250371448743066914177045297349790499393383714983610656788284849471202307280636584327"
        "7686126625209755349207156122194204927858832822178876482328886601346250730695570219279378939846797541015320"
        "509583119701346731744706630706787109375e-177"},
    {0x1.fffffffffffffp-587, chars_format::scientific, 462,
        "3."
        "9484127069845649001445750551923666909099370892448503108850190577696595780053300056772064665572204104471154"
        "2248261898523244000138836141243633812271929585544571951878058031003590451157242249952258161864704551532149"
        "5558376074630276339866500742897486133828354090594699580998786767429967221313576569698942404614561273168655"
        "5372253250419510698414312244388409855717665644357752964657773202692501461391140438558757879693595082030641"
        "01916623940269346348941326141357421875e-177"},
    {0x1.fffffffffffffp-586, chars_format::scientific, 461,
        "7."
        "8968254139691298002891501103847333818198741784897006217700381155393191560106600113544129331144408208942308"
        "4496523797046488000277672282487267624543859171089143903756116062007180902314484499904516323729409103064299"
        "1116752149260552679733001485794972267656708181189399161997573534859934442627153139397884809229122546337311"
        "0744506500839021396828624488776819711435331288715505929315546405385002922782280877117515759387190164061282"
        "0383324788053869269788265228271484375e-177"},
    {0x1.fffffffffffffp-585, chars_format::scientific, 461,
        "1."
        "5793650827938259600578300220769466763639748356979401243540076231078638312021320022708825866228881641788461"
        "6899304759409297600055534456497453524908771834217828780751223212401436180462896899980903264745881820612859"
        "8223350429852110535946600297158994453531341636237879832399514706971986888525430627879576961845824509267462"
        "2148901300167804279365724897755363942287066257743101185863109281077000584556456175423503151877438032812256"
        "4076664957610773853957653045654296875e-176"},
    {0x1.fffffffffffffp-584, chars_format::scientific, 460,
        "3."
        "1587301655876519201156600441538933527279496713958802487080152462157276624042640045417651732457763283576923"
        "3798609518818595200111068912994907049817543668435657561502446424802872360925793799961806529491763641225719"
        "6446700859704221071893200594317988907062683272475759664799029413943973777050861255759153923691649018534924"
        "4297802600335608558731449795510727884574132515486202371726218562154001169112912350847006303754876065624512"
        "815332991522154770791530609130859375e-176"},
    {0x1.fffffffffffffp-583, chars_format::scientific, 459,
        "6."
        "3174603311753038402313200883077867054558993427917604974160304924314553248085280090835303464915526567153846"
        "7597219037637190400222137825989814099635087336871315123004892849605744721851587599923613058983527282451439"
        "2893401719408442143786401188635977814125366544951519329598058827887947554101722511518307847383298037069848"
        "8595605200671217117462899591021455769148265030972404743452437124308002338225824701694012607509752131249025"
        "63066598304430954158306121826171875e-176"},
    {0x1.fffffffffffffp-582, chars_format::scientific, 459,
        "1."
        "2634920662350607680462640176615573410911798685583520994832060984862910649617056018167060692983105313430769"
        "3519443807527438080044427565197962819927017467374263024600978569921148944370317519984722611796705456490287"
        "8578680343881688428757280237727195562825073308990303865919611765577589510820344502303661569476659607413969"
        "7719121040134243423492579918204291153829653006194480948690487424861600467645164940338802521501950426249805"
        "12613319660886190831661224365234375e-175"},
    {0x1.fffffffffffffp-581, chars_format::scientific, 458,
        "2."
        "5269841324701215360925280353231146821823597371167041989664121969725821299234112036334121385966210626861538"
        "7038887615054876160088855130395925639854034934748526049201957139842297888740635039969445223593410912980575"
        "7157360687763376857514560475454391125650146617980607731839223531155179021640689004607323138953319214827939"
        "5438242080268486846985159836408582307659306012388961897380974849723200935290329880677605043003900852499610"
        "2522663932177238166332244873046875e-175"},
    {0x1.fffffffffffffp-580, chars_format::scientific, 457,
        "5."
        "0539682649402430721850560706462293643647194742334083979328243939451642598468224072668242771932421253723077"
        "4077775230109752320177710260791851279708069869497052098403914279684595777481270079938890447186821825961151"
        "4314721375526753715029120950908782251300293235961215463678447062310358043281378009214646277906638429655879"
        "0876484160536973693970319672817164615318612024777923794761949699446401870580659761355210086007801704999220"
        "504532786435447633266448974609375e-175"},
    {0x1.fffffffffffffp-579, chars_format::scientific, 457,
        "1."
        "0107936529880486144370112141292458728729438948466816795865648787890328519693644814533648554386484250744615"
        "4815555046021950464035542052158370255941613973899410419680782855936919155496254015987778089437364365192230"
        "2862944275105350743005824190181756450260058647192243092735689412462071608656275601842929255581327685931175"
        "8175296832107394738794063934563432923063722404955584758952389939889280374116131952271042017201560340999844"
        "100906557287089526653289794921875e-174"},
    {0x1.fffffffffffffp-578, chars_format::scientific, 456,
        "2."
        "0215873059760972288740224282584917457458877896933633591731297575780657039387289629067297108772968501489230"
        "9631110092043900928071084104316740511883227947798820839361565711873838310992508031975556178874728730384460"
        "5725888550210701486011648380363512900520117294384486185471378824924143217312551203685858511162655371862351"
        "6350593664214789477588127869126865846127444809911169517904779879778560748232263904542084034403120681999688"
        "20181311457417905330657958984375e-174"},
    {0x1.fffffffffffffp-577, chars_format::scientific, 455,
        "4."
        "0431746119521944577480448565169834914917755793867267183462595151561314078774579258134594217545937002978461"
        "9262220184087801856142168208633481023766455895597641678723131423747676621985016063951112357749457460768921"
        "1451777100421402972023296760727025801040234588768972370942757649848286434625102407371717022325310743724703"
        "2701187328429578955176255738253731692254889619822339035809559759557121496464527809084168068806241363999376"
        "4036262291483581066131591796875e-174"},
    {0x1.fffffffffffffp-576, chars_format::scientific, 454,
        "8."
        "0863492239043889154960897130339669829835511587734534366925190303122628157549158516269188435091874005956923"
        "8524440368175603712284336417266962047532911791195283357446262847495353243970032127902224715498914921537842"
        "2903554200842805944046593521454051602080469177537944741885515299696572869250204814743434044650621487449406"
        "5402374656859157910352511476507463384509779239644678071619119519114242992929055618168336137612482727998752"
        "807252458296716213226318359375e-174"},
    {0x1.fffffffffffffp-575, chars_format::scientific, 454,
        "1."
        "6172698447808777830992179426067933965967102317546906873385038060624525631509831703253837687018374801191384"
        "7704888073635120742456867283453392409506582358239056671489252569499070648794006425580444943099782984307568"
        "4580710840168561188809318704290810320416093835507588948377103059939314573850040962948686808930124297489881"
        "3080474931371831582070502295301492676901955847928935614323823903822848598585811123633667227522496545599750"
        "561450491659343242645263671875e-173"},
    {0x1.fffffffffffffp-574, chars_format::scientific, 453,
        "3."
        "2345396895617555661984358852135867931934204635093813746770076121249051263019663406507675374036749602382769"
        "5409776147270241484913734566906784819013164716478113342978505138998141297588012851160889886199565968615136"
        "9161421680337122377618637408581620640832187671015177896754206119878629147700081925897373617860248594979762"
        "6160949862743663164141004590602985353803911695857871228647647807645697197171622247267334455044993091199501"
        "12290098331868648529052734375e-173"},
    {0x1.fffffffffffffp-573, chars_format::scientific, 452,
        "6."
        "4690793791235111323968717704271735863868409270187627493540152242498102526039326813015350748073499204765539"
        "0819552294540482969827469133813569638026329432956226685957010277996282595176025702321779772399131937230273"
        "8322843360674244755237274817163241281664375342030355793508412239757258295400163851794747235720497189959525"
        "2321899725487326328282009181205970707607823391715742457295295615291394394343244494534668910089986182399002"
        "2458019666373729705810546875e-173"},
    {0x1.fffffffffffffp-572, chars_format::scientific, 452,
        "1."
        "2938158758247022264793743540854347172773681854037525498708030448499620505207865362603070149614699840953107"
        "8163910458908096593965493826762713927605265886591245337191402055599256519035205140464355954479826387446054"
        "7664568672134848951047454963432648256332875068406071158701682447951451659080032770358949447144099437991905"
        "0464379945097465265656401836241194141521564678343148491459059123058278878868648898906933782017997236479800"
        "4491603933274745941162109375e-172"},
    {0x1.fffffffffffffp-571, chars_format::scientific, 451,
        "2."
        "5876317516494044529587487081708694345547363708075050997416060896999241010415730725206140299229399681906215"
        "6327820917816193187930987653525427855210531773182490674382804111198513038070410280928711908959652774892109"
        "5329137344269697902094909926865296512665750136812142317403364895902903318160065540717898894288198875983810"
        "0928759890194930531312803672482388283043129356686296982918118246116557757737297797813867564035994472959600"
        "898320786654949188232421875e-172"},
    {0x1.fffffffffffffp-570, chars_format::scientific, 450,
        "5."
        "1752635032988089059174974163417388691094727416150101994832121793998482020831461450412280598458799363812431"
        "2655641835632386375861975307050855710421063546364981348765608222397026076140820561857423817919305549784219"
        "0658274688539395804189819853730593025331500273624284634806729791805806636320131081435797788576397751967620"
        "1857519780389861062625607344964776566086258713372593965836236492233115515474595595627735128071988945919201"
        "79664157330989837646484375e-172"},
    {0x1.fffffffffffffp-569, chars_format::scientific, 450,
        "1."
        "0350527006597617811834994832683477738218945483230020398966424358799696404166292290082456119691759872762486"
        "2531128367126477275172395061410171142084212709272996269753121644479405215228164112371484763583861109956843"
        "8131654937707879160837963970746118605066300054724856926961345958361161327264026216287159557715279550393524"
        "0371503956077972212525121468992955313217251742674518793167247298446623103094919119125547025614397789183840"
        "35932831466197967529296875e-171"},
    {0x1.fffffffffffffp-568, chars_format::scientific, 449,
        "2."
        "0701054013195235623669989665366955476437890966460040797932848717599392808332584580164912239383519745524972"
        "5062256734252954550344790122820342284168425418545992539506243288958810430456328224742969527167722219913687"
        "6263309875415758321675927941492237210132600109449713853922691916722322654528052432574319115430559100787048"
        "0743007912155944425050242937985910626434503485349037586334494596893246206189838238251094051228795578367680"
        "7186566293239593505859375e-171"},
    {0x1.fffffffffffffp-567, chars_format::scientific, 448,
        "4."
        "1402108026390471247339979330733910952875781932920081595865697435198785616665169160329824478767039491049945"
        "0124513468505909100689580245640684568336850837091985079012486577917620860912656449485939054335444439827375"
        "2526619750831516643351855882984474420265200218899427707845383833444645309056104865148638230861118201574096"
        "1486015824311888850100485875971821252869006970698075172668989193786492412379676476502188102457591156735361"
        "437313258647918701171875e-171"},
    {0x1.fffffffffffffp-566, chars_format::scientific, 447,
        "8."
        "2804216052780942494679958661467821905751563865840163191731394870397571233330338320659648957534078982099890"
        "0249026937011818201379160491281369136673701674183970158024973155835241721825312898971878108670888879654750"
        "5053239501663033286703711765968948840530400437798855415690767666889290618112209730297276461722236403148192"
        "2972031648623777700200971751943642505738013941396150345337978387572984824759352953004376204915182313470722"
        "87462651729583740234375e-171"},
    {0x1.fffffffffffffp-565, chars_format::scientific, 447,
        "1."
        "6560843210556188498935991732293564381150312773168032638346278974079514246666067664131929791506815796419978"
        "0049805387402363640275832098256273827334740334836794031604994631167048344365062579794375621734177775930950"
        "1010647900332606657340742353193789768106080087559771083138153533377858123622441946059455292344447280629638"
        "4594406329724755540040194350388728501147602788279230069067595677514596964951870590600875240983036462694144"
        "57492530345916748046875e-170"},
    {0x1.fffffffffffffp-564, chars_format::scientific, 446,
        "3."
        "3121686421112376997871983464587128762300625546336065276692557948159028493332135328263859583013631592839956"
        "0099610774804727280551664196512547654669480669673588063209989262334096688730125159588751243468355551861900"
        "2021295800665213314681484706387579536212160175119542166276307066755716247244883892118910584688894561259276"
        "9188812659449511080080388700777457002295205576558460138135191355029193929903741181201750481966072925388289"
        "1498506069183349609375e-170"},
    {0x1.fffffffffffffp-563, chars_format::scientific, 445,
        "6."
        "6243372842224753995743966929174257524601251092672130553385115896318056986664270656527719166027263185679912"
        "0199221549609454561103328393025095309338961339347176126419978524668193377460250319177502486936711103723800"
        "4042591601330426629362969412775159072424320350239084332552614133511432494489767784237821169377789122518553"
        "8377625318899022160160777401554914004590411153116920276270382710058387859807482362403500963932145850776578"
        "299701213836669921875e-170"},
    {0x1.fffffffffffffp-562, chars_format::scientific, 445,
        "1."
        "3248674568444950799148793385834851504920250218534426110677023179263611397332854131305543833205452637135982"
        "4039844309921890912220665678605019061867792267869435225283995704933638675492050063835500497387342220744760"
        "0808518320266085325872593882555031814484864070047816866510522826702286498897953556847564233875557824503710"
        "7675525063779804432032155480310982800918082230623384055254076542011677571961496472480700192786429170155315"
        "659940242767333984375e-169"},
    {0x1.fffffffffffffp-561, chars_format::scientific, 444,
        "2."
        "6497349136889901598297586771669703009840500437068852221354046358527222794665708262611087666410905274271964"
        "8079688619843781824441331357210038123735584535738870450567991409867277350984100127671000994774684441489520"
        "1617036640532170651745187765110063628969728140095633733021045653404572997795907113695128467751115649007421"
        "5351050127559608864064310960621965601836164461246768110508153084023355143922992944961400385572858340310631"
        "31988048553466796875e-169"},
    {0x1.fffffffffffffp-560, chars_format::scientific, 443,
        "5."
        "2994698273779803196595173543339406019681000874137704442708092717054445589331416525222175332821810548543929"
        "6159377239687563648882662714420076247471169071477740901135982819734554701968200255342001989549368882979040"
        "3234073281064341303490375530220127257939456280191267466042091306809145995591814227390256935502231298014843"
        "0702100255119217728128621921243931203672328922493536221016306168046710287845985889922800771145716680621262"
        "6397609710693359375e-169"},
    {0x1.fffffffffffffp-559, chars_format::scientific, 443,
        "1."
        "0598939654755960639319034708667881203936200174827540888541618543410889117866283305044435066564362109708785"
        "9231875447937512729776532542884015249494233814295548180227196563946910940393640051068400397909873776595808"
        "0646814656212868260698075106044025451587891256038253493208418261361829199118362845478051387100446259602968"
        "6140420051023843545625724384248786240734465784498707244203261233609342057569197177984560154229143336124252"
        "5279521942138671875e-168"},
    {0x1.fffffffffffffp-558, chars_format::scientific, 442,
        "2."
        "1197879309511921278638069417335762407872400349655081777083237086821778235732566610088870133128724219417571"
        "8463750895875025459553065085768030498988467628591096360454393127893821880787280102136800795819747553191616"
        "1293629312425736521396150212088050903175782512076506986416836522723658398236725690956102774200892519205937"
        "2280840102047687091251448768497572481468931568997414488406522467218684115138394355969120308458286672248505"
        "055904388427734375e-168"},
    {0x1.fffffffffffffp-557, chars_format::scientific, 441,
        "4."
        "2395758619023842557276138834671524815744800699310163554166474173643556471465133220177740266257448438835143"
        "6927501791750050919106130171536060997976935257182192720908786255787643761574560204273601591639495106383232"
        "2587258624851473042792300424176101806351565024153013972833673045447316796473451381912205548401785038411874"
        "4561680204095374182502897536995144962937863137994828976813044934437368230276788711938240616916573344497010"
        "11180877685546875e-168"},
    {0x1.fffffffffffffp-556, chars_format::scientific, 440,
        "8."
        "4791517238047685114552277669343049631489601398620327108332948347287112942930266440355480532514896877670287"
        "3855003583500101838212260343072121995953870514364385441817572511575287523149120408547203183278990212766464"
        "5174517249702946085584600848352203612703130048306027945667346090894633592946902763824411096803570076823748"
        "9123360408190748365005795073990289925875726275989657953626089868874736460553577423876481233833146688994020"
        "2236175537109375e-168"},
    {0x1.fffffffffffffp-555, chars_format::scientific, 440,
        "1."
        "6958303447609537022910455533868609926297920279724065421666589669457422588586053288071096106502979375534057"
        "4771000716700020367642452068614424399190774102872877088363514502315057504629824081709440636655798042553292"
        "9034903449940589217116920169670440722540626009661205589133469218178926718589380552764882219360714015364749"
        "7824672081638149673001159014798057985175145255197931590725217973774947292110715484775296246766629337798804"
        "0447235107421875e-167"},
    {0x1.fffffffffffffp-554, chars_format::scientific, 439,
        "3."
        "3916606895219074045820911067737219852595840559448130843333179338914845177172106576142192213005958751068114"
        "9542001433400040735284904137228848798381548205745754176727029004630115009259648163418881273311596085106585"
        "8069806899881178434233840339340881445081252019322411178266938436357853437178761105529764438721428030729499"
        "5649344163276299346002318029596115970350290510395863181450435947549894584221430969550592493533258675597608"
        "089447021484375e-167"},
    {0x1.fffffffffffffp-553, chars_format::scientific, 438,
        "6."
        "7833213790438148091641822135474439705191681118896261686666358677829690354344213152284384426011917502136229"
        "9084002866800081470569808274457697596763096411491508353454058009260230018519296326837762546623192170213171"
        "6139613799762356868467680678681762890162504038644822356533876872715706874357522211059528877442856061458999"
        "1298688326552598692004636059192231940700581020791726362900871895099789168442861939101184987066517351195216"
        "17889404296875e-167"},
    {0x1.fffffffffffffp-552, chars_format::scientific, 438,
        "1."
        "3566642758087629618328364427094887941038336223779252337333271735565938070868842630456876885202383500427245"
        "9816800573360016294113961654891539519352619282298301670690811601852046003703859265367552509324638434042634"
        "3227922759952471373693536135736352578032500807728964471306775374543141374871504442211905775488571212291799"
        "8259737665310519738400927211838446388140116204158345272580174379019957833688572387820236997413303470239043"
        "23577880859375e-166"},
    {0x1.fffffffffffffp-551, chars_format::scientific, 437,
        "2."
        "7133285516175259236656728854189775882076672447558504674666543471131876141737685260913753770404767000854491"
        "9633601146720032588227923309783079038705238564596603341381623203704092007407718530735105018649276868085268"
        "6455845519904942747387072271472705156065001615457928942613550749086282749743008884423811550977142424583599"
        "6519475330621039476801854423676892776280232408316690545160348758039915667377144775640473994826606940478086"
        "4715576171875e-166"},
    {0x1.fffffffffffffp-550, chars_format::scientific, 436,
        "5."
        "4266571032350518473313457708379551764153344895117009349333086942263752283475370521827507540809534001708983"
        "9267202293440065176455846619566158077410477129193206682763246407408184014815437061470210037298553736170537"
        "2911691039809885494774144542945410312130003230915857885227101498172565499486017768847623101954284849167199"
        "3038950661242078953603708847353785552560464816633381090320697516079831334754289551280947989653213880956172"
        "943115234375e-166"},
    {0x1.fffffffffffffp-549, chars_format::scientific, 436,
        "1."
        "0853314206470103694662691541675910352830668979023401869866617388452750456695074104365501508161906800341796"
        "7853440458688013035291169323913231615482095425838641336552649281481636802963087412294042007459710747234107"
        "4582338207961977098954828908589082062426000646183171577045420299634513099897203553769524620390856969833439"
        "8607790132248415790720741769470757110512092963326676218064139503215966266950857910256189597930642776191234"
        "588623046875e-165"},
    {0x1.fffffffffffffp-548, chars_format::scientific, 435,
        "2."
        "1706628412940207389325383083351820705661337958046803739733234776905500913390148208731003016323813600683593"
        "5706880917376026070582338647826463230964190851677282673105298562963273605926174824588084014919421494468214"
        "9164676415923954197909657817178164124852001292366343154090840599269026199794407107539049240781713939666879"
        "7215580264496831581441483538941514221024185926653352436128279006431932533901715820512379195861285552382469"
        "17724609375e-165"},
    {0x1.fffffffffffffp-547, chars_format::scientific, 434,
        "4."
        "3413256825880414778650766166703641411322675916093607479466469553811001826780296417462006032647627201367187"
        "1413761834752052141164677295652926461928381703354565346210597125926547211852349649176168029838842988936429"
        "8329352831847908395819315634356328249704002584732686308181681198538052399588814215078098481563427879333759"
        "4431160528993663162882967077883028442048371853306704872256558012863865067803431641024758391722571104764938"
        "3544921875e-165"},
    {0x1.fffffffffffffp-546, chars_format::scientific, 433,
        "8."
        "6826513651760829557301532333407282822645351832187214958932939107622003653560592834924012065295254402734374"
        "2827523669504104282329354591305852923856763406709130692421194251853094423704699298352336059677685977872859"
        "6658705663695816791638631268712656499408005169465372616363362397076104799177628430156196963126855758667518"
        "8862321057987326325765934155766056884096743706613409744513116025727730135606863282049516783445142209529876"
        "708984375e-165"},
    {0x1.fffffffffffffp-545, chars_format::scientific, 433,
        "1."
        "7365302730352165911460306466681456564529070366437442991786587821524400730712118566984802413059050880546874"
        "8565504733900820856465870918261170584771352681341826138484238850370618884740939859670467211935537195574571"
        "9331741132739163358327726253742531299881601033893074523272672479415220959835525686031239392625371151733503"
        "7772464211597465265153186831153211376819348741322681948902623205145546027121372656409903356689028441905975"
        "341796875e-164"},
    {0x1.fffffffffffffp-544, chars_format::scientific, 432,
        "3."
        "4730605460704331822920612933362913129058140732874885983573175643048801461424237133969604826118101761093749"
        "7131009467801641712931741836522341169542705362683652276968477700741237769481879719340934423871074391149143"
        "8663482265478326716655452507485062599763202067786149046545344958830441919671051372062478785250742303467007"
        "5544928423194930530306373662306422753638697482645363897805246410291092054242745312819806713378056883811950"
        "68359375e-164"},
    {0x1.fffffffffffffp-543, chars_format::scientific, 431,
        "6."
        "9461210921408663645841225866725826258116281465749771967146351286097602922848474267939209652236203522187499"
        "4262018935603283425863483673044682339085410725367304553936955401482475538963759438681868847742148782298287"
        "7326964530956653433310905014970125199526404135572298093090689917660883839342102744124957570501484606934015"
        "1089856846389861060612747324612845507277394965290727795610492820582184108485490625639613426756113767623901"
        "3671875e-164"},
    {0x1.fffffffffffffp-542, chars_format::scientific, 431,
        "1."
        "3892242184281732729168245173345165251623256293149954393429270257219520584569694853587841930447240704437499"
        "8852403787120656685172696734608936467817082145073460910787391080296495107792751887736373769548429756459657"
        "5465392906191330686662181002994025039905280827114459618618137983532176767868420548824991514100296921386803"
        "0217971369277972212122549464922569101455478993058145559122098564116436821697098125127922685351222753524780"
        "2734375e-163"},
    {0x1.fffffffffffffp-541, chars_format::scientific, 430,
        "2."
        "7784484368563465458336490346690330503246512586299908786858540514439041169139389707175683860894481408874999"
        "7704807574241313370345393469217872935634164290146921821574782160592990215585503775472747539096859512919315"
        "0930785812382661373324362005988050079810561654228919237236275967064353535736841097649983028200593842773606"
        "0435942738555944424245098929845138202910957986116291118244197128232873643394196250255845370702445507049560"
        "546875e-163"},
    {0x1.fffffffffffffp-540, chars_format::scientific, 429,
        "5."
        "5568968737126930916672980693380661006493025172599817573717081028878082338278779414351367721788962817749999"
        "5409615148482626740690786938435745871268328580293843643149564321185980431171007550945495078193719025838630"
        "1861571624765322746648724011976100159621123308457838474472551934128707071473682195299966056401187685547212"
        "0871885477111888848490197859690276405821915972232582236488394256465747286788392500511690741404891014099121"
        "09375e-163"},
    {0x1.fffffffffffffp-539, chars_format::scientific, 429,
        "1."
        "1113793747425386183334596138676132201298605034519963514743416205775616467655755882870273544357792563549999"
        "9081923029696525348138157387687149174253665716058768728629912864237196086234201510189099015638743805167726"
        "0372314324953064549329744802395220031924224661691567694894510386825741414294736439059993211280237537109442"
        "4174377095422377769698039571938055281164383194446516447297678851293149457357678500102338148280978202819824"
        "21875e-162"},
    {0x1.fffffffffffffp-538, chars_format::scientific, 428,
        "2."
        "2227587494850772366669192277352264402597210069039927029486832411551232935311511765740547088715585127099999"
        "8163846059393050696276314775374298348507331432117537457259825728474392172468403020378198031277487610335452"
        "0744628649906129098659489604790440063848449323383135389789020773651482828589472878119986422560475074218884"
        "8348754190844755539396079143876110562328766388893032894595357702586298914715357000204676296561956405639648"
        "4375e-162"},
    {0x1.fffffffffffffp-537, chars_format::scientific, 427,
        "4."
        "4455174989701544733338384554704528805194420138079854058973664823102465870623023531481094177431170254199999"
        "6327692118786101392552629550748596697014662864235074914519651456948784344936806040756396062554975220670904"
        "1489257299812258197318979209580880127696898646766270779578041547302965657178945756239972845120950148437769"
        "6697508381689511078792158287752221124657532777786065789190715405172597829430714000409352593123912811279296"
        "875e-162"},
    {0x1.fffffffffffffp-536, chars_format::scientific, 426,
        "8."
        "8910349979403089466676769109409057610388840276159708117947329646204931741246047062962188354862340508399999"
        "2655384237572202785105259101497193394029325728470149829039302913897568689873612081512792125109950441341808"
        "2978514599624516394637958419161760255393797293532541559156083094605931314357891512479945690241900296875539"
        "3395016763379022157584316575504442249315065555572131578381430810345195658861428000818705186247825622558593"
        "75e-162"},
    {0x1.fffffffffffffp-535, chars_format::scientific, 426,
        "1."
        "7782069995880617893335353821881811522077768055231941623589465929240986348249209412592437670972468101679999"
        "8531076847514440557021051820299438678805865145694029965807860582779513737974722416302558425021990088268361"
        "6595702919924903278927591683832352051078759458706508311831216618921186262871578302495989138048380059375107"
        "8679003352675804431516863315100888449863013111114426315676286162069039131772285600163741037249565124511718"
        "75e-161"},
    {0x1.fffffffffffffp-534, chars_format::scientific, 425,
        "3."
        "5564139991761235786670707643763623044155536110463883247178931858481972696498418825184875341944936203359999"
        "7062153695028881114042103640598877357611730291388059931615721165559027475949444832605116850043980176536723"
        "3191405839849806557855183367664704102157518917413016623662433237842372525743156604991978276096760118750215"
        "7358006705351608863033726630201776899726026222228852631352572324138078263544571200327482074499130249023437"
        "5e-161"},
    {0x1.fffffffffffffp-533, chars_format::scientific, 424,
        "7."
        "1128279983522471573341415287527246088311072220927766494357863716963945392996837650369750683889872406719999"
        "4124307390057762228084207281197754715223460582776119863231442331118054951898889665210233700087960353073446"
        "6382811679699613115710366735329408204315037834826033247324866475684745051486313209983956552193520237500431"
        "4716013410703217726067453260403553799452052444457705262705144648276156527089142400654964148998260498046875"
        "e-161"},
    {0x1.fffffffffffffp-532, chars_format::scientific, 424,
        "1."
        "4225655996704494314668283057505449217662214444185553298871572743392789078599367530073950136777974481343999"
        "8824861478011552445616841456239550943044692116555223972646288466223610990379777933042046740017592070614689"
        "3276562335939922623142073347065881640863007566965206649464973295136949010297262641996791310438704047500086"
        "2943202682140643545213490652080710759890410488891541052541028929655231305417828480130992829799652099609375"
        "e-160"},
    {0x1.fffffffffffffp-531, chars_format::scientific, 423,
        "2."
        "8451311993408988629336566115010898435324428888371106597743145486785578157198735060147900273555948962687999"
        "7649722956023104891233682912479101886089384233110447945292576932447221980759555866084093480035184141229378"
        "6553124671879845246284146694131763281726015133930413298929946590273898020594525283993582620877408095000172"
        "588640536428128709042698130416142151978082097778308210508205785931046261083565696026198565959930419921875e"
        "-160"},
    {0x1.fffffffffffffp-530, chars_format::scientific, 422,
        "5."
        "6902623986817977258673132230021796870648857776742213195486290973571156314397470120295800547111897925375999"
        "5299445912046209782467365824958203772178768466220895890585153864894443961519111732168186960070368282458757"
        "3106249343759690492568293388263526563452030267860826597859893180547796041189050567987165241754816190000345"
        "17728107285625741808539626083228430395616419555661642101641157186209252216713139205239713191986083984375e-"
        "160"},
    {0x1.fffffffffffffp-529, chars_format::scientific, 422,
        "1."
        "1380524797363595451734626446004359374129771555348442639097258194714231262879494024059160109422379585075199"
        "9059889182409241956493473164991640754435753693244179178117030772978888792303822346433637392014073656491751"
        "4621249868751938098513658677652705312690406053572165319571978636109559208237810113597433048350963238000069"
        "03545621457125148361707925216645686079123283911132328420328231437241850443342627841047942638397216796875e-"
        "159"},
    {0x1.fffffffffffffp-528, chars_format::scientific, 421,
        "2."
        "2761049594727190903469252892008718748259543110696885278194516389428462525758988048118320218844759170150399"
        "8119778364818483912986946329983281508871507386488358356234061545957777584607644692867274784028147312983502"
        "9242499737503876197027317355305410625380812107144330639143957272219118416475620227194866096701926476000138"
        "0709124291425029672341585043329137215824656782226465684065646287448370088668525568209588527679443359375e-"
        "159"},
    {0x1.fffffffffffffp-527, chars_format::scientific, 420,
        "4."
        "5522099189454381806938505784017437496519086221393770556389032778856925051517976096236640437689518340300799"
        "6239556729636967825973892659966563017743014772976716712468123091915555169215289385734549568056294625967005"
        "8484999475007752394054634710610821250761624214288661278287914544438236832951240454389732193403852952000276"
        "141824858285005934468317008665827443164931356445293136813129257489674017733705113641917705535888671875e-"
        "159"},
    {0x1.fffffffffffffp-526, chars_format::scientific, 419,
        "9."
        "1044198378908763613877011568034874993038172442787541112778065557713850103035952192473280875379036680601599"
        "2479113459273935651947785319933126035486029545953433424936246183831110338430578771469099136112589251934011"
        "6969998950015504788109269421221642501523248428577322556575829088876473665902480908779464386807705904000552"
        "28364971657001186893663401733165488632986271289058627362625851497934803546741022728383541107177734375e-"
        "159"},
    {0x1.fffffffffffffp-525, chars_format::scientific, 419,
        "1."
        "8208839675781752722775402313606974998607634488557508222555613111542770020607190438494656175075807336120319"
        "8495822691854787130389557063986625207097205909190686684987249236766222067686115754293819827222517850386802"
        "3393999790003100957621853884244328500304649685715464511315165817775294733180496181755892877361541180800110"
        "45672994331400237378732680346633097726597254257811725472525170299586960709348204545676708221435546875e-"
        "158"},
    {0x1.fffffffffffffp-524, chars_format::scientific, 418,
        "3."
        "6417679351563505445550804627213949997215268977115016445111226223085540041214380876989312350151614672240639"
        "6991645383709574260779114127973250414194411818381373369974498473532444135372231508587639654445035700773604"
        "6787999580006201915243707768488657000609299371430929022630331635550589466360992363511785754723082361600220"
        "9134598866280047475746536069326619545319450851562345094505034059917392141869640909135341644287109375e-"
        "158"},
    {0x1.fffffffffffffp-523, chars_format::scientific, 417,
        "7."
        "2835358703127010891101609254427899994430537954230032890222452446171080082428761753978624700303229344481279"
        "3983290767419148521558228255946500828388823636762746739948996947064888270744463017175279308890071401547209"
        "3575999160012403830487415536977314001218598742861858045260663271101178932721984727023571509446164723200441"
        "826919773256009495149307213865323909063890170312469018901006811983478428373928181827068328857421875e-158"},
    {0x1.fffffffffffffp-522, chars_format::scientific, 417,
        "1."
        "4567071740625402178220321850885579998886107590846006578044490489234216016485752350795724940060645868896255"
        "8796658153483829704311645651189300165677764727352549347989799389412977654148892603435055861778014280309441"
        "8715199832002480766097483107395462800243719748572371609052132654220235786544396945404714301889232944640088"
        "365383954651201899029861442773064781812778034062493803780201362396695685674785636365413665771484375e-157"},
    {0x1.fffffffffffffp-521, chars_format::scientific, 416,
        "2."
        "9134143481250804356440643701771159997772215181692013156088980978468432032971504701591449880121291737792511"
        "7593316306967659408623291302378600331355529454705098695979598778825955308297785206870111723556028560618883"
        "7430399664004961532194966214790925600487439497144743218104265308440471573088793890809428603778465889280176"
        "73076790930240379805972288554612956362555606812498760756040272479339137134957127273082733154296875e-157"},
    {0x1.fffffffffffffp-520, chars_format::scientific, 415,
        "5."
        "8268286962501608712881287403542319995544430363384026312177961956936864065943009403182899760242583475585023"
        "5186632613935318817246582604757200662711058909410197391959197557651910616595570413740223447112057121237767"
        "4860799328009923064389932429581851200974878994289486436208530616880943146177587781618857207556931778560353"
        "4615358186048075961194457710922591272511121362499752151208054495867827426991425454616546630859375e-157"},
    {0x1.fffffffffffffp-519, chars_format::scientific, 415,
        "1."
        "1653657392500321742576257480708463999108886072676805262435592391387372813188601880636579952048516695117004"
        "7037326522787063763449316520951440132542211781882039478391839511530382123319114082748044689422411424247553"
        "4972159865601984612877986485916370240194975798857897287241706123376188629235517556323771441511386355712070"
        "6923071637209615192238891542184518254502224272499950430241610899173565485398285090923309326171875e-156"},
    {0x1.fffffffffffffp-518, chars_format::scientific, 414,
        "2."
        "3307314785000643485152514961416927998217772145353610524871184782774745626377203761273159904097033390234009"
        "4074653045574127526898633041902880265084423563764078956783679023060764246638228165496089378844822848495106"
        "9944319731203969225755972971832740480389951597715794574483412246752377258471035112647542883022772711424141"
        "384614327441923038447778308436903650900444854499990086048322179834713097079657018184661865234375e-156"},
    {0x1.fffffffffffffp-517, chars_format::scientific, 413,
        "4."
        "6614629570001286970305029922833855996435544290707221049742369565549491252754407522546319808194066780468018"
        "8149306091148255053797266083805760530168847127528157913567358046121528493276456330992178757689645696990213"
        "9888639462407938451511945943665480960779903195431589148966824493504754516942070225295085766045545422848282"
        "76922865488384607689555661687380730180088970899998017209664435966942619415931403636932373046875e-156"},
    {0x1.fffffffffffffp-516, chars_format::scientific, 412,
        "9."
        "3229259140002573940610059845667711992871088581414442099484739131098982505508815045092639616388133560936037"
        "6298612182296510107594532167611521060337694255056315827134716092243056986552912661984357515379291393980427"
        "9777278924815876903023891887330961921559806390863178297933648987009509033884140450590171532091090845696565"
        "5384573097676921537911132337476146036017794179999603441932887193388523883186280727386474609375e-156"},
    {0x1.fffffffffffffp-515, chars_format::scientific, 412,
        "1."
        "8645851828000514788122011969133542398574217716282888419896947826219796501101763009018527923277626712187207"
        "5259722436459302021518906433522304212067538851011263165426943218448611397310582532396871503075858278796085"
        "5955455784963175380604778377466192384311961278172635659586729797401901806776828090118034306418218169139313"
        "1076914619535384307582226467495229207203558835999920688386577438677704776637256145477294921875e-155"},
    {0x1.fffffffffffffp-514, chars_format::scientific, 411,
        "3."
        "7291703656001029576244023938267084797148435432565776839793895652439593002203526018037055846555253424374415"
        "0519444872918604043037812867044608424135077702022526330853886436897222794621165064793743006151716557592171"
        "1910911569926350761209556754932384768623922556345271319173459594803803613553656180236068612836436338278626"
        "215382923907076861516445293499045841440711767199984137677315487735540955327451229095458984375e-155"},
    {0x1.fffffffffffffp-513, chars_format::scientific, 410,
        "7."
        "4583407312002059152488047876534169594296870865131553679587791304879186004407052036074111693110506848748830"
        "1038889745837208086075625734089216848270155404045052661707772873794445589242330129587486012303433115184342"
        "3821823139852701522419113509864769537247845112690542638346919189607607227107312360472137225672872676557252"
        "43076584781415372303289058699809168288142353439996827535463097547108191065490245819091796875e-155"},
    {0x1.fffffffffffffp-512, chars_format::scientific, 410,
        "1."
        "4916681462400411830497609575306833918859374173026310735917558260975837200881410407214822338622101369749766"
        "0207777949167441617215125146817843369654031080809010532341554574758889117848466025917497202460686623036868"
        "4764364627970540304483822701972953907449569022538108527669383837921521445421462472094427445134574535311450"
        "48615316956283074460657811739961833657628470687999365507092619509421638213098049163818359375e-154"},
    {0x1.fffffffffffffp-511, chars_format::scientific, 409,
        "2."
        "9833362924800823660995219150613667837718748346052621471835116521951674401762820814429644677244202739499532"
        "0415555898334883234430250293635686739308062161618021064683109149517778235696932051834994404921373246073736"
        "9528729255941080608967645403945907814899138045076217055338767675843042890842924944188854890269149070622900"
        "9723063391256614892131562347992366731525694137599873101418523901884327642619609832763671875e-154"},
    {0x1.fffffffffffffp-510, chars_format::scientific, 408,
        "5."
        "9666725849601647321990438301227335675437496692105242943670233043903348803525641628859289354488405478999064"
        "0831111796669766468860500587271373478616124323236042129366218299035556471393864103669988809842746492147473"
        "9057458511882161217935290807891815629798276090152434110677535351686085781685849888377709780538298141245801"
        "944612678251322978426312469598473346305138827519974620283704780376865528523921966552734375e-154"},
    {0x1.fffffffffffffp-509, chars_format::scientific, 408,
        "1."
        "1933345169920329464398087660245467135087499338421048588734046608780669760705128325771857870897681095799812"
        "8166222359333953293772100117454274695723224864647208425873243659807111294278772820733997761968549298429494"
        "7811491702376432243587058161578363125959655218030486822135507070337217156337169977675541956107659628249160"
        "388922535650264595685262493919694669261027765503994924056740956075373105704784393310546875e-153"},
    {0x1.fffffffffffffp-508, chars_format::scientific, 407,
        "2."
        "3866690339840658928796175320490934270174998676842097177468093217561339521410256651543715741795362191599625"
        "6332444718667906587544200234908549391446449729294416851746487319614222588557545641467995523937098596858989"
        "5622983404752864487174116323156726251919310436060973644271014140674434312674339955351083912215319256498320"
        "77784507130052919137052498783938933852205553100798984811348191215074621140956878662109375e-153"},
    {0x1.fffffffffffffp-507, chars_format::scientific, 406,
        "4."
        "7733380679681317857592350640981868540349997353684194354936186435122679042820513303087431483590724383199251"
        "2664889437335813175088400469817098782892899458588833703492974639228445177115091282935991047874197193717979"
        "1245966809505728974348232646313452503838620872121947288542028281348868625348679910702167824430638512996641"
        "5556901426010583827410499756787786770441110620159796962269638243014924228191375732421875e-153"},
    {0x1.fffffffffffffp-506, chars_format::scientific, 405,
        "9."
        "5466761359362635715184701281963737080699994707368388709872372870245358085641026606174862967181448766398502"
        "5329778874671626350176800939634197565785798917177667406985949278456890354230182565871982095748394387435958"
        "2491933619011457948696465292626905007677241744243894577084056562697737250697359821404335648861277025993283"
        "111380285202116765482099951357557354088222124031959392453927648602984845638275146484375e-153"},
    {0x1.fffffffffffffp-505, chars_format::scientific, 405,
        "1."
        "9093352271872527143036940256392747416139998941473677741974474574049071617128205321234972593436289753279700"
        "5065955774934325270035360187926839513157159783435533481397189855691378070846036513174396419149678877487191"
        "6498386723802291589739293058525381001535448348848778915416811312539547450139471964280867129772255405198656"
        "622276057040423353096419990271511470817644424806391878490785529720596969127655029296875e-152"},
    {0x1.fffffffffffffp-504, chars_format::scientific, 404,
        "3."
        "8186704543745054286073880512785494832279997882947355483948949148098143234256410642469945186872579506559401"
        "0131911549868650540070720375853679026314319566871066962794379711382756141692073026348792838299357754974383"
        "2996773447604583179478586117050762003070896697697557830833622625079094900278943928561734259544510810397313"
        "24455211408084670619283998054302294163528884961278375698157105944119393825531005859375e-152"},
    {0x1.fffffffffffffp-503, chars_format::scientific, 403,
        "7."
        "6373409087490108572147761025570989664559995765894710967897898296196286468512821284939890373745159013118802"
        "0263823099737301080141440751707358052628639133742133925588759422765512283384146052697585676598715509948766"
        "5993546895209166358957172234101524006141793395395115661667245250158189800557887857123468519089021620794626"
        "4891042281616934123856799610860458832705776992255675139631421188823878765106201171875e-152"},
    {0x1.fffffffffffffp-502, chars_format::scientific, 403,
        "1."
        "5274681817498021714429552205114197932911999153178942193579579659239257293702564256987978074749031802623760"
        "4052764619947460216028288150341471610525727826748426785117751884553102456676829210539517135319743101989753"
        "3198709379041833271791434446820304801228358679079023132333449050031637960111577571424693703817804324158925"
        "2978208456323386824771359922172091766541155398451135027926284237764775753021240234375e-151"},
    {0x1.fffffffffffffp-501, chars_format::scientific, 402,
        "3."
        "0549363634996043428859104410228395865823998306357884387159159318478514587405128513975956149498063605247520"
        "8105529239894920432056576300682943221051455653496853570235503769106204913353658421079034270639486203979506"
        "6397418758083666543582868893640609602456717358158046264666898100063275920223155142849387407635608648317850"
        "595641691264677364954271984434418353308231079690227005585256847552955150604248046875e-151"},
    {0x1.fffffffffffffp-500, chars_format::scientific, 401,
        "6."
        "1098727269992086857718208820456791731647996612715768774318318636957029174810257027951912298996127210495041"
        "6211058479789840864113152601365886442102911306993707140471007538212409826707316842158068541278972407959013"
        "2794837516167333087165737787281219204913434716316092529333796200126551840446310285698774815271217296635701"
        "19128338252935472990854396886883670661646215938045401117051369510591030120849609375e-151"},
    {0x1.fffffffffffffp-499, chars_format::scientific, 401,
        "1."
        "2219745453998417371543641764091358346329599322543153754863663727391405834962051405590382459799225442099008"
        "3242211695957968172822630520273177288420582261398741428094201507642481965341463368431613708255794481591802"
        "6558967503233466617433147557456243840982686943263218505866759240025310368089262057139754963054243459327140"
        "23825667650587094598170879377376734132329243187609080223410273902118206024169921875e-150"},
    {0x1.fffffffffffffp-498, chars_format::scientific, 400,
        "2."
        "4439490907996834743087283528182716692659198645086307509727327454782811669924102811180764919598450884198016"
        "6484423391915936345645261040546354576841164522797482856188403015284963930682926736863227416511588963183605"
        "3117935006466933234866295114912487681965373886526437011733518480050620736178524114279509926108486918654280"
        "4765133530117418919634175875475346826465848637521816044682054780423641204833984375e-150"},
    {0x1.fffffffffffffp-497, chars_format::scientific, 399,
        "4."
        "8878981815993669486174567056365433385318397290172615019454654909565623339848205622361529839196901768396033"
        "2968846783831872691290522081092709153682329045594965712376806030569927861365853473726454833023177926367210"
        "6235870012933866469732590229824975363930747773052874023467036960101241472357048228559019852216973837308560"
        "953026706023483783926835175095069365293169727504363208936410956084728240966796875e-150"},
    {0x1.fffffffffffffp-496, chars_format::scientific, 398,
        "9."
        "7757963631987338972349134112730866770636794580345230038909309819131246679696411244723059678393803536792066"
        "5937693567663745382581044162185418307364658091189931424753612061139855722731706947452909666046355852734421"
        "2471740025867732939465180459649950727861495546105748046934073920202482944714096457118039704433947674617121"
        "90605341204696756785367035019013873058633945500872641787282191216945648193359375e-150"},
    {0x1.fffffffffffffp-495, chars_format::scientific, 398,
        "1."
        "9551592726397467794469826822546173354127358916069046007781861963826249335939282248944611935678760707358413"
        "3187538713532749076516208832437083661472931618237986284950722412227971144546341389490581933209271170546884"
        "2494348005173546587893036091929990145572299109221149609386814784040496588942819291423607940886789534923424"
        "38121068240939351357073407003802774611726789100174528357456438243389129638671875e-149"},
    {0x1.fffffffffffffp-494, chars_format::scientific, 397,
        "3."
        "9103185452794935588939653645092346708254717832138092015563723927652498671878564497889223871357521414716826"
        "6375077427065498153032417664874167322945863236475972569901444824455942289092682778981163866418542341093768"
        "4988696010347093175786072183859980291144598218442299218773629568080993177885638582847215881773579069846848"
        "7624213648187870271414681400760554922345357820034905671491287648677825927734375e-149"},
    {0x1.fffffffffffffp-493, chars_format::scientific, 396,
        "7."
        "8206370905589871177879307290184693416509435664276184031127447855304997343757128995778447742715042829433653"
        "2750154854130996306064835329748334645891726472951945139802889648911884578185365557962327732837084682187536"
        "9977392020694186351572144367719960582289196436884598437547259136161986355771277165694431763547158139693697"
        "524842729637574054282936280152110984469071564006981134298257529735565185546875e-149"},
    {0x1.fffffffffffffp-492, chars_format::scientific, 396,
        "1."
        "5641274181117974235575861458036938683301887132855236806225489571060999468751425799155689548543008565886730"
        "6550030970826199261212967065949666929178345294590389027960577929782376915637073111592465546567416936437507"
        "3995478404138837270314428873543992116457839287376919687509451827232397271154255433138886352709431627938739"
        "504968545927514810856587256030422196893814312801396226859651505947113037109375e-148"},
    {0x1.fffffffffffffp-491, chars_format::scientific, 395,
        "3."
        "1282548362235948471151722916073877366603774265710473612450979142121998937502851598311379097086017131773461"
        "3100061941652398522425934131899333858356690589180778055921155859564753831274146223184931093134833872875014"
        "7990956808277674540628857747087984232915678574753839375018903654464794542308510866277772705418863255877479"
        "00993709185502962171317451206084439378762862560279245371930301189422607421875e-148"},
    {0x1.fffffffffffffp-490, chars_format::scientific, 394,
        "6."
        "2565096724471896942303445832147754733207548531420947224901958284243997875005703196622758194172034263546922"
        "6200123883304797044851868263798667716713381178361556111842311719129507662548292446369862186269667745750029"
        "5981913616555349081257715494175968465831357149507678750037807308929589084617021732555545410837726511754958"
        "0198741837100592434263490241216887875752572512055849074386060237884521484375e-148"},
    {0x1.fffffffffffffp-489, chars_format::scientific, 394,
        "1."
        "2513019344894379388460689166429550946641509706284189444980391656848799575001140639324551638834406852709384"
        "5240024776660959408970373652759733543342676235672311222368462343825901532509658489273972437253933549150005"
        "9196382723311069816251543098835193693166271429901535750007561461785917816923404346511109082167545302350991"
        "6039748367420118486852698048243377575150514502411169814877212047576904296875e-147"},
    {0x1.fffffffffffffp-488, chars_format::scientific, 393,
        "2."
        "5026038689788758776921378332859101893283019412568378889960783313697599150002281278649103277668813705418769"
        "0480049553321918817940747305519467086685352471344622444736924687651803065019316978547944874507867098300011"
        "8392765446622139632503086197670387386332542859803071500015122923571835633846808693022218164335090604701983"
        "207949673484023697370539609648675515030102900482233962975442409515380859375e-147"},
    {0x1.fffffffffffffp-487, chars_format::scientific, 392,
        "5."
        "0052077379577517553842756665718203786566038825136757779921566627395198300004562557298206555337627410837538"
        "0960099106643837635881494611038934173370704942689244889473849375303606130038633957095889749015734196600023"
        "6785530893244279265006172395340774772665085719606143000030245847143671267693617386044436328670181209403966"
        "41589934696804739474107921929735103006020580096446792595088481903076171875e-147"},
    {0x1.fffffffffffffp-486, chars_format::scientific, 392,
        "1."
        "0010415475915503510768551333143640757313207765027351555984313325479039660000912511459641311067525482167507"
        "6192019821328767527176298922207786834674140988537848977894769875060721226007726791419177949803146839320004"
        "7357106178648855853001234479068154954533017143921228600006049169428734253538723477208887265734036241880793"
        "28317986939360947894821584385947020601204116019289358519017696380615234375e-146"},
    {0x1.fffffffffffffp-485, chars_format::scientific, 391,
        "2."
        "0020830951831007021537102666287281514626415530054703111968626650958079320001825022919282622135050964335015"
        "2384039642657535054352597844415573669348281977075697955789539750121442452015453582838355899606293678640009"
        "4714212357297711706002468958136309909066034287842457200012098338857468507077446954417774531468072483761586"
        "5663597387872189578964316877189404120240823203857871703803539276123046875e-146"},
    {0x1.fffffffffffffp-484, chars_format::scientific, 390,
        "4."
        "0041661903662014043074205332574563029252831060109406223937253301916158640003650045838565244270101928670030"
        "4768079285315070108705195688831147338696563954151395911579079500242884904030907165676711799212587357280018"
        "9428424714595423412004937916272619818132068575684914400024196677714937014154893908835549062936144967523173"
        "132719477574437915792863375437880824048164640771574340760707855224609375e-146"},
    {0x1.fffffffffffffp-483, chars_format::scientific, 389,
        "8."
        "0083323807324028086148410665149126058505662120218812447874506603832317280007300091677130488540203857340060"
        "9536158570630140217410391377662294677393127908302791823158159000485769808061814331353423598425174714560037"
        "8856849429190846824009875832545239636264137151369828800048393355429874028309787817671098125872289935046346"
        "26543895514887583158572675087576164809632928154314868152141571044921875e-146"},
    {0x1.fffffffffffffp-482, chars_format::scientific, 389,
        "1."
        "6016664761464805617229682133029825211701132424043762489574901320766463456001460018335426097708040771468012"
        "1907231714126028043482078275532458935478625581660558364631631800097153961612362866270684719685034942912007"
        "5771369885838169364801975166509047927252827430273965760009678671085974805661957563534219625174457987009269"
        "25308779102977516631714535017515232961926585630862973630428314208984375e-145"},
    {0x1.fffffffffffffp-481, chars_format::scientific, 388,
        "3."
        "2033329522929611234459364266059650423402264848087524979149802641532926912002920036670852195416081542936024"
        "3814463428252056086964156551064917870957251163321116729263263600194307923224725732541369439370069885824015"
        "1542739771676338729603950333018095854505654860547931520019357342171949611323915127068439250348915974018538"
        "5061755820595503326342907003503046592385317126172594726085662841796875e-145"},
    {0x1.fffffffffffffp-480, chars_format::scientific, 387,
        "6."
        "4066659045859222468918728532119300846804529696175049958299605283065853824005840073341704390832163085872048"
        "7628926856504112173928313102129835741914502326642233458526527200388615846449451465082738878740139771648030"
        "3085479543352677459207900666036191709011309721095863040038714684343899222647830254136878500697831948037077"
        "012351164119100665268581400700609318477063425234518945217132568359375e-145"},
    {0x1.fffffffffffffp-479, chars_format::scientific, 387,
        "1."
        "2813331809171844493783745706423860169360905939235009991659921056613170764801168014668340878166432617174409"
        "7525785371300822434785662620425967148382900465328446691705305440077723169289890293016547775748027954329606"
        "0617095908670535491841580133207238341802261944219172608007742936868779844529566050827375700139566389607415"
        "402470232823820133053716280140121863695412685046903789043426513671875e-144"},
    {0x1.fffffffffffffp-478, chars_format::scientific, 386,
        "2."
        "5626663618343688987567491412847720338721811878470019983319842113226341529602336029336681756332865234348819"
        "5051570742601644869571325240851934296765800930656893383410610880155446338579780586033095551496055908659212"
        "1234191817341070983683160266414476683604523888438345216015485873737559689059132101654751400279132779214830"
        "80494046564764026610743256028024372739082537009380757808685302734375e-144"},
    {0x1.fffffffffffffp-477, chars_format::scientific, 385,
        "5."
        "1253327236687377975134982825695440677443623756940039966639684226452683059204672058673363512665730468697639"
        "0103141485203289739142650481703868593531601861313786766821221760310892677159561172066191102992111817318424"
        "2468383634682141967366320532828953367209047776876690432030971747475119378118264203309502800558265558429661"
        "6098809312952805322148651205604874547816507401876151561737060546875e-144"},
    {0x1.fffffffffffffp-476, chars_format::scientific, 385,
        "1."
        "0250665447337475595026996565139088135488724751388007993327936845290536611840934411734672702533146093739527"
        "8020628297040657947828530096340773718706320372262757353364244352062178535431912234413238220598422363463684"
        "8493676726936428393473264106565790673441809555375338086406194349495023875623652840661900560111653111685932"
        "3219761862590561064429730241120974909563301480375230312347412109375e-143"},
    {0x1.fffffffffffffp-475, chars_format::scientific, 384,
        "2."
        "0501330894674951190053993130278176270977449502776015986655873690581073223681868823469345405066292187479055"
        "6041256594081315895657060192681547437412640744525514706728488704124357070863824468826476441196844726927369"
        "6987353453872856786946528213131581346883619110750676172812388698990047751247305681323801120223306223371864"
        "643952372518112212885946048224194981912660296075046062469482421875e-143"},
    {0x1.fffffffffffffp-474, chars_format::scientific, 383,
        "4."
        "1002661789349902380107986260556352541954899005552031973311747381162146447363737646938690810132584374958111"
        "2082513188162631791314120385363094874825281489051029413456977408248714141727648937652952882393689453854739"
        "3974706907745713573893056426263162693767238221501352345624777397980095502494611362647602240446612446743729"
        "28790474503622442577189209644838996382532059215009212493896484375e-143"},
    {0x1.fffffffffffffp-473, chars_format::scientific, 382,
        "8."
        "2005323578699804760215972521112705083909798011104063946623494762324292894727475293877381620265168749916222"
        "4165026376325263582628240770726189749650562978102058826913954816497428283455297875305905764787378907709478"
        "7949413815491427147786112852526325387534476443002704691249554795960191004989222725295204480893224893487458"
        "5758094900724488515437841928967799276506411843001842498779296875e-143"},
    {0x1.fffffffffffffp-472, chars_format::scientific, 382,
        "1."
        "6401064715739960952043194504222541016781959602220812789324698952464858578945495058775476324053033749983244"
        "4833005275265052716525648154145237949930112595620411765382790963299485656691059575061181152957475781541895"
        "7589882763098285429557222570505265077506895288600540938249910959192038200997844545059040896178644978697491"
        "7151618980144897703087568385793559855301282368600368499755859375e-142"},
    {0x1.fffffffffffffp-471, chars_format::scientific, 381,
        "3."
        "2802129431479921904086389008445082033563919204441625578649397904929717157890990117550952648106067499966488"
        "9666010550530105433051296308290475899860225191240823530765581926598971313382119150122362305914951563083791"
        "5179765526196570859114445141010530155013790577201081876499821918384076401995689090118081792357289957394983"
        "430323796028979540617513677158711971060256473720073699951171875e-142"},
    {0x1.fffffffffffffp-470, chars_format::scientific, 380,
        "6."
        "5604258862959843808172778016890164067127838408883251157298795809859434315781980235101905296212134999932977"
        "9332021101060210866102592616580951799720450382481647061531163853197942626764238300244724611829903126167583"
        "0359531052393141718228890282021060310027581154402163752999643836768152803991378180236163584714579914789966"
        "86064759205795908123502735431742394212051294744014739990234375e-142"},
    {0x1.fffffffffffffp-469, chars_format::scientific, 380,
        "1."
        "3120851772591968761634555603378032813425567681776650231459759161971886863156396047020381059242426999986595"
        "5866404220212042173220518523316190359944090076496329412306232770639588525352847660048944922365980625233516"
        "6071906210478628343645778056404212062005516230880432750599928767353630560798275636047232716942915982957993"
        "37212951841159181624700547086348478842410258948802947998046875e-141"},
    {0x1.fffffffffffffp-468, chars_format::scientific, 379,
        "2."
        "6241703545183937523269111206756065626851135363553300462919518323943773726312792094040762118484853999973191"
        "1732808440424084346441037046632380719888180152992658824612465541279177050705695320097889844731961250467033"
        "2143812420957256687291556112808424124011032461760865501199857534707261121596551272094465433885831965915986"
        "7442590368231836324940109417269695768482051789760589599609375e-141"},
    {0x1.fffffffffffffp-467, chars_format::scientific, 378,
        "5."
        "2483407090367875046538222413512131253702270727106600925839036647887547452625584188081524236969707999946382"
        "3465616880848168692882074093264761439776360305985317649224931082558354101411390640195779689463922500934066"
        "4287624841914513374583112225616848248022064923521731002399715069414522243193102544188930867771663931831973"
        "488518073646367264988021883453939153696410357952117919921875e-141"},
    {0x1.fffffffffffffp-466, chars_format::scientific, 378,
        "1."
        "0496681418073575009307644482702426250740454145421320185167807329577509490525116837616304847393941599989276"
        "4693123376169633738576414818652952287955272061197063529844986216511670820282278128039155937892784500186813"
        "2857524968382902674916622445123369649604412984704346200479943013882904448638620508837786173554332786366394"
        "697703614729273452997604376690787830739282071590423583984375e-140"},
    {0x1.fffffffffffffp-465, chars_format::scientific, 377,
        "2."
        "0993362836147150018615288965404852501480908290842640370335614659155018981050233675232609694787883199978552"
        "9386246752339267477152829637305904575910544122394127059689972433023341640564556256078311875785569000373626"
        "5715049936765805349833244890246739299208825969408692400959886027765808897277241017675572347108665572732789"
        "39540722945854690599520875338157566147856414318084716796875e-140"},
    {0x1.fffffffffffffp-464, chars_format::scientific, 376,
        "4."
        "1986725672294300037230577930809705002961816581685280740671229318310037962100467350465219389575766399957105"
        "8772493504678534954305659274611809151821088244788254119379944866046683281129112512156623751571138000747253"
        "1430099873531610699666489780493478598417651938817384801919772055531617794554482035351144694217331145465578"
        "7908144589170938119904175067631513229571282863616943359375e-140"},
    {0x1.fffffffffffffp-463, chars_format::scientific, 375,
        "8."
        "3973451344588600074461155861619410005923633163370561481342458636620075924200934700930438779151532799914211"
        "7544987009357069908611318549223618303642176489576508238759889732093366562258225024313247503142276001494506"
        "2860199747063221399332979560986957196835303877634769603839544111063235589108964070702289388434662290931157"
        "581628917834187623980835013526302645914256572723388671875e-140"},
    {0x1.fffffffffffffp-462, chars_format::scientific, 375,
        "1."
        "6794690268917720014892231172323882001184726632674112296268491727324015184840186940186087755830306559982842"
        "3508997401871413981722263709844723660728435297915301647751977946418673312451645004862649500628455200298901"
        "2572039949412644279866595912197391439367060775526953920767908822212647117821792814140457877686932458186231"
        "516325783566837524796167002705260529182851314544677734375e-139"},
    {0x1.fffffffffffffp-461, chars_format::scientific, 374,
        "3."
        "3589380537835440029784462344647764002369453265348224592536983454648030369680373880372175511660613119965684"
        "7017994803742827963444527419689447321456870595830603295503955892837346624903290009725299001256910400597802"
        "5144079898825288559733191824394782878734121551053907841535817644425294235643585628280915755373864916372463"
        "03265156713367504959233400541052105836570262908935546875e-139"},
    {0x1.fffffffffffffp-460, chars_format::scientific, 373,
        "6."
        "7178761075670880059568924689295528004738906530696449185073966909296060739360747760744351023321226239931369"
        "4035989607485655926889054839378894642913741191661206591007911785674693249806580019450598002513820801195605"
        "0288159797650577119466383648789565757468243102107815683071635288850588471287171256561831510747729832744926"
        "0653031342673500991846680108210421167314052581787109375e-139"},
    {0x1.fffffffffffffp-459, chars_format::scientific, 373,
        "1."
        "3435752215134176011913784937859105600947781306139289837014793381859212147872149552148870204664245247986273"
        "8807197921497131185377810967875778928582748238332241318201582357134938649961316003890119600502764160239121"
        "0057631959530115423893276729757913151493648620421563136614327057770117694257434251312366302149545966548985"
        "2130606268534700198369336021642084233462810516357421875e-138"},
    {0x1.fffffffffffffp-458, chars_format::scientific, 372,
        "2."
        "6871504430268352023827569875718211201895562612278579674029586763718424295744299104297740409328490495972547"
        "7614395842994262370755621935751557857165496476664482636403164714269877299922632007780239201005528320478242"
        "0115263919060230847786553459515826302987297240843126273228654115540235388514868502624732604299091933097970"
        "426121253706940039673867204328416846692562103271484375e-138"},
    {0x1.fffffffffffffp-457, chars_format::scientific, 371,
        "5."
        "3743008860536704047655139751436422403791125224557159348059173527436848591488598208595480818656980991945095"
        "5228791685988524741511243871503115714330992953328965272806329428539754599845264015560478402011056640956484"
        "0230527838120461695573106919031652605974594481686252546457308231080470777029737005249465208598183866195940"
        "85224250741388007934773440865683369338512420654296875e-138"},
    {0x1.fffffffffffffp-456, chars_format::scientific, 371,
        "1."
        "0748601772107340809531027950287284480758225044911431869611834705487369718297719641719096163731396198389019"
        "1045758337197704948302248774300623142866198590665793054561265885707950919969052803112095680402211328191296"
        "8046105567624092339114621383806330521194918896337250509291461646216094155405947401049893041719636773239188"
        "17044850148277601586954688173136673867702484130859375e-137"},
    {0x1.fffffffffffffp-455, chars_format::scientific, 370,
        "2."
        "1497203544214681619062055900574568961516450089822863739223669410974739436595439283438192327462792396778038"
        "2091516674395409896604497548601246285732397181331586109122531771415901839938105606224191360804422656382593"
        "6092211135248184678229242767612661042389837792674501018582923292432188310811894802099786083439273546478376"
        "3408970029655520317390937634627334773540496826171875e-137"},
    {0x1.fffffffffffffp-454, chars_format::scientific, 369,
        "4."
        "2994407088429363238124111801149137923032900179645727478447338821949478873190878566876384654925584793556076"
        "4183033348790819793208995097202492571464794362663172218245063542831803679876211212448382721608845312765187"
        "2184422270496369356458485535225322084779675585349002037165846584864376621623789604199572166878547092956752"
        "681794005931104063478187526925466954708099365234375e-137"},
    {0x1.fffffffffffffp-453, chars_format::scientific, 368,
        "8."
        "5988814176858726476248223602298275846065800359291454956894677643898957746381757133752769309851169587112152"
        "8366066697581639586417990194404985142929588725326344436490127085663607359752422424896765443217690625530374"
        "4368844540992738712916971070450644169559351170698004074331693169728753243247579208399144333757094185913505"
        "36358801186220812695637505385093390941619873046875e-137"},
    {0x1.fffffffffffffp-452, chars_format::scientific, 368,
        "1."
        "7197762835371745295249644720459655169213160071858290991378935528779791549276351426750553861970233917422430"
        "5673213339516327917283598038880997028585917745065268887298025417132721471950484484979353088643538125106074"
        "8873768908198547742583394214090128833911870234139600814866338633945750648649515841679828866751418837182701"
        "07271760237244162539127501077018678188323974609375e-136"},
    {0x1.fffffffffffffp-451, chars_format::scientific, 367,
        "3."
        "4395525670743490590499289440919310338426320143716581982757871057559583098552702853501107723940467834844861"
        "1346426679032655834567196077761994057171835490130537774596050834265442943900968969958706177287076250212149"
        "7747537816397095485166788428180257667823740468279201629732677267891501297299031683359657733502837674365402"
        "1454352047448832507825500215403735637664794921875e-136"},
    {0x1.fffffffffffffp-450, chars_format::scientific, 366,
        "6."
        "8791051341486981180998578881838620676852640287433163965515742115119166197105405707002215447880935669689722"
        "2692853358065311669134392155523988114343670980261075549192101668530885887801937939917412354574152500424299"
        "5495075632794190970333576856360515335647480936558403259465354535783002594598063366719315467005675348730804"
        "290870409489766501565100043080747127532958984375e-136"},
    {0x1.fffffffffffffp-449, chars_format::scientific, 366,
        "1."
        "3758210268297396236199715776367724135370528057486632793103148423023833239421081141400443089576187133937944"
        "4538570671613062333826878431104797622868734196052215109838420333706177177560387587983482470914830500084859"
        "9099015126558838194066715371272103067129496187311680651893070907156600518919612673343863093401135069746160"
        "858174081897953300313020008616149425506591796875e-135"},
    {0x1.fffffffffffffp-448, chars_format::scientific, 365,
        "2."
        "7516420536594792472399431552735448270741056114973265586206296846047666478842162282800886179152374267875888"
        "9077141343226124667653756862209595245737468392104430219676840667412354355120775175966964941829661000169719"
        "8198030253117676388133430742544206134258992374623361303786141814313201037839225346687726186802270139492321"
        "71634816379590660062604001723229885101318359375e-135"},
    {0x1.fffffffffffffp-447, chars_format::scientific, 364,
        "5."
        "5032841073189584944798863105470896541482112229946531172412593692095332957684324565601772358304748535751777"
        "8154282686452249335307513724419190491474936784208860439353681334824708710241550351933929883659322000339439"
        "6396060506235352776266861485088412268517984749246722607572283628626402075678450693375452373604540278984643"
        "4326963275918132012520800344645977020263671875e-135"},
    {0x1.fffffffffffffp-446, chars_format::scientific, 364,
        "1."
        "1006568214637916988959772621094179308296422445989306234482518738419066591536864913120354471660949707150355"
        "5630856537290449867061502744883838098294987356841772087870736266964941742048310070386785976731864400067887"
        "9279212101247070555253372297017682453703596949849344521514456725725280415135690138675090474720908055796928"
        "6865392655183626402504160068929195404052734375e-134"},
    {0x1.fffffffffffffp-445, chars_format::scientific, 363,
        "2."
        "2013136429275833977919545242188358616592844891978612468965037476838133183073729826240708943321899414300711"
        "1261713074580899734123005489767676196589974713683544175741472533929883484096620140773571953463728800135775"
        "8558424202494141110506744594035364907407193899698689043028913451450560830271380277350180949441816111593857"
        "373078531036725280500832013785839080810546875e-134"},
    {0x1.fffffffffffffp-444, chars_format::scientific, 362,
        "4."
        "4026272858551667955839090484376717233185689783957224937930074953676266366147459652481417886643798828601422"
        "2523426149161799468246010979535352393179949427367088351482945067859766968193240281547143906927457600271551"
        "7116848404988282221013489188070729814814387799397378086057826902901121660542760554700361898883632223187714"
        "74615706207345056100166402757167816162109375e-134"},
    {0x1.fffffffffffffp-443, chars_format::scientific, 361,
        "8."
        "8052545717103335911678180968753434466371379567914449875860149907352532732294919304962835773287597657202844"
        "5046852298323598936492021959070704786359898854734176702965890135719533936386480563094287813854915200543103"
        "4233696809976564442026978376141459629628775598794756172115653805802243321085521109400723797767264446375429"
        "4923141241469011220033280551433563232421875e-134"},
    {0x1.fffffffffffffp-442, chars_format::scientific, 361,
        "1."
        "7610509143420667182335636193750686893274275913582889975172029981470506546458983860992567154657519531440568"
        "9009370459664719787298404391814140957271979770946835340593178027143906787277296112618857562770983040108620"
        "6846739361995312888405395675228291925925755119758951234423130761160448664217104221880144759553452889275085"
        "8984628248293802244006656110286712646484375e-133"},
    {0x1.fffffffffffffp-441, chars_format::scientific, 360,
        "3."
        "5221018286841334364671272387501373786548551827165779950344059962941013092917967721985134309315039062881137"
        "8018740919329439574596808783628281914543959541893670681186356054287813574554592225237715125541966080217241"
        "3693478723990625776810791350456583851851510239517902468846261522320897328434208443760289519106905778550171"
        "796925649658760448801331222057342529296875e-133"},
    {0x1.fffffffffffffp-440, chars_format::scientific, 359,
        "7."
        "0442036573682668729342544775002747573097103654331559900688119925882026185835935443970268618630078125762275"
        "6037481838658879149193617567256563829087919083787341362372712108575627149109184450475430251083932160434482"
        "7386957447981251553621582700913167703703020479035804937692523044641794656868416887520579038213811557100343"
        "59385129931752089760266244411468505859375e-133"},
    {0x1.fffffffffffffp-439, chars_format::scientific, 359,
        "1."
        "4088407314736533745868508955000549514619420730866311980137623985176405237167187088794053723726015625152455"
        "1207496367731775829838723513451312765817583816757468272474542421715125429821836890095086050216786432086896"
        "5477391489596250310724316540182633540740604095807160987538504608928358931373683377504115807642762311420068"
        "71877025986350417952053248882293701171875e-132"},
    {0x1.fffffffffffffp-438, chars_format::scientific, 358,
        "2."
        "8176814629473067491737017910001099029238841461732623960275247970352810474334374177588107447452031250304910"
        "2414992735463551659677447026902625531635167633514936544949084843430250859643673780190172100433572864173793"
        "0954782979192500621448633080365267081481208191614321975077009217856717862747366755008231615285524622840137"
        "4375405197270083590410649776458740234375e-132"},
    {0x1.fffffffffffffp-437, chars_format::scientific, 357,
        "5."
        "6353629258946134983474035820002198058477682923465247920550495940705620948668748355176214894904062500609820"
        "4829985470927103319354894053805251063270335267029873089898169686860501719287347560380344200867145728347586"
        "1909565958385001242897266160730534162962416383228643950154018435713435725494733510016463230571049245680274"
        "875081039454016718082129955291748046875e-132"},
    {0x1.fffffffffffffp-436, chars_format::scientific, 357,
        "1."
        "1270725851789226996694807164000439611695536584693049584110099188141124189733749671035242978980812500121964"
        "0965997094185420663870978810761050212654067053405974617979633937372100343857469512076068840173429145669517"
        "2381913191677000248579453232146106832592483276645728790030803687142687145098946702003292646114209849136054"
        "975016207890803343616425991058349609375e-131"},
    {0x1.fffffffffffffp-435, chars_format::scientific, 356,
        "2."
        "2541451703578453993389614328000879223391073169386099168220198376282248379467499342070485957961625000243928"
        "1931994188370841327741957621522100425308134106811949235959267874744200687714939024152137680346858291339034"
        "4763826383354000497158906464292213665184966553291457580061607374285374290197893404006585292228419698272109"
        "95003241578160668723285198211669921875e-131"},
    {0x1.fffffffffffffp-434, chars_format::scientific, 355,
        "4."
        "5082903407156907986779228656001758446782146338772198336440396752564496758934998684140971915923250000487856"
        "3863988376741682655483915243044200850616268213623898471918535749488401375429878048304275360693716582678068"
        "9527652766708000994317812928584427330369933106582915160123214748570748580395786808013170584456839396544219"
        "9000648315632133744657039642333984375e-131"},
    {0x1.fffffffffffffp-433, chars_format::scientific, 354,
        "9."
        "0165806814313815973558457312003516893564292677544396672880793505128993517869997368281943831846500000975712"
        "7727976753483365310967830486088401701232536427247796943837071498976802750859756096608550721387433165356137"
        "9055305533416001988635625857168854660739866213165830320246429497141497160791573616026341168913678793088439"
        "800129663126426748931407928466796875e-131"},
    {0x1.fffffffffffffp-432, chars_format::scientific, 354,
        "1."
        "8033161362862763194711691462400703378712858535508879334576158701025798703573999473656388766369300000195142"
        "5545595350696673062193566097217680340246507285449559388767414299795360550171951219321710144277486633071227"
        "5811061106683200397727125171433770932147973242633166064049285899428299432158314723205268233782735758617687"
        "960025932625285349786281585693359375e-130"},
    {0x1.fffffffffffffp-431, chars_format::scientific, 353,
        "3."
        "6066322725725526389423382924801406757425717071017758669152317402051597407147998947312777532738600000390285"
        "1091190701393346124387132194435360680493014570899118777534828599590721100343902438643420288554973266142455"
        "1622122213366400795454250342867541864295946485266332128098571798856598864316629446410536467565471517235375"
        "92005186525057069957256317138671875e-130"},
    {0x1.fffffffffffffp-430, chars_format::scientific, 352,
        "7."
        "2132645451451052778846765849602813514851434142035517338304634804103194814295997894625555065477200000780570"
        "2182381402786692248774264388870721360986029141798237555069657199181442200687804877286840577109946532284910"
        "3244244426732801590908500685735083728591892970532664256197143597713197728633258892821072935130943034470751"
        "8401037305011413991451263427734375e-130"},
    {0x1.fffffffffffffp-429, chars_format::scientific, 352,
        "1."
        "4426529090290210555769353169920562702970286828407103467660926960820638962859199578925111013095440000156114"
        "0436476280557338449754852877774144272197205828359647511013931439836288440137560975457368115421989306456982"
        "0648848885346560318181700137147016745718378594106532851239428719542639545726651778564214587026188606894150"
        "3680207461002282798290252685546875e-129"},
    {0x1.fffffffffffffp-428, chars_format::scientific, 351,
        "2."
        "8853058180580421111538706339841125405940573656814206935321853921641277925718399157850222026190880000312228"
        "0872952561114676899509705755548288544394411656719295022027862879672576880275121950914736230843978612913964"
        "1297697770693120636363400274294033491436757188213065702478857439085279091453303557128429174052377213788300"
        "736041492200456559658050537109375e-129"},
    {0x1.fffffffffffffp-427, chars_format::scientific, 350,
        "5."
        "7706116361160842223077412679682250811881147313628413870643707843282555851436798315700444052381760000624456"
        "1745905122229353799019411511096577088788823313438590044055725759345153760550243901829472461687957225827928"
        "2595395541386241272726800548588066982873514376426131404957714878170558182906607114256858348104754427576601"
        "47208298440091311931610107421875e-129"},
    {0x1.fffffffffffffp-426, chars_format::scientific, 350,
        "1."
        "1541223272232168444615482535936450162376229462725682774128741568656511170287359663140088810476352000124891"
        "2349181024445870759803882302219315417757764662687718008811145151869030752110048780365894492337591445165585"
        "6519079108277248254545360109717613396574702875285226280991542975634111636581321422851371669620950885515320"
        "29441659688018262386322021484375e-128"},
    {0x1.fffffffffffffp-425, chars_format::scientific, 349,
        "2."
        "3082446544464336889230965071872900324752458925451365548257483137313022340574719326280177620952704000249782"
        "4698362048891741519607764604438630835515529325375436017622290303738061504220097560731788984675182890331171"
        "3038158216554496509090720219435226793149405750570452561983085951268223273162642845702743339241901771030640"
        "5888331937603652477264404296875e-128"},
    {0x1.fffffffffffffp-424, chars_format::scientific, 348,
        "4."
        "6164893088928673778461930143745800649504917850902731096514966274626044681149438652560355241905408000499564"
        "9396724097783483039215529208877261671031058650750872035244580607476123008440195121463577969350365780662342"
        "6076316433108993018181440438870453586298811501140905123966171902536446546325285691405486678483803542061281"
        "177666387520730495452880859375e-128"},
    {0x1.fffffffffffffp-423, chars_format::scientific, 347,
        "9."
        "2329786177857347556923860287491601299009835701805462193029932549252089362298877305120710483810816000999129"
        "8793448195566966078431058417754523342062117301501744070489161214952246016880390242927155938700731561324685"
        "2152632866217986036362880877740907172597623002281810247932343805072893092650571382810973356967607084122562"
        "35533277504146099090576171875e-128"},
    {0x1.fffffffffffffp-422, chars_format::scientific, 347,
        "1."
        "8465957235571469511384772057498320259801967140361092438605986509850417872459775461024142096762163200199825"
        "9758689639113393215686211683550904668412423460300348814097832242990449203376078048585431187740146312264937"
        "0430526573243597207272576175548181434519524600456362049586468761014578618530114276562194671393521416824512"
        "47106655500829219818115234375e-127"},
    {0x1.fffffffffffffp-421, chars_format::scientific, 346,
        "3."
        "6931914471142939022769544114996640519603934280722184877211973019700835744919550922048284193524326400399651"
        "9517379278226786431372423367101809336824846920600697628195664485980898406752156097170862375480292624529874"
        "0861053146487194414545152351096362869039049200912724099172937522029157237060228553124389342787042833649024"
        "9421331100165843963623046875e-127"},
    {0x1.fffffffffffffp-420, chars_format::scientific, 345,
        "7."
        "3863828942285878045539088229993281039207868561444369754423946039401671489839101844096568387048652800799303"
        "9034758556453572862744846734203618673649693841201395256391328971961796813504312194341724750960585249059748"
        "1722106292974388829090304702192725738078098401825448198345875044058314474120457106248778685574085667298049"
        "884266220033168792724609375e-127"},
    {0x1.fffffffffffffp-419, chars_format::scientific, 345,
        "1."
        "4772765788457175609107817645998656207841573712288873950884789207880334297967820368819313677409730560159860"
        "7806951711290714572548969346840723734729938768240279051278265794392359362700862438868344950192117049811949"
        "6344421258594877765818060940438545147615619680365089639669175008811662894824091421249755737114817133459609"
        "976853244006633758544921875e-126"},
    {0x1.fffffffffffffp-418, chars_format::scientific, 344,
        "2."
        "9545531576914351218215635291997312415683147424577747901769578415760668595935640737638627354819461120319721"
        "5613903422581429145097938693681447469459877536480558102556531588784718725401724877736689900384234099623899"
        "2688842517189755531636121880877090295231239360730179279338350017623325789648182842499511474229634266919219"
        "95370648801326751708984375e-126"},
    {0x1.fffffffffffffp-417, chars_format::scientific, 343,
        "5."
        "9091063153828702436431270583994624831366294849155495803539156831521337191871281475277254709638922240639443"
        "1227806845162858290195877387362894938919755072961116205113063177569437450803449755473379800768468199247798"
        "5377685034379511063272243761754180590462478721460358558676700035246651579296365684999022948459268533838439"
        "9074129760265350341796875e-126"},
    {0x1.fffffffffffffp-416, chars_format::scientific, 343,
        "1."
        "1818212630765740487286254116798924966273258969831099160707831366304267438374256295055450941927784448127888"
        "6245561369032571658039175477472578987783951014592223241022612635513887490160689951094675960153693639849559"
        "7075537006875902212654448752350836118092495744292071711735340007049330315859273136999804589691853706767687"
        "9814825952053070068359375e-125"},
    {0x1.fffffffffffffp-415, chars_format::scientific, 342,
        "2."
        "3636425261531480974572508233597849932546517939662198321415662732608534876748512590110901883855568896255777"
        "2491122738065143316078350954945157975567902029184446482045225271027774980321379902189351920307387279699119"
        "4151074013751804425308897504701672236184991488584143423470680014098660631718546273999609179383707413535375"
        "962965190410614013671875e-125"},
    {0x1.fffffffffffffp-414, chars_format::scientific, 341,
        "4."
        "7272850523062961949145016467195699865093035879324396642831325465217069753497025180221803767711137792511554"
        "4982245476130286632156701909890315951135804058368892964090450542055549960642759804378703840614774559398238"
        "8302148027503608850617795009403344472369982977168286846941360028197321263437092547999218358767414827070751"
        "92593038082122802734375e-125"},
    {0x1.fffffffffffffp-413, chars_format::scientific, 340,
        "9."
        "4545701046125923898290032934391399730186071758648793285662650930434139506994050360443607535422275585023108"
        "9964490952260573264313403819780631902271608116737785928180901084111099921285519608757407681229549118796477"
        "6604296055007217701235590018806688944739965954336573693882720056394642526874185095998436717534829654141503"
        "8518607616424560546875e-125"},
    {0x1.fffffffffffffp-412, chars_format::scientific, 340,
        "1."
        "8909140209225184779658006586878279946037214351729758657132530186086827901398810072088721507084455117004621"
        "7992898190452114652862680763956126380454321623347557185636180216822219984257103921751481536245909823759295"
        "5320859211001443540247118003761337788947993190867314738776544011278928505374837019199687343506965930828300"
        "7703721523284912109375e-124"},
    {0x1.fffffffffffffp-411, chars_format::scientific, 339,
        "3."
        "7818280418450369559316013173756559892074428703459517314265060372173655802797620144177443014168910234009243"
        "5985796380904229305725361527912252760908643246695114371272360433644439968514207843502963072491819647518591"
        "0641718422002887080494236007522675577895986381734629477553088022557857010749674038399374687013931861656601"
        "540744304656982421875e-124"},
    {0x1.fffffffffffffp-410, chars_format::scientific, 338,
        "7."
        "5636560836900739118632026347513119784148857406919034628530120744347311605595240288354886028337820468018487"
        "1971592761808458611450723055824505521817286493390228742544720867288879937028415687005926144983639295037182"
        "1283436844005774160988472015045351155791972763469258955106176045115714021499348076798749374027863723313203"
        "08148860931396484375e-124"},
    {0x1.fffffffffffffp-409, chars_format::scientific, 338,
        "1."
        "5127312167380147823726405269502623956829771481383806925706024148869462321119048057670977205667564093603697"
        "4394318552361691722290144611164901104363457298678045748508944173457775987405683137401185228996727859007436"
        "4256687368801154832197694403009070231158394552693851791021235209023142804299869615359749874805572744662640"
        "61629772186279296875e-123"},
    {0x1.fffffffffffffp-408, chars_format::scientific, 337,
        "3."
        "0254624334760295647452810539005247913659542962767613851412048297738924642238096115341954411335128187207394"
        "8788637104723383444580289222329802208726914597356091497017888346915551974811366274802370457993455718014872"
        "8513374737602309664395388806018140462316789105387703582042470418046285608599739230719499749611145489325281"
        "2325954437255859375e-123"},
    {0x1.fffffffffffffp-407, chars_format::scientific, 336,
        "6."
        "0509248669520591294905621078010495827319085925535227702824096595477849284476192230683908822670256374414789"
        "7577274209446766889160578444659604417453829194712182994035776693831103949622732549604740915986911436029745"
        "7026749475204619328790777612036280924633578210775407164084940836092571217199478461438999499222290978650562"
        "465190887451171875e-123"},
    {0x1.fffffffffffffp-406, chars_format::scientific, 336,
        "1."
        "2101849733904118258981124215602099165463817185107045540564819319095569856895238446136781764534051274882957"
        "9515454841889353377832115688931920883490765838942436598807155338766220789924546509920948183197382287205949"
        "1405349895040923865758155522407256184926715642155081432816988167218514243439895692287799899844458195730112"
        "493038177490234375e-122"},
    {0x1.fffffffffffffp-405, chars_format::scientific, 335,
        "2."
        "4203699467808236517962248431204198330927634370214091081129638638191139713790476892273563529068102549765915"
        "9030909683778706755664231377863841766981531677884873197614310677532441579849093019841896366394764574411898"
        "2810699790081847731516311044814512369853431284310162865633976334437028486879791384575599799688916391460224"
        "98607635498046875e-122"},
    {0x1.fffffffffffffp-404, chars_format::scientific, 334,
        "4."
        "8407398935616473035924496862408396661855268740428182162259277276382279427580953784547127058136205099531831"
        "8061819367557413511328462755727683533963063355769746395228621355064883159698186039683792732789529148823796"
        "5621399580163695463032622089629024739706862568620325731267952668874056973759582769151199599377832782920449"
        "9721527099609375e-122"},
    {0x1.fffffffffffffp-403, chars_format::scientific, 333,
        "9."
        "6814797871232946071848993724816793323710537480856364324518554552764558855161907569094254116272410199063663"
        "6123638735114827022656925511455367067926126711539492790457242710129766319396372079367585465579058297647593"
        "1242799160327390926065244179258049479413725137240651462535905337748113947519165538302399198755665565840899"
        "944305419921875e-122"},
    {0x1.fffffffffffffp-402, chars_format::scientific, 333,
        "1."
        "9362959574246589214369798744963358664742107496171272864903710910552911771032381513818850823254482039812732"
        "7224727747022965404531385102291073413585225342307898558091448542025953263879274415873517093115811659529518"
        "6248559832065478185213048835851609895882745027448130292507181067549622789503833107660479839751133113168179"
        "988861083984375e-121"},
    {0x1.fffffffffffffp-401, chars_format::scientific, 332,
        "3."
        "8725919148493178428739597489926717329484214992342545729807421821105823542064763027637701646508964079625465"
        "4449455494045930809062770204582146827170450684615797116182897084051906527758548831747034186231623319059037"
        "2497119664130956370426097671703219791765490054896260585014362135099245579007666215320959679502266226336359"
        "97772216796875e-121"},
    {0x1.fffffffffffffp-400, chars_format::scientific, 331,
        "7."
        "7451838296986356857479194979853434658968429984685091459614843642211647084129526055275403293017928159250930"
        "8898910988091861618125540409164293654340901369231594232365794168103813055517097663494068372463246638118074"
        "4994239328261912740852195343406439583530980109792521170028724270198491158015332430641919359004532452672719"
        "9554443359375e-121"},
    {0x1.fffffffffffffp-399, chars_format::scientific, 331,
        "1."
        "5490367659397271371495838995970686931793685996937018291922968728442329416825905211055080658603585631850186"
        "1779782197618372323625108081832858730868180273846318846473158833620762611103419532698813674492649327623614"
        "8998847865652382548170439068681287916706196021958504234005744854039698231603066486128383871800906490534543"
        "9910888671875e-120"},
    {0x1.fffffffffffffp-398, chars_format::scientific, 330,
        "3."
        "0980735318794542742991677991941373863587371993874036583845937456884658833651810422110161317207171263700372"
        "3559564395236744647250216163665717461736360547692637692946317667241525222206839065397627348985298655247229"
        "7997695731304765096340878137362575833412392043917008468011489708079396463206132972256767743601812981069087"
        "982177734375e-120"},
    {0x1.fffffffffffffp-397, chars_format::scientific, 329,
        "6."
        "1961470637589085485983355983882747727174743987748073167691874913769317667303620844220322634414342527400744"
        "7119128790473489294500432327331434923472721095385275385892635334483050444413678130795254697970597310494459"
        "5995391462609530192681756274725151666824784087834016936022979416158792926412265944513535487203625962138175"
        "96435546875e-120"},
    {0x1.fffffffffffffp-396, chars_format::scientific, 329,
        "1."
        "2392294127517817097196671196776549545434948797549614633538374982753863533460724168844064526882868505480148"
        "9423825758094697858900086465466286984694544219077055077178527066896610088882735626159050939594119462098891"
        "9199078292521906038536351254945030333364956817566803387204595883231758585282453188902707097440725192427635"
        "19287109375e-119"},
    {0x1.fffffffffffffp-395, chars_format::scientific, 328,
        "2."
        "4784588255035634194393342393553099090869897595099229267076749965507727066921448337688129053765737010960297"
        "8847651516189395717800172930932573969389088438154110154357054133793220177765471252318101879188238924197783"
        "8398156585043812077072702509890060666729913635133606774409191766463517170564906377805414194881450384855270"
        "3857421875e-119"},
    {0x1.fffffffffffffp-394, chars_format::scientific, 327,
        "4."
        "9569176510071268388786684787106198181739795190198458534153499931015454133842896675376258107531474021920595"
        "7695303032378791435600345861865147938778176876308220308714108267586440355530942504636203758376477848395567"
        "6796313170087624154145405019780121333459827270267213548818383532927034341129812755610828389762900769710540"
        "771484375e-119"},
    {0x1.fffffffffffffp-393, chars_format::scientific, 326,
        "9."
        "9138353020142536777573369574212396363479590380396917068306999862030908267685793350752516215062948043841191"
        "5390606064757582871200691723730295877556353752616440617428216535172880711061885009272407516752955696791135"
        "3592626340175248308290810039560242666919654540534427097636767065854068682259625511221656779525801539421081"
        "54296875e-119"},
    {0x1.fffffffffffffp-392, chars_format::scientific, 326,
        "1."
        "9827670604028507355514673914842479272695918076079383413661399972406181653537158670150503243012589608768238"
        "3078121212951516574240138344746059175511270750523288123485643307034576142212377001854481503350591139358227"
        "0718525268035049661658162007912048533383930908106885419527353413170813736451925102244331355905160307884216"
        "30859375e-118"},
    {0x1.fffffffffffffp-391, chars_format::scientific, 325,
        "3."
        "9655341208057014711029347829684958545391836152158766827322799944812363307074317340301006486025179217536476"
        "6156242425903033148480276689492118351022541501046576246971286614069152284424754003708963006701182278716454"
        "1437050536070099323316324015824097066767861816213770839054706826341627472903850204488662711810320615768432"
        "6171875e-118"},
    {0x1.fffffffffffffp-390, chars_format::scientific, 324,
        "7."
        "9310682416114029422058695659369917090783672304317533654645599889624726614148634680602012972050358435072953"
        "2312484851806066296960553378984236702045083002093152493942573228138304568849508007417926013402364557432908"
        "2874101072140198646632648031648194133535723632427541678109413652683254945807700408977325423620641231536865"
        "234375e-118"},
    {0x1.fffffffffffffp-389, chars_format::scientific, 324,
        "1."
        "5862136483222805884411739131873983418156734460863506730929119977924945322829726936120402594410071687014590"
        "6462496970361213259392110675796847340409016600418630498788514645627660913769901601483585202680472911486581"
        "6574820214428039729326529606329638826707144726485508335621882730536650989161540081795465084724128246307373"
        "046875e-117"},
    {0x1.fffffffffffffp-388, chars_format::scientific, 323,
        "3."
        "1724272966445611768823478263747966836313468921727013461858239955849890645659453872240805188820143374029181"
        "2924993940722426518784221351593694680818033200837260997577029291255321827539803202967170405360945822973163"
        "3149640428856079458653059212659277653414289452971016671243765461073301978323080163590930169448256492614746"
        "09375e-117"},
    {0x1.fffffffffffffp-387, chars_format::scientific, 322,
        "6."
        "3448545932891223537646956527495933672626937843454026923716479911699781291318907744481610377640286748058362"
        "5849987881444853037568442703187389361636066401674521995154058582510643655079606405934340810721891645946326"
        "6299280857712158917306118425318555306828578905942033342487530922146603956646160327181860338896512985229492"
        "1875e-117"},
    {0x1.fffffffffffffp-386, chars_format::scientific, 322,
        "1."
        "2689709186578244707529391305499186734525387568690805384743295982339956258263781548896322075528057349611672"
        "5169997576288970607513688540637477872327213280334904399030811716502128731015921281186868162144378329189265"
        "3259856171542431783461223685063711061365715781188406668497506184429320791329232065436372067779302597045898"
        "4375e-116"},
    {0x1.fffffffffffffp-385, chars_format::scientific, 321,
        "2."
        "5379418373156489415058782610998373469050775137381610769486591964679912516527563097792644151056114699223345"
        "0339995152577941215027377081274955744654426560669808798061623433004257462031842562373736324288756658378530"
        "6519712343084863566922447370127422122731431562376813336995012368858641582658464130872744135558605194091796"
        "875e-116"},
    {0x1.fffffffffffffp-384, chars_format::scientific, 320,
        "5."
        "0758836746312978830117565221996746938101550274763221538973183929359825033055126195585288302112229398446690"
        "0679990305155882430054754162549911489308853121339617596123246866008514924063685124747472648577513316757061"
        "3039424686169727133844894740254844245462863124753626673990024737717283165316928261745488271117210388183593"
        "75e-116"},
    {0x1.fffffffffffffp-383, chars_format::scientific, 320,
        "1."
        "0151767349262595766023513044399349387620310054952644307794636785871965006611025239117057660422445879689338"
        "0135998061031176486010950832509982297861770624267923519224649373201702984812737024949494529715502663351412"
        "2607884937233945426768978948050968849092572624950725334798004947543456633063385652349097654223442077636718"
        "75e-115"},
    {0x1.fffffffffffffp-382, chars_format::scientific, 319,
        "2."
        "0303534698525191532047026088798698775240620109905288615589273571743930013222050478234115320844891759378676"
        "0271996122062352972021901665019964595723541248535847038449298746403405969625474049898989059431005326702824"
        "5215769874467890853537957896101937698185145249901450669596009895086913266126771304698195308446884155273437"
        "5e-115"},
    {0x1.fffffffffffffp-381, chars_format::scientific, 318,
        "4."
        "0607069397050383064094052177597397550481240219810577231178547143487860026444100956468230641689783518757352"
        "0543992244124705944043803330039929191447082497071694076898597492806811939250948099797978118862010653405649"
        "0431539748935781707075915792203875396370290499802901339192019790173826532253542609396390616893768310546875"
        "e-115"},
    {0x1.fffffffffffffp-380, chars_format::scientific, 317,
        "8."
        "1214138794100766128188104355194795100962480439621154462357094286975720052888201912936461283379567037514704"
        "1087984488249411888087606660079858382894164994143388153797194985613623878501896199595956237724021306811298"
        "086307949787156341415183158440775079274058099960580267838403958034765306450708521879278123378753662109375e"
        "-115"},
    {0x1.fffffffffffffp-379, chars_format::scientific, 317,
        "1."
        "6242827758820153225637620871038959020192496087924230892471418857395144010577640382587292256675913407502940"
        "8217596897649882377617521332015971676578832998828677630759438997122724775700379239919191247544804261362259"
        "617261589957431268283036631688155015854811619992116053567680791606953061290141704375855624675750732421875e"
        "-114"},
    {0x1.fffffffffffffp-378, chars_format::scientific, 316,
        "3."
        "2485655517640306451275241742077918040384992175848461784942837714790288021155280765174584513351826815005881"
        "6435193795299764755235042664031943353157665997657355261518877994245449551400758479838382495089608522724519"
        "23452317991486253656607326337631003170962323998423210713536158321390612258028340875171124935150146484375e-"
        "114"},
    {0x1.fffffffffffffp-377, chars_format::scientific, 315,
        "6."
        "4971311035280612902550483484155836080769984351696923569885675429580576042310561530349169026703653630011763"
        "2870387590599529510470085328063886706315331995314710523037755988490899102801516959676764990179217045449038"
        "4690463598297250731321465267526200634192464799684642142707231664278122451605668175034224987030029296875e-"
        "114"},
    {0x1.fffffffffffffp-376, chars_format::scientific, 315,
        "1."
        "2994262207056122580510096696831167216153996870339384713977135085916115208462112306069833805340730726002352"
        "6574077518119905902094017065612777341263066399062942104607551197698179820560303391935352998035843409089807"
        "6938092719659450146264293053505240126838492959936928428541446332855624490321133635006844997406005859375e-"
        "113"},
    {0x1.fffffffffffffp-375, chars_format::scientific, 314,
        "2."
        "5988524414112245161020193393662334432307993740678769427954270171832230416924224612139667610681461452004705"
        "3148155036239811804188034131225554682526132798125884209215102395396359641120606783870705996071686818179615"
        "387618543931890029252858610701048025367698591987385685708289266571124898064226727001368999481201171875e-"
        "113"},
    {0x1.fffffffffffffp-374, chars_format::scientific, 313,
        "5."
        "1977048828224490322040386787324668864615987481357538855908540343664460833848449224279335221362922904009410"
        "6296310072479623608376068262451109365052265596251768418430204790792719282241213567741411992143373636359230"
        "77523708786378005850571722140209605073539718397477137141657853314224979612845345400273799896240234375e-"
        "113"},
    {0x1.fffffffffffffp-373, chars_format::scientific, 313,
        "1."
        "0395409765644898064408077357464933772923197496271507771181708068732892166769689844855867044272584580801882"
        "1259262014495924721675213652490221873010453119250353683686040958158543856448242713548282398428674727271846"
        "15504741757275601170114344428041921014707943679495427428331570662844995922569069080054759979248046875e-"
        "112"},
    {0x1.fffffffffffffp-372, chars_format::scientific, 312,
        "2."
        "0790819531289796128816154714929867545846394992543015542363416137465784333539379689711734088545169161603764"
        "2518524028991849443350427304980443746020906238500707367372081916317087712896485427096564796857349454543692"
        "3100948351455120234022868885608384202941588735899085485666314132568999184513813816010951995849609375e-"
        "112"},
    {0x1.fffffffffffffp-371, chars_format::scientific, 311,
        "4."
        "1581639062579592257632309429859735091692789985086031084726832274931568667078759379423468177090338323207528"
        "5037048057983698886700854609960887492041812477001414734744163832634175425792970854193129593714698909087384"
        "620189670291024046804573777121676840588317747179817097133262826513799836902762763202190399169921875e-112"},
    {0x1.fffffffffffffp-370, chars_format::scientific, 310,
        "8."
        "3163278125159184515264618859719470183385579970172062169453664549863137334157518758846936354180676646415057"
        "0074096115967397773401709219921774984083624954002829469488327665268350851585941708386259187429397818174769"
        "24037934058204809360914755424335368117663549435963419426652565302759967380552552640438079833984375e-112"},
    {0x1.fffffffffffffp-369, chars_format::scientific, 310,
        "1."
        "6632655625031836903052923771943894036677115994034412433890732909972627466831503751769387270836135329283011"
        "4014819223193479554680341843984354996816724990800565893897665533053670170317188341677251837485879563634953"
        "84807586811640961872182951084867073623532709887192683885330513060551993476110510528087615966796875e-111"},
    {0x1.fffffffffffffp-368, chars_format::scientific, 309,
        "3."
        "3265311250063673806105847543887788073354231988068824867781465819945254933663007503538774541672270658566022"
        "8029638446386959109360683687968709993633449981601131787795331066107340340634376683354503674971759127269907"
        "6961517362328192374436590216973414724706541977438536777066102612110398695222102105617523193359375e-111"},
    {0x1.fffffffffffffp-367, chars_format::scientific, 308,
        "6."
        "6530622500127347612211695087775576146708463976137649735562931639890509867326015007077549083344541317132045"
        "6059276892773918218721367375937419987266899963202263575590662132214680681268753366709007349943518254539815"
        "392303472465638474887318043394682944941308395487707355413220522422079739044420421123504638671875e-111"},
    {0x1.fffffffffffffp-366, chars_format::scientific, 308,
        "1."
        "3306124500025469522442339017555115229341692795227529947112586327978101973465203001415509816668908263426409"
        "1211855378554783643744273475187483997453379992640452715118132426442936136253750673341801469988703650907963"
        "078460694493127694977463608678936588988261679097541471082644104484415947808884084224700927734375e-110"},
    {0x1.fffffffffffffp-365, chars_format::scientific, 307,
        "2."
        "6612249000050939044884678035110230458683385590455059894225172655956203946930406002831019633337816526852818"
        "2423710757109567287488546950374967994906759985280905430236264852885872272507501346683602939977407301815926"
        "15692138898625538995492721735787317797652335819508294216528820896883189561776816844940185546875e-110"},
    {0x1.fffffffffffffp-364, chars_format::scientific, 306,
        "5."
        "3224498000101878089769356070220460917366771180910119788450345311912407893860812005662039266675633053705636"
        "4847421514219134574977093900749935989813519970561810860472529705771744545015002693367205879954814603631852"
        "3138427779725107799098544347157463559530467163901658843305764179376637912355363368988037109375e-110"},
    {0x1.fffffffffffffp-363, chars_format::scientific, 306,
        "1."
        "0644899600020375617953871214044092183473354236182023957690069062382481578772162401132407853335126610741127"
        "2969484302843826914995418780149987197962703994112362172094505941154348909003000538673441175990962920726370"
        "4627685555945021559819708869431492711906093432780331768661152835875327582471072673797607421875e-109"},
    {0x1.fffffffffffffp-362, chars_format::scientific, 305,
        "2."
        "1289799200040751235907742428088184366946708472364047915380138124764963157544324802264815706670253221482254"
        "5938968605687653829990837560299974395925407988224724344189011882308697818006001077346882351981925841452740"
        "925537111189004311963941773886298542381218686556066353732230567175065516494214534759521484375e-109"},
    {0x1.fffffffffffffp-361, chars_format::scientific, 304,
        "4."
        "2579598400081502471815484856176368733893416944728095830760276249529926315088649604529631413340506442964509"
        "1877937211375307659981675120599948791850815976449448688378023764617395636012002154693764703963851682905481"
        "85107422237800862392788354777259708476243737311213270746446113435013103298842906951904296875e-109"},
    {0x1.fffffffffffffp-360, chars_format::scientific, 303,
        "8."
        "5159196800163004943630969712352737467786833889456191661520552499059852630177299209059262826681012885929018"
        "3755874422750615319963350241199897583701631952898897376756047529234791272024004309387529407927703365810963"
        "7021484447560172478557670955451941695248747462242654149289222687002620659768581390380859375e-109"},
    {0x1.fffffffffffffp-359, chars_format::scientific, 303,
        "1."
        "7031839360032600988726193942470547493557366777891238332304110499811970526035459841811852565336202577185803"
        "6751174884550123063992670048239979516740326390579779475351209505846958254404800861877505881585540673162192"
        "7404296889512034495711534191090388339049749492448530829857844537400524131953716278076171875e-108"},
    {0x1.fffffffffffffp-358, chars_format::scientific, 302,
        "3."
        "4063678720065201977452387884941094987114733555782476664608220999623941052070919683623705130672405154371607"
        "3502349769100246127985340096479959033480652781159558950702419011693916508809601723755011763171081346324385"
        "480859377902406899142306838218077667809949898489706165971568907480104826390743255615234375e-108"},
    {0x1.fffffffffffffp-357, chars_format::scientific, 301,
        "6."
        "8127357440130403954904775769882189974229467111564953329216441999247882104141839367247410261344810308743214"
        "7004699538200492255970680192959918066961305562319117901404838023387833017619203447510023526342162692648770"
        "96171875580481379828461367643615533561989979697941233194313781496020965278148651123046875e-108"},
    {0x1.fffffffffffffp-356, chars_format::scientific, 301,
        "1."
        "3625471488026080790980955153976437994845893422312990665843288399849576420828367873449482052268962061748642"
        "9400939907640098451194136038591983613392261112463823580280967604677566603523840689502004705268432538529754"
        "19234375116096275965692273528723106712397995939588246638862756299204193055629730224609375e-107"},
    {0x1.fffffffffffffp-355, chars_format::scientific, 300,
        "2."
        "7250942976052161581961910307952875989691786844625981331686576799699152841656735746898964104537924123497285"
        "8801879815280196902388272077183967226784522224927647160561935209355133207047681379004009410536865077059508"
        "3846875023219255193138454705744621342479599187917649327772551259840838611125946044921875e-107"},
    {0x1.fffffffffffffp-354, chars_format::scientific, 299,
        "5."
        "4501885952104323163923820615905751979383573689251962663373153599398305683313471493797928209075848246994571"
        "7603759630560393804776544154367934453569044449855294321123870418710266414095362758008018821073730154119016"
        "769375004643851038627690941148924268495919837583529865554510251968167722225189208984375e-107"},
    {0x1.fffffffffffffp-353, chars_format::scientific, 299,
        "1."
        "0900377190420864632784764123181150395876714737850392532674630719879661136662694298759585641815169649398914"
        "3520751926112078760955308830873586890713808889971058864224774083742053282819072551601603764214746030823803"
        "353875000928770207725538188229784853699183967516705973110902050393633544445037841796875e-106"},
    {0x1.fffffffffffffp-352, chars_format::scientific, 298,
        "2."
        "1800754380841729265569528246362300791753429475700785065349261439759322273325388597519171283630339298797828"
        "7041503852224157521910617661747173781427617779942117728449548167484106565638145103203207528429492061647606"
        "70775000185754041545107637645956970739836793503341194622180410078726708889007568359375e-106"},
    {0x1.fffffffffffffp-351, chars_format::scientific, 297,
        "4."
        "3601508761683458531139056492724601583506858951401570130698522879518644546650777195038342567260678597595657"
        "4083007704448315043821235323494347562855235559884235456899096334968213131276290206406415056858984123295213"
        "4155000037150808309021527529191394147967358700668238924436082015745341777801513671875e-106"},
    {0x1.fffffffffffffp-350, chars_format::scientific, 296,
        "8."
        "7203017523366917062278112985449203167013717902803140261397045759037289093301554390076685134521357195191314"
        "8166015408896630087642470646988695125710471119768470913798192669936426262552580412812830113717968246590426"
        "831000007430161661804305505838278829593471740133647784887216403149068355560302734375e-106"},
    {0x1.fffffffffffffp-349, chars_format::scientific, 296,
        "1."
        "7440603504673383412455622597089840633402743580560628052279409151807457818660310878015337026904271439038262"
        "9633203081779326017528494129397739025142094223953694182759638533987285252510516082562566022743593649318085"
        "366200001486032332360861101167655765918694348026729556977443280629813671112060546875e-105"},
    {0x1.fffffffffffffp-348, chars_format::scientific, 295,
        "3."
        "4881207009346766824911245194179681266805487161121256104558818303614915637320621756030674053808542878076525"
        "9266406163558652035056988258795478050284188447907388365519277067974570505021032165125132045487187298636170"
        "73240000297206466472172220233531153183738869605345911395488656125962734222412109375e-105"},
    {0x1.fffffffffffffp-347, chars_format::scientific, 294,
        "6."
        "9762414018693533649822490388359362533610974322242512209117636607229831274641243512061348107617085756153051"
        "8532812327117304070113976517590956100568376895814776731038554135949141010042064330250264090974374597272341"
        "4648000059441293294434444046706230636747773921069182279097731225192546844482421875e-105"},
    {0x1.fffffffffffffp-346, chars_format::scientific, 294,
        "1."
        "3952482803738706729964498077671872506722194864448502441823527321445966254928248702412269621523417151230610"
        "3706562465423460814022795303518191220113675379162955346207710827189828202008412866050052818194874919454468"
        "2929600011888258658886888809341246127349554784213836455819546245038509368896484375e-104"},
    {0x1.fffffffffffffp-345, chars_format::scientific, 293,
        "2."
        "7904965607477413459928996155343745013444389728897004883647054642891932509856497404824539243046834302461220"
        "7413124930846921628045590607036382440227350758325910692415421654379656404016825732100105636389749838908936"
        "585920002377651731777377761868249225469910956842767291163909249007701873779296875e-104"},
    {0x1.fffffffffffffp-344, chars_format::scientific, 292,
        "5."
        "5809931214954826919857992310687490026888779457794009767294109285783865019712994809649078486093668604922441"
        "4826249861693843256091181214072764880454701516651821384830843308759312808033651464200211272779499677817873"
        "17184000475530346355475552373649845093982191368553458232781849801540374755859375e-104"},
    {0x1.fffffffffffffp-343, chars_format::scientific, 292,
        "1."
        "1161986242990965383971598462137498005377755891558801953458821857156773003942598961929815697218733720984488"
        "2965249972338768651218236242814552976090940303330364276966168661751862561606730292840042254555899935563574"
        "63436800095106069271095110474729969018796438273710691646556369960308074951171875e-103"},
    {0x1.fffffffffffffp-342, chars_format::scientific, 291,
        "2."
        "2323972485981930767943196924274996010755511783117603906917643714313546007885197923859631394437467441968976"
        "5930499944677537302436472485629105952181880606660728553932337323503725123213460585680084509111799871127149"
        "2687360019021213854219022094945993803759287654742138329311273992061614990234375e-103"},
    {0x1.fffffffffffffp-341, chars_format::scientific, 290,
        "4."
        "4647944971963861535886393848549992021511023566235207813835287428627092015770395847719262788874934883937953"
        "1860999889355074604872944971258211904363761213321457107864674647007450246426921171360169018223599742254298"
        "537472003804242770843804418989198760751857530948427665862254798412322998046875e-103"},
    {0x1.fffffffffffffp-340, chars_format::scientific, 289,
        "8."
        "9295889943927723071772787697099984043022047132470415627670574857254184031540791695438525577749869767875906"
        "3721999778710149209745889942516423808727522426642914215729349294014900492853842342720338036447199484508597"
        "07494400760848554168760883797839752150371506189685533172450959682464599609375e-103"},
    {0x1.fffffffffffffp-339, chars_format::scientific, 289,
        "1."
        "7859177988785544614354557539419996808604409426494083125534114971450836806308158339087705115549973953575181"
        "2744399955742029841949177988503284761745504485328582843145869858802980098570768468544067607289439896901719"
        "41498880152169710833752176759567950430074301237937106634490191936492919921875e-102"},
    {0x1.fffffffffffffp-338, chars_format::scientific, 288,
        "3."
        "5718355977571089228709115078839993617208818852988166251068229942901673612616316678175410231099947907150362"
        "5488799911484059683898355977006569523491008970657165686291739717605960197141536937088135214578879793803438"
        "8299776030433942166750435351913590086014860247587421326898038387298583984375e-102"},
    {0x1.fffffffffffffp-337, chars_format::scientific, 287,
        "7."
        "1436711955142178457418230157679987234417637705976332502136459885803347225232633356350820462199895814300725"
        "0977599822968119367796711954013139046982017941314331372583479435211920394283073874176270429157759587606877"
        "659955206086788433350087070382718017202972049517484265379607677459716796875e-102"},
    {0x1.fffffffffffffp-336, chars_format::scientific, 287,
        "1."
        "4287342391028435691483646031535997446883527541195266500427291977160669445046526671270164092439979162860145"
        "0195519964593623873559342390802627809396403588262866274516695887042384078856614774835254085831551917521375"
        "531991041217357686670017414076543603440594409903496853075921535491943359375e-101"},
    {0x1.fffffffffffffp-335, chars_format::scientific, 286,
        "2."
        "8574684782056871382967292063071994893767055082390533000854583954321338890093053342540328184879958325720290"
        "0391039929187247747118684781605255618792807176525732549033391774084768157713229549670508171663103835042751"
        "06398208243471537334003482815308720688118881980699370615184307098388671875e-101"},
    {0x1.fffffffffffffp-334, chars_format::scientific, 285,
        "5."
        "7149369564113742765934584126143989787534110164781066001709167908642677780186106685080656369759916651440580"
        "0782079858374495494237369563210511237585614353051465098066783548169536315426459099341016343326207670085502"
        "1279641648694307466800696563061744137623776396139874123036861419677734375e-101"},
    {0x1.fffffffffffffp-333, chars_format::scientific, 285,
        "1."
        "1429873912822748553186916825228797957506822032956213200341833581728535556037221337016131273951983330288116"
        "0156415971674899098847473912642102247517122870610293019613356709633907263085291819868203268665241534017100"
        "4255928329738861493360139312612348827524755279227974824607372283935546875e-100"},
    {0x1.fffffffffffffp-332, chars_format::scientific, 284,
        "2."
        "2859747825645497106373833650457595915013644065912426400683667163457071112074442674032262547903966660576232"
        "0312831943349798197694947825284204495034245741220586039226713419267814526170583639736406537330483068034200"
        "851185665947772298672027862522469765504951055845594964921474456787109375e-100"},
    {0x1.fffffffffffffp-331, chars_format::scientific, 283,
        "4."
        "5719495651290994212747667300915191830027288131824852801367334326914142224148885348064525095807933321152464"
        "0625663886699596395389895650568408990068491482441172078453426838535629052341167279472813074660966136068401"
        "70237133189554459734405572504493953100990211169118992984294891357421875e-100"},
    {0x1.fffffffffffffp-330, chars_format::scientific, 282,
        "9."
        "1438991302581988425495334601830383660054576263649705602734668653828284448297770696129050191615866642304928"
        "1251327773399192790779791301136817980136982964882344156906853677071258104682334558945626149321932272136803"
        "4047426637910891946881114500898790620198042233823798596858978271484375e-100"},
    {0x1.fffffffffffffp-329, chars_format::scientific, 282,
        "1."
        "8287798260516397685099066920366076732010915252729941120546933730765656889659554139225810038323173328460985"
        "6250265554679838558155958260227363596027396592976468831381370735414251620936466911789125229864386454427360"
        "6809485327582178389376222900179758124039608446764759719371795654296875e-99"},
    {0x1.fffffffffffffp-328, chars_format::scientific, 281,
        "3."
        "6575596521032795370198133840732153464021830505459882241093867461531313779319108278451620076646346656921971"
        "2500531109359677116311916520454727192054793185952937662762741470828503241872933823578250459728772908854721"
        "361897065516435677875244580035951624807921689352951943874359130859375e-99"},
    {0x1.fffffffffffffp-327, chars_format::scientific, 280,
        "7."
        "3151193042065590740396267681464306928043661010919764482187734923062627558638216556903240153292693313843942"
        "5001062218719354232623833040909454384109586371905875325525482941657006483745867647156500919457545817709442"
        "72379413103287135575048916007190324961584337870590388774871826171875e-99"},
    {0x1.fffffffffffffp-326, chars_format::scientific, 280,
        "1."
        "4630238608413118148079253536292861385608732202183952896437546984612525511727643311380648030658538662768788"
        "5000212443743870846524766608181890876821917274381175065105096588331401296749173529431300183891509163541888"
        "54475882620657427115009783201438064992316867574118077754974365234375e-98"},
    {0x1.fffffffffffffp-325, chars_format::scientific, 279,
        "2."
        "9260477216826236296158507072585722771217464404367905792875093969225051023455286622761296061317077325537577"
        "0000424887487741693049533216363781753643834548762350130210193176662802593498347058862600367783018327083777"
        "0895176524131485423001956640287612998463373514823615550994873046875e-98"},
    {0x1.fffffffffffffp-324, chars_format::scientific, 278,
        "5."
        "8520954433652472592317014145171445542434928808735811585750187938450102046910573245522592122634154651075154"
        "0000849774975483386099066432727563507287669097524700260420386353325605186996694117725200735566036654167554"
        "179035304826297084600391328057522599692674702964723110198974609375e-98"},
    {0x1.fffffffffffffp-323, chars_format::scientific, 278,
        "1."
        "1704190886730494518463402829034289108486985761747162317150037587690020409382114649104518424526830930215030"
        "8000169954995096677219813286545512701457533819504940052084077270665121037399338823545040147113207330833510"
        "835807060965259416920078265611504519938534940592944622039794921875e-97"},
    {0x1.fffffffffffffp-322, chars_format::scientific, 277,
        "2."
        "3408381773460989036926805658068578216973971523494324634300075175380040818764229298209036849053661860430061"
        "6000339909990193354439626573091025402915067639009880104168154541330242074798677647090080294226414661667021"
        "67161412193051883384015653122300903987706988118588924407958984375e-97"},
    {0x1.fffffffffffffp-321, chars_format::scientific, 276,
        "4."
        "6816763546921978073853611316137156433947943046988649268600150350760081637528458596418073698107323720860123"
        "2000679819980386708879253146182050805830135278019760208336309082660484149597355294180160588452829323334043"
        "3432282438610376676803130624460180797541397623717784881591796875e-97"},
    {0x1.fffffffffffffp-320, chars_format::scientific, 275,
        "9."
        "3633527093843956147707222632274312867895886093977298537200300701520163275056917192836147396214647441720246"
        "4001359639960773417758506292364101611660270556039520416672618165320968299194710588360321176905658646668086"
        "686456487722075335360626124892036159508279524743556976318359375e-97"},
    {0x1.fffffffffffffp-319, chars_format::scientific, 275,
        "1."
        "8726705418768791229541444526454862573579177218795459707440060140304032655011383438567229479242929488344049"
        "2800271927992154683551701258472820322332054111207904083334523633064193659838942117672064235381131729333617"
        "337291297544415067072125224978407231901655904948711395263671875e-96"},
    {0x1.fffffffffffffp-318, chars_format::scientific, 274,
        "3."
        "7453410837537582459082889052909725147158354437590919414880120280608065310022766877134458958485858976688098"
        "5600543855984309367103402516945640644664108222415808166669047266128387319677884235344128470762263458667234"
        "67458259508883013414425044995681446380331180989742279052734375e-96"},
    {0x1.fffffffffffffp-317, chars_format::scientific, 273,
        "7."
        "4906821675075164918165778105819450294316708875181838829760240561216130620045533754268917916971717953376197"
        "1201087711968618734206805033891281289328216444831616333338094532256774639355768470688256941524526917334469"
        "3491651901776602682885008999136289276066236197948455810546875e-96"},
    {0x1.fffffffffffffp-316, chars_format::scientific, 273,
        "1."
        "4981364335015032983633155621163890058863341775036367765952048112243226124009106750853783583394343590675239"
        "4240217542393723746841361006778256257865643288966323266667618906451354927871153694137651388304905383466893"
        "8698330380355320536577001799827257855213247239589691162109375e-95"},
    {0x1.fffffffffffffp-315, chars_format::scientific, 272,
        "2."
        "9962728670030065967266311242327780117726683550072735531904096224486452248018213501707567166788687181350478"
        "8480435084787447493682722013556512515731286577932646533335237812902709855742307388275302776609810766933787"
        "739666076071064107315400359965451571042649447917938232421875e-95"},
    {0x1.fffffffffffffp-314, chars_format::scientific, 271,
        "5."
        "9925457340060131934532622484655560235453367100145471063808192448972904496036427003415134333577374362700957"
        "6960870169574894987365444027113025031462573155865293066670475625805419711484614776550605553219621533867575"
        "47933215214212821463080071993090314208529889583587646484375e-95"},
    {0x1.fffffffffffffp-313, chars_format::scientific, 271,
        "1."
        "1985091468012026386906524496931112047090673420029094212761638489794580899207285400683026866715474872540191"
        "5392174033914978997473088805422605006292514631173058613334095125161083942296922955310121110643924306773515"
        "09586643042842564292616014398618062841705977916717529296875e-94"},
    {0x1.fffffffffffffp-312, chars_format::scientific, 270,
        "2."
        "3970182936024052773813048993862224094181346840058188425523276979589161798414570801366053733430949745080383"
        "0784348067829957994946177610845210012585029262346117226668190250322167884593845910620242221287848613547030"
        "1917328608568512858523202879723612568341195583343505859375e-94"},
    {0x1.fffffffffffffp-311, chars_format::scientific, 269,
        "4."
        "7940365872048105547626097987724448188362693680116376851046553959178323596829141602732107466861899490160766"
        "1568696135659915989892355221690420025170058524692234453336380500644335769187691821240484442575697227094060"
        "383465721713702571704640575944722513668239116668701171875e-94"},
    {0x1.fffffffffffffp-310, chars_format::scientific, 268,
        "9."
        "5880731744096211095252195975448896376725387360232753702093107918356647193658283205464214933723798980321532"
        "3137392271319831979784710443380840050340117049384468906672761001288671538375383642480968885151394454188120"
        "76693144342740514340928115188944502733647823333740234375e-94"},
    {0x1.fffffffffffffp-309, chars_format::scientific, 268,
        "1."
        "9176146348819242219050439195089779275345077472046550740418621583671329438731656641092842986744759796064306"
        "4627478454263966395956942088676168010068023409876893781334552200257734307675076728496193777030278890837624"
        "15338628868548102868185623037788900546729564666748046875e-93"},
    {0x1.fffffffffffffp-308, chars_format::scientific, 267,
        "3."
        "8352292697638484438100878390179558550690154944093101480837243167342658877463313282185685973489519592128612"
        "9254956908527932791913884177352336020136046819753787562669104400515468615350153456992387554060557781675248"
        "3067725773709620573637124607557780109345912933349609375e-93"},
    {0x1.fffffffffffffp-307, chars_format::scientific, 266,
        "7."
        "6704585395276968876201756780359117101380309888186202961674486334685317754926626564371371946979039184257225"
        "8509913817055865583827768354704672040272093639507575125338208801030937230700306913984775108121115563350496"
        "613545154741924114727424921511556021869182586669921875e-93"},
    {0x1.fffffffffffffp-306, chars_format::scientific, 266,
        "1."
        "5340917079055393775240351356071823420276061977637240592334897266937063550985325312874274389395807836851445"
        "1701982763411173116765553670940934408054418727901515025067641760206187446140061382796955021624223112670099"
        "322709030948384822945484984302311204373836517333984375e-92"},
    {0x1.fffffffffffffp-305, chars_format::scientific, 265,
        "3."
        "0681834158110787550480702712143646840552123955274481184669794533874127101970650625748548778791615673702890"
        "3403965526822346233531107341881868816108837455803030050135283520412374892280122765593910043248446225340198"
        "64541806189676964589096996860462240874767303466796875e-92"},
    {0x1.fffffffffffffp-304, chars_format::scientific, 264,
        "6."
        "1363668316221575100961405424287293681104247910548962369339589067748254203941301251497097557583231347405780"
        "6807931053644692467062214683763737632217674911606060100270567040824749784560245531187820086496892450680397"
        "2908361237935392917819399372092448174953460693359375e-92"},
    {0x1.fffffffffffffp-303, chars_format::scientific, 264,
        "1."
        "2272733663244315020192281084857458736220849582109792473867917813549650840788260250299419511516646269481156"
        "1361586210728938493412442936752747526443534982321212020054113408164949956912049106237564017299378490136079"
        "4581672247587078583563879874418489634990692138671875e-91"},
    {0x1.fffffffffffffp-302, chars_format::scientific, 263,
        "2."
        "4545467326488630040384562169714917472441699164219584947735835627099301681576520500598839023033292538962312"
        "2723172421457876986824885873505495052887069964642424040108226816329899913824098212475128034598756980272158"
        "916334449517415716712775974883697926998138427734375e-91"},
    {0x1.fffffffffffffp-301, chars_format::scientific, 262,
        "4."
        "9090934652977260080769124339429834944883398328439169895471671254198603363153041001197678046066585077924624"
        "5446344842915753973649771747010990105774139929284848080216453632659799827648196424950256069197513960544317"
        "83266889903483143342555194976739585399627685546875e-91"},
    {0x1.fffffffffffffp-300, chars_format::scientific, 261,
        "9."
        "8181869305954520161538248678859669889766796656878339790943342508397206726306082002395356092133170155849249"
        "0892689685831507947299543494021980211548279858569696160432907265319599655296392849900512138395027921088635"
        "6653377980696628668511038995347917079925537109375e-91"},
    {0x1.fffffffffffffp-299, chars_format::scientific, 261,
        "1."
        "9636373861190904032307649735771933977953359331375667958188668501679441345261216400479071218426634031169849"
        "8178537937166301589459908698804396042309655971713939232086581453063919931059278569980102427679005584217727"
        "1330675596139325733702207799069583415985107421875e-90"},
    {0x1.fffffffffffffp-298, chars_format::scientific, 260,
        "3."
        "9272747722381808064615299471543867955906718662751335916377337003358882690522432800958142436853268062339699"
        "6357075874332603178919817397608792084619311943427878464173162906127839862118557139960204855358011168435454"
        "266135119227865146740441559813916683197021484375e-90"},
    {0x1.fffffffffffffp-297, chars_format::scientific, 259,
        "7."
        "8545495444763616129230598943087735911813437325502671832754674006717765381044865601916284873706536124679399"
        "2714151748665206357839634795217584169238623886855756928346325812255679724237114279920409710716022336870908"
        "53227023845573029348088311962783336639404296875e-90"},
    {0x1.fffffffffffffp-296, chars_format::scientific, 259,
        "1."
        "5709099088952723225846119788617547182362687465100534366550934801343553076208973120383256974741307224935879"
        "8542830349733041271567926959043516833847724777371151385669265162451135944847422855984081942143204467374181"
        "70645404769114605869617662392556667327880859375e-89"},
    {0x1.fffffffffffffp-295, chars_format::scientific, 258,
        "3."
        "1418198177905446451692239577235094364725374930201068733101869602687106152417946240766513949482614449871759"
        "7085660699466082543135853918087033667695449554742302771338530324902271889694845711968163884286408934748363"
        "4129080953822921173923532478511333465576171875e-89"},
    {0x1.fffffffffffffp-294, chars_format::scientific, 257,
        "6."
        "2836396355810892903384479154470188729450749860402137466203739205374212304835892481533027898965228899743519"
        "4171321398932165086271707836174067335390899109484605542677060649804543779389691423936327768572817869496726"
        "825816190764584234784706495702266693115234375e-89"},
    {0x1.fffffffffffffp-293, chars_format::scientific, 257,
        "1."
        "2567279271162178580676895830894037745890149972080427493240747841074842460967178496306605579793045779948703"
        "8834264279786433017254341567234813467078179821896921108535412129960908755877938284787265553714563573899345"
        "365163238152916846956941299140453338623046875e-88"},
    {0x1.fffffffffffffp-292, chars_format::scientific, 256,
        "2."
        "5134558542324357161353791661788075491780299944160854986481495682149684921934356992613211159586091559897407"
        "7668528559572866034508683134469626934156359643793842217070824259921817511755876569574531107429127147798690"
        "73032647630583369391388259828090667724609375e-88"},
    {0x1.fffffffffffffp-291, chars_format::scientific, 255,
        "5."
        "0269117084648714322707583323576150983560599888321709972962991364299369843868713985226422319172183119794815"
        "5337057119145732069017366268939253868312719287587684434141648519843635023511753139149062214858254295597381"
        "4606529526116673878277651965618133544921875e-88"},
    {0x1.fffffffffffffp-290, chars_format::scientific, 255,
        "1."
        "0053823416929742864541516664715230196712119977664341994592598272859873968773742797045284463834436623958963"
        "1067411423829146413803473253787850773662543857517536886828329703968727004702350627829812442971650859119476"
        "2921305905223334775655530393123626708984375e-87"},
    {0x1.fffffffffffffp-289, chars_format::scientific, 254,
        "2."
        "0107646833859485729083033329430460393424239955328683989185196545719747937547485594090568927668873247917926"
        "2134822847658292827606946507575701547325087715035073773656659407937454009404701255659624885943301718238952"
        "584261181044666955131106078624725341796875e-87"},
    {0x1.fffffffffffffp-288, chars_format::scientific, 253,
        "4."
        "0215293667718971458166066658860920786848479910657367978370393091439495875094971188181137855337746495835852"
        "4269645695316585655213893015151403094650175430070147547313318815874908018809402511319249771886603436477905"
        "16852236208933391026221215724945068359375e-87"},
    {0x1.fffffffffffffp-287, chars_format::scientific, 252,
        "8."
        "0430587335437942916332133317721841573696959821314735956740786182878991750189942376362275710675492991671704"
        "8539291390633171310427786030302806189300350860140295094626637631749816037618805022638499543773206872955810"
        "3370447241786678205244243144989013671875e-87"},
    {0x1.fffffffffffffp-286, chars_format::scientific, 252,
        "1."
        "6086117467087588583266426663544368314739391964262947191348157236575798350037988475272455142135098598334340"
        "9707858278126634262085557206060561237860070172028059018925327526349963207523761004527699908754641374591162"
        "0674089448357335641048848628997802734375e-86"},
    {0x1.fffffffffffffp-285, chars_format::scientific, 251,
        "3."
        "2172234934175177166532853327088736629478783928525894382696314473151596700075976950544910284270197196668681"
        "9415716556253268524171114412121122475720140344056118037850655052699926415047522009055399817509282749182324"
        "134817889671467128209769725799560546875e-86"},
    {0x1.fffffffffffffp-284, chars_format::scientific, 250,
        "6."
        "4344469868350354333065706654177473258957567857051788765392628946303193400151953901089820568540394393337363"
        "8831433112506537048342228824242244951440280688112236075701310105399852830095044018110799635018565498364648"
        "26963577934293425641953945159912109375e-86"},
    {0x1.fffffffffffffp-283, chars_format::scientific, 250,
        "1."
        "2868893973670070866613141330835494651791513571410357753078525789260638680030390780217964113708078878667472"
        "7766286622501307409668445764848448990288056137622447215140262021079970566019008803622159927003713099672929"
        "65392715586858685128390789031982421875e-85"},
    {0x1.fffffffffffffp-282, chars_format::scientific, 249,
        "2."
        "5737787947340141733226282661670989303583027142820715506157051578521277360060781560435928227416157757334945"
        "5532573245002614819336891529696897980576112275244894430280524042159941132038017607244319854007426199345859"
        "3078543117371737025678157806396484375e-85"},
    {0x1.fffffffffffffp-281, chars_format::scientific, 248,
        "5."
        "1475575894680283466452565323341978607166054285641431012314103157042554720121563120871856454832315514669891"
        "1065146490005229638673783059393795961152224550489788860561048084319882264076035214488639708014852398691718"
        "615708623474347405135631561279296875e-85"},
    {0x1.fffffffffffffp-280, chars_format::scientific, 248,
        "1."
        "0295115178936056693290513064668395721433210857128286202462820631408510944024312624174371290966463102933978"
        "2213029298001045927734756611878759192230444910097957772112209616863976452815207042897727941602970479738343"
        "723141724694869481027126312255859375e-84"},
    {0x1.fffffffffffffp-279, chars_format::scientific, 247,
        "2."
        "0590230357872113386581026129336791442866421714256572404925641262817021888048625248348742581932926205867956"
        "4426058596002091855469513223757518384460889820195915544224419233727952905630414085795455883205940959476687"
        "44628344938973896205425262451171875e-84"},
    {0x1.fffffffffffffp-278, chars_format::scientific, 246,
        "4."
        "1180460715744226773162052258673582885732843428513144809851282525634043776097250496697485163865852411735912"
        "8852117192004183710939026447515036768921779640391831088448838467455905811260828171590911766411881918953374"
        "8925668987794779241085052490234375e-84"},
    {0x1.fffffffffffffp-277, chars_format::scientific, 245,
        "8."
        "2360921431488453546324104517347165771465686857026289619702565051268087552194500993394970327731704823471825"
        "7704234384008367421878052895030073537843559280783662176897676934911811622521656343181823532823763837906749"
        "785133797558955848217010498046875e-84"},
    {0x1.fffffffffffffp-276, chars_format::scientific, 245,
        "1."
        "6472184286297690709264820903469433154293137371405257923940513010253617510438900198678994065546340964694365"
        "1540846876801673484375610579006014707568711856156732435379535386982362324504331268636364706564752767581349"
        "957026759511791169643402099609375e-83"},
    {0x1.fffffffffffffp-275, chars_format::scientific, 244,
        "3."
        "2944368572595381418529641806938866308586274742810515847881026020507235020877800397357988131092681929388730"
        "3081693753603346968751221158012029415137423712313464870759070773964724649008662537272729413129505535162699"
        "91405351902358233928680419921875e-83"},
    {0x1.fffffffffffffp-274, chars_format::scientific, 243,
        "6."
        "5888737145190762837059283613877732617172549485621031695762052041014470041755600794715976262185363858777460"
        "6163387507206693937502442316024058830274847424626929741518141547929449298017325074545458826259011070325399"
        "8281070380471646785736083984375e-83"},
    {0x1.fffffffffffffp-273, chars_format::scientific, 243,
        "1."
        "3177747429038152567411856722775546523434509897124206339152410408202894008351120158943195252437072771755492"
        "1232677501441338787500488463204811766054969484925385948303628309585889859603465014909091765251802214065079"
        "9656214076094329357147216796875e-82"},
    {0x1.fffffffffffffp-272, chars_format::scientific, 242,
        "2."
        "6355494858076305134823713445551093046869019794248412678304820816405788016702240317886390504874145543510984"
        "2465355002882677575000976926409623532109938969850771896607256619171779719206930029818183530503604428130159"
        "931242815218865871429443359375e-82"},
    {0x1.fffffffffffffp-271, chars_format::scientific, 241,
        "5."
        "2710989716152610269647426891102186093738039588496825356609641632811576033404480635772781009748291087021968"
        "4930710005765355150001953852819247064219877939701543793214513238343559438413860059636367061007208856260319"
        "86248563043773174285888671875e-82"},
    {0x1.fffffffffffffp-270, chars_format::scientific, 241,
        "1."
        "0542197943230522053929485378220437218747607917699365071321928326562315206680896127154556201949658217404393"
        "6986142001153071030000390770563849412843975587940308758642902647668711887682772011927273412201441771252063"
        "97249712608754634857177734375e-81"},
    {0x1.fffffffffffffp-269, chars_format::scientific, 240,
        "2."
        "1084395886461044107858970756440874437495215835398730142643856653124630413361792254309112403899316434808787"
        "3972284002306142060000781541127698825687951175880617517285805295337423775365544023854546824402883542504127"
        "9449942521750926971435546875e-81"},
    {0x1.fffffffffffffp-268, chars_format::scientific, 239,
        "4."
        "2168791772922088215717941512881748874990431670797460285287713306249260826723584508618224807798632869617574"
        "7944568004612284120001563082255397651375902351761235034571610590674847550731088047709093648805767085008255"
        "889988504350185394287109375e-81"},
    {0x1.fffffffffffffp-267, chars_format::scientific, 238,
        "8."
        "4337583545844176431435883025763497749980863341594920570575426612498521653447169017236449615597265739235149"
        "5889136009224568240003126164510795302751804703522470069143221181349695101462176095418187297611534170016511"
        "77997700870037078857421875e-81"},
    {0x1.fffffffffffffp-266, chars_format::scientific, 238,
        "1."
        "6867516709168835286287176605152699549996172668318984114115085322499704330689433803447289923119453147847029"
        "9177827201844913648000625232902159060550360940704494013828644236269939020292435219083637459522306834003302"
        "35599540174007415771484375e-80"},
    {0x1.fffffffffffffp-265, chars_format::scientific, 237,
        "3."
        "3735033418337670572574353210305399099992345336637968228230170644999408661378867606894579846238906295694059"
        "8355654403689827296001250465804318121100721881408988027657288472539878040584870438167274919044613668006604"
        "7119908034801483154296875e-80"},
    {0x1.fffffffffffffp-264, chars_format::scientific, 236,
        "6."
        "7470066836675341145148706420610798199984690673275936456460341289998817322757735213789159692477812591388119"
        "6711308807379654592002500931608636242201443762817976055314576945079756081169740876334549838089227336013209"
        "423981606960296630859375e-80"},
    {0x1.fffffffffffffp-263, chars_format::scientific, 236,
        "1."
        "3494013367335068229029741284122159639996938134655187291292068257999763464551547042757831938495562518277623"
        "9342261761475930918400500186321727248440288752563595211062915389015951216233948175266909967617845467202641"
        "884796321392059326171875e-79"},
    {0x1.fffffffffffffp-262, chars_format::scientific, 235,
        "2."
        "6988026734670136458059482568244319279993876269310374582584136515999526929103094085515663876991125036555247"
        "8684523522951861836801000372643454496880577505127190422125830778031902432467896350533819935235690934405283"
        "76959264278411865234375e-79"},
    {0x1.fffffffffffffp-261, chars_format::scientific, 234,
        "5."
        "3976053469340272916118965136488638559987752538620749165168273031999053858206188171031327753982250073110495"
        "7369047045903723673602000745286908993761155010254380844251661556063804864935792701067639870471381868810567"
        "5391852855682373046875e-79"},
    {0x1.fffffffffffffp-260, chars_format::scientific, 234,
        "1."
        "0795210693868054583223793027297727711997550507724149833033654606399810771641237634206265550796450014622099"
        "1473809409180744734720400149057381798752231002050876168850332311212760972987158540213527974094276373762113"
        "5078370571136474609375e-78"},
    {0x1.fffffffffffffp-259, chars_format::scientific, 233,
        "2."
        "1590421387736109166447586054595455423995101015448299666067309212799621543282475268412531101592900029244198"
        "2947618818361489469440800298114763597504462004101752337700664622425521945974317080427055948188552747524227"
        "015674114227294921875e-78"},
    {0x1.fffffffffffffp-258, chars_format::scientific, 232,
        "4."
        "3180842775472218332895172109190910847990202030896599332134618425599243086564950536825062203185800058488396"
        "5895237636722978938881600596229527195008924008203504675401329244851043891948634160854111896377105495048454"
        "03134822845458984375e-78"},
    {0x1.fffffffffffffp-257, chars_format::scientific, 231,
        "8."
        "6361685550944436665790344218381821695980404061793198664269236851198486173129901073650124406371600116976793"
        "1790475273445957877763201192459054390017848016407009350802658489702087783897268321708223792754210990096908"
        "0626964569091796875e-78"},
    {0x1.fffffffffffffp-256, chars_format::scientific, 231,
        "1."
        "7272337110188887333158068843676364339196080812358639732853847370239697234625980214730024881274320023395358"
        "6358095054689191575552640238491810878003569603281401870160531697940417556779453664341644758550842198019381"
        "6125392913818359375e-77"},
    {0x1.fffffffffffffp-255, chars_format::scientific, 230,
        "3."
        "4544674220377774666316137687352728678392161624717279465707694740479394469251960429460049762548640046790717"
        "2716190109378383151105280476983621756007139206562803740321063395880835113558907328683289517101684396038763"
        "225078582763671875e-77"},
    {0x1.fffffffffffffp-254, chars_format::scientific, 229,
        "6."
        "9089348440755549332632275374705457356784323249434558931415389480958788938503920858920099525097280093581434"
        "5432380218756766302210560953967243512014278413125607480642126791761670227117814657366579034203368792077526"
        "45015716552734375e-77"},
    {0x1.fffffffffffffp-253, chars_format::scientific, 229,
        "1."
        "3817869688151109866526455074941091471356864649886911786283077896191757787700784171784019905019456018716286"
        "9086476043751353260442112190793448702402855682625121496128425358352334045423562931473315806840673758415505"
        "29003143310546875e-76"},
    {0x1.fffffffffffffp-252, chars_format::scientific, 228,
        "2."
        "7635739376302219733052910149882182942713729299773823572566155792383515575401568343568039810038912037432573"
        "8172952087502706520884224381586897404805711365250242992256850716704668090847125862946631613681347516831010"
        "5800628662109375e-76"},
    {0x1.fffffffffffffp-251, chars_format::scientific, 227,
        "5."
        "5271478752604439466105820299764365885427458599547647145132311584767031150803136687136079620077824074865147"
        "6345904175005413041768448763173794809611422730500485984513701433409336181694251725893263227362695033662021"
        "160125732421875e-76"},
    {0x1.fffffffffffffp-250, chars_format::scientific, 227,
        "1."
        "1054295750520887893221164059952873177085491719909529429026462316953406230160627337427215924015564814973029"
        "5269180835001082608353689752634758961922284546100097196902740286681867236338850345178652645472539006732404"
        "232025146484375e-75"},
    {0x1.fffffffffffffp-249, chars_format::scientific, 226,
        "2."
        "2108591501041775786442328119905746354170983439819058858052924633906812460321254674854431848031129629946059"
        "0538361670002165216707379505269517923844569092200194393805480573363734472677700690357305290945078013464808"
        "46405029296875e-75"},
    {0x1.fffffffffffffp-248, chars_format::scientific, 225,
        "4."
        "4217183002083551572884656239811492708341966879638117716105849267813624920642509349708863696062259259892118"
        "1076723340004330433414759010539035847689138184400388787610961146727468945355401380714610581890156026929616"
        "9281005859375e-75"},
    {0x1.fffffffffffffp-247, chars_format::scientific, 224,
        "8."
        "8434366004167103145769312479622985416683933759276235432211698535627249841285018699417727392124518519784236"
        "2153446680008660866829518021078071695378276368800777575221922293454937890710802761429221163780312053859233"
        "856201171875e-75"},
    {0x1.fffffffffffffp-246, chars_format::scientific, 224,
        "1."
        "7686873200833420629153862495924597083336786751855247086442339707125449968257003739883545478424903703956847"
        "2430689336001732173365903604215614339075655273760155515044384458690987578142160552285844232756062410771846"
        "771240234375e-74"},
    {0x1.fffffffffffffp-245, chars_format::scientific, 223,
        "3."
        "5373746401666841258307724991849194166673573503710494172884679414250899936514007479767090956849807407913694"
        "4861378672003464346731807208431228678151310547520311030088768917381975156284321104571688465512124821543693"
        "54248046875e-74"},
    {0x1.fffffffffffffp-244, chars_format::scientific, 222,
        "7."
        "0747492803333682516615449983698388333347147007420988345769358828501799873028014959534181913699614815827388"
        "9722757344006928693463614416862457356302621095040622060177537834763950312568642209143376931024249643087387"
        "0849609375e-74"},
    {0x1.fffffffffffffp-243, chars_format::scientific, 222,
        "1."
        "4149498560666736503323089996739677666669429401484197669153871765700359974605602991906836382739922963165477"
        "7944551468801385738692722883372491471260524219008124412035507566952790062513728441828675386204849928617477"
        "4169921875e-73"},
    {0x1.fffffffffffffp-242, chars_format::scientific, 221,
        "2."
        "8298997121333473006646179993479355333338858802968395338307743531400719949211205983813672765479845926330955"
        "5889102937602771477385445766744982942521048438016248824071015133905580125027456883657350772409699857234954"
        "833984375e-73"},
    {0x1.fffffffffffffp-241, chars_format::scientific, 220,
        "5."
        "6597994242666946013292359986958710666677717605936790676615487062801439898422411967627345530959691852661911"
        "1778205875205542954770891533489965885042096876032497648142030267811160250054913767314701544819399714469909"
        "66796875e-73"},
    {0x1.fffffffffffffp-240, chars_format::scientific, 220,
        "1."
        "1319598848533389202658471997391742133335543521187358135323097412560287979684482393525469106191938370532382"
        "2355641175041108590954178306697993177008419375206499529628406053562232050010982753462940308963879942893981"
        "93359375e-72"},
    {0x1.fffffffffffffp-239, chars_format::scientific, 219,
        "2."
        "2639197697066778405316943994783484266671087042374716270646194825120575959368964787050938212383876741064764"
        "4711282350082217181908356613395986354016838750412999059256812107124464100021965506925880617927759885787963"
        "8671875e-72"},
    {0x1.fffffffffffffp-238, chars_format::scientific, 218,
        "4."
        "5278395394133556810633887989566968533342174084749432541292389650241151918737929574101876424767753482129528"
        "9422564700164434363816713226791972708033677500825998118513624214248928200043931013851761235855519771575927"
        "734375e-72"},
    {0x1.fffffffffffffp-237, chars_format::scientific, 217,
        "9."
        "0556790788267113621267775979133937066684348169498865082584779300482303837475859148203752849535506964259057"
        "8845129400328868727633426453583945416067355001651996237027248428497856400087862027703522471711039543151855"
        "46875e-72"},
    {0x1.fffffffffffffp-236, chars_format::scientific, 217,
        "1."
        "8111358157653422724253555195826787413336869633899773016516955860096460767495171829640750569907101392851811"
        "5769025880065773745526685290716789083213471000330399247405449685699571280017572405540704494342207908630371"
        "09375e-71"},
    {0x1.fffffffffffffp-235, chars_format::scientific, 216,
        "3."
        "6222716315306845448507110391653574826673739267799546033033911720192921534990343659281501139814202785703623"
        "1538051760131547491053370581433578166426942000660798494810899371399142560035144811081408988684415817260742"
        "1875e-71"},
    {0x1.fffffffffffffp-234, chars_format::scientific, 215,
        "7."
        "2445432630613690897014220783307149653347478535599092066067823440385843069980687318563002279628405571407246"
        "3076103520263094982106741162867156332853884001321596989621798742798285120070289622162817977368831634521484"
        "375e-71"},
    {0x1.fffffffffffffp-233, chars_format::scientific, 215,
        "1."
        "4489086526122738179402844156661429930669495707119818413213564688077168613996137463712600455925681114281449"
        "2615220704052618996421348232573431266570776800264319397924359748559657024014057924432563595473766326904296"
        "875e-70"},
    {0x1.fffffffffffffp-232, chars_format::scientific, 214,
        "2."
        "8978173052245476358805688313322859861338991414239636826427129376154337227992274927425200911851362228562898"
        "5230441408105237992842696465146862533141553600528638795848719497119314048028115848865127190947532653808593"
        "75e-70"},
    {0x1.fffffffffffffp-231, chars_format::scientific, 213,
        "5."
        "7956346104490952717611376626645719722677982828479273652854258752308674455984549854850401823702724457125797"
        "0460882816210475985685392930293725066283107201057277591697438994238628096056231697730254381895065307617187"
        "5e-70"},
    {0x1.fffffffffffffp-230, chars_format::scientific, 213,
        "1."
        "1591269220898190543522275325329143944535596565695854730570851750461734891196909970970080364740544891425159"
        "4092176563242095197137078586058745013256621440211455518339487798847725619211246339546050876379013061523437"
        "5e-69"},
    {0x1.fffffffffffffp-229, chars_format::scientific, 212,
        "2."
        "3182538441796381087044550650658287889071193131391709461141703500923469782393819941940160729481089782850318"
        "8184353126484190394274157172117490026513242880422911036678975597695451238422492679092101752758026123046875"
        "e-69"},
    {0x1.fffffffffffffp-228, chars_format::scientific, 211,
        "4."
        "6365076883592762174089101301316575778142386262783418922283407001846939564787639883880321458962179565700637"
        "636870625296838078854831434423498005302648576084582207335795119539090247684498535818420350551605224609375e"
        "-69"},
    {0x1.fffffffffffffp-227, chars_format::scientific, 210,
        "9."
        "2730153767185524348178202602633151556284772525566837844566814003693879129575279767760642917924359131401275"
        "27374125059367615770966286884699601060529715216916441467159023907818049536899707163684070110321044921875e-"
        "69"},
    {0x1.fffffffffffffp-226, chars_format::scientific, 210,
        "1."
        "8546030753437104869635640520526630311256954505113367568913362800738775825915055953552128583584871826280255"
        "05474825011873523154193257376939920212105943043383288293431804781563609907379941432736814022064208984375e-"
        "68"},
    {0x1.fffffffffffffp-225, chars_format::scientific, 209,
        "3."
        "7092061506874209739271281041053260622513909010226735137826725601477551651830111907104257167169743652560510"
        "1094965002374704630838651475387984042421188608676657658686360956312721981475988286547362804412841796875e-"
        "68"},
    {0x1.fffffffffffffp-224, chars_format::scientific, 208,
        "7."
        "4184123013748419478542562082106521245027818020453470275653451202955103303660223814208514334339487305121020"
        "218993000474940926167730295077596808484237721735331531737272191262544396295197657309472560882568359375e-"
        "68"},
    {0x1.fffffffffffffp-223, chars_format::scientific, 208,
        "1."
        "4836824602749683895708512416421304249005563604090694055130690240591020660732044762841702866867897461024204"
        "043798600094988185233546059015519361696847544347066306347454438252508879259039531461894512176513671875e-"
        "67"},
    {0x1.fffffffffffffp-222, chars_format::scientific, 207,
        "2."
        "9673649205499367791417024832842608498011127208181388110261380481182041321464089525683405733735794922048408"
        "08759720018997637046709211803103872339369508869413261269490887650501775851807906292378902435302734375e-"
        "67"},
    {0x1.fffffffffffffp-221, chars_format::scientific, 206,
        "5."
        "9347298410998735582834049665685216996022254416362776220522760962364082642928179051366811467471589844096816"
        "1751944003799527409341842360620774467873901773882652253898177530100355170361581258475780487060546875e-67"},
    {0x1.fffffffffffffp-220, chars_format::scientific, 206,
        "1."
        "1869459682199747116566809933137043399204450883272555244104552192472816528585635810273362293494317968819363"
        "2350388800759905481868368472124154893574780354776530450779635506020071034072316251695156097412109375e-66"},
    {0x1.fffffffffffffp-219, chars_format::scientific, 205,
        "2."
        "3738919364399494233133619866274086798408901766545110488209104384945633057171271620546724586988635937638726"
        "470077760151981096373673694424830978714956070955306090155927101204014206814463250339031219482421875e-66"},
    {0x1.fffffffffffffp-218, chars_format::scientific, 204,
        "4."
        "7477838728798988466267239732548173596817803533090220976418208769891266114342543241093449173977271875277452"
        "94015552030396219274734738884966195742991214191061218031185420240802841362892650067806243896484375e-66"},
    {0x1.fffffffffffffp-217, chars_format::scientific, 203,
        "9."
        "4955677457597976932534479465096347193635607066180441952836417539782532228685086482186898347954543750554905"
        "8803110406079243854946947776993239148598242838212243606237084048160568272578530013561248779296875e-66"},
    {0x1.fffffffffffffp-216, chars_format::scientific, 203,
        "1."
        "8991135491519595386506895893019269438727121413236088390567283507956506445737017296437379669590908750110981"
        "1760622081215848770989389555398647829719648567642448721247416809632113654515706002712249755859375e-65"},
    {0x1.fffffffffffffp-215, chars_format::scientific, 202,
        "3."
        "7982270983039190773013791786038538877454242826472176781134567015913012891474034592874759339181817500221962"
        "352124416243169754197877911079729565943929713528489744249483361926422730903141200542449951171875e-65"},
    {0x1.fffffffffffffp-214, chars_format::scientific, 201,
        "7."
        "5964541966078381546027583572077077754908485652944353562269134031826025782948069185749518678363635000443924"
        "70424883248633950839575582215945913188785942705697948849896672385284546180628240108489990234375e-65"},
    {0x1.fffffffffffffp-213, chars_format::scientific, 201,
        "1."
        "5192908393215676309205516714415415550981697130588870712453826806365205156589613837149903735672727000088784"
        "94084976649726790167915116443189182637757188541139589769979334477056909236125648021697998046875e-64"},
    {0x1.fffffffffffffp-212, chars_format::scientific, 200,
        "3."
        "0385816786431352618411033428830831101963394261177741424907653612730410313179227674299807471345454000177569"
        "8816995329945358033583023288637836527551437708227917953995866895411381847225129604339599609375e-64"},
    {0x1.fffffffffffffp-211, chars_format::scientific, 199,
        "6."
        "0771633572862705236822066857661662203926788522355482849815307225460820626358455348599614942690908000355139"
        "763399065989071606716604657727567305510287541645583590799173379082276369445025920867919921875e-64"},
    {0x1.fffffffffffffp-210, chars_format::scientific, 199,
        "1."
        "2154326714572541047364413371532332440785357704471096569963061445092164125271691069719922988538181600071027"
        "952679813197814321343320931545513461102057508329116718159834675816455273889005184173583984375e-63"},
    {0x1.fffffffffffffp-209, chars_format::scientific, 198,
        "2."
        "4308653429145082094728826743064664881570715408942193139926122890184328250543382139439845977076363200142055"
        "90535962639562864268664186309102692220411501665823343631966935163291054777801036834716796875e-63"},
    {0x1.fffffffffffffp-208, chars_format::scientific, 197,
        "4."
        "8617306858290164189457653486129329763141430817884386279852245780368656501086764278879691954152726400284111"
        "8107192527912572853732837261820538444082300333164668726393387032658210955560207366943359375e-63"},
    {0x1.fffffffffffffp-207, chars_format::scientific, 196,
        "9."
        "7234613716580328378915306972258659526282861635768772559704491560737313002173528557759383908305452800568223"
        "621438505582514570746567452364107688816460066632933745278677406531642191112041473388671875e-63"},
    {0x1.fffffffffffffp-206, chars_format::scientific, 196,
        "1."
        "9446922743316065675783061394451731905256572327153754511940898312147462600434705711551876781661090560113644"
        "724287701116502914149313490472821537763292013326586749055735481306328438222408294677734375e-62"},
    {0x1.fffffffffffffp-205, chars_format::scientific, 195,
        "3."
        "8893845486632131351566122788903463810513144654307509023881796624294925200869411423103753563322181120227289"
        "44857540223300582829862698094564307552658402665317349811147096261265687644481658935546875e-62"},
    {0x1.fffffffffffffp-204, chars_format::scientific, 194,
        "7."
        "7787690973264262703132245577806927621026289308615018047763593248589850401738822846207507126644362240454578"
        "8971508044660116565972539618912861510531680533063469962229419252253137528896331787109375e-62"},
    {0x1.fffffffffffffp-203, chars_format::scientific, 194,
        "1."
        "5557538194652852540626449115561385524205257861723003609552718649717970080347764569241501425328872448090915"
        "7794301608932023313194507923782572302106336106612693992445883850450627505779266357421875e-61"},
    {0x1.fffffffffffffp-202, chars_format::scientific, 193,
        "3."
        "1115076389305705081252898231122771048410515723446007219105437299435940160695529138483002850657744896181831"
        "558860321786404662638901584756514460421267221322538798489176770090125501155853271484375e-61"},
    {0x1.fffffffffffffp-201, chars_format::scientific, 192,
        "6."
        "2230152778611410162505796462245542096821031446892014438210874598871880321391058276966005701315489792363663"
        "11772064357280932527780316951302892084253444264507759697835354018025100231170654296875e-61"},
    {0x1.fffffffffffffp-200, chars_format::scientific, 192,
        "1."
        "2446030555722282032501159292449108419364206289378402887642174919774376064278211655393201140263097958472732"
        "62354412871456186505556063390260578416850688852901551939567070803605020046234130859375e-60"},
    {0x1.fffffffffffffp-199, chars_format::scientific, 191,
        "2."
        "4892061111444564065002318584898216838728412578756805775284349839548752128556423310786402280526195916945465"
        "2470882574291237301111212678052115683370137770580310387913414160721004009246826171875e-60"},
    {0x1.fffffffffffffp-198, chars_format::scientific, 190,
        "4."
        "9784122222889128130004637169796433677456825157513611550568699679097504257112846621572804561052391833890930"
        "494176514858247460222242535610423136674027554116062077582682832144200801849365234375e-60"},
    {0x1.fffffffffffffp-197, chars_format::scientific, 189,
        "9."
        "9568244445778256260009274339592867354913650315027223101137399358195008514225693243145609122104783667781860"
        "98835302971649492044448507122084627334805510823212415516536566428840160369873046875e-60"},
    {0x1.fffffffffffffp-196, chars_format::scientific, 189,
        "1."
        "9913648889155651252001854867918573470982730063005444620227479871639001702845138648629121824420956733556372"
        "19767060594329898408889701424416925466961102164642483103307313285768032073974609375e-59"},
    {0x1.fffffffffffffp-195, chars_format::scientific, 188,
        "3."
        "9827297778311302504003709735837146941965460126010889240454959743278003405690277297258243648841913467112744"
        "3953412118865979681777940284883385093392220432928496620661462657153606414794921875e-59"},
    {0x1.fffffffffffffp-194, chars_format::scientific, 187,
        "7."
        "9654595556622605008007419471674293883930920252021778480909919486556006811380554594516487297683826934225488"
        "790682423773195936355588056976677018678444086585699324132292531430721282958984375e-59"},
    {0x1.fffffffffffffp-193, chars_format::scientific, 187,
        "1."
        "5930919111324521001601483894334858776786184050404355696181983897311201362276110918903297459536765386845097"
        "758136484754639187271117611395335403735688817317139864826458506286144256591796875e-58"},
    {0x1.fffffffffffffp-192, chars_format::scientific, 186,
        "3."
        "1861838222649042003202967788669717553572368100808711392363967794622402724552221837806594919073530773690195"
        "51627296950927837454223522279067080747137763463427972965291701257228851318359375e-58"},
    {0x1.fffffffffffffp-191, chars_format::scientific, 185,
        "6."
        "3723676445298084006405935577339435107144736201617422784727935589244805449104443675613189838147061547380391"
        "0325459390185567490844704455813416149427552692685594593058340251445770263671875e-58"},
    {0x1.fffffffffffffp-190, chars_format::scientific, 185,
        "1."
        "2744735289059616801281187115467887021428947240323484556945587117848961089820888735122637967629412309476078"
        "2065091878037113498168940891162683229885510538537118918611668050289154052734375e-57"},
    {0x1.fffffffffffffp-189, chars_format::scientific, 184,
        "2."
        "5489470578119233602562374230935774042857894480646969113891174235697922179641777470245275935258824618952156"
        "413018375607422699633788178232536645977102107707423783722333610057830810546875e-57"},
    {0x1.fffffffffffffp-188, chars_format::scientific, 183,
        "5."
        "0978941156238467205124748461871548085715788961293938227782348471395844359283554940490551870517649237904312"
        "82603675121484539926757635646507329195420421541484756744466722011566162109375e-57"},
    {0x1.fffffffffffffp-187, chars_format::scientific, 183,
        "1."
        "0195788231247693441024949692374309617143157792258787645556469694279168871856710988098110374103529847580862"
        "56520735024296907985351527129301465839084084308296951348893344402313232421875e-56"},
    {0x1.fffffffffffffp-186, chars_format::scientific, 182,
        "2."
        "0391576462495386882049899384748619234286315584517575291112939388558337743713421976196220748207059695161725"
        "1304147004859381597070305425860293167816816861659390269778668880462646484375e-56"},
    {0x1.fffffffffffffp-185, chars_format::scientific, 181,
        "4."
        "0783152924990773764099798769497238468572631169035150582225878777116675487426843952392441496414119390323450"
        "260829400971876319414061085172058633563363372331878053955733776092529296875e-56"},
    {0x1.fffffffffffffp-184, chars_format::scientific, 180,
        "8."
        "1566305849981547528199597538994476937145262338070301164451757554233350974853687904784882992828238780646900"
        "52165880194375263882812217034411726712672674466375610791146755218505859375e-56"},
    {0x1.fffffffffffffp-183, chars_format::scientific, 180,
        "1."
        "6313261169996309505639919507798895387429052467614060232890351510846670194970737580956976598565647756129380"
        "10433176038875052776562443406882345342534534893275122158229351043701171875e-55"},
    {0x1.fffffffffffffp-182, chars_format::scientific, 179,
        "3."
        "2626522339992619011279839015597790774858104935228120465780703021693340389941475161913953197131295512258760"
        "2086635207775010555312488681376469068506906978655024431645870208740234375e-55"},
    {0x1.fffffffffffffp-181, chars_format::scientific, 178,
        "6."
        "5253044679985238022559678031195581549716209870456240931561406043386680779882950323827906394262591024517520"
        "417327041555002111062497736275293813701381395731004886329174041748046875e-55"},
    {0x1.fffffffffffffp-180, chars_format::scientific, 178,
        "1."
        "3050608935997047604511935606239116309943241974091248186312281208677336155976590064765581278852518204903504"
        "083465408311000422212499547255058762740276279146200977265834808349609375e-54"},
    {0x1.fffffffffffffp-179, chars_format::scientific, 177,
        "2."
        "6101217871994095209023871212478232619886483948182496372624562417354672311953180129531162557705036409807008"
        "16693081662200084442499909451011752548055255829240195453166961669921875e-54"},
    {0x1.fffffffffffffp-178, chars_format::scientific, 176,
        "5."
        "2202435743988190418047742424956465239772967896364992745249124834709344623906360259062325115410072819614016"
        "3338616332440016888499981890202350509611051165848039090633392333984375e-54"},
    {0x1.fffffffffffffp-177, chars_format::scientific, 176,
        "1."
        "0440487148797638083609548484991293047954593579272998549049824966941868924781272051812465023082014563922803"
        "2667723266488003377699996378040470101922210233169607818126678466796875e-53"},
    {0x1.fffffffffffffp-176, chars_format::scientific, 175,
        "2."
        "0880974297595276167219096969982586095909187158545997098099649933883737849562544103624930046164029127845606"
        "533544653297600675539999275608094020384442046633921563625335693359375e-53"},
    {0x1.fffffffffffffp-175, chars_format::scientific, 174,
        "4."
        "1761948595190552334438193939965172191818374317091994196199299867767475699125088207249860092328058255691213"
        "06708930659520135107999855121618804076888409326784312725067138671875e-53"},
    {0x1.fffffffffffffp-174, chars_format::scientific, 173,
        "8."
        "3523897190381104668876387879930344383636748634183988392398599735534951398250176414499720184656116511382426"
        "1341786131904027021599971024323760815377681865356862545013427734375e-53"},
    {0x1.fffffffffffffp-173, chars_format::scientific, 173,
        "1."
        "6704779438076220933775277575986068876727349726836797678479719947106990279650035282899944036931223302276485"
        "2268357226380805404319994204864752163075536373071372509002685546875e-52"},
    {0x1.fffffffffffffp-172, chars_format::scientific, 172,
        "3."
        "3409558876152441867550555151972137753454699453673595356959439894213980559300070565799888073862446604552970"
        "453671445276161080863998840972950432615107274614274501800537109375e-52"},
    {0x1.fffffffffffffp-171, chars_format::scientific, 171,
        "6."
        "6819117752304883735101110303944275506909398907347190713918879788427961118600141131599776147724893209105940"
        "90734289055232216172799768194590086523021454922854900360107421875e-52"},
    {0x1.fffffffffffffp-170, chars_format::scientific, 171,
        "1."
        "3363823550460976747020222060788855101381879781469438142783775957685592223720028226319955229544978641821188"
        "18146857811046443234559953638918017304604290984570980072021484375e-51"},
    {0x1.fffffffffffffp-169, chars_format::scientific, 170,
        "2."
        "6727647100921953494040444121577710202763759562938876285567551915371184447440056452639910459089957283642376"
        "3629371562209288646911990727783603460920858196914196014404296875e-51"},
    {0x1.fffffffffffffp-168, chars_format::scientific, 169,
        "5."
        "3455294201843906988080888243155420405527519125877752571135103830742368894880112905279820918179914567284752"
        "725874312441857729382398145556720692184171639382839202880859375e-51"},
    {0x1.fffffffffffffp-167, chars_format::scientific, 169,
        "1."
        "0691058840368781397616177648631084081105503825175550514227020766148473778976022581055964183635982913456950"
        "545174862488371545876479629111344138436834327876567840576171875e-50"},
    {0x1.fffffffffffffp-166, chars_format::scientific, 168,
        "2."
        "1382117680737562795232355297262168162211007650351101028454041532296947557952045162111928367271965826913901"
        "09034972497674309175295925822268827687366865575313568115234375e-50"},
    {0x1.fffffffffffffp-165, chars_format::scientific, 167,
        "4."
        "2764235361475125590464710594524336324422015300702202056908083064593895115904090324223856734543931653827802"
        "1806994499534861835059185164453765537473373115062713623046875e-50"},
    {0x1.fffffffffffffp-164, chars_format::scientific, 166,
        "8."
        "5528470722950251180929421189048672648844030601404404113816166129187790231808180648447713469087863307655604"
        "361398899906972367011837032890753107494674623012542724609375e-50"},
    {0x1.fffffffffffffp-163, chars_format::scientific, 166,
        "1."
        "7105694144590050236185884237809734529768806120280880822763233225837558046361636129689542693817572661531120"
        "872279779981394473402367406578150621498934924602508544921875e-49"},
    {0x1.fffffffffffffp-162, chars_format::scientific, 165,
        "3."
        "4211388289180100472371768475619469059537612240561761645526466451675116092723272259379085387635145323062241"
        "74455955996278894680473481315630124299786984920501708984375e-49"},
    {0x1.fffffffffffffp-161, chars_format::scientific, 164,
        "6."
        "8422776578360200944743536951238938119075224481123523291052932903350232185446544518758170775270290646124483"
        "4891191199255778936094696263126024859957396984100341796875e-49"},
    {0x1.fffffffffffffp-160, chars_format::scientific, 164,
        "1."
        "3684555315672040188948707390247787623815044896224704658210586580670046437089308903751634155054058129224896"
        "6978238239851155787218939252625204971991479396820068359375e-48"},
    {0x1.fffffffffffffp-159, chars_format::scientific, 163,
        "2."
        "7369110631344080377897414780495575247630089792449409316421173161340092874178617807503268310108116258449793"
        "395647647970231157443787850525040994398295879364013671875e-48"},
    {0x1.fffffffffffffp-158, chars_format::scientific, 162,
        "5."
        "4738221262688160755794829560991150495260179584898818632842346322680185748357235615006536620216232516899586"
        "79129529594046231488757570105008198879659175872802734375e-48"},
    {0x1.fffffffffffffp-157, chars_format::scientific, 162,
        "1."
        "0947644252537632151158965912198230099052035916979763726568469264536037149671447123001307324043246503379917"
        "35825905918809246297751514021001639775931835174560546875e-47"},
    {0x1.fffffffffffffp-156, chars_format::scientific, 161,
        "2."
        "1895288505075264302317931824396460198104071833959527453136938529072074299342894246002614648086493006759834"
        "7165181183761849259550302804200327955186367034912109375e-47"},
    {0x1.fffffffffffffp-155, chars_format::scientific, 160,
        "4."
        "3790577010150528604635863648792920396208143667919054906273877058144148598685788492005229296172986013519669"
        "433036236752369851910060560840065591037273406982421875e-47"},
    {0x1.fffffffffffffp-154, chars_format::scientific, 159,
        "8."
        "7581154020301057209271727297585840792416287335838109812547754116288297197371576984010458592345972027039338"
        "86607247350473970382012112168013118207454681396484375e-47"},
    {0x1.fffffffffffffp-153, chars_format::scientific, 159,
        "1."
        "7516230804060211441854345459517168158483257467167621962509550823257659439474315396802091718469194405407867"
        "77321449470094794076402422433602623641490936279296875e-46"},
    {0x1.fffffffffffffp-152, chars_format::scientific, 158,
        "3."
        "5032461608120422883708690919034336316966514934335243925019101646515318878948630793604183436938388810815735"
        "5464289894018958815280484486720524728298187255859375e-46"},
    {0x1.fffffffffffffp-151, chars_format::scientific, 157,
        "7."
        "0064923216240845767417381838068672633933029868670487850038203293030637757897261587208366873876777621631471"
        "092857978803791763056096897344104945659637451171875e-46"},
    {0x1.fffffffffffffp-150, chars_format::scientific, 157,
        "1."
        "4012984643248169153483476367613734526786605973734097570007640658606127551579452317441673374775355524326294"
        "218571595760758352611219379468820989131927490234375e-45"},
    {0x1.fffffffffffffp-149, chars_format::scientific, 156,
        "2."
        "8025969286496338306966952735227469053573211947468195140015281317212255103158904634883346749550711048652588"
        "43714319152151670522243875893764197826385498046875e-45"},
    {0x1.fffffffffffffp-148, chars_format::scientific, 155,
        "5."
        "6051938572992676613933905470454938107146423894936390280030562634424510206317809269766693499101422097305176"
        "8742863830430334104448775178752839565277099609375e-45"},
    {0x1.fffffffffffffp-147, chars_format::scientific, 155,
        "1."
        "1210387714598535322786781094090987621429284778987278056006112526884902041263561853953338699820284419461035"
        "3748572766086066820889755035750567913055419921875e-44"},
    {0x1.fffffffffffffp-146, chars_format::scientific, 154,
        "2."
        "2420775429197070645573562188181975242858569557974556112012225053769804082527123707906677399640568838922070"
        "749714553217213364177951007150113582611083984375e-44"},
    {0x1.fffffffffffffp-145, chars_format::scientific, 153,
        "4."
        "4841550858394141291147124376363950485717139115949112224024450107539608165054247415813354799281137677844141"
        "49942910643442672835590201430022716522216796875e-44"},
    {0x1.fffffffffffffp-144, chars_format::scientific, 152,
        "8."
        "9683101716788282582294248752727900971434278231898224448048900215079216330108494831626709598562275355688282"
        "9988582128688534567118040286004543304443359375e-44"},
    {0x1.fffffffffffffp-143, chars_format::scientific, 152,
        "1."
        "7936620343357656516458849750545580194286855646379644889609780043015843266021698966325341919712455071137656"
        "5997716425737706913423608057200908660888671875e-43"},
    {0x1.fffffffffffffp-142, chars_format::scientific, 151,
        "3."
        "5873240686715313032917699501091160388573711292759289779219560086031686532043397932650683839424910142275313"
        "199543285147541382684721611440181732177734375e-43"},
    {0x1.fffffffffffffp-141, chars_format::scientific, 150,
        "7."
        "1746481373430626065835399002182320777147422585518579558439120172063373064086795865301367678849820284550626"
        "39908657029508276536944322288036346435546875e-43"},
    {0x1.fffffffffffffp-140, chars_format::scientific, 150,
        "1."
        "4349296274686125213167079800436464155429484517103715911687824034412674612817359173060273535769964056910125"
        "27981731405901655307388864457607269287109375e-42"},
    {0x1.fffffffffffffp-139, chars_format::scientific, 149,
        "2."
        "8698592549372250426334159600872928310858969034207431823375648068825349225634718346120547071539928113820250"
        "5596346281180331061477772891521453857421875e-42"},
    {0x1.fffffffffffffp-138, chars_format::scientific, 148,
        "5."
        "7397185098744500852668319201745856621717938068414863646751296137650698451269436692241094143079856227640501"
        "119269256236066212295554578304290771484375e-42"},
    {0x1.fffffffffffffp-137, chars_format::scientific, 148,
        "1."
        "1479437019748900170533663840349171324343587613682972729350259227530139690253887338448218828615971245528100"
        "223853851247213242459110915660858154296875e-41"},
    {0x1.fffffffffffffp-136, chars_format::scientific, 147,
        "2."
        "2958874039497800341067327680698342648687175227365945458700518455060279380507774676896437657231942491056200"
        "44770770249442648491822183132171630859375e-41"},
    {0x1.fffffffffffffp-135, chars_format::scientific, 146,
        "4."
        "5917748078995600682134655361396685297374350454731890917401036910120558761015549353792875314463884982112400"
        "8954154049888529698364436626434326171875e-41"},
    {0x1.fffffffffffffp-134, chars_format::scientific, 145,
        "9."
        "1835496157991201364269310722793370594748700909463781834802073820241117522031098707585750628927769964224801"
        "790830809977705939672887325286865234375e-41"},
    {0x1.fffffffffffffp-133, chars_format::scientific, 145,
        "1."
        "8367099231598240272853862144558674118949740181892756366960414764048223504406219741517150125785553992844960"
        "358166161995541187934577465057373046875e-40"},
    {0x1.fffffffffffffp-132, chars_format::scientific, 144,
        "3."
        "6734198463196480545707724289117348237899480363785512733920829528096447008812439483034300251571107985689920"
        "71633232399108237586915493011474609375e-40"},
    {0x1.fffffffffffffp-131, chars_format::scientific, 143,
        "7."
        "3468396926392961091415448578234696475798960727571025467841659056192894017624878966068600503142215971379841"
        "4326646479821647517383098602294921875e-40"},
    {0x1.fffffffffffffp-130, chars_format::scientific, 143,
        "1."
        "4693679385278592218283089715646939295159792145514205093568331811238578803524975793213720100628443194275968"
        "2865329295964329503476619720458984375e-39"},
    {0x1.fffffffffffffp-129, chars_format::scientific, 142,
        "2."
        "9387358770557184436566179431293878590319584291028410187136663622477157607049951586427440201256886388551936"
        "573065859192865900695323944091796875e-39"},
    {0x1.fffffffffffffp-128, chars_format::scientific, 141,
        "5."
        "8774717541114368873132358862587757180639168582056820374273327244954315214099903172854880402513772777103873"
        "14613171838573180139064788818359375e-39"},
    {0x1.fffffffffffffp-127, chars_format::scientific, 141,
        "1."
        "1754943508222873774626471772517551436127833716411364074854665448990863042819980634570976080502754555420774"
        "62922634367714636027812957763671875e-38"},
    {0x1.fffffffffffffp-126, chars_format::scientific, 140,
        "2."
        "3509887016445747549252943545035102872255667432822728149709330897981726085639961269141952161005509110841549"
        "2584526873542927205562591552734375e-38"},
    {0x1.fffffffffffffp-125, chars_format::scientific, 139,
        "4."
        "7019774032891495098505887090070205744511334865645456299418661795963452171279922538283904322011018221683098"
        "516905374708585441112518310546875e-38"},
    {0x1.fffffffffffffp-124, chars_format::scientific, 138,
        "9."
        "4039548065782990197011774180140411489022669731290912598837323591926904342559845076567808644022036443366197"
        "03381074941717088222503662109375e-38"},
    {0x1.fffffffffffffp-123, chars_format::scientific, 138,
        "1."
        "8807909613156598039402354836028082297804533946258182519767464718385380868511969015313561728804407288673239"
        "40676214988343417644500732421875e-37"},
    {0x1.fffffffffffffp-122, chars_format::scientific, 137,
        "3."
        "7615819226313196078804709672056164595609067892516365039534929436770761737023938030627123457608814577346478"
        "8135242997668683528900146484375e-37"},
    {0x1.fffffffffffffp-121, chars_format::scientific, 136,
        "7."
        "5231638452626392157609419344112329191218135785032730079069858873541523474047876061254246915217629154692957"
        "627048599533736705780029296875e-37"},
    {0x1.fffffffffffffp-120, chars_format::scientific, 136,
        "1."
        "5046327690525278431521883868822465838243627157006546015813971774708304694809575212250849383043525830938591"
        "525409719906747341156005859375e-36"},
    {0x1.fffffffffffffp-119, chars_format::scientific, 135,
        "3."
        "0092655381050556863043767737644931676487254314013092031627943549416609389619150424501698766087051661877183"
        "05081943981349468231201171875e-36"},
    {0x1.fffffffffffffp-118, chars_format::scientific, 134,
        "6."
        "0185310762101113726087535475289863352974508628026184063255887098833218779238300849003397532174103323754366"
        "1016388796269893646240234375e-36"},
    {0x1.fffffffffffffp-117, chars_format::scientific, 134,
        "1."
        "2037062152420222745217507095057972670594901725605236812651177419766643755847660169800679506434820664750873"
        "2203277759253978729248046875e-35"},
    {0x1.fffffffffffffp-116, chars_format::scientific, 133,
        "2."
        "4074124304840445490435014190115945341189803451210473625302354839533287511695320339601359012869641329501746"
        "440655551850795745849609375e-35"},
    {0x1.fffffffffffffp-115, chars_format::scientific, 132,
        "4."
        "8148248609680890980870028380231890682379606902420947250604709679066575023390640679202718025739282659003492"
        "88131110370159149169921875e-35"},
    {0x1.fffffffffffffp-114, chars_format::scientific, 131,
        "9."
        "6296497219361781961740056760463781364759213804841894501209419358133150046781281358405436051478565318006985"
        "7626222074031829833984375e-35"},
    {0x1.fffffffffffffp-113, chars_format::scientific, 131,
        "1."
        "9259299443872356392348011352092756272951842760968378900241883871626630009356256271681087210295713063601397"
        "1525244414806365966796875e-34"},
    {0x1.fffffffffffffp-112, chars_format::scientific, 130,
        "3."
        "8518598887744712784696022704185512545903685521936757800483767743253260018712512543362174420591426127202794"
        "305048882961273193359375e-34"},
    {0x1.fffffffffffffp-111, chars_format::scientific, 129,
        "7."
        "7037197775489425569392045408371025091807371043873515600967535486506520037425025086724348841182852254405588"
        "61009776592254638671875e-34"},
    {0x1.fffffffffffffp-110, chars_format::scientific, 129,
        "1."
        "5407439555097885113878409081674205018361474208774703120193507097301304007485005017344869768236570450881117"
        "72201955318450927734375e-33"},
    {0x1.fffffffffffffp-109, chars_format::scientific, 128,
        "3."
        "0814879110195770227756818163348410036722948417549406240387014194602608014970010034689739536473140901762235"
        "4440391063690185546875e-33"},
    {0x1.fffffffffffffp-108, chars_format::scientific, 127,
        "6."
        "1629758220391540455513636326696820073445896835098812480774028389205216029940020069379479072946281803524470"
        "888078212738037109375e-33"},
    {0x1.fffffffffffffp-107, chars_format::scientific, 127,
        "1."
        "2325951644078308091102727265339364014689179367019762496154805677841043205988004013875895814589256360704894"
        "177615642547607421875e-32"},
    {0x1.fffffffffffffp-106, chars_format::scientific, 126,
        "2."
        "4651903288156616182205454530678728029378358734039524992309611355682086411976008027751791629178512721409788"
        "35523128509521484375e-32"},
    {0x1.fffffffffffffp-105, chars_format::scientific, 125,
        "4."
        "9303806576313232364410909061357456058756717468079049984619222711364172823952016055503583258357025442819576"
        "7104625701904296875e-32"},
    {0x1.fffffffffffffp-104, chars_format::scientific, 124,
        "9."
        "8607613152626464728821818122714912117513434936158099969238445422728345647904032111007166516714050885639153"
        "420925140380859375e-32"},
    {0x1.fffffffffffffp-103, chars_format::scientific, 124,
        "1."
        "9721522630525292945764363624542982423502686987231619993847689084545669129580806422201433303342810177127830"
        "684185028076171875e-31"},
    {0x1.fffffffffffffp-102, chars_format::scientific, 123,
        "3."
        "9443045261050585891528727249085964847005373974463239987695378169091338259161612844402866606685620354255661"
        "36837005615234375e-31"},
    {0x1.fffffffffffffp-101, chars_format::scientific, 122,
        "7."
        "8886090522101171783057454498171929694010747948926479975390756338182676518323225688805733213371240708511322"
        "7367401123046875e-31"},
    {0x1.fffffffffffffp-100, chars_format::scientific, 122,
        "1."
        "5777218104420234356611490899634385938802149589785295995078151267636535303664645137761146642674248141702264"
        "5473480224609375e-30"},
    {0x1.fffffffffffffp-99, chars_format::scientific, 121,
        "3."
        "1554436208840468713222981799268771877604299179570591990156302535273070607329290275522293285348496283404529"
        "094696044921875e-30"},
    {0x1.fffffffffffffp-98, chars_format::scientific, 120,
        "6."
        "3108872417680937426445963598537543755208598359141183980312605070546141214658580551044586570696992566809058"
        "18939208984375e-30"},
    {0x1.fffffffffffffp-97, chars_format::scientific, 120,
        "1."
        "2621774483536187485289192719707508751041719671828236796062521014109228242931716110208917314139398513361811"
        "63787841796875e-29"},
    {0x1.fffffffffffffp-96, chars_format::scientific, 119,
        "2."
        "5243548967072374970578385439415017502083439343656473592125042028218456485863432220417834628278797026723623"
        "2757568359375e-29"},
    {0x1.fffffffffffffp-95, chars_format::scientific, 118,
        "5."
        "0487097934144749941156770878830035004166878687312947184250084056436912971726864440835669256557594053447246"
        "551513671875e-29"},
    {0x1.fffffffffffffp-94, chars_format::scientific, 118,
        "1."
        "0097419586828949988231354175766007000833375737462589436850016811287382594345372888167133851311518810689449"
        "310302734375e-28"},
    {0x1.fffffffffffffp-93, chars_format::scientific, 117,
        "2."
        "0194839173657899976462708351532014001666751474925178873700033622574765188690745776334267702623037621378898"
        "62060546875e-28"},
    {0x1.fffffffffffffp-92, chars_format::scientific, 116,
        "4."
        "0389678347315799952925416703064028003333502949850357747400067245149530377381491552668535405246075242757797"
        "2412109375e-28"},
    {0x1.fffffffffffffp-91, chars_format::scientific, 115,
        "8."
        "0779356694631599905850833406128056006667005899700715494800134490299060754762983105337070810492150485515594"
        "482421875e-28"},
    {0x1.fffffffffffffp-90, chars_format::scientific, 115,
        "1."
        "6155871338926319981170166681225611201333401179940143098960026898059812150952596621067414162098430097103118"
        "896484375e-27"},
    {0x1.fffffffffffffp-89, chars_format::scientific, 114,
        "3."
        "2311742677852639962340333362451222402666802359880286197920053796119624301905193242134828324196860194206237"
        "79296875e-27"},
    {0x1.fffffffffffffp-88, chars_format::scientific, 113,
        "6."
        "4623485355705279924680666724902444805333604719760572395840107592239248603810386484269656648393720388412475"
        "5859375e-27"},
    {0x1.fffffffffffffp-87, chars_format::scientific, 113,
        "1."
        "2924697071141055984936133344980488961066720943952114479168021518447849720762077296853931329678744077682495"
        "1171875e-26"},
    {0x1.fffffffffffffp-86, chars_format::scientific, 112,
        "2."
        "5849394142282111969872266689960977922133441887904228958336043036895699441524154593707862659357488155364990"
        "234375e-26"},
    {0x1.fffffffffffffp-85, chars_format::scientific, 111,
        "5."
        "1698788284564223939744533379921955844266883775808457916672086073791398883048309187415725318714976310729980"
        "46875e-26"},
    {0x1.fffffffffffffp-84, chars_format::scientific, 111,
        "1."
        "0339757656912844787948906675984391168853376755161691583334417214758279776609661837483145063742995262145996"
        "09375e-25"},
    {0x1.fffffffffffffp-83, chars_format::scientific, 110,
        "2."
        "0679515313825689575897813351968782337706753510323383166668834429516559553219323674966290127485990524291992"
        "1875e-25"},
    {0x1.fffffffffffffp-82, chars_format::scientific, 109,
        "4."
        "1359030627651379151795626703937564675413507020646766333337668859033119106438647349932580254971981048583984"
        "375e-25"},
    {0x1.fffffffffffffp-81, chars_format::scientific, 108,
        "8."
        "2718061255302758303591253407875129350827014041293532666675337718066238212877294699865160509943962097167968"
        "75e-25"},
    {0x1.fffffffffffffp-80, chars_format::scientific, 108,
        "1."
        "6543612251060551660718250681575025870165402808258706533335067543613247642575458939973032101988792419433593"
        "75e-24"},
    {0x1.fffffffffffffp-79, chars_format::scientific, 107,
        "3."
        "3087224502121103321436501363150051740330805616517413066670135087226495285150917879946064203977584838867187"
        "5e-24"},
    {0x1.fffffffffffffp-78, chars_format::scientific, 106,
        "6."
        "6174449004242206642873002726300103480661611233034826133340270174452990570301835759892128407955169677734375"
        "e-24"},
    {0x1.fffffffffffffp-77, chars_format::scientific, 106,
        "1."
        "3234889800848441328574600545260020696132322246606965226668054034890598114060367151978425681591033935546875"
        "e-23"},
    {0x1.fffffffffffffp-76, chars_format::scientific, 105,
        "2."
        "646977960169688265714920109052004139226464449321393045333610806978119622812073430395685136318206787109375e"
        "-23"},
    {0x1.fffffffffffffp-75, chars_format::scientific, 104,
        "5."
        "29395592033937653142984021810400827845292889864278609066722161395623924562414686079137027263641357421875e-"
        "23"},
    {0x1.fffffffffffffp-74, chars_format::scientific, 104,
        "1."
        "05879118406787530628596804362080165569058577972855721813344432279124784912482937215827405452728271484375e-"
        "22"},
    {0x1.fffffffffffffp-73, chars_format::scientific, 103,
        "2."
        "1175823681357506125719360872416033113811715594571144362668886455824956982496587443165481090545654296875e-"
        "22"},
    {0x1.fffffffffffffp-72, chars_format::scientific, 102,
        "4.235164736271501225143872174483206622762343118914228872533777291164991396499317488633096218109130859375e-"
        "22"},
    {0x1.fffffffffffffp-71, chars_format::scientific, 101,
        "8.47032947254300245028774434896641324552468623782845774506755458232998279299863497726619243621826171875e-"
        "22"},
    {0x1.fffffffffffffp-70, chars_format::scientific, 101,
        "1.69406589450860049005754886979328264910493724756569154901351091646599655859972699545323848724365234375e-"
        "21"},
    {0x1.fffffffffffffp-69, chars_format::scientific, 100,
        "3.3881317890172009801150977395865652982098744951313830980270218329319931171994539909064769744873046875e-"
        "21"},
    {0x1.fffffffffffffp-68, chars_format::scientific, 99,
        "6.776263578034401960230195479173130596419748990262766196054043665863986234398907981812953948974609375e-"
        "21"},
    {0x1.fffffffffffffp-67, chars_format::scientific, 99,
        "1.355252715606880392046039095834626119283949798052553239210808733172797246879781596362590789794921875e-"
        "20"},
    {0x1.fffffffffffffp-66, chars_format::scientific, 98,
        "2.71050543121376078409207819166925223856789959610510647842161746634559449375956319272518157958984375e-20"},
    {0x1.fffffffffffffp-65, chars_format::scientific, 97,
        "5.4210108624275215681841563833385044771357991922102129568432349326911889875191263854503631591796875e-20"},
    {0x1.fffffffffffffp-64, chars_format::scientific, 97,
        "1.0842021724855043136368312766677008954271598384420425913686469865382377975038252770900726318359375e-19"},
    {0x1.fffffffffffffp-63, chars_format::scientific, 96,
        "2.168404344971008627273662553335401790854319676884085182737293973076475595007650554180145263671875e-19"},
    {0x1.fffffffffffffp-62, chars_format::scientific, 95,
        "4.33680868994201725454732510667080358170863935376817036547458794615295119001530110836029052734375e-19"},
    {0x1.fffffffffffffp-61, chars_format::scientific, 94,
        "8.6736173798840345090946502133416071634172787075363407309491758923059023800306022167205810546875e-19"},
    {0x1.fffffffffffffp-60, chars_format::scientific, 94,
        "1.7347234759768069018189300426683214326834557415072681461898351784611804760061204433441162109375e-18"},
    {0x1.fffffffffffffp-59, chars_format::scientific, 93,
        "3.469446951953613803637860085336642865366911483014536292379670356922360952012240886688232421875e-18"},
    {0x1.fffffffffffffp-58, chars_format::scientific, 92,
        "6.93889390390722760727572017067328573073382296602907258475934071384472190402448177337646484375e-18"},
    {0x1.fffffffffffffp-57, chars_format::scientific, 92,
        "1.38777878078144552145514403413465714614676459320581451695186814276894438080489635467529296875e-17"},
    {0x1.fffffffffffffp-56, chars_format::scientific, 91,
        "2.7755575615628910429102880682693142922935291864116290339037362855378887616097927093505859375e-17"},
    {0x1.fffffffffffffp-55, chars_format::scientific, 90,
        "5.551115123125782085820576136538628584587058372823258067807472571075777523219585418701171875e-17"},
    {0x1.fffffffffffffp-54, chars_format::scientific, 90,
        "1.110223024625156417164115227307725716917411674564651613561494514215155504643917083740234375e-16"},
    {0x1.fffffffffffffp-53, chars_format::scientific, 89,
        "2.22044604925031283432823045461545143383482334912930322712298902843031100928783416748046875e-16"},
    {0x1.fffffffffffffp-52, chars_format::scientific, 88,
        "4.4408920985006256686564609092309028676696466982586064542459780568606220185756683349609375e-16"},
    {0x1.fffffffffffffp-51, chars_format::scientific, 87,
        "8.881784197001251337312921818461805735339293396517212908491956113721244037151336669921875e-16"},
    {0x1.fffffffffffffp-50, chars_format::scientific, 87,
        "1.776356839400250267462584363692361147067858679303442581698391222744248807430267333984375e-15"},
    {0x1.fffffffffffffp-49, chars_format::scientific, 86,
        "3.55271367880050053492516872738472229413571735860688516339678244548849761486053466796875e-15"},
    {0x1.fffffffffffffp-48, chars_format::scientific, 85,
        "7.1054273576010010698503374547694445882714347172137703267935648909769952297210693359375e-15"},
    {0x1.fffffffffffffp-47, chars_format::scientific, 85,
        "1.4210854715202002139700674909538889176542869434427540653587129781953990459442138671875e-14"},
    {0x1.fffffffffffffp-46, chars_format::scientific, 84,
        "2.842170943040400427940134981907777835308573886885508130717425956390798091888427734375e-14"},
    {0x1.fffffffffffffp-45, chars_format::scientific, 83,
        "5.68434188608080085588026996381555567061714777377101626143485191278159618377685546875e-14"},
    {0x1.fffffffffffffp-44, chars_format::scientific, 83,
        "1.13686837721616017117605399276311113412342955475420325228697038255631923675537109375e-13"},
    {0x1.fffffffffffffp-43, chars_format::scientific, 82,
        "2.2737367544323203423521079855262222682468591095084065045739407651126384735107421875e-13"},
    {0x1.fffffffffffffp-42, chars_format::scientific, 81,
        "4.547473508864640684704215971052444536493718219016813009147881530225276947021484375e-13"},
    {0x1.fffffffffffffp-41, chars_format::scientific, 80,
        "9.09494701772928136940843194210488907298743643803362601829576306045055389404296875e-13"},
    {0x1.fffffffffffffp-40, chars_format::scientific, 80,
        "1.81898940354585627388168638842097781459748728760672520365915261209011077880859375e-12"},
    {0x1.fffffffffffffp-39, chars_format::scientific, 79,
        "3.6379788070917125477633727768419556291949745752134504073183052241802215576171875e-12"},
    {0x1.fffffffffffffp-38, chars_format::scientific, 78,
        "7.275957614183425095526745553683911258389949150426900814636610448360443115234375e-12"},
    {0x1.fffffffffffffp-37, chars_format::scientific, 78,
        "1.455191522836685019105349110736782251677989830085380162927322089672088623046875e-11"},
    {0x1.fffffffffffffp-36, chars_format::scientific, 77,
        "2.91038304567337003821069822147356450335597966017076032585464417934417724609375e-11"},
    {0x1.fffffffffffffp-35, chars_format::scientific, 76,
        "5.8207660913467400764213964429471290067119593203415206517092883586883544921875e-11"},
    {0x1.fffffffffffffp-34, chars_format::scientific, 76,
        "1.1641532182693480152842792885894258013423918640683041303418576717376708984375e-10"},
    {0x1.fffffffffffffp-33, chars_format::scientific, 75,
        "2.328306436538696030568558577178851602684783728136608260683715343475341796875e-10"},
    {0x1.fffffffffffffp-32, chars_format::scientific, 74,
        "4.65661287307739206113711715435770320536956745627321652136743068695068359375e-10"},
    {0x1.fffffffffffffp-31, chars_format::scientific, 73,
        "9.3132257461547841222742343087154064107391349125464330427348613739013671875e-10"},
    {0x1.fffffffffffffp-30, chars_format::scientific, 73,
        "1.8626451492309568244548468617430812821478269825092866085469722747802734375e-09"},
    {0x1.fffffffffffffp-29, chars_format::scientific, 72,
        "3.725290298461913648909693723486162564295653965018573217093944549560546875e-09"},
    {0x1.fffffffffffffp-28, chars_format::scientific, 71,
        "7.45058059692382729781938744697232512859130793003714643418788909912109375e-09"},
    {0x1.fffffffffffffp-27, chars_format::scientific, 71,
        "1.49011611938476545956387748939446502571826158600742928683757781982421875e-08"},
    {0x1.fffffffffffffp-26, chars_format::scientific, 70,
        "2.9802322387695309191277549787889300514365231720148585736751556396484375e-08"},
    {0x1.fffffffffffffp-25, chars_format::scientific, 69,
        "5.960464477539061838255509957577860102873046344029717147350311279296875e-08"},
    {0x1.fffffffffffffp-24, chars_format::scientific, 69,
        "1.192092895507812367651101991515572020574609268805943429470062255859375e-07"},
    {0x1.fffffffffffffp-23, chars_format::scientific, 68,
        "2.38418579101562473530220398303114404114921853761188685894012451171875e-07"},
    {0x1.fffffffffffffp-22, chars_format::scientific, 67,
        "4.7683715820312494706044079660622880822984370752237737178802490234375e-07"},
    {0x1.fffffffffffffp-21, chars_format::scientific, 66,
        "9.536743164062498941208815932124576164596874150447547435760498046875e-07"},
    {0x1.fffffffffffffp-20, chars_format::scientific, 66,
        "1.907348632812499788241763186424915232919374830089509487152099609375e-06"},
    {0x1.fffffffffffffp-19, chars_format::scientific, 65,
        "3.81469726562499957648352637284983046583874966017901897430419921875e-06"},
    {0x1.fffffffffffffp-18, chars_format::scientific, 64,
        "7.6293945312499991529670527456996609316774993203580379486083984375e-06"},
    {0x1.fffffffffffffp-17, chars_format::scientific, 64,
        "1.5258789062499998305934105491399321863354998640716075897216796875e-05"},
    {0x1.fffffffffffffp-16, chars_format::scientific, 63,
        "3.051757812499999661186821098279864372670999728143215179443359375e-05"},
    {0x1.fffffffffffffp-15, chars_format::scientific, 62,
        "6.10351562499999932237364219655972874534199945628643035888671875e-05"},
    {0x1.fffffffffffffp-14, chars_format::scientific, 62,
        "1.22070312499999986447472843931194574906839989125728607177734375e-04"},
    {0x1.fffffffffffffp-13, chars_format::scientific, 61,
        "2.4414062499999997289494568786238914981367997825145721435546875e-04"},
    {0x1.fffffffffffffp-12, chars_format::scientific, 60,
        "4.882812499999999457898913757247782996273599565029144287109375e-04"},
    {0x1.fffffffffffffp-11, chars_format::scientific, 59,
        "9.76562499999999891579782751449556599254719913005828857421875e-04"},
    {0x1.fffffffffffffp-10, chars_format::scientific, 59,
        "1.95312499999999978315956550289911319850943982601165771484375e-03"},
    {0x1.fffffffffffffp-9, chars_format::scientific, 58,
        "3.9062499999999995663191310057982263970188796520233154296875e-03"},
    {0x1.fffffffffffffp-8, chars_format::scientific, 57,
        "7.812499999999999132638262011596452794037759304046630859375e-03"},
    {0x1.fffffffffffffp-7, chars_format::scientific, 57,
        "1.562499999999999826527652402319290558807551860809326171875e-02"},
    {0x1.fffffffffffffp-6, chars_format::scientific, 56,
        "3.12499999999999965305530480463858111761510372161865234375e-02"},
    {0x1.fffffffffffffp-5, chars_format::scientific, 55,
        "6.2499999999999993061106096092771622352302074432373046875e-02"},
    {0x1.fffffffffffffp-4, chars_format::scientific, 55,
        "1.2499999999999998612221219218554324470460414886474609375e-01"},
    {0x1.fffffffffffffp-3, chars_format::scientific, 54,
        "2.499999999999999722444243843710864894092082977294921875e-01"},
    {0x1.fffffffffffffp-2, chars_format::scientific, 53, "4.99999999999999944488848768742172978818416595458984375e-01"},
    {0x1.fffffffffffffp-1, chars_format::scientific, 52, "9.9999999999999988897769753748434595763683319091796875e-01"},
    {0x1.fffffffffffffp+0, chars_format::scientific, 52, "1.9999999999999997779553950749686919152736663818359375e+00"},
    {0x1.fffffffffffffp+1, chars_format::scientific, 51, "3.999999999999999555910790149937383830547332763671875e+00"},
    {0x1.fffffffffffffp+2, chars_format::scientific, 50, "7.99999999999999911182158029987476766109466552734375e+00"},
    {0x1.fffffffffffffp+3, chars_format::scientific, 50, "1.59999999999999982236431605997495353221893310546875e+01"},
    {0x1.fffffffffffffp+4, chars_format::scientific, 49, "3.1999999999999996447286321199499070644378662109375e+01"},
    {0x1.fffffffffffffp+5, chars_format::scientific, 48, "6.399999999999999289457264239899814128875732421875e+01"},
    {0x1.fffffffffffffp+6, chars_format::scientific, 48, "1.279999999999999857891452847979962825775146484375e+02"},
    {0x1.fffffffffffffp+7, chars_format::scientific, 47, "2.55999999999999971578290569595992565155029296875e+02"},
    {0x1.fffffffffffffp+8, chars_format::scientific, 46, "5.1199999999999994315658113919198513031005859375e+02"},
    {0x1.fffffffffffffp+9, chars_format::scientific, 46, "1.0239999999999998863131622783839702606201171875e+03"},
    {0x1.fffffffffffffp+10, chars_format::scientific, 45, "2.047999999999999772626324556767940521240234375e+03"},
    {0x1.fffffffffffffp+11, chars_format::scientific, 44, "4.09599999999999954525264911353588104248046875e+03"},
    {0x1.fffffffffffffp+12, chars_format::scientific, 43, "8.1919999999999990905052982270717620849609375e+03"},
    {0x1.fffffffffffffp+13, chars_format::scientific, 43, "1.6383999999999998181010596454143524169921875e+04"},
    {0x1.fffffffffffffp+14, chars_format::scientific, 42, "3.276799999999999636202119290828704833984375e+04"},
    {0x1.fffffffffffffp+15, chars_format::scientific, 41, "6.55359999999999927240423858165740966796875e+04"},
    {0x1.fffffffffffffp+16, chars_format::scientific, 41, "1.31071999999999985448084771633148193359375e+05"},
    {0x1.fffffffffffffp+17, chars_format::scientific, 40, "2.6214399999999997089616954326629638671875e+05"},
    {0x1.fffffffffffffp+18, chars_format::scientific, 39, "5.242879999999999417923390865325927734375e+05"},
    {0x1.fffffffffffffp+19, chars_format::scientific, 39, "1.048575999999999883584678173065185546875e+06"},
    {0x1.fffffffffffffp+20, chars_format::scientific, 38, "2.09715199999999976716935634613037109375e+06"},
    {0x1.fffffffffffffp+21, chars_format::scientific, 37, "4.1943039999999995343387126922607421875e+06"},
    {0x1.fffffffffffffp+22, chars_format::scientific, 36, "8.388607999999999068677425384521484375e+06"},
    {0x1.fffffffffffffp+23, chars_format::scientific, 36, "1.677721599999999813735485076904296875e+07"},
    {0x1.fffffffffffffp+24, chars_format::scientific, 35, "3.35544319999999962747097015380859375e+07"},
    {0x1.fffffffffffffp+25, chars_format::scientific, 34, "6.7108863999999992549419403076171875e+07"},
    {0x1.fffffffffffffp+26, chars_format::scientific, 34, "1.3421772799999998509883880615234375e+08"},
    {0x1.fffffffffffffp+27, chars_format::scientific, 33, "2.684354559999999701976776123046875e+08"},
    {0x1.fffffffffffffp+28, chars_format::scientific, 32, "5.36870911999999940395355224609375e+08"},
    {0x1.fffffffffffffp+29, chars_format::scientific, 32, "1.07374182399999988079071044921875e+09"},
    {0x1.fffffffffffffp+30, chars_format::scientific, 31, "2.1474836479999997615814208984375e+09"},
    {0x1.fffffffffffffp+31, chars_format::scientific, 30, "4.294967295999999523162841796875e+09"},
    {0x1.fffffffffffffp+32, chars_format::scientific, 29, "8.58993459199999904632568359375e+09"},
    {0x1.fffffffffffffp+33, chars_format::scientific, 29, "1.71798691839999980926513671875e+10"},
    {0x1.fffffffffffffp+34, chars_format::scientific, 28, "3.4359738367999996185302734375e+10"},
    {0x1.fffffffffffffp+35, chars_format::scientific, 27, "6.871947673599999237060546875e+10"},
    {0x1.fffffffffffffp+36, chars_format::scientific, 27, "1.374389534719999847412109375e+11"},
    {0x1.fffffffffffffp+37, chars_format::scientific, 26, "2.74877906943999969482421875e+11"},
    {0x1.fffffffffffffp+38, chars_format::scientific, 25, "5.4975581388799993896484375e+11"},
    {0x1.fffffffffffffp+39, chars_format::scientific, 25, "1.0995116277759998779296875e+12"},
    {0x1.fffffffffffffp+40, chars_format::scientific, 24, "2.199023255551999755859375e+12"},
    {0x1.fffffffffffffp+41, chars_format::scientific, 23, "4.39804651110399951171875e+12"},
    {0x1.fffffffffffffp+42, chars_format::scientific, 22, "8.7960930222079990234375e+12"},
    {0x1.fffffffffffffp+43, chars_format::scientific, 22, "1.7592186044415998046875e+13"},
    {0x1.fffffffffffffp+44, chars_format::scientific, 21, "3.518437208883199609375e+13"},
    {0x1.fffffffffffffp+45, chars_format::scientific, 20, "7.03687441776639921875e+13"},
    {0x1.fffffffffffffp+46, chars_format::scientific, 20, "1.40737488355327984375e+14"},
    {0x1.fffffffffffffp+47, chars_format::scientific, 19, "2.8147497671065596875e+14"},
    {0x1.fffffffffffffp+48, chars_format::scientific, 18, "5.629499534213119375e+14"},
    {0x1.fffffffffffffp+49, chars_format::scientific, 18, "1.125899906842623875e+15"},
    {0x1.fffffffffffffp+50, chars_format::scientific, 17, "2.25179981368524775e+15"},
    {0x1.fffffffffffffp+51, chars_format::scientific, 16, "4.5035996273704955e+15"},
    {0x1.fffffffffffffp+52, chars_format::scientific, 15, "9.007199254740991e+15"},
    {0x1.fffffffffffffp+53, chars_format::scientific, 16, "1.8014398509481982e+16"},
    {0x1.fffffffffffffp+54, chars_format::scientific, 16, "3.6028797018963964e+16"},
    {0x1.fffffffffffffp+55, chars_format::scientific, 16, "7.2057594037927928e+16"},
    {0x1.fffffffffffffp+56, chars_format::scientific, 17, "1.44115188075855856e+17"},
    {0x1.fffffffffffffp+57, chars_format::scientific, 17, "2.88230376151711712e+17"},
    {0x1.fffffffffffffp+58, chars_format::scientific, 17, "5.76460752303423424e+17"},
    {0x1.fffffffffffffp+59, chars_format::scientific, 18, "1.152921504606846848e+18"},
    {0x1.fffffffffffffp+60, chars_format::scientific, 18, "2.305843009213693696e+18"},
    {0x1.fffffffffffffp+61, chars_format::scientific, 18, "4.611686018427387392e+18"},
    {0x1.fffffffffffffp+62, chars_format::scientific, 18, "9.223372036854774784e+18"},
    {0x1.fffffffffffffp+63, chars_format::scientific, 19, "1.8446744073709549568e+19"},
    {0x1.fffffffffffffp+64, chars_format::scientific, 19, "3.6893488147419099136e+19"},
    {0x1.fffffffffffffp+65, chars_format::scientific, 19, "7.3786976294838198272e+19"},
    {0x1.fffffffffffffp+66, chars_format::scientific, 20, "1.47573952589676396544e+20"},
    {0x1.fffffffffffffp+67, chars_format::scientific, 20, "2.95147905179352793088e+20"},
    {0x1.fffffffffffffp+68, chars_format::scientific, 20, "5.90295810358705586176e+20"},
    {0x1.fffffffffffffp+69, chars_format::scientific, 21, "1.180591620717411172352e+21"},
    {0x1.fffffffffffffp+70, chars_format::scientific, 21, "2.361183241434822344704e+21"},
    {0x1.fffffffffffffp+71, chars_format::scientific, 21, "4.722366482869644689408e+21"},
    {0x1.fffffffffffffp+72, chars_format::scientific, 21, "9.444732965739289378816e+21"},
    {0x1.fffffffffffffp+73, chars_format::scientific, 22, "1.8889465931478578757632e+22"},
    {0x1.fffffffffffffp+74, chars_format::scientific, 22, "3.7778931862957157515264e+22"},
    {0x1.fffffffffffffp+75, chars_format::scientific, 22, "7.5557863725914315030528e+22"},
    {0x1.fffffffffffffp+76, chars_format::scientific, 23, "1.51115727451828630061056e+23"},
    {0x1.fffffffffffffp+77, chars_format::scientific, 23, "3.02231454903657260122112e+23"},
    {0x1.fffffffffffffp+78, chars_format::scientific, 23, "6.04462909807314520244224e+23"},
    {0x1.fffffffffffffp+79, chars_format::scientific, 24, "1.208925819614629040488448e+24"},
    {0x1.fffffffffffffp+80, chars_format::scientific, 24, "2.417851639229258080976896e+24"},
    {0x1.fffffffffffffp+81, chars_format::scientific, 24, "4.835703278458516161953792e+24"},
    {0x1.fffffffffffffp+82, chars_format::scientific, 24, "9.671406556917032323907584e+24"},
    {0x1.fffffffffffffp+83, chars_format::scientific, 25, "1.9342813113834064647815168e+25"},
    {0x1.fffffffffffffp+84, chars_format::scientific, 25, "3.8685626227668129295630336e+25"},
    {0x1.fffffffffffffp+85, chars_format::scientific, 25, "7.7371252455336258591260672e+25"},
    {0x1.fffffffffffffp+86, chars_format::scientific, 26, "1.54742504910672517182521344e+26"},
    {0x1.fffffffffffffp+87, chars_format::scientific, 26, "3.09485009821345034365042688e+26"},
    {0x1.fffffffffffffp+88, chars_format::scientific, 26, "6.18970019642690068730085376e+26"},
    {0x1.fffffffffffffp+89, chars_format::scientific, 27, "1.237940039285380137460170752e+27"},
    {0x1.fffffffffffffp+90, chars_format::scientific, 27, "2.475880078570760274920341504e+27"},
    {0x1.fffffffffffffp+91, chars_format::scientific, 27, "4.951760157141520549840683008e+27"},
    {0x1.fffffffffffffp+92, chars_format::scientific, 27, "9.903520314283041099681366016e+27"},
    {0x1.fffffffffffffp+93, chars_format::scientific, 28, "1.9807040628566082199362732032e+28"},
    {0x1.fffffffffffffp+94, chars_format::scientific, 28, "3.9614081257132164398725464064e+28"},
    {0x1.fffffffffffffp+95, chars_format::scientific, 28, "7.9228162514264328797450928128e+28"},
    {0x1.fffffffffffffp+96, chars_format::scientific, 29, "1.58456325028528657594901856256e+29"},
    {0x1.fffffffffffffp+97, chars_format::scientific, 29, "3.16912650057057315189803712512e+29"},
    {0x1.fffffffffffffp+98, chars_format::scientific, 29, "6.33825300114114630379607425024e+29"},
    {0x1.fffffffffffffp+99, chars_format::scientific, 30, "1.267650600228229260759214850048e+30"},
    {0x1.fffffffffffffp+100, chars_format::scientific, 30, "2.535301200456458521518429700096e+30"},
    {0x1.fffffffffffffp+101, chars_format::scientific, 30, "5.070602400912917043036859400192e+30"},
    {0x1.fffffffffffffp+102, chars_format::scientific, 31, "1.0141204801825834086073718800384e+31"},
    {0x1.fffffffffffffp+103, chars_format::scientific, 31, "2.0282409603651668172147437600768e+31"},
    {0x1.fffffffffffffp+104, chars_format::scientific, 31, "4.0564819207303336344294875201536e+31"},
    {0x1.fffffffffffffp+105, chars_format::scientific, 31, "8.1129638414606672688589750403072e+31"},
    {0x1.fffffffffffffp+106, chars_format::scientific, 32, "1.62259276829213345377179500806144e+32"},
    {0x1.fffffffffffffp+107, chars_format::scientific, 32, "3.24518553658426690754359001612288e+32"},
    {0x1.fffffffffffffp+108, chars_format::scientific, 32, "6.49037107316853381508718003224576e+32"},
    {0x1.fffffffffffffp+109, chars_format::scientific, 33, "1.298074214633706763017436006449152e+33"},
    {0x1.fffffffffffffp+110, chars_format::scientific, 33, "2.596148429267413526034872012898304e+33"},
    {0x1.fffffffffffffp+111, chars_format::scientific, 33, "5.192296858534827052069744025796608e+33"},
    {0x1.fffffffffffffp+112, chars_format::scientific, 34, "1.0384593717069654104139488051593216e+34"},
    {0x1.fffffffffffffp+113, chars_format::scientific, 34, "2.0769187434139308208278976103186432e+34"},
    {0x1.fffffffffffffp+114, chars_format::scientific, 34, "4.1538374868278616416557952206372864e+34"},
    {0x1.fffffffffffffp+115, chars_format::scientific, 34, "8.3076749736557232833115904412745728e+34"},
    {0x1.fffffffffffffp+116, chars_format::scientific, 35, "1.66153499473114465666231808825491456e+35"},
    {0x1.fffffffffffffp+117, chars_format::scientific, 35, "3.32306998946228931332463617650982912e+35"},
    {0x1.fffffffffffffp+118, chars_format::scientific, 35, "6.64613997892457862664927235301965824e+35"},
    {0x1.fffffffffffffp+119, chars_format::scientific, 36, "1.329227995784915725329854470603931648e+36"},
    {0x1.fffffffffffffp+120, chars_format::scientific, 36, "2.658455991569831450659708941207863296e+36"},
    {0x1.fffffffffffffp+121, chars_format::scientific, 36, "5.316911983139662901319417882415726592e+36"},
    {0x1.fffffffffffffp+122, chars_format::scientific, 37, "1.0633823966279325802638835764831453184e+37"},
    {0x1.fffffffffffffp+123, chars_format::scientific, 37, "2.1267647932558651605277671529662906368e+37"},
    {0x1.fffffffffffffp+124, chars_format::scientific, 37, "4.2535295865117303210555343059325812736e+37"},
    {0x1.fffffffffffffp+125, chars_format::scientific, 37, "8.5070591730234606421110686118651625472e+37"},
    {0x1.fffffffffffffp+126, chars_format::scientific, 38, "1.70141183460469212842221372237303250944e+38"},
    {0x1.fffffffffffffp+127, chars_format::scientific, 38, "3.40282366920938425684442744474606501888e+38"},
    {0x1.fffffffffffffp+128, chars_format::scientific, 38, "6.80564733841876851368885488949213003776e+38"},
    {0x1.fffffffffffffp+129, chars_format::scientific, 39, "1.361129467683753702737770977898426007552e+39"},
    {0x1.fffffffffffffp+130, chars_format::scientific, 39, "2.722258935367507405475541955796852015104e+39"},
    {0x1.fffffffffffffp+131, chars_format::scientific, 39, "5.444517870735014810951083911593704030208e+39"},
    {0x1.fffffffffffffp+132, chars_format::scientific, 40, "1.0889035741470029621902167823187408060416e+40"},
    {0x1.fffffffffffffp+133, chars_format::scientific, 40, "2.1778071482940059243804335646374816120832e+40"},
    {0x1.fffffffffffffp+134, chars_format::scientific, 40, "4.3556142965880118487608671292749632241664e+40"},
    {0x1.fffffffffffffp+135, chars_format::scientific, 40, "8.7112285931760236975217342585499264483328e+40"},
    {0x1.fffffffffffffp+136, chars_format::scientific, 41, "1.74224571863520473950434685170998528966656e+41"},
    {0x1.fffffffffffffp+137, chars_format::scientific, 41, "3.48449143727040947900869370341997057933312e+41"},
    {0x1.fffffffffffffp+138, chars_format::scientific, 41, "6.96898287454081895801738740683994115866624e+41"},
    {0x1.fffffffffffffp+139, chars_format::scientific, 42, "1.393796574908163791603477481367988231733248e+42"},
    {0x1.fffffffffffffp+140, chars_format::scientific, 42, "2.787593149816327583206954962735976463466496e+42"},
    {0x1.fffffffffffffp+141, chars_format::scientific, 42, "5.575186299632655166413909925471952926932992e+42"},
    {0x1.fffffffffffffp+142, chars_format::scientific, 43, "1.1150372599265310332827819850943905853865984e+43"},
    {0x1.fffffffffffffp+143, chars_format::scientific, 43, "2.2300745198530620665655639701887811707731968e+43"},
    {0x1.fffffffffffffp+144, chars_format::scientific, 43, "4.4601490397061241331311279403775623415463936e+43"},
    {0x1.fffffffffffffp+145, chars_format::scientific, 43, "8.9202980794122482662622558807551246830927872e+43"},
    {0x1.fffffffffffffp+146, chars_format::scientific, 44, "1.78405961588244965325245117615102493661855744e+44"},
    {0x1.fffffffffffffp+147, chars_format::scientific, 44, "3.56811923176489930650490235230204987323711488e+44"},
    {0x1.fffffffffffffp+148, chars_format::scientific, 44, "7.13623846352979861300980470460409974647422976e+44"},
    {0x1.fffffffffffffp+149, chars_format::scientific, 45, "1.427247692705959722601960940920819949294845952e+45"},
    {0x1.fffffffffffffp+150, chars_format::scientific, 45, "2.854495385411919445203921881841639898589691904e+45"},
    {0x1.fffffffffffffp+151, chars_format::scientific, 45, "5.708990770823838890407843763683279797179383808e+45"},
    {0x1.fffffffffffffp+152, chars_format::scientific, 46, "1.1417981541647677780815687527366559594358767616e+46"},
    {0x1.fffffffffffffp+153, chars_format::scientific, 46, "2.2835963083295355561631375054733119188717535232e+46"},
    {0x1.fffffffffffffp+154, chars_format::scientific, 46, "4.5671926166590711123262750109466238377435070464e+46"},
    {0x1.fffffffffffffp+155, chars_format::scientific, 46, "9.1343852333181422246525500218932476754870140928e+46"},
    {0x1.fffffffffffffp+156, chars_format::scientific, 47, "1.82687704666362844493051000437864953509740281856e+47"},
    {0x1.fffffffffffffp+157, chars_format::scientific, 47, "3.65375409332725688986102000875729907019480563712e+47"},
    {0x1.fffffffffffffp+158, chars_format::scientific, 47, "7.30750818665451377972204001751459814038961127424e+47"},
    {0x1.fffffffffffffp+159, chars_format::scientific, 48, "1.461501637330902755944408003502919628077922254848e+48"},
    {0x1.fffffffffffffp+160, chars_format::scientific, 48, "2.923003274661805511888816007005839256155844509696e+48"},
    {0x1.fffffffffffffp+161, chars_format::scientific, 48, "5.846006549323611023777632014011678512311689019392e+48"},
    {0x1.fffffffffffffp+162, chars_format::scientific, 49, "1.1692013098647222047555264028023357024623378038784e+49"},
    {0x1.fffffffffffffp+163, chars_format::scientific, 49, "2.3384026197294444095110528056046714049246756077568e+49"},
    {0x1.fffffffffffffp+164, chars_format::scientific, 49, "4.6768052394588888190221056112093428098493512155136e+49"},
    {0x1.fffffffffffffp+165, chars_format::scientific, 49, "9.3536104789177776380442112224186856196987024310272e+49"},
    {0x1.fffffffffffffp+166, chars_format::scientific, 50, "1.87072209578355552760884224448373712393974048620544e+50"},
    {0x1.fffffffffffffp+167, chars_format::scientific, 50, "3.74144419156711105521768448896747424787948097241088e+50"},
    {0x1.fffffffffffffp+168, chars_format::scientific, 50, "7.48288838313422211043536897793494849575896194482176e+50"},
    {0x1.fffffffffffffp+169, chars_format::scientific, 51, "1.496577676626844422087073795586989699151792388964352e+51"},
    {0x1.fffffffffffffp+170, chars_format::scientific, 51, "2.993155353253688844174147591173979398303584777928704e+51"},
    {0x1.fffffffffffffp+171, chars_format::scientific, 51, "5.986310706507377688348295182347958796607169555857408e+51"},
    {0x1.fffffffffffffp+172, chars_format::scientific, 52,
        "1.1972621413014755376696590364695917593214339111714816e+52"},
    {0x1.fffffffffffffp+173, chars_format::scientific, 52,
        "2.3945242826029510753393180729391835186428678223429632e+52"},
    {0x1.fffffffffffffp+174, chars_format::scientific, 52,
        "4.7890485652059021506786361458783670372857356446859264e+52"},
    {0x1.fffffffffffffp+175, chars_format::scientific, 52,
        "9.5780971304118043013572722917567340745714712893718528e+52"},
    {0x1.fffffffffffffp+176, chars_format::scientific, 53,
        "1.91561942608236086027145445835134681491429425787437056e+53"},
    {0x1.fffffffffffffp+177, chars_format::scientific, 53,
        "3.83123885216472172054290891670269362982858851574874112e+53"},
    {0x1.fffffffffffffp+178, chars_format::scientific, 53,
        "7.66247770432944344108581783340538725965717703149748224e+53"},
    {0x1.fffffffffffffp+179, chars_format::scientific, 54,
        "1.532495540865888688217163566681077451931435406299496448e+54"},
    {0x1.fffffffffffffp+180, chars_format::scientific, 54,
        "3.064991081731777376434327133362154903862870812598992896e+54"},
    {0x1.fffffffffffffp+181, chars_format::scientific, 54,
        "6.129982163463554752868654266724309807725741625197985792e+54"},
    {0x1.fffffffffffffp+182, chars_format::scientific, 55,
        "1.2259964326927109505737308533448619615451483250395971584e+55"},
    {0x1.fffffffffffffp+183, chars_format::scientific, 55,
        "2.4519928653854219011474617066897239230902966500791943168e+55"},
    {0x1.fffffffffffffp+184, chars_format::scientific, 55,
        "4.9039857307708438022949234133794478461805933001583886336e+55"},
    {0x1.fffffffffffffp+185, chars_format::scientific, 55,
        "9.8079714615416876045898468267588956923611866003167772672e+55"},
    {0x1.fffffffffffffp+186, chars_format::scientific, 56,
        "1.96159429230833752091796936535177913847223732006335545344e+56"},
    {0x1.fffffffffffffp+187, chars_format::scientific, 56,
        "3.92318858461667504183593873070355827694447464012671090688e+56"},
    {0x1.fffffffffffffp+188, chars_format::scientific, 56,
        "7.84637716923335008367187746140711655388894928025342181376e+56"},
    {0x1.fffffffffffffp+189, chars_format::scientific, 57,
        "1.569275433846670016734375492281423310777789856050684362752e+57"},
    {0x1.fffffffffffffp+190, chars_format::scientific, 57,
        "3.138550867693340033468750984562846621555579712101368725504e+57"},
    {0x1.fffffffffffffp+191, chars_format::scientific, 57,
        "6.277101735386680066937501969125693243111159424202737451008e+57"},
    {0x1.fffffffffffffp+192, chars_format::scientific, 58,
        "1.2554203470773360133875003938251386486222318848405474902016e+58"},
    {0x1.fffffffffffffp+193, chars_format::scientific, 58,
        "2.5108406941546720267750007876502772972444637696810949804032e+58"},
    {0x1.fffffffffffffp+194, chars_format::scientific, 58,
        "5.0216813883093440535500015753005545944889275393621899608064e+58"},
    {0x1.fffffffffffffp+195, chars_format::scientific, 59,
        "1.00433627766186881071000031506011091889778550787243799216128e+59"},
    {0x1.fffffffffffffp+196, chars_format::scientific, 59,
        "2.00867255532373762142000063012022183779557101574487598432256e+59"},
    {0x1.fffffffffffffp+197, chars_format::scientific, 59,
        "4.01734511064747524284000126024044367559114203148975196864512e+59"},
    {0x1.fffffffffffffp+198, chars_format::scientific, 59,
        "8.03469022129495048568000252048088735118228406297950393729024e+59"},
    {0x1.fffffffffffffp+199, chars_format::scientific, 60,
        "1.606938044258990097136000504096177470236456812595900787458048e+60"},
    {0x1.fffffffffffffp+200, chars_format::scientific, 60,
        "3.213876088517980194272001008192354940472913625191801574916096e+60"},
    {0x1.fffffffffffffp+201, chars_format::scientific, 60,
        "6.427752177035960388544002016384709880945827250383603149832192e+60"},
    {0x1.fffffffffffffp+202, chars_format::scientific, 61,
        "1.2855504354071920777088004032769419761891654500767206299664384e+61"},
    {0x1.fffffffffffffp+203, chars_format::scientific, 61,
        "2.5711008708143841554176008065538839523783309001534412599328768e+61"},
    {0x1.fffffffffffffp+204, chars_format::scientific, 61,
        "5.1422017416287683108352016131077679047566618003068825198657536e+61"},
    {0x1.fffffffffffffp+205, chars_format::scientific, 62,
        "1.02844034832575366216704032262155358095133236006137650397315072e+62"},
    {0x1.fffffffffffffp+206, chars_format::scientific, 62,
        "2.05688069665150732433408064524310716190266472012275300794630144e+62"},
    {0x1.fffffffffffffp+207, chars_format::scientific, 62,
        "4.11376139330301464866816129048621432380532944024550601589260288e+62"},
    {0x1.fffffffffffffp+208, chars_format::scientific, 62,
        "8.22752278660602929733632258097242864761065888049101203178520576e+62"},
    {0x1.fffffffffffffp+209, chars_format::scientific, 63,
        "1.645504557321205859467264516194485729522131776098202406357041152e+63"},
    {0x1.fffffffffffffp+210, chars_format::scientific, 63,
        "3.291009114642411718934529032388971459044263552196404812714082304e+63"},
    {0x1.fffffffffffffp+211, chars_format::scientific, 63,
        "6.582018229284823437869058064777942918088527104392809625428164608e+63"},
    {0x1.fffffffffffffp+212, chars_format::scientific, 64,
        "1.3164036458569646875738116129555885836177054208785619250856329216e+64"},
    {0x1.fffffffffffffp+213, chars_format::scientific, 64,
        "2.6328072917139293751476232259111771672354108417571238501712658432e+64"},
    {0x1.fffffffffffffp+214, chars_format::scientific, 64,
        "5.2656145834278587502952464518223543344708216835142477003425316864e+64"},
    {0x1.fffffffffffffp+215, chars_format::scientific, 65,
        "1.05312291668557175005904929036447086689416433670284954006850633728e+65"},
    {0x1.fffffffffffffp+216, chars_format::scientific, 65,
        "2.10624583337114350011809858072894173378832867340569908013701267456e+65"},
    {0x1.fffffffffffffp+217, chars_format::scientific, 65,
        "4.21249166674228700023619716145788346757665734681139816027402534912e+65"},
    {0x1.fffffffffffffp+218, chars_format::scientific, 65,
        "8.42498333348457400047239432291576693515331469362279632054805069824e+65"},
    {0x1.fffffffffffffp+219, chars_format::scientific, 66,
        "1.684996666696914800094478864583153387030662938724559264109610139648e+66"},
    {0x1.fffffffffffffp+220, chars_format::scientific, 66,
        "3.369993333393829600188957729166306774061325877449118528219220279296e+66"},
    {0x1.fffffffffffffp+221, chars_format::scientific, 66,
        "6.739986666787659200377915458332613548122651754898237056438440558592e+66"},
    {0x1.fffffffffffffp+222, chars_format::scientific, 67,
        "1.3479973333575318400755830916665227096245303509796474112876881117184e+67"},
    {0x1.fffffffffffffp+223, chars_format::scientific, 67,
        "2.6959946667150636801511661833330454192490607019592948225753762234368e+67"},
    {0x1.fffffffffffffp+224, chars_format::scientific, 67,
        "5.3919893334301273603023323666660908384981214039185896451507524468736e+67"},
    {0x1.fffffffffffffp+225, chars_format::scientific, 68,
        "1.07839786668602547206046647333321816769962428078371792903015048937472e+68"},
    {0x1.fffffffffffffp+226, chars_format::scientific, 68,
        "2.15679573337205094412093294666643633539924856156743585806030097874944e+68"},
    {0x1.fffffffffffffp+227, chars_format::scientific, 68,
        "4.31359146674410188824186589333287267079849712313487171612060195749888e+68"},
    {0x1.fffffffffffffp+228, chars_format::scientific, 68,
        "8.62718293348820377648373178666574534159699424626974343224120391499776e+68"},
    {0x1.fffffffffffffp+229, chars_format::scientific, 69,
        "1.725436586697640755296746357333149068319398849253948686448240782999552e+69"},
    {0x1.fffffffffffffp+230, chars_format::scientific, 69,
        "3.450873173395281510593492714666298136638797698507897372896481565999104e+69"},
    {0x1.fffffffffffffp+231, chars_format::scientific, 69,
        "6.901746346790563021186985429332596273277595397015794745792963131998208e+69"},
    {0x1.fffffffffffffp+232, chars_format::scientific, 70,
        "1.3803492693581126042373970858665192546555190794031589491585926263996416e+70"},
    {0x1.fffffffffffffp+233, chars_format::scientific, 70,
        "2.7606985387162252084747941717330385093110381588063178983171852527992832e+70"},
    {0x1.fffffffffffffp+234, chars_format::scientific, 70,
        "5.5213970774324504169495883434660770186220763176126357966343705055985664e+70"},
    {0x1.fffffffffffffp+235, chars_format::scientific, 71,
        "1.10427941548649008338991766869321540372441526352252715932687410111971328e+71"},
    {0x1.fffffffffffffp+236, chars_format::scientific, 71,
        "2.20855883097298016677983533738643080744883052704505431865374820223942656e+71"},
    {0x1.fffffffffffffp+237, chars_format::scientific, 71,
        "4.41711766194596033355967067477286161489766105409010863730749640447885312e+71"},
    {0x1.fffffffffffffp+238, chars_format::scientific, 71,
        "8.83423532389192066711934134954572322979532210818021727461499280895770624e+71"},
    {0x1.fffffffffffffp+239, chars_format::scientific, 72,
        "1.766847064778384133423868269909144645959064421636043454922998561791541248e+72"},
    {0x1.fffffffffffffp+240, chars_format::scientific, 72,
        "3.533694129556768266847736539818289291918128843272086909845997123583082496e+72"},
    {0x1.fffffffffffffp+241, chars_format::scientific, 72,
        "7.067388259113536533695473079636578583836257686544173819691994247166164992e+72"},
    {0x1.fffffffffffffp+242, chars_format::scientific, 73,
        "1.4134776518227073067390946159273157167672515373088347639383988494332329984e+73"},
    {0x1.fffffffffffffp+243, chars_format::scientific, 73,
        "2.8269553036454146134781892318546314335345030746176695278767976988664659968e+73"},
    {0x1.fffffffffffffp+244, chars_format::scientific, 73,
        "5.6539106072908292269563784637092628670690061492353390557535953977329319936e+73"},
    {0x1.fffffffffffffp+245, chars_format::scientific, 74,
        "1.13078212145816584539127569274185257341380122984706781115071907954658639872e+74"},
    {0x1.fffffffffffffp+246, chars_format::scientific, 74,
        "2.26156424291633169078255138548370514682760245969413562230143815909317279744e+74"},
    {0x1.fffffffffffffp+247, chars_format::scientific, 74,
        "4.52312848583266338156510277096741029365520491938827124460287631818634559488e+74"},
    {0x1.fffffffffffffp+248, chars_format::scientific, 74,
        "9.04625697166532676313020554193482058731040983877654248920575263637269118976e+74"},
    {0x1.fffffffffffffp+249, chars_format::scientific, 75,
        "1.809251394333065352626041108386964117462081967755308497841150527274538237952e+75"},
    {0x1.fffffffffffffp+250, chars_format::scientific, 75,
        "3.618502788666130705252082216773928234924163935510616995682301054549076475904e+75"},
    {0x1.fffffffffffffp+251, chars_format::scientific, 75,
        "7.237005577332261410504164433547856469848327871021233991364602109098152951808e+75"},
    {0x1.fffffffffffffp+252, chars_format::scientific, 76,
        "1.4474011154664522821008328867095712939696655742042467982729204218196305903616e+76"},
    {0x1.fffffffffffffp+253, chars_format::scientific, 76,
        "2.8948022309329045642016657734191425879393311484084935965458408436392611807232e+76"},
    {0x1.fffffffffffffp+254, chars_format::scientific, 76,
        "5.7896044618658091284033315468382851758786622968169871930916816872785223614464e+76"},
    {0x1.fffffffffffffp+255, chars_format::scientific, 77,
        "1.15792089237316182568066630936765703517573245936339743861833633745570447228928e+77"},
    {0x1.fffffffffffffp+256, chars_format::scientific, 77,
        "2.31584178474632365136133261873531407035146491872679487723667267491140894457856e+77"},
    {0x1.fffffffffffffp+257, chars_format::scientific, 77,
        "4.63168356949264730272266523747062814070292983745358975447334534982281788915712e+77"},
    {0x1.fffffffffffffp+258, chars_format::scientific, 77,
        "9.26336713898529460544533047494125628140585967490717950894669069964563577831424e+77"},
    {0x1.fffffffffffffp+259, chars_format::scientific, 78,
        "1.852673427797058921089066094988251256281171934981435901789338139929127155662848e+78"},
    {0x1.fffffffffffffp+260, chars_format::scientific, 78,
        "3.705346855594117842178132189976502512562343869962871803578676279858254311325696e+78"},
    {0x1.fffffffffffffp+261, chars_format::scientific, 78,
        "7.410693711188235684356264379953005025124687739925743607157352559716508622651392e+78"},
    {0x1.fffffffffffffp+262, chars_format::scientific, 79,
        "1.4821387422376471368712528759906010050249375479851487214314705119433017245302784e+79"},
    {0x1.fffffffffffffp+263, chars_format::scientific, 79,
        "2.9642774844752942737425057519812020100498750959702974428629410238866034490605568e+79"},
    {0x1.fffffffffffffp+264, chars_format::scientific, 79,
        "5.9285549689505885474850115039624040200997501919405948857258820477732068981211136e+79"},
    {0x1.fffffffffffffp+265, chars_format::scientific, 80,
        "1.18571099379011770949700230079248080401995003838811897714517640955464137962422272e+80"},
    {0x1.fffffffffffffp+266, chars_format::scientific, 80,
        "2.37142198758023541899400460158496160803990007677623795429035281910928275924844544e+80"},
    {0x1.fffffffffffffp+267, chars_format::scientific, 80,
        "4.74284397516047083798800920316992321607980015355247590858070563821856551849689088e+80"},
    {0x1.fffffffffffffp+268, chars_format::scientific, 80,
        "9.48568795032094167597601840633984643215960030710495181716141127643713103699378176e+80"},
    {0x1.fffffffffffffp+269, chars_format::scientific, 81,
        "1.897137590064188335195203681267969286431920061420990363432282255287426207398756352e+81"},
    {0x1.fffffffffffffp+270, chars_format::scientific, 81,
        "3.794275180128376670390407362535938572863840122841980726864564510574852414797512704e+81"},
    {0x1.fffffffffffffp+271, chars_format::scientific, 81,
        "7.588550360256753340780814725071877145727680245683961453729129021149704829595025408e+81"},
    {0x1.fffffffffffffp+272, chars_format::scientific, 82,
        "1.5177100720513506681561629450143754291455360491367922907458258042299409659190050816e+82"},
    {0x1.fffffffffffffp+273, chars_format::scientific, 82,
        "3.0354201441027013363123258900287508582910720982735845814916516084598819318380101632e+82"},
    {0x1.fffffffffffffp+274, chars_format::scientific, 82,
        "6.0708402882054026726246517800575017165821441965471691629833032169197638636760203264e+82"},
    {0x1.fffffffffffffp+275, chars_format::scientific, 83,
        "1.21416805764108053452493035601150034331642883930943383259666064338395277273520406528e+83"},
    {0x1.fffffffffffffp+276, chars_format::scientific, 83,
        "2.42833611528216106904986071202300068663285767861886766519332128676790554547040813056e+83"},
    {0x1.fffffffffffffp+277, chars_format::scientific, 83,
        "4.85667223056432213809972142404600137326571535723773533038664257353581109094081626112e+83"},
    {0x1.fffffffffffffp+278, chars_format::scientific, 83,
        "9.71334446112864427619944284809200274653143071447547066077328514707162218188163252224e+83"},
    {0x1.fffffffffffffp+279, chars_format::scientific, 84,
        "1.942668892225728855239888569618400549306286142895094132154657029414324436376326504448e+84"},
    {0x1.fffffffffffffp+280, chars_format::scientific, 84,
        "3.885337784451457710479777139236801098612572285790188264309314058828648872752653008896e+84"},
    {0x1.fffffffffffffp+281, chars_format::scientific, 84,
        "7.770675568902915420959554278473602197225144571580376528618628117657297745505306017792e+84"},
    {0x1.fffffffffffffp+282, chars_format::scientific, 85,
        "1.5541351137805830841919108556947204394450289143160753057237256235314595491010612035584e+85"},
    {0x1.fffffffffffffp+283, chars_format::scientific, 85,
        "3.1082702275611661683838217113894408788900578286321506114474512470629190982021224071168e+85"},
    {0x1.fffffffffffffp+284, chars_format::scientific, 85,
        "6.2165404551223323367676434227788817577801156572643012228949024941258381964042448142336e+85"},
    {0x1.fffffffffffffp+285, chars_format::scientific, 86,
        "1.24330809102446646735352868455577635155602313145286024457898049882516763928084896284672e+86"},
    {0x1.fffffffffffffp+286, chars_format::scientific, 86,
        "2.48661618204893293470705736911155270311204626290572048915796099765033527856169792569344e+86"},
    {0x1.fffffffffffffp+287, chars_format::scientific, 86,
        "4.97323236409786586941411473822310540622409252581144097831592199530067055712339585138688e+86"},
    {0x1.fffffffffffffp+288, chars_format::scientific, 86,
        "9.94646472819573173882822947644621081244818505162288195663184399060134111424679170277376e+86"},
    {0x1.fffffffffffffp+289, chars_format::scientific, 87,
        "1.989292945639146347765645895289242162489637010324576391326368798120268222849358340554752e+87"},
    {0x1.fffffffffffffp+290, chars_format::scientific, 87,
        "3.978585891278292695531291790578484324979274020649152782652737596240536445698716681109504e+87"},
    {0x1.fffffffffffffp+291, chars_format::scientific, 87,
        "7.957171782556585391062583581156968649958548041298305565305475192481072891397433362219008e+87"},
    {0x1.fffffffffffffp+292, chars_format::scientific, 88,
        "1.5914343565113170782125167162313937299917096082596611130610950384962145782794866724438016e+88"},
    {0x1.fffffffffffffp+293, chars_format::scientific, 88,
        "3.1828687130226341564250334324627874599834192165193222261221900769924291565589733448876032e+88"},
    {0x1.fffffffffffffp+294, chars_format::scientific, 88,
        "6.3657374260452683128500668649255749199668384330386444522443801539848583131179466897752064e+88"},
    {0x1.fffffffffffffp+295, chars_format::scientific, 89,
        "1.27314748520905366257001337298511498399336768660772889044887603079697166262358933795504128e+89"},
    {0x1.fffffffffffffp+296, chars_format::scientific, 89,
        "2.54629497041810732514002674597022996798673537321545778089775206159394332524717867591008256e+89"},
    {0x1.fffffffffffffp+297, chars_format::scientific, 89,
        "5.09258994083621465028005349194045993597347074643091556179550412318788665049435735182016512e+89"},
    {0x1.fffffffffffffp+298, chars_format::scientific, 90,
        "1.018517988167242930056010698388091987194694149286183112359100824637577330098871470364033024e+90"},
    {0x1.fffffffffffffp+299, chars_format::scientific, 90,
        "2.037035976334485860112021396776183974389388298572366224718201649275154660197742940728066048e+90"},
    {0x1.fffffffffffffp+300, chars_format::scientific, 90,
        "4.074071952668971720224042793552367948778776597144732449436403298550309320395485881456132096e+90"},
    {0x1.fffffffffffffp+301, chars_format::scientific, 90,
        "8.148143905337943440448085587104735897557553194289464898872806597100618640790971762912264192e+90"},
    {0x1.fffffffffffffp+302, chars_format::scientific, 91,
        "1.6296287810675886880896171174209471795115106388578929797745613194201237281581943525824528384e+91"},
    {0x1.fffffffffffffp+303, chars_format::scientific, 91,
        "3.2592575621351773761792342348418943590230212777157859595491226388402474563163887051649056768e+91"},
    {0x1.fffffffffffffp+304, chars_format::scientific, 91,
        "6.5185151242703547523584684696837887180460425554315719190982452776804949126327774103298113536e+91"},
    {0x1.fffffffffffffp+305, chars_format::scientific, 92,
        "1.30370302485407095047169369393675774360920851108631438381964905553609898252655548206596227072e+92"},
    {0x1.fffffffffffffp+306, chars_format::scientific, 92,
        "2.60740604970814190094338738787351548721841702217262876763929811107219796505311096413192454144e+92"},
    {0x1.fffffffffffffp+307, chars_format::scientific, 92,
        "5.21481209941628380188677477574703097443683404434525753527859622214439593010622192826384908288e+92"},
    {0x1.fffffffffffffp+308, chars_format::scientific, 93,
        "1.042962419883256760377354955149406194887366808869051507055719244428879186021244385652769816576e+93"},
    {0x1.fffffffffffffp+309, chars_format::scientific, 93,
        "2.085924839766513520754709910298812389774733617738103014111438488857758372042488771305539633152e+93"},
    {0x1.fffffffffffffp+310, chars_format::scientific, 93,
        "4.171849679533027041509419820597624779549467235476206028222876977715516744084977542611079266304e+93"},
    {0x1.fffffffffffffp+311, chars_format::scientific, 93,
        "8.343699359066054083018839641195249559098934470952412056445753955431033488169955085222158532608e+93"},
    {0x1.fffffffffffffp+312, chars_format::scientific, 94,
        "1.6687398718132108166037679282390499118197868941904824112891507910862066976339910170444317065216e+94"},
    {0x1.fffffffffffffp+313, chars_format::scientific, 94,
        "3.3374797436264216332075358564780998236395737883809648225783015821724133952679820340888634130432e+94"},
    {0x1.fffffffffffffp+314, chars_format::scientific, 94,
        "6.6749594872528432664150717129561996472791475767619296451566031643448267905359640681777268260864e+94"},
    {0x1.fffffffffffffp+315, chars_format::scientific, 95,
        "1.33499189745056865328301434259123992945582951535238592903132063286896535810719281363554536521728e+95"},
    {0x1.fffffffffffffp+316, chars_format::scientific, 95,
        "2.66998379490113730656602868518247985891165903070477185806264126573793071621438562727109073043456e+95"},
    {0x1.fffffffffffffp+317, chars_format::scientific, 95,
        "5.33996758980227461313205737036495971782331806140954371612528253147586143242877125454218146086912e+95"},
    {0x1.fffffffffffffp+318, chars_format::scientific, 96,
        "1.067993517960454922626411474072991943564663612281908743225056506295172286485754250908436292173824e+96"},
    {0x1.fffffffffffffp+319, chars_format::scientific, 96,
        "2.135987035920909845252822948145983887129327224563817486450113012590344572971508501816872584347648e+96"},
    {0x1.fffffffffffffp+320, chars_format::scientific, 96,
        "4.271974071841819690505645896291967774258654449127634972900226025180689145943017003633745168695296e+96"},
    {0x1.fffffffffffffp+321, chars_format::scientific, 96,
        "8.543948143683639381011291792583935548517308898255269945800452050361378291886034007267490337390592e+96"},
    {0x1.fffffffffffffp+322, chars_format::scientific, 97,
        "1.7087896287367278762022583585167871097034617796510539891600904100722756583772068014534980674781184e+97"},
    {0x1.fffffffffffffp+323, chars_format::scientific, 97,
        "3.4175792574734557524045167170335742194069235593021079783201808201445513167544136029069961349562368e+97"},
    {0x1.fffffffffffffp+324, chars_format::scientific, 97,
        "6.8351585149469115048090334340671484388138471186042159566403616402891026335088272058139922699124736e+97"},
    {0x1.fffffffffffffp+325, chars_format::scientific, 98,
        "1.36703170298938230096180668681342968776276942372084319132807232805782052670176544116279845398249472e+98"},
    {0x1.fffffffffffffp+326, chars_format::scientific, 98,
        "2.73406340597876460192361337362685937552553884744168638265614465611564105340353088232559690796498944e+98"},
    {0x1.fffffffffffffp+327, chars_format::scientific, 98,
        "5.46812681195752920384722674725371875105107769488337276531228931223128210680706176465119381592997888e+98"},
    {0x1.fffffffffffffp+328, chars_format::scientific, 99,
        "1.093625362391505840769445349450743750210215538976674553062457862446256421361412352930238763185995776e+"
        "99"},
    {0x1.fffffffffffffp+329, chars_format::scientific, 99,
        "2.187250724783011681538890698901487500420431077953349106124915724892512842722824705860477526371991552e+"
        "99"},
    {0x1.fffffffffffffp+330, chars_format::scientific, 99,
        "4.374501449566023363077781397802975000840862155906698212249831449785025685445649411720955052743983104e+"
        "99"},
    {0x1.fffffffffffffp+331, chars_format::scientific, 99,
        "8.749002899132046726155562795605950001681724311813396424499662899570051370891298823441910105487966208e+"
        "99"},
    {0x1.fffffffffffffp+332, chars_format::scientific, 100,
        "1.7498005798264093452311125591211900003363448623626792848999325799140102741782597646883820210975932416e+"
        "100"},
    {0x1.fffffffffffffp+333, chars_format::scientific, 100,
        "3.4996011596528186904622251182423800006726897247253585697998651598280205483565195293767640421951864832e+"
        "100"},
    {0x1.fffffffffffffp+334, chars_format::scientific, 100,
        "6.9992023193056373809244502364847600013453794494507171395997303196560410967130390587535280843903729664e+"
        "100"},
    {0x1.fffffffffffffp+335, chars_format::scientific, 101,
        "1.39984046386112747618489004729695200026907588989014342791994606393120821934260781175070561687807459328e+"
        "101"},
    {0x1.fffffffffffffp+336, chars_format::scientific, 101,
        "2.79968092772225495236978009459390400053815177978028685583989212786241643868521562350141123375614918656e+"
        "101"},
    {0x1.fffffffffffffp+337, chars_format::scientific, 101,
        "5.59936185544450990473956018918780800107630355956057371167978425572483287737043124700282246751229837312e+"
        "101"},
    {0x1.fffffffffffffp+338, chars_format::scientific, 102,
        "1.119872371088901980947912037837561600215260711912114742335956851144966575474086249400564493502459674624e+"
        "102"},
    {0x1.fffffffffffffp+339, chars_format::scientific, 102,
        "2.239744742177803961895824075675123200430521423824229484671913702289933150948172498801128987004919349248e+"
        "102"},
    {0x1.fffffffffffffp+340, chars_format::scientific, 102,
        "4.479489484355607923791648151350246400861042847648458969343827404579866301896344997602257974009838698496e+"
        "102"},
    {0x1.fffffffffffffp+341, chars_format::scientific, 102,
        "8.958978968711215847583296302700492801722085695296917938687654809159732603792689995204515948019677396992e+"
        "102"},
    {0x1.fffffffffffffp+342, chars_format::scientific, 103,
        "1."
        "7917957937422431695166592605400985603444171390593835877375309618319465207585379990409031896039354793984e+"
        "103"},
    {0x1.fffffffffffffp+343, chars_format::scientific, 103,
        "3."
        "5835915874844863390333185210801971206888342781187671754750619236638930415170759980818063792078709587968e+"
        "103"},
    {0x1.fffffffffffffp+344, chars_format::scientific, 103,
        "7."
        "1671831749689726780666370421603942413776685562375343509501238473277860830341519961636127584157419175936e+"
        "103"},
    {0x1.fffffffffffffp+345, chars_format::scientific, 104,
        "1."
        "43343663499379453561332740843207884827553371124750687019002476946555721660683039923272255168314838351872e+"
        "104"},
    {0x1.fffffffffffffp+346, chars_format::scientific, 104,
        "2."
        "86687326998758907122665481686415769655106742249501374038004953893111443321366079846544510336629676703744e+"
        "104"},
    {0x1.fffffffffffffp+347, chars_format::scientific, 104,
        "5."
        "73374653997517814245330963372831539310213484499002748076009907786222886642732159693089020673259353407488e+"
        "104"},
    {0x1.fffffffffffffp+348, chars_format::scientific, 105,
        "1."
        "146749307995035628490661926745663078620426968998005496152019815572445773285464319386178041346518706814976e"
        "+105"},
    {0x1.fffffffffffffp+349, chars_format::scientific, 105,
        "2."
        "293498615990071256981323853491326157240853937996010992304039631144891546570928638772356082693037413629952e"
        "+105"},
    {0x1.fffffffffffffp+350, chars_format::scientific, 105,
        "4."
        "586997231980142513962647706982652314481707875992021984608079262289783093141857277544712165386074827259904e"
        "+105"},
    {0x1.fffffffffffffp+351, chars_format::scientific, 105,
        "9."
        "173994463960285027925295413965304628963415751984043969216158524579566186283714555089424330772149654519808e"
        "+105"},
    {0x1.fffffffffffffp+352, chars_format::scientific, 106,
        "1."
        "8347988927920570055850590827930609257926831503968087938432317049159132372567429110178848661544299309039616"
        "e+106"},
    {0x1.fffffffffffffp+353, chars_format::scientific, 106,
        "3."
        "6695977855841140111701181655861218515853663007936175876864634098318264745134858220357697323088598618079232"
        "e+106"},
    {0x1.fffffffffffffp+354, chars_format::scientific, 106,
        "7."
        "3391955711682280223402363311722437031707326015872351753729268196636529490269716440715394646177197236158464"
        "e+106"},
    {0x1.fffffffffffffp+355, chars_format::scientific, 107,
        "1."
        "4678391142336456044680472662344487406341465203174470350745853639327305898053943288143078929235439447231692"
        "8e+107"},
    {0x1.fffffffffffffp+356, chars_format::scientific, 107,
        "2."
        "9356782284672912089360945324688974812682930406348940701491707278654611796107886576286157858470878894463385"
        "6e+107"},
    {0x1.fffffffffffffp+357, chars_format::scientific, 107,
        "5."
        "8713564569345824178721890649377949625365860812697881402983414557309223592215773152572315716941757788926771"
        "2e+107"},
    {0x1.fffffffffffffp+358, chars_format::scientific, 108,
        "1."
        "1742712913869164835744378129875589925073172162539576280596682911461844718443154630514463143388351557785354"
        "24e+108"},
    {0x1.fffffffffffffp+359, chars_format::scientific, 108,
        "2."
        "3485425827738329671488756259751179850146344325079152561193365822923689436886309261028926286776703115570708"
        "48e+108"},
    {0x1.fffffffffffffp+360, chars_format::scientific, 108,
        "4."
        "6970851655476659342977512519502359700292688650158305122386731645847378873772618522057852573553406231141416"
        "96e+108"},
    {0x1.fffffffffffffp+361, chars_format::scientific, 108,
        "9."
        "3941703310953318685955025039004719400585377300316610244773463291694757747545237044115705147106812462282833"
        "92e+108"},
    {0x1.fffffffffffffp+362, chars_format::scientific, 109,
        "1."
        "8788340662190663737191005007800943880117075460063322048954692658338951549509047408823141029421362492456566"
        "784e+109"},
    {0x1.fffffffffffffp+363, chars_format::scientific, 109,
        "3."
        "7576681324381327474382010015601887760234150920126644097909385316677903099018094817646282058842724984913133"
        "568e+109"},
    {0x1.fffffffffffffp+364, chars_format::scientific, 109,
        "7."
        "5153362648762654948764020031203775520468301840253288195818770633355806198036189635292564117685449969826267"
        "136e+109"},
    {0x1.fffffffffffffp+365, chars_format::scientific, 110,
        "1."
        "5030672529752530989752804006240755104093660368050657639163754126671161239607237927058512823537089993965253"
        "4272e+110"},
    {0x1.fffffffffffffp+366, chars_format::scientific, 110,
        "3."
        "0061345059505061979505608012481510208187320736101315278327508253342322479214475854117025647074179987930506"
        "8544e+110"},
    {0x1.fffffffffffffp+367, chars_format::scientific, 110,
        "6."
        "0122690119010123959011216024963020416374641472202630556655016506684644958428951708234051294148359975861013"
        "7088e+110"},
    {0x1.fffffffffffffp+368, chars_format::scientific, 111,
        "1."
        "2024538023802024791802243204992604083274928294440526111331003301336928991685790341646810258829671995172202"
        "74176e+111"},
    {0x1.fffffffffffffp+369, chars_format::scientific, 111,
        "2."
        "4049076047604049583604486409985208166549856588881052222662006602673857983371580683293620517659343990344405"
        "48352e+111"},
    {0x1.fffffffffffffp+370, chars_format::scientific, 111,
        "4."
        "8098152095208099167208972819970416333099713177762104445324013205347715966743161366587241035318687980688810"
        "96704e+111"},
    {0x1.fffffffffffffp+371, chars_format::scientific, 111,
        "9."
        "6196304190416198334417945639940832666199426355524208890648026410695431933486322733174482070637375961377621"
        "93408e+111"},
    {0x1.fffffffffffffp+372, chars_format::scientific, 112,
        "1."
        "9239260838083239666883589127988166533239885271104841778129605282139086386697264546634896414127475192275524"
        "386816e+112"},
    {0x1.fffffffffffffp+373, chars_format::scientific, 112,
        "3."
        "8478521676166479333767178255976333066479770542209683556259210564278172773394529093269792828254950384551048"
        "773632e+112"},
    {0x1.fffffffffffffp+374, chars_format::scientific, 112,
        "7."
        "6957043352332958667534356511952666132959541084419367112518421128556345546789058186539585656509900769102097"
        "547264e+112"},
    {0x1.fffffffffffffp+375, chars_format::scientific, 113,
        "1."
        "5391408670466591733506871302390533226591908216883873422503684225711269109357811637307917131301980153820419"
        "5094528e+113"},
    {0x1.fffffffffffffp+376, chars_format::scientific, 113,
        "3."
        "0782817340933183467013742604781066453183816433767746845007368451422538218715623274615834262603960307640839"
        "0189056e+113"},
    {0x1.fffffffffffffp+377, chars_format::scientific, 113,
        "6."
        "1565634681866366934027485209562132906367632867535493690014736902845076437431246549231668525207920615281678"
        "0378112e+113"},
    {0x1.fffffffffffffp+378, chars_format::scientific, 114,
        "1."
        "2313126936373273386805497041912426581273526573507098738002947380569015287486249309846333705041584123056335"
        "60756224e+114"},
    {0x1.fffffffffffffp+379, chars_format::scientific, 114,
        "2."
        "4626253872746546773610994083824853162547053147014197476005894761138030574972498619692667410083168246112671"
        "21512448e+114"},
    {0x1.fffffffffffffp+380, chars_format::scientific, 114,
        "4."
        "9252507745493093547221988167649706325094106294028394952011789522276061149944997239385334820166336492225342"
        "43024896e+114"},
    {0x1.fffffffffffffp+381, chars_format::scientific, 114,
        "9."
        "8505015490986187094443976335299412650188212588056789904023579044552122299889994478770669640332672984450684"
        "86049792e+114"},
    {0x1.fffffffffffffp+382, chars_format::scientific, 115,
        "1."
        "9701003098197237418888795267059882530037642517611357980804715808910424459977998895754133928066534596890136"
        "972099584e+115"},
    {0x1.fffffffffffffp+383, chars_format::scientific, 115,
        "3."
        "9402006196394474837777590534119765060075285035222715961609431617820848919955997791508267856133069193780273"
        "944199168e+115"},
    {0x1.fffffffffffffp+384, chars_format::scientific, 115,
        "7."
        "8804012392788949675555181068239530120150570070445431923218863235641697839911995583016535712266138387560547"
        "888398336e+115"},
    {0x1.fffffffffffffp+385, chars_format::scientific, 116,
        "1."
        "5760802478557789935111036213647906024030114014089086384643772647128339567982399116603307142453227677512109"
        "5776796672e+116"},
    {0x1.fffffffffffffp+386, chars_format::scientific, 116,
        "3."
        "1521604957115579870222072427295812048060228028178172769287545294256679135964798233206614284906455355024219"
        "1553593344e+116"},
    {0x1.fffffffffffffp+387, chars_format::scientific, 116,
        "6."
        "3043209914231159740444144854591624096120456056356345538575090588513358271929596466413228569812910710048438"
        "3107186688e+116"},
    {0x1.fffffffffffffp+388, chars_format::scientific, 117,
        "1."
        "2608641982846231948088828970918324819224091211271269107715018117702671654385919293282645713962582142009687"
        "66214373376e+117"},
    {0x1.fffffffffffffp+389, chars_format::scientific, 117,
        "2."
        "5217283965692463896177657941836649638448182422542538215430036235405343308771838586565291427925164284019375"
        "32428746752e+117"},
    {0x1.fffffffffffffp+390, chars_format::scientific, 117,
        "5."
        "0434567931384927792355315883673299276896364845085076430860072470810686617543677173130582855850328568038750"
        "64857493504e+117"},
    {0x1.fffffffffffffp+391, chars_format::scientific, 118,
        "1."
        "0086913586276985558471063176734659855379272969017015286172014494162137323508735434626116571170065713607750"
        "129714987008e+118"},
    {0x1.fffffffffffffp+392, chars_format::scientific, 118,
        "2."
        "0173827172553971116942126353469319710758545938034030572344028988324274647017470869252233142340131427215500"
        "259429974016e+118"},
    {0x1.fffffffffffffp+393, chars_format::scientific, 118,
        "4."
        "0347654345107942233884252706938639421517091876068061144688057976648549294034941738504466284680262854431000"
        "518859948032e+118"},
    {0x1.fffffffffffffp+394, chars_format::scientific, 118,
        "8."
        "0695308690215884467768505413877278843034183752136122289376115953297098588069883477008932569360525708862001"
        "037719896064e+118"},
    {0x1.fffffffffffffp+395, chars_format::scientific, 119,
        "1."
        "6139061738043176893553701082775455768606836750427224457875223190659419717613976695401786513872105141772400"
        "2075439792128e+119"},
    {0x1.fffffffffffffp+396, chars_format::scientific, 119,
        "3."
        "2278123476086353787107402165550911537213673500854448915750446381318839435227953390803573027744210283544800"
        "4150879584256e+119"},
    {0x1.fffffffffffffp+397, chars_format::scientific, 119,
        "6."
        "4556246952172707574214804331101823074427347001708897831500892762637678870455906781607146055488420567089600"
        "8301759168512e+119"},
    {0x1.fffffffffffffp+398, chars_format::scientific, 120,
        "1."
        "2911249390434541514842960866220364614885469400341779566300178552527535774091181356321429211097684113417920"
        "16603518337024e+120"},
    {0x1.fffffffffffffp+399, chars_format::scientific, 120,
        "2."
        "5822498780869083029685921732440729229770938800683559132600357105055071548182362712642858422195368226835840"
        "33207036674048e+120"},
    {0x1.fffffffffffffp+400, chars_format::scientific, 120,
        "5."
        "1644997561738166059371843464881458459541877601367118265200714210110143096364725425285716844390736453671680"
        "66414073348096e+120"},
    {0x1.fffffffffffffp+401, chars_format::scientific, 121,
        "1."
        "0328999512347633211874368692976291691908375520273423653040142842022028619272945085057143368878147290734336"
        "132828146696192e+121"},
    {0x1.fffffffffffffp+402, chars_format::scientific, 121,
        "2."
        "0657999024695266423748737385952583383816751040546847306080285684044057238545890170114286737756294581468672"
        "265656293392384e+121"},
    {0x1.fffffffffffffp+403, chars_format::scientific, 121,
        "4."
        "1315998049390532847497474771905166767633502081093694612160571368088114477091780340228573475512589162937344"
        "531312586784768e+121"},
    {0x1.fffffffffffffp+404, chars_format::scientific, 121,
        "8."
        "2631996098781065694994949543810333535267004162187389224321142736176228954183560680457146951025178325874689"
        "062625173569536e+121"},
    {0x1.fffffffffffffp+405, chars_format::scientific, 122,
        "1."
        "6526399219756213138998989908762066707053400832437477844864228547235245790836712136091429390205035665174937"
        "8125250347139072e+122"},
    {0x1.fffffffffffffp+406, chars_format::scientific, 122,
        "3."
        "3052798439512426277997979817524133414106801664874955689728457094470491581673424272182858780410071330349875"
        "6250500694278144e+122"},
    {0x1.fffffffffffffp+407, chars_format::scientific, 122,
        "6."
        "6105596879024852555995959635048266828213603329749911379456914188940983163346848544365717560820142660699751"
        "2501001388556288e+122"},
    {0x1.fffffffffffffp+408, chars_format::scientific, 123,
        "1."
        "3221119375804970511199191927009653365642720665949982275891382837788196632669369708873143512164028532139950"
        "25002002777112576e+123"},
    {0x1.fffffffffffffp+409, chars_format::scientific, 123,
        "2."
        "6442238751609941022398383854019306731285441331899964551782765675576393265338739417746287024328057064279900"
        "50004005554225152e+123"},
    {0x1.fffffffffffffp+410, chars_format::scientific, 123,
        "5."
        "2884477503219882044796767708038613462570882663799929103565531351152786530677478835492574048656114128559801"
        "00008011108450304e+123"},
    {0x1.fffffffffffffp+411, chars_format::scientific, 124,
        "1."
        "0576895500643976408959353541607722692514176532759985820713106270230557306135495767098514809731222825711960"
        "200016022216900608e+124"},
    {0x1.fffffffffffffp+412, chars_format::scientific, 124,
        "2."
        "1153791001287952817918707083215445385028353065519971641426212540461114612270991534197029619462445651423920"
        "400032044433801216e+124"},
    {0x1.fffffffffffffp+413, chars_format::scientific, 124,
        "4."
        "2307582002575905635837414166430890770056706131039943282852425080922229224541983068394059238924891302847840"
        "800064088867602432e+124"},
    {0x1.fffffffffffffp+414, chars_format::scientific, 124,
        "8."
        "4615164005151811271674828332861781540113412262079886565704850161844458449083966136788118477849782605695681"
        "600128177735204864e+124"},
    {0x1.fffffffffffffp+415, chars_format::scientific, 125,
        "1."
        "6923032801030362254334965666572356308022682452415977313140970032368891689816793227357623695569956521139136"
        "3200256355470409728e+125"},
    {0x1.fffffffffffffp+416, chars_format::scientific, 125,
        "3."
        "3846065602060724508669931333144712616045364904831954626281940064737783379633586454715247391139913042278272"
        "6400512710940819456e+125"},
    {0x1.fffffffffffffp+417, chars_format::scientific, 125,
        "6."
        "7692131204121449017339862666289425232090729809663909252563880129475566759267172909430494782279826084556545"
        "2801025421881638912e+125"},
    {0x1.fffffffffffffp+418, chars_format::scientific, 126,
        "1."
        "3538426240824289803467972533257885046418145961932781850512776025895113351853434581886098956455965216911309"
        "05602050843763277824e+126"},
    {0x1.fffffffffffffp+419, chars_format::scientific, 126,
        "2."
        "7076852481648579606935945066515770092836291923865563701025552051790226703706869163772197912911930433822618"
        "11204101687526555648e+126"},
    {0x1.fffffffffffffp+420, chars_format::scientific, 126,
        "5."
        "4153704963297159213871890133031540185672583847731127402051104103580453407413738327544395825823860867645236"
        "22408203375053111296e+126"},
    {0x1.fffffffffffffp+421, chars_format::scientific, 127,
        "1."
        "0830740992659431842774378026606308037134516769546225480410220820716090681482747665508879165164772173529047"
        "244816406750106222592e+127"},
    {0x1.fffffffffffffp+422, chars_format::scientific, 127,
        "2."
        "1661481985318863685548756053212616074269033539092450960820441641432181362965495331017758330329544347058094"
        "489632813500212445184e+127"},
    {0x1.fffffffffffffp+423, chars_format::scientific, 127,
        "4."
        "3322963970637727371097512106425232148538067078184901921640883282864362725930990662035516660659088694116188"
        "979265627000424890368e+127"},
    {0x1.fffffffffffffp+424, chars_format::scientific, 127,
        "8."
        "6645927941275454742195024212850464297076134156369803843281766565728725451861981324071033321318177388232377"
        "958531254000849780736e+127"},
    {0x1.fffffffffffffp+425, chars_format::scientific, 128,
        "1."
        "7329185588255090948439004842570092859415226831273960768656353313145745090372396264814206664263635477646475"
        "5917062508001699561472e+128"},
    {0x1.fffffffffffffp+426, chars_format::scientific, 128,
        "3."
        "4658371176510181896878009685140185718830453662547921537312706626291490180744792529628413328527270955292951"
        "1834125016003399122944e+128"},
    {0x1.fffffffffffffp+427, chars_format::scientific, 128,
        "6."
        "9316742353020363793756019370280371437660907325095843074625413252582980361489585059256826657054541910585902"
        "3668250032006798245888e+128"},
    {0x1.fffffffffffffp+428, chars_format::scientific, 129,
        "1."
        "3863348470604072758751203874056074287532181465019168614925082650516596072297917011851365331410908382117180"
        "47336500064013596491776e+129"},
    {0x1.fffffffffffffp+429, chars_format::scientific, 129,
        "2."
        "7726696941208145517502407748112148575064362930038337229850165301033192144595834023702730662821816764234360"
        "94673000128027192983552e+129"},
    {0x1.fffffffffffffp+430, chars_format::scientific, 129,
        "5."
        "5453393882416291035004815496224297150128725860076674459700330602066384289191668047405461325643633528468721"
        "89346000256054385967104e+129"},
    {0x1.fffffffffffffp+431, chars_format::scientific, 130,
        "1."
        "1090678776483258207000963099244859430025745172015334891940066120413276857838333609481092265128726705693744"
        "378692000512108771934208e+130"},
    {0x1.fffffffffffffp+432, chars_format::scientific, 130,
        "2."
        "2181357552966516414001926198489718860051490344030669783880132240826553715676667218962184530257453411387488"
        "757384001024217543868416e+130"},
    {0x1.fffffffffffffp+433, chars_format::scientific, 130,
        "4."
        "4362715105933032828003852396979437720102980688061339567760264481653107431353334437924369060514906822774977"
        "514768002048435087736832e+130"},
    {0x1.fffffffffffffp+434, chars_format::scientific, 130,
        "8."
        "8725430211866065656007704793958875440205961376122679135520528963306214862706668875848738121029813645549955"
        "029536004096870175473664e+130"},
    {0x1.fffffffffffffp+435, chars_format::scientific, 131,
        "1."
        "7745086042373213131201540958791775088041192275224535827104105792661242972541333775169747624205962729109991"
        "0059072008193740350947328e+131"},
    {0x1.fffffffffffffp+436, chars_format::scientific, 131,
        "3."
        "5490172084746426262403081917583550176082384550449071654208211585322485945082667550339495248411925458219982"
        "0118144016387480701894656e+131"},
    {0x1.fffffffffffffp+437, chars_format::scientific, 131,
        "7."
        "0980344169492852524806163835167100352164769100898143308416423170644971890165335100678990496823850916439964"
        "0236288032774961403789312e+131"},
    {0x1.fffffffffffffp+438, chars_format::scientific, 132,
        "1."
        "4196068833898570504961232767033420070432953820179628661683284634128994378033067020135798099364770183287992"
        "80472576065549922807578624e+132"},
    {0x1.fffffffffffffp+439, chars_format::scientific, 132,
        "2."
        "8392137667797141009922465534066840140865907640359257323366569268257988756066134040271596198729540366575985"
        "60945152131099845615157248e+132"},
    {0x1.fffffffffffffp+440, chars_format::scientific, 132,
        "5."
        "6784275335594282019844931068133680281731815280718514646733138536515977512132268080543192397459080733151971"
        "21890304262199691230314496e+132"},
    {0x1.fffffffffffffp+441, chars_format::scientific, 133,
        "1."
        "1356855067118856403968986213626736056346363056143702929346627707303195502426453616108638479491816146630394"
        "243780608524399382460628992e+133"},
    {0x1.fffffffffffffp+442, chars_format::scientific, 133,
        "2."
        "2713710134237712807937972427253472112692726112287405858693255414606391004852907232217276958983632293260788"
        "487561217048798764921257984e+133"},
    {0x1.fffffffffffffp+443, chars_format::scientific, 133,
        "4."
        "5427420268475425615875944854506944225385452224574811717386510829212782009705814464434553917967264586521576"
        "975122434097597529842515968e+133"},
    {0x1.fffffffffffffp+444, chars_format::scientific, 133,
        "9."
        "0854840536950851231751889709013888450770904449149623434773021658425564019411628928869107835934529173043153"
        "950244868195195059685031936e+133"},
    {0x1.fffffffffffffp+445, chars_format::scientific, 134,
        "1."
        "8170968107390170246350377941802777690154180889829924686954604331685112803882325785773821567186905834608630"
        "7900489736390390119370063872e+134"},
    {0x1.fffffffffffffp+446, chars_format::scientific, 134,
        "3."
        "6341936214780340492700755883605555380308361779659849373909208663370225607764651571547643134373811669217261"
        "5800979472780780238740127744e+134"},
    {0x1.fffffffffffffp+447, chars_format::scientific, 134,
        "7."
        "2683872429560680985401511767211110760616723559319698747818417326740451215529303143095286268747623338434523"
        "1601958945561560477480255488e+134"},
    {0x1.fffffffffffffp+448, chars_format::scientific, 135,
        "1."
        "4536774485912136197080302353442222152123344711863939749563683465348090243105860628619057253749524667686904"
        "63203917891123120954960510976e+135"},
    {0x1.fffffffffffffp+449, chars_format::scientific, 135,
        "2."
        "9073548971824272394160604706884444304246689423727879499127366930696180486211721257238114507499049335373809"
        "26407835782246241909921021952e+135"},
    {0x1.fffffffffffffp+450, chars_format::scientific, 135,
        "5."
        "8147097943648544788321209413768888608493378847455758998254733861392360972423442514476229014998098670747618"
        "52815671564492483819842043904e+135"},
    {0x1.fffffffffffffp+451, chars_format::scientific, 136,
        "1."
        "1629419588729708957664241882753777721698675769491151799650946772278472194484688502895245802999619734149523"
        "705631343128984967639684087808e+136"},
    {0x1.fffffffffffffp+452, chars_format::scientific, 136,
        "2."
        "3258839177459417915328483765507555443397351538982303599301893544556944388969377005790491605999239468299047"
        "411262686257969935279368175616e+136"},
    {0x1.fffffffffffffp+453, chars_format::scientific, 136,
        "4."
        "6517678354918835830656967531015110886794703077964607198603787089113888777938754011580983211998478936598094"
        "822525372515939870558736351232e+136"},
    {0x1.fffffffffffffp+454, chars_format::scientific, 136,
        "9."
        "3035356709837671661313935062030221773589406155929214397207574178227777555877508023161966423996957873196189"
        "645050745031879741117472702464e+136"},
    {0x1.fffffffffffffp+455, chars_format::scientific, 137,
        "1."
        "8607071341967534332262787012406044354717881231185842879441514835645555511175501604632393284799391574639237"
        "9290101490063759482234945404928e+137"},
    {0x1.fffffffffffffp+456, chars_format::scientific, 137,
        "3."
        "7214142683935068664525574024812088709435762462371685758883029671291111022351003209264786569598783149278475"
        "8580202980127518964469890809856e+137"},
    {0x1.fffffffffffffp+457, chars_format::scientific, 137,
        "7."
        "4428285367870137329051148049624177418871524924743371517766059342582222044702006418529573139197566298556951"
        "7160405960255037928939781619712e+137"},
    {0x1.fffffffffffffp+458, chars_format::scientific, 138,
        "1."
        "4885657073574027465810229609924835483774304984948674303553211868516444408940401283705914627839513259711390"
        "34320811920510075857879563239424e+138"},
    {0x1.fffffffffffffp+459, chars_format::scientific, 138,
        "2."
        "9771314147148054931620459219849670967548609969897348607106423737032888817880802567411829255679026519422780"
        "68641623841020151715759126478848e+138"},
    {0x1.fffffffffffffp+460, chars_format::scientific, 138,
        "5."
        "9542628294296109863240918439699341935097219939794697214212847474065777635761605134823658511358053038845561"
        "37283247682040303431518252957696e+138"},
    {0x1.fffffffffffffp+461, chars_format::scientific, 139,
        "1."
        "1908525658859221972648183687939868387019443987958939442842569494813155527152321026964731702271610607769112"
        "274566495364080606863036505915392e+139"},
    {0x1.fffffffffffffp+462, chars_format::scientific, 139,
        "2."
        "3817051317718443945296367375879736774038887975917878885685138989626311054304642053929463404543221215538224"
        "549132990728161213726073011830784e+139"},
    {0x1.fffffffffffffp+463, chars_format::scientific, 139,
        "4."
        "7634102635436887890592734751759473548077775951835757771370277979252622108609284107858926809086442431076449"
        "098265981456322427452146023661568e+139"},
    {0x1.fffffffffffffp+464, chars_format::scientific, 139,
        "9."
        "5268205270873775781185469503518947096155551903671515542740555958505244217218568215717853618172884862152898"
        "196531962912644854904292047323136e+139"},
    {0x1.fffffffffffffp+465, chars_format::scientific, 140,
        "1."
        "9053641054174755156237093900703789419231110380734303108548111191701048843443713643143570723634576972430579"
        "6393063925825289709808584094646272e+140"},
    {0x1.fffffffffffffp+466, chars_format::scientific, 140,
        "3."
        "8107282108349510312474187801407578838462220761468606217096222383402097686887427286287141447269153944861159"
        "2786127851650579419617168189292544e+140"},
    {0x1.fffffffffffffp+467, chars_format::scientific, 140,
        "7."
        "6214564216699020624948375602815157676924441522937212434192444766804195373774854572574282894538307889722318"
        "5572255703301158839234336378585088e+140"},
    {0x1.fffffffffffffp+468, chars_format::scientific, 141,
        "1."
        "5242912843339804124989675120563031535384888304587442486838488953360839074754970914514856578907661577944463"
        "71144511406602317678468672757170176e+141"},
    {0x1.fffffffffffffp+469, chars_format::scientific, 141,
        "3."
        "0485825686679608249979350241126063070769776609174884973676977906721678149509941829029713157815323155888927"
        "42289022813204635356937345514340352e+141"},
    {0x1.fffffffffffffp+470, chars_format::scientific, 141,
        "6."
        "0971651373359216499958700482252126141539553218349769947353955813443356299019883658059426315630646311777854"
        "84578045626409270713874691028680704e+141"},
    {0x1.fffffffffffffp+471, chars_format::scientific, 142,
        "1."
        "2194330274671843299991740096450425228307910643669953989470791162688671259803976731611885263126129262355570"
        "969156091252818541427749382057361408e+142"},
    {0x1.fffffffffffffp+472, chars_format::scientific, 142,
        "2."
        "4388660549343686599983480192900850456615821287339907978941582325377342519607953463223770526252258524711141"
        "938312182505637082855498764114722816e+142"},
    {0x1.fffffffffffffp+473, chars_format::scientific, 142,
        "4."
        "8777321098687373199966960385801700913231642574679815957883164650754685039215906926447541052504517049422283"
        "876624365011274165710997528229445632e+142"},
    {0x1.fffffffffffffp+474, chars_format::scientific, 142,
        "9."
        "7554642197374746399933920771603401826463285149359631915766329301509370078431813852895082105009034098844567"
        "753248730022548331421995056458891264e+142"},
    {0x1.fffffffffffffp+475, chars_format::scientific, 143,
        "1."
        "9510928439474949279986784154320680365292657029871926383153265860301874015686362770579016421001806819768913"
        "5506497460045096662843990112917782528e+143"},
    {0x1.fffffffffffffp+476, chars_format::scientific, 143,
        "3."
        "9021856878949898559973568308641360730585314059743852766306531720603748031372725541158032842003613639537827"
        "1012994920090193325687980225835565056e+143"},
    {0x1.fffffffffffffp+477, chars_format::scientific, 143,
        "7."
        "8043713757899797119947136617282721461170628119487705532613063441207496062745451082316065684007227279075654"
        "2025989840180386651375960451671130112e+143"},
    {0x1.fffffffffffffp+478, chars_format::scientific, 144,
        "1."
        "5608742751579959423989427323456544292234125623897541106522612688241499212549090216463213136801445455815130"
        "84051979680360773302751920903342260224e+144"},
    {0x1.fffffffffffffp+479, chars_format::scientific, 144,
        "3."
        "1217485503159918847978854646913088584468251247795082213045225376482998425098180432926426273602890911630261"
        "68103959360721546605503841806684520448e+144"},
    {0x1.fffffffffffffp+480, chars_format::scientific, 144,
        "6."
        "2434971006319837695957709293826177168936502495590164426090450752965996850196360865852852547205781823260523"
        "36207918721443093211007683613369040896e+144"},
    {0x1.fffffffffffffp+481, chars_format::scientific, 145,
        "1."
        "2486994201263967539191541858765235433787300499118032885218090150593199370039272173170570509441156364652104"
        "672415837442886186422015367226738081792e+145"},
    {0x1.fffffffffffffp+482, chars_format::scientific, 145,
        "2."
        "4973988402527935078383083717530470867574600998236065770436180301186398740078544346341141018882312729304209"
        "344831674885772372844030734453476163584e+145"},
    {0x1.fffffffffffffp+483, chars_format::scientific, 145,
        "4."
        "9947976805055870156766167435060941735149201996472131540872360602372797480157088692682282037764625458608418"
        "689663349771544745688061468906952327168e+145"},
    {0x1.fffffffffffffp+484, chars_format::scientific, 145,
        "9."
        "9895953610111740313532334870121883470298403992944263081744721204745594960314177385364564075529250917216837"
        "379326699543089491376122937813904654336e+145"},
    {0x1.fffffffffffffp+485, chars_format::scientific, 146,
        "1."
        "9979190722022348062706466974024376694059680798588852616348944240949118992062835477072912815105850183443367"
        "4758653399086178982752245875627809308672e+146"},
    {0x1.fffffffffffffp+486, chars_format::scientific, 146,
        "3."
        "9958381444044696125412933948048753388119361597177705232697888481898237984125670954145825630211700366886734"
        "9517306798172357965504491751255618617344e+146"},
    {0x1.fffffffffffffp+487, chars_format::scientific, 146,
        "7."
        "9916762888089392250825867896097506776238723194355410465395776963796475968251341908291651260423400733773469"
        "9034613596344715931008983502511237234688e+146"},
    {0x1.fffffffffffffp+488, chars_format::scientific, 147,
        "1."
        "5983352577617878450165173579219501355247744638871082093079155392759295193650268381658330252084680146754693"
        "98069227192689431862017967005022474469376e+147"},
    {0x1.fffffffffffffp+489, chars_format::scientific, 147,
        "3."
        "1966705155235756900330347158439002710495489277742164186158310785518590387300536763316660504169360293509387"
        "96138454385378863724035934010044948938752e+147"},
    {0x1.fffffffffffffp+490, chars_format::scientific, 147,
        "6."
        "3933410310471513800660694316878005420990978555484328372316621571037180774601073526633321008338720587018775"
        "92276908770757727448071868020089897877504e+147"},
    {0x1.fffffffffffffp+491, chars_format::scientific, 148,
        "1."
        "2786682062094302760132138863375601084198195711096865674463324314207436154920214705326664201667744117403755"
        "184553817541515454896143736040179795755008e+148"},
    {0x1.fffffffffffffp+492, chars_format::scientific, 148,
        "2."
        "5573364124188605520264277726751202168396391422193731348926648628414872309840429410653328403335488234807510"
        "369107635083030909792287472080359591510016e+148"},
    {0x1.fffffffffffffp+493, chars_format::scientific, 148,
        "5."
        "1146728248377211040528555453502404336792782844387462697853297256829744619680858821306656806670976469615020"
        "738215270166061819584574944160719183020032e+148"},
    {0x1.fffffffffffffp+494, chars_format::scientific, 149,
        "1."
        "0229345649675442208105711090700480867358556568877492539570659451365948923936171764261331361334195293923004"
        "1476430540332123639169149888321438366040064e+149"},
    {0x1.fffffffffffffp+495, chars_format::scientific, 149,
        "2."
        "0458691299350884416211422181400961734717113137754985079141318902731897847872343528522662722668390587846008"
        "2952861080664247278338299776642876732080128e+149"},
    {0x1.fffffffffffffp+496, chars_format::scientific, 149,
        "4."
        "0917382598701768832422844362801923469434226275509970158282637805463795695744687057045325445336781175692016"
        "5905722161328494556676599553285753464160256e+149"},
    {0x1.fffffffffffffp+497, chars_format::scientific, 149,
        "8."
        "1834765197403537664845688725603846938868452551019940316565275610927591391489374114090650890673562351384033"
        "1811444322656989113353199106571506928320512e+149"},
    {0x1.fffffffffffffp+498, chars_format::scientific, 150,
        "1."
        "6366953039480707532969137745120769387773690510203988063313055122185518278297874822818130178134712470276806"
        "63622888645313978226706398213143013856641024e+150"},
    {0x1.fffffffffffffp+499, chars_format::scientific, 150,
        "3."
        "2733906078961415065938275490241538775547381020407976126626110244371036556595749645636260356269424940553613"
        "27245777290627956453412796426286027713282048e+150"},
    {0x1.fffffffffffffp+500, chars_format::scientific, 150,
        "6."
        "5467812157922830131876550980483077551094762040815952253252220488742073113191499291272520712538849881107226"
        "54491554581255912906825592852572055426564096e+150"},
    {0x1.fffffffffffffp+501, chars_format::scientific, 151,
        "1."
        "3093562431584566026375310196096615510218952408163190450650444097748414622638299858254504142507769976221445"
        "308983109162511825813651185705144110853128192e+151"},
    {0x1.fffffffffffffp+502, chars_format::scientific, 151,
        "2."
        "6187124863169132052750620392193231020437904816326380901300888195496829245276599716509008285015539952442890"
        "617966218325023651627302371410288221706256384e+151"},
    {0x1.fffffffffffffp+503, chars_format::scientific, 151,
        "5."
        "2374249726338264105501240784386462040875809632652761802601776390993658490553199433018016570031079904885781"
        "235932436650047303254604742820576443412512768e+151"},
    {0x1.fffffffffffffp+504, chars_format::scientific, 152,
        "1."
        "0474849945267652821100248156877292408175161926530552360520355278198731698110639886603603314006215980977156"
        "2471864873300094606509209485641152886825025536e+152"},
    {0x1.fffffffffffffp+505, chars_format::scientific, 152,
        "2."
        "0949699890535305642200496313754584816350323853061104721040710556397463396221279773207206628012431961954312"
        "4943729746600189213018418971282305773650051072e+152"},
    {0x1.fffffffffffffp+506, chars_format::scientific, 152,
        "4."
        "1899399781070611284400992627509169632700647706122209442081421112794926792442559546414413256024863923908624"
        "9887459493200378426036837942564611547300102144e+152"},
    {0x1.fffffffffffffp+507, chars_format::scientific, 152,
        "8."
        "3798799562141222568801985255018339265401295412244418884162842225589853584885119092828826512049727847817249"
        "9774918986400756852073675885129223094600204288e+152"},
    {0x1.fffffffffffffp+508, chars_format::scientific, 153,
        "1."
        "6759759912428244513760397051003667853080259082448883776832568445117970716977023818565765302409945569563449"
        "99549837972801513704147351770258446189200408576e+153"},
    {0x1.fffffffffffffp+509, chars_format::scientific, 153,
        "3."
        "3519519824856489027520794102007335706160518164897767553665136890235941433954047637131530604819891139126899"
        "99099675945603027408294703540516892378400817152e+153"},
    {0x1.fffffffffffffp+510, chars_format::scientific, 153,
        "6."
        "7039039649712978055041588204014671412321036329795535107330273780471882867908095274263061209639782278253799"
        "98199351891206054816589407081033784756801634304e+153"},
    {0x1.fffffffffffffp+511, chars_format::scientific, 154,
        "1."
        "3407807929942595611008317640802934282464207265959107021466054756094376573581619054852612241927956455650759"
        "996398703782412109633178814162067569513603268608e+154"},
    {0x1.fffffffffffffp+512, chars_format::scientific, 154,
        "2."
        "6815615859885191222016635281605868564928414531918214042932109512188753147163238109705224483855912911301519"
        "992797407564824219266357628324135139027206537216e+154"},
    {0x1.fffffffffffffp+513, chars_format::scientific, 154,
        "5."
        "3631231719770382444033270563211737129856829063836428085864219024377506294326476219410448967711825822603039"
        "985594815129648438532715256648270278054413074432e+154"},
    {0x1.fffffffffffffp+514, chars_format::scientific, 155,
        "1."
        "0726246343954076488806654112642347425971365812767285617172843804875501258865295243882089793542365164520607"
        "9971189630259296877065430513296540556108826148864e+155"},
    {0x1.fffffffffffffp+515, chars_format::scientific, 155,
        "2."
        "1452492687908152977613308225284694851942731625534571234345687609751002517730590487764179587084730329041215"
        "9942379260518593754130861026593081112217652297728e+155"},
    {0x1.fffffffffffffp+516, chars_format::scientific, 155,
        "4."
        "2904985375816305955226616450569389703885463251069142468691375219502005035461180975528359174169460658082431"
        "9884758521037187508261722053186162224435304595456e+155"},
    {0x1.fffffffffffffp+517, chars_format::scientific, 155,
        "8."
        "5809970751632611910453232901138779407770926502138284937382750439004010070922361951056718348338921316164863"
        "9769517042074375016523444106372324448870609190912e+155"},
    {0x1.fffffffffffffp+518, chars_format::scientific, 156,
        "1."
        "7161994150326522382090646580227755881554185300427656987476550087800802014184472390211343669667784263232972"
        "79539034084148750033046888212744648897741218381824e+156"},
    {0x1.fffffffffffffp+519, chars_format::scientific, 156,
        "3."
        "4323988300653044764181293160455511763108370600855313974953100175601604028368944780422687339335568526465945"
        "59078068168297500066093776425489297795482436763648e+156"},
    {0x1.fffffffffffffp+520, chars_format::scientific, 156,
        "6."
        "8647976601306089528362586320911023526216741201710627949906200351203208056737889560845374678671137052931891"
        "18156136336595000132187552850978595590964873527296e+156"},
    {0x1.fffffffffffffp+521, chars_format::scientific, 157,
        "1."
        "3729595320261217905672517264182204705243348240342125589981240070240641611347577912169074935734227410586378"
        "236312272673190000264375105701957191181929747054592e+157"},
    {0x1.fffffffffffffp+522, chars_format::scientific, 157,
        "2."
        "7459190640522435811345034528364409410486696480684251179962480140481283222695155824338149871468454821172756"
        "472624545346380000528750211403914382363859494109184e+157"},
    {0x1.fffffffffffffp+523, chars_format::scientific, 157,
        "5."
        "4918381281044871622690069056728818820973392961368502359924960280962566445390311648676299742936909642345512"
        "945249090692760001057500422807828764727718988218368e+157"},
    {0x1.fffffffffffffp+524, chars_format::scientific, 158,
        "1."
        "0983676256208974324538013811345763764194678592273700471984992056192513289078062329735259948587381928469102"
        "5890498181385520002115000845615657529455437976436736e+158"},
    {0x1.fffffffffffffp+525, chars_format::scientific, 158,
        "2."
        "1967352512417948649076027622691527528389357184547400943969984112385026578156124659470519897174763856938205"
        "1780996362771040004230001691231315058910875952873472e+158"},
    {0x1.fffffffffffffp+526, chars_format::scientific, 158,
        "4."
        "3934705024835897298152055245383055056778714369094801887939968224770053156312249318941039794349527713876410"
        "3561992725542080008460003382462630117821751905746944e+158"},
    {0x1.fffffffffffffp+527, chars_format::scientific, 158,
        "8."
        "7869410049671794596304110490766110113557428738189603775879936449540106312624498637882079588699055427752820"
        "7123985451084160016920006764925260235643503811493888e+158"},
    {0x1.fffffffffffffp+528, chars_format::scientific, 159,
        "1."
        "7573882009934358919260822098153222022711485747637920755175987289908021262524899727576415917739811085550564"
        "14247970902168320033840013529850520471287007622987776e+159"},
    {0x1.fffffffffffffp+529, chars_format::scientific, 159,
        "3."
        "5147764019868717838521644196306444045422971495275841510351974579816042525049799455152831835479622171101128"
        "28495941804336640067680027059701040942574015245975552e+159"},
    {0x1.fffffffffffffp+530, chars_format::scientific, 159,
        "7."
        "0295528039737435677043288392612888090845942990551683020703949159632085050099598910305663670959244342202256"
        "56991883608673280135360054119402081885148030491951104e+159"},
    {0x1.fffffffffffffp+531, chars_format::scientific, 160,
        "1."
        "4059105607947487135408657678522577618169188598110336604140789831926417010019919782061132734191848868440451"
        "313983767217346560270720108238804163770296060983902208e+160"},
    {0x1.fffffffffffffp+532, chars_format::scientific, 160,
        "2."
        "8118211215894974270817315357045155236338377196220673208281579663852834020039839564122265468383697736880902"
        "627967534434693120541440216477608327540592121967804416e+160"},
    {0x1.fffffffffffffp+533, chars_format::scientific, 160,
        "5."
        "6236422431789948541634630714090310472676754392441346416563159327705668040079679128244530936767395473761805"
        "255935068869386241082880432955216655081184243935608832e+160"},
    {0x1.fffffffffffffp+534, chars_format::scientific, 161,
        "1."
        "1247284486357989708326926142818062094535350878488269283312631865541133608015935825648906187353479094752361"
        "0511870137738772482165760865910433310162368487871217664e+161"},
    {0x1.fffffffffffffp+535, chars_format::scientific, 161,
        "2."
        "2494568972715979416653852285636124189070701756976538566625263731082267216031871651297812374706958189504722"
        "1023740275477544964331521731820866620324736975742435328e+161"},
    {0x1.fffffffffffffp+536, chars_format::scientific, 161,
        "4."
        "4989137945431958833307704571272248378141403513953077133250527462164534432063743302595624749413916379009444"
        "2047480550955089928663043463641733240649473951484870656e+161"},
    {0x1.fffffffffffffp+537, chars_format::scientific, 161,
        "8."
        "9978275890863917666615409142544496756282807027906154266501054924329068864127486605191249498827832758018888"
        "4094961101910179857326086927283466481298947902969741312e+161"},
    {0x1.fffffffffffffp+538, chars_format::scientific, 162,
        "1."
        "7995655178172783533323081828508899351256561405581230853300210984865813772825497321038249899765566551603777"
        "68189922203820359714652173854566932962597895805939482624e+162"},
    {0x1.fffffffffffffp+539, chars_format::scientific, 162,
        "3."
        "5991310356345567066646163657017798702513122811162461706600421969731627545650994642076499799531133103207555"
        "36379844407640719429304347709133865925195791611878965248e+162"},
    {0x1.fffffffffffffp+540, chars_format::scientific, 162,
        "7."
        "1982620712691134133292327314035597405026245622324923413200843939463255091301989284152999599062266206415110"
        "72759688815281438858608695418267731850391583223757930496e+162"},
    {0x1.fffffffffffffp+541, chars_format::scientific, 163,
        "1."
        "4396524142538226826658465462807119481005249124464984682640168787892651018260397856830599919812453241283022"
        "145519377630562877717217390836535463700783166447515860992e+163"},
    {0x1.fffffffffffffp+542, chars_format::scientific, 163,
        "2."
        "8793048285076453653316930925614238962010498248929969365280337575785302036520795713661199839624906482566044"
        "291038755261125755434434781673070927401566332895031721984e+163"},
    {0x1.fffffffffffffp+543, chars_format::scientific, 163,
        "5."
        "7586096570152907306633861851228477924020996497859938730560675151570604073041591427322399679249812965132088"
        "582077510522251510868869563346141854803132665790063443968e+163"},
    {0x1.fffffffffffffp+544, chars_format::scientific, 164,
        "1."
        "1517219314030581461326772370245695584804199299571987746112135030314120814608318285464479935849962593026417"
        "7164155021044503021737739126692283709606265331580126887936e+164"},
    {0x1.fffffffffffffp+545, chars_format::scientific, 164,
        "2."
        "3034438628061162922653544740491391169608398599143975492224270060628241629216636570928959871699925186052835"
        "4328310042089006043475478253384567419212530663160253775872e+164"},
    {0x1.fffffffffffffp+546, chars_format::scientific, 164,
        "4."
        "6068877256122325845307089480982782339216797198287950984448540121256483258433273141857919743399850372105670"
        "8656620084178012086950956506769134838425061326320507551744e+164"},
    {0x1.fffffffffffffp+547, chars_format::scientific, 164,
        "9."
        "2137754512244651690614178961965564678433594396575901968897080242512966516866546283715839486799700744211341"
        "7313240168356024173901913013538269676850122652641015103488e+164"},
    {0x1.fffffffffffffp+548, chars_format::scientific, 165,
        "1."
        "8427550902448930338122835792393112935686718879315180393779416048502593303373309256743167897359940148842268"
        "34626480336712048347803826027076539353700245305282030206976e+165"},
    {0x1.fffffffffffffp+549, chars_format::scientific, 165,
        "3."
        "6855101804897860676245671584786225871373437758630360787558832097005186606746618513486335794719880297684536"
        "69252960673424096695607652054153078707400490610564060413952e+165"},
    {0x1.fffffffffffffp+550, chars_format::scientific, 165,
        "7."
        "3710203609795721352491343169572451742746875517260721575117664194010373213493237026972671589439760595369073"
        "38505921346848193391215304108306157414800981221128120827904e+165"},
    {0x1.fffffffffffffp+551, chars_format::scientific, 166,
        "1."
        "4742040721959144270498268633914490348549375103452144315023532838802074642698647405394534317887952119073814"
        "677011842693696386782430608216612314829601962442256241655808e+166"},
    {0x1.fffffffffffffp+552, chars_format::scientific, 166,
        "2."
        "9484081443918288540996537267828980697098750206904288630047065677604149285397294810789068635775904238147629"
        "354023685387392773564861216433224629659203924884512483311616e+166"},
    {0x1.fffffffffffffp+553, chars_format::scientific, 166,
        "5."
        "8968162887836577081993074535657961394197500413808577260094131355208298570794589621578137271551808476295258"
        "708047370774785547129722432866449259318407849769024966623232e+166"},
    {0x1.fffffffffffffp+554, chars_format::scientific, 167,
        "1."
        "1793632577567315416398614907131592278839500082761715452018826271041659714158917924315627454310361695259051"
        "7416094741549571094259444865732898518636815699538049933246464e+167"},
    {0x1.fffffffffffffp+555, chars_format::scientific, 167,
        "2."
        "3587265155134630832797229814263184557679000165523430904037652542083319428317835848631254908620723390518103"
        "4832189483099142188518889731465797037273631399076099866492928e+167"},
    {0x1.fffffffffffffp+556, chars_format::scientific, 167,
        "4."
        "7174530310269261665594459628526369115358000331046861808075305084166638856635671697262509817241446781036206"
        "9664378966198284377037779462931594074547262798152199732985856e+167"},
    {0x1.fffffffffffffp+557, chars_format::scientific, 167,
        "9."
        "4349060620538523331188919257052738230716000662093723616150610168333277713271343394525019634482893562072413"
        "9328757932396568754075558925863188149094525596304399465971712e+167"},
    {0x1.fffffffffffffp+558, chars_format::scientific, 168,
        "1."
        "8869812124107704666237783851410547646143200132418744723230122033666655542654268678905003926896578712414482"
        "78657515864793137508151117851726376298189051192608798931943424e+168"},
    {0x1.fffffffffffffp+559, chars_format::scientific, 168,
        "3."
        "7739624248215409332475567702821095292286400264837489446460244067333311085308537357810007853793157424828965"
        "57315031729586275016302235703452752596378102385217597863886848e+168"},
    {0x1.fffffffffffffp+560, chars_format::scientific, 168,
        "7."
        "5479248496430818664951135405642190584572800529674978892920488134666622170617074715620015707586314849657931"
        "14630063459172550032604471406905505192756204770435195727773696e+168"},
    {0x1.fffffffffffffp+561, chars_format::scientific, 169,
        "1."
        "5095849699286163732990227081128438116914560105934995778584097626933324434123414943124003141517262969931586"
        "229260126918345100065208942813811010385512409540870391455547392e+169"},
    {0x1.fffffffffffffp+562, chars_format::scientific, 169,
        "3."
        "0191699398572327465980454162256876233829120211869991557168195253866648868246829886248006283034525939863172"
        "458520253836690200130417885627622020771024819081740782911094784e+169"},
    {0x1.fffffffffffffp+563, chars_format::scientific, 169,
        "6."
        "0383398797144654931960908324513752467658240423739983114336390507733297736493659772496012566069051879726344"
        "917040507673380400260835771255244041542049638163481565822189568e+169"},
    {0x1.fffffffffffffp+564, chars_format::scientific, 170,
        "1."
        "2076679759428930986392181664902750493531648084747996622867278101546659547298731954499202513213810375945268"
        "9834081015346760800521671542510488083084099276326963131644379136e+170"},
    {0x1.fffffffffffffp+565, chars_format::scientific, 170,
        "2."
        "4153359518857861972784363329805500987063296169495993245734556203093319094597463908998405026427620751890537"
        "9668162030693521601043343085020976166168198552653926263288758272e+170"},
    {0x1.fffffffffffffp+566, chars_format::scientific, 170,
        "4."
        "8306719037715723945568726659611001974126592338991986491469112406186638189194927817996810052855241503781075"
        "9336324061387043202086686170041952332336397105307852526577516544e+170"},
    {0x1.fffffffffffffp+567, chars_format::scientific, 170,
        "9."
        "6613438075431447891137453319222003948253184677983972982938224812373276378389855635993620105710483007562151"
        "8672648122774086404173372340083904664672794210615705053155033088e+170"},
    {0x1.fffffffffffffp+568, chars_format::scientific, 171,
        "1."
        "9322687615086289578227490663844400789650636935596794596587644962474655275677971127198724021142096601512430"
        "37345296245548172808346744680167809329345588421231410106310066176e+171"},
    {0x1.fffffffffffffp+569, chars_format::scientific, 171,
        "3."
        "8645375230172579156454981327688801579301273871193589193175289924949310551355942254397448042284193203024860"
        "74690592491096345616693489360335618658691176842462820212620132352e+171"},
    {0x1.fffffffffffffp+570, chars_format::scientific, 171,
        "7."
        "7290750460345158312909962655377603158602547742387178386350579849898621102711884508794896084568386406049721"
        "49381184982192691233386978720671237317382353684925640425240264704e+171"},
    {0x1.fffffffffffffp+571, chars_format::scientific, 172,
        "1."
        "5458150092069031662581992531075520631720509548477435677270115969979724220542376901758979216913677281209944"
        "298762369964385382466773957441342474634764707369851280850480529408e+172"},
    {0x1.fffffffffffffp+572, chars_format::scientific, 172,
        "3."
        "0916300184138063325163985062151041263441019096954871354540231939959448441084753803517958433827354562419888"
        "597524739928770764933547914882684949269529414739702561700961058816e+172"},
    {0x1.fffffffffffffp+573, chars_format::scientific, 172,
        "6."
        "1832600368276126650327970124302082526882038193909742709080463879918896882169507607035916867654709124839777"
        "195049479857541529867095829765369898539058829479405123401922117632e+172"},
    {0x1.fffffffffffffp+574, chars_format::scientific, 173,
        "1."
        "2366520073655225330065594024860416505376407638781948541816092775983779376433901521407183373530941824967955"
        "4390098959715083059734191659530739797078117658958810246803844235264e+173"},
    {0x1.fffffffffffffp+575, chars_format::scientific, 173,
        "2."
        "4733040147310450660131188049720833010752815277563897083632185551967558752867803042814366747061883649935910"
        "8780197919430166119468383319061479594156235317917620493607688470528e+173"},
    {0x1.fffffffffffffp+576, chars_format::scientific, 173,
        "4."
        "9466080294620901320262376099441666021505630555127794167264371103935117505735606085628733494123767299871821"
        "7560395838860332238936766638122959188312470635835240987215376941056e+173"},
    {0x1.fffffffffffffp+577, chars_format::scientific, 173,
        "9."
        "8932160589241802640524752198883332043011261110255588334528742207870235011471212171257466988247534599743643"
        "5120791677720664477873533276245918376624941271670481974430753882112e+173"},
    {0x1.fffffffffffffp+578, chars_format::scientific, 174,
        "1."
        "9786432117848360528104950439776666408602252222051117666905748441574047002294242434251493397649506919948728"
        "70241583355441328955747066552491836753249882543340963948861507764224e+174"},
    {0x1.fffffffffffffp+579, chars_format::scientific, 174,
        "3."
        "9572864235696721056209900879553332817204504444102235333811496883148094004588484868502986795299013839897457"
        "40483166710882657911494133104983673506499765086681927897723015528448e+174"},
    {0x1.fffffffffffffp+580, chars_format::scientific, 174,
        "7."
        "9145728471393442112419801759106665634409008888204470667622993766296188009176969737005973590598027679794914"
        "80966333421765315822988266209967347012999530173363855795446031056896e+174"},
    {0x1.fffffffffffffp+581, chars_format::scientific, 175,
        "1."
        "5829145694278688422483960351821333126881801777640894133524598753259237601835393947401194718119605535958982"
        "961932666843530631645976532419934694025999060346727711590892062113792e+175"},
    {0x1.fffffffffffffp+582, chars_format::scientific, 175,
        "3."
        "1658291388557376844967920703642666253763603555281788267049197506518475203670787894802389436239211071917965"
        "923865333687061263291953064839869388051998120693455423181784124227584e+175"},
    {0x1.fffffffffffffp+583, chars_format::scientific, 175,
        "6."
        "3316582777114753689935841407285332507527207110563576534098395013036950407341575789604778872478422143835931"
        "847730667374122526583906129679738776103996241386910846363568248455168e+175"},
    {0x1.fffffffffffffp+584, chars_format::scientific, 176,
        "1."
        "2663316555422950737987168281457066501505441422112715306819679002607390081468315157920955774495684428767186"
        "3695461334748245053167812259359477552207992482773821692727136496910336e+176"},
    {0x1.fffffffffffffp+585, chars_format::scientific, 176,
        "2."
        "5326633110845901475974336562914133003010882844225430613639358005214780162936630315841911548991368857534372"
        "7390922669496490106335624518718955104415984965547643385454272993820672e+176"},
    {0x1.fffffffffffffp+586, chars_format::scientific, 176,
        "5."
        "0653266221691802951948673125828266006021765688450861227278716010429560325873260631683823097982737715068745"
        "4781845338992980212671249037437910208831969931095286770908545987641344e+176"},
    {0x1.fffffffffffffp+587, chars_format::scientific, 177,
        "1."
        "0130653244338360590389734625165653201204353137690172245455743202085912065174652126336764619596547543013749"
        "09563690677985960425342498074875820417663939862190573541817091975282688e+177"},
    {0x1.fffffffffffffp+588, chars_format::scientific, 177,
        "2."
        "0261306488676721180779469250331306402408706275380344490911486404171824130349304252673529239193095086027498"
        "19127381355971920850684996149751640835327879724381147083634183950565376e+177"},
    {0x1.fffffffffffffp+589, chars_format::scientific, 177,
        "4."
        "0522612977353442361558938500662612804817412550760688981822972808343648260698608505347058478386190172054996"
        "38254762711943841701369992299503281670655759448762294167268367901130752e+177"},
    {0x1.fffffffffffffp+590, chars_format::scientific, 177,
        "8."
        "1045225954706884723117877001325225609634825101521377963645945616687296521397217010694116956772380344109992"
        "76509525423887683402739984599006563341311518897524588334536735802261504e+177"},
    {0x1.fffffffffffffp+591, chars_format::scientific, 178,
        "1."
        "6209045190941376944623575400265045121926965020304275592729189123337459304279443402138823391354476068821998"
        "553019050847775366805479969198013126682623037795049176669073471604523008e+178"},
    {0x1.fffffffffffffp+592, chars_format::scientific, 178,
        "3."
        "2418090381882753889247150800530090243853930040608551185458378246674918608558886804277646782708952137643997"
        "106038101695550733610959938396026253365246075590098353338146943209046016e+178"},
    {0x1.fffffffffffffp+593, chars_format::scientific, 178,
        "6."
        "4836180763765507778494301601060180487707860081217102370916756493349837217117773608555293565417904275287994"
        "212076203391101467221919876792052506730492151180196706676293886418092032e+178"},
    {0x1.fffffffffffffp+594, chars_format::scientific, 179,
        "1."
        "2967236152753101555698860320212036097541572016243420474183351298669967443423554721711058713083580855057598"
        "8424152406782202934443839753584105013460984302360393413352587772836184064e+179"},
    {0x1.fffffffffffffp+595, chars_format::scientific, 179,
        "2."
        "5934472305506203111397720640424072195083144032486840948366702597339934886847109443422117426167161710115197"
        "6848304813564405868887679507168210026921968604720786826705175545672368128e+179"},
    {0x1.fffffffffffffp+596, chars_format::scientific, 179,
        "5."
        "1868944611012406222795441280848144390166288064973681896733405194679869773694218886844234852334323420230395"
        "3696609627128811737775359014336420053843937209441573653410351091344736256e+179"},
    {0x1.fffffffffffffp+597, chars_format::scientific, 180,
        "1."
        "0373788922202481244559088256169628878033257612994736379346681038935973954738843777368846970466864684046079"
        "07393219254257623475550718028672840107687874418883147306820702182689472512e+180"},
    {0x1.fffffffffffffp+598, chars_format::scientific, 180,
        "2."
        "0747577844404962489118176512339257756066515225989472758693362077871947909477687554737693940933729368092158"
        "14786438508515246951101436057345680215375748837766294613641404365378945024e+180"},
    {0x1.fffffffffffffp+599, chars_format::scientific, 180,
        "4."
        "1495155688809924978236353024678515512133030451978945517386724155743895818955375109475387881867458736184316"
        "29572877017030493902202872114691360430751497675532589227282808730757890048e+180"},
    {0x1.fffffffffffffp+600, chars_format::scientific, 180,
        "8."
        "2990311377619849956472706049357031024266060903957891034773448311487791637910750218950775763734917472368632"
        "59145754034060987804405744229382720861502995351065178454565617461515780096e+180"},
    {0x1.fffffffffffffp+601, chars_format::scientific, 181,
        "1."
        "6598062275523969991294541209871406204853212180791578206954689662297558327582150043790155152746983494473726"
        "518291508068121975608811488458765441723005990702130356909131234923031560192e+181"},
    {0x1.fffffffffffffp+602, chars_format::scientific, 181,
        "3."
        "3196124551047939982589082419742812409706424361583156413909379324595116655164300087580310305493966988947453"
        "036583016136243951217622976917530883446011981404260713818262469846063120384e+181"},
    {0x1.fffffffffffffp+603, chars_format::scientific, 181,
        "6."
        "6392249102095879965178164839485624819412848723166312827818758649190233310328600175160620610987933977894906"
        "073166032272487902435245953835061766892023962808521427636524939692126240768e+181"},
    {0x1.fffffffffffffp+604, chars_format::scientific, 182,
        "1."
        "3278449820419175993035632967897124963882569744633262565563751729838046662065720035032124122197586795578981"
        "2146332064544975804870491907670123533784047925617042855273049879384252481536e+182"},
    {0x1.fffffffffffffp+605, chars_format::scientific, 182,
        "2."
        "6556899640838351986071265935794249927765139489266525131127503459676093324131440070064248244395173591157962"
        "4292664129089951609740983815340247067568095851234085710546099758768504963072e+182"},
    {0x1.fffffffffffffp+606, chars_format::scientific, 182,
        "5."
        "3113799281676703972142531871588499855530278978533050262255006919352186648262880140128496488790347182315924"
        "8585328258179903219481967630680494135136191702468171421092199517537009926144e+182"},
    {0x1.fffffffffffffp+607, chars_format::scientific, 183,
        "1."
        "0622759856335340794428506374317699971106055795706610052451001383870437329652576028025699297758069436463184"
        "97170656516359806438963935261360988270272383404936342842184399035074019852288e+183"},
    {0x1.fffffffffffffp+608, chars_format::scientific, 183,
        "2."
        "1245519712670681588857012748635399942212111591413220104902002767740874659305152056051398595516138872926369"
        "94341313032719612877927870522721976540544766809872685684368798070148039704576e+183"},
    {0x1.fffffffffffffp+609, chars_format::scientific, 183,
        "4."
        "2491039425341363177714025497270799884424223182826440209804005535481749318610304112102797191032277745852739"
        "88682626065439225755855741045443953081089533619745371368737596140296079409152e+183"},
    {0x1.fffffffffffffp+610, chars_format::scientific, 183,
        "8."
        "4982078850682726355428050994541599768848446365652880419608011070963498637220608224205594382064555491705479"
        "77365252130878451511711482090887906162179067239490742737475192280592158818304e+183"},
    {0x1.fffffffffffffp+611, chars_format::scientific, 184,
        "1."
        "6996415770136545271085610198908319953769689273130576083921602214192699727444121644841118876412911098341095"
        "954730504261756903023422964181775812324358134478981485474950384561184317636608e+184"},
    {0x1.fffffffffffffp+612, chars_format::scientific, 184,
        "3."
        "3992831540273090542171220397816639907539378546261152167843204428385399454888243289682237752825822196682191"
        "909461008523513806046845928363551624648716268957962970949900769122368635273216e+184"},
    {0x1.fffffffffffffp+613, chars_format::scientific, 184,
        "6."
        "7985663080546181084342440795633279815078757092522304335686408856770798909776486579364475505651644393364383"
        "818922017047027612093691856727103249297432537915925941899801538244737270546432e+184"},
    {0x1.fffffffffffffp+614, chars_format::scientific, 185,
        "1."
        "3597132616109236216868488159126655963015751418504460867137281771354159781955297315872895101130328878672876"
        "7637844034094055224187383713454206498594865075831851883799603076489474541092864e+185"},
    {0x1.fffffffffffffp+615, chars_format::scientific, 185,
        "2."
        "7194265232218472433736976318253311926031502837008921734274563542708319563910594631745790202260657757345753"
        "5275688068188110448374767426908412997189730151663703767599206152978949082185728e+185"},
    {0x1.fffffffffffffp+616, chars_format::scientific, 185,
        "5."
        "4388530464436944867473952636506623852063005674017843468549127085416639127821189263491580404521315514691507"
        "0551376136376220896749534853816825994379460303327407535198412305957898164371456e+185"},
    {0x1.fffffffffffffp+617, chars_format::scientific, 186,
        "1."
        "0877706092887388973494790527301324770412601134803568693709825417083327825564237852698316080904263102938301"
        "41102752272752441793499069707633651988758920606654815070396824611915796328742912e+186"},
    {0x1.fffffffffffffp+618, chars_format::scientific, 186,
        "2."
        "1755412185774777946989581054602649540825202269607137387419650834166655651128475705396632161808526205876602"
        "82205504545504883586998139415267303977517841213309630140793649223831592657485824e+186"},
    {0x1.fffffffffffffp+619, chars_format::scientific, 186,
        "4."
        "3510824371549555893979162109205299081650404539214274774839301668333311302256951410793264323617052411753205"
        "64411009091009767173996278830534607955035682426619260281587298447663185314971648e+186"},
    {0x1.fffffffffffffp+620, chars_format::scientific, 186,
        "8."
        "7021648743099111787958324218410598163300809078428549549678603336666622604513902821586528647234104823506411"
        "28822018182019534347992557661069215910071364853238520563174596895326370629943296e+186"},
    {0x1.fffffffffffffp+621, chars_format::scientific, 187,
        "1."
        "7404329748619822357591664843682119632660161815685709909935720667333324520902780564317305729446820964701282"
        "257644036364039068695985115322138431820142729706477041126349193790652741259886592e+187"},
    {0x1.fffffffffffffp+622, chars_format::scientific, 187,
        "3."
        "4808659497239644715183329687364239265320323631371419819871441334666649041805561128634611458893641929402564"
        "515288072728078137391970230644276863640285459412954082252698387581305482519773184e+187"},
    {0x1.fffffffffffffp+623, chars_format::scientific, 187,
        "6."
        "9617318994479289430366659374728478530640647262742839639742882669333298083611122257269222917787283858805129"
        "030576145456156274783940461288553727280570918825908164505396775162610965039546368e+187"},
    {0x1.fffffffffffffp+624, chars_format::scientific, 188,
        "1."
        "3923463798895857886073331874945695706128129452548567927948576533866659616722224451453844583557456771761025"
        "8061152290912312549567880922577107454561141837651816329010793550325221930079092736e+188"},
    {0x1.fffffffffffffp+625, chars_format::scientific, 188,
        "2."
        "7846927597791715772146663749891391412256258905097135855897153067733319233444448902907689167114913543522051"
        "6122304581824625099135761845154214909122283675303632658021587100650443860158185472e+188"},
    {0x1.fffffffffffffp+626, chars_format::scientific, 188,
        "5."
        "5693855195583431544293327499782782824512517810194271711794306135466638466888897805815378334229827087044103"
        "2244609163649250198271523690308429818244567350607265316043174201300887720316370944e+188"},
    {0x1.fffffffffffffp+627, chars_format::scientific, 189,
        "1."
        "1138771039116686308858665499956556564902503562038854342358861227093327693377779561163075666845965417408820"
        "64489218327298500396543047380616859636489134701214530632086348402601775440632741888e+189"},
    {0x1.fffffffffffffp+628, chars_format::scientific, 189,
        "2."
        "2277542078233372617717330999913113129805007124077708684717722454186655386755559122326151333691930834817641"
        "28978436654597000793086094761233719272978269402429061264172696805203550881265483776e+189"},
    {0x1.fffffffffffffp+629, chars_format::scientific, 189,
        "4."
        "4555084156466745235434661999826226259610014248155417369435444908373310773511118244652302667383861669635282"
        "57956873309194001586172189522467438545956538804858122528345393610407101762530967552e+189"},
    {0x1.fffffffffffffp+630, chars_format::scientific, 189,
        "8."
        "9110168312933490470869323999652452519220028496310834738870889816746621547022236489304605334767723339270565"
        "15913746618388003172344379044934877091913077609716245056690787220814203525061935104e+189"},
    {0x1.fffffffffffffp+631, chars_format::scientific, 190,
        "1."
        "7822033662586698094173864799930490503844005699262166947774177963349324309404447297860921066953544667854113"
        "031827493236776006344688758089869754183826155219432490113381574441628407050123870208e+190"},
    {0x1.fffffffffffffp+632, chars_format::scientific, 190,
        "3."
        "5644067325173396188347729599860981007688011398524333895548355926698648618808894595721842133907089335708226"
        "063654986473552012689377516179739508367652310438864980226763148883256814100247740416e+190"},
    {0x1.fffffffffffffp+633, chars_format::scientific, 190,
        "7."
        "1288134650346792376695459199721962015376022797048667791096711853397297237617789191443684267814178671416452"
        "127309972947104025378755032359479016735304620877729960453526297766513628200495480832e+190"},
    {0x1.fffffffffffffp+634, chars_format::scientific, 191,
        "1."
        "4257626930069358475339091839944392403075204559409733558219342370679459447523557838288736853562835734283290"
        "4254619945894208050757510064718958033470609241755459920907052595533027256400990961664e+191"},
    {0x1.fffffffffffffp+635, chars_format::scientific, 191,
        "2."
        "8515253860138716950678183679888784806150409118819467116438684741358918895047115676577473707125671468566580"
        "8509239891788416101515020129437916066941218483510919841814105191066054512801981923328e+191"},
    {0x1.fffffffffffffp+636, chars_format::scientific, 191,
        "5."
        "7030507720277433901356367359777569612300818237638934232877369482717837790094231353154947414251342937133161"
        "7018479783576832203030040258875832133882436967021839683628210382132109025603963846656e+191"},
    {0x1.fffffffffffffp+637, chars_format::scientific, 192,
        "1."
        "1406101544055486780271273471955513922460163647527786846575473896543567558018846270630989482850268587426632"
        "34036959567153664406060080517751664267764873934043679367256420764264218051207927693312e+192"},
    {0x1.fffffffffffffp+638, chars_format::scientific, 192,
        "2."
        "2812203088110973560542546943911027844920327295055573693150947793087135116037692541261978965700537174853264"
        "68073919134307328812120161035503328535529747868087358734512841528528436102415855386624e+192"},
    {0x1.fffffffffffffp+639, chars_format::scientific, 192,
        "4."
        "5624406176221947121085093887822055689840654590111147386301895586174270232075385082523957931401074349706529"
        "36147838268614657624240322071006657071059495736174717469025683057056872204831710773248e+192"},
    {0x1.fffffffffffffp+640, chars_format::scientific, 192,
        "9."
        "1248812352443894242170187775644111379681309180222294772603791172348540464150770165047915862802148699413058"
        "72295676537229315248480644142013314142118991472349434938051366114113744409663421546496e+192"},
    {0x1.fffffffffffffp+641, chars_format::scientific, 193,
        "1."
        "8249762470488778848434037555128822275936261836044458954520758234469708092830154033009583172560429739882611"
        "744591353074458630496961288284026628284237982944698869876102732228227488819326843092992e+193"},
    {0x1.fffffffffffffp+642, chars_format::scientific, 193,
        "3."
        "6499524940977557696868075110257644551872523672088917909041516468939416185660308066019166345120859479765223"
        "489182706148917260993922576568053256568475965889397739752205464456454977638653686185984e+193"},
    {0x1.fffffffffffffp+643, chars_format::scientific, 193,
        "7."
        "2999049881955115393736150220515289103745047344177835818083032937878832371320616132038332690241718959530446"
        "978365412297834521987845153136106513136951931778795479504410928912909955277307372371968e+193"},
    {0x1.fffffffffffffp+644, chars_format::scientific, 194,
        "1."
        "4599809976391023078747230044103057820749009468835567163616606587575766474264123226407666538048343791906089"
        "3956730824595669043975690306272213026273903863557590959008821857825819910554614744743936e+194"},
    {0x1.fffffffffffffp+645, chars_format::scientific, 194,
        "2."
        "9199619952782046157494460088206115641498018937671134327233213175151532948528246452815333076096687583812178"
        "7913461649191338087951380612544426052547807727115181918017643715651639821109229489487872e+194"},
    {0x1.fffffffffffffp+646, chars_format::scientific, 194,
        "5."
        "8399239905564092314988920176412231282996037875342268654466426350303065897056492905630666152193375167624357"
        "5826923298382676175902761225088852105095615454230363836035287431303279642218458978975744e+194"},
    {0x1.fffffffffffffp+647, chars_format::scientific, 195,
        "1."
        "1679847981112818462997784035282446256599207575068453730893285270060613179411298581126133230438675033524871"
        "51653846596765352351805522450177704210191230908460727672070574862606559284436917957951488e+195"},
    {0x1.fffffffffffffp+648, chars_format::scientific, 195,
        "2."
        "3359695962225636925995568070564892513198415150136907461786570540121226358822597162252266460877350067049743"
        "03307693193530704703611044900355408420382461816921455344141149725213118568873835915902976e+195"},
    {0x1.fffffffffffffp+649, chars_format::scientific, 195,
        "4."
        "6719391924451273851991136141129785026396830300273814923573141080242452717645194324504532921754700134099486"
        "06615386387061409407222089800710816840764923633842910688282299450426237137747671831805952e+195"},
    {0x1.fffffffffffffp+650, chars_format::scientific, 195,
        "9."
        "3438783848902547703982272282259570052793660600547629847146282160484905435290388649009065843509400268198972"
        "13230772774122818814444179601421633681529847267685821376564598900852474275495343663611904e+195"},
    {0x1.fffffffffffffp+651, chars_format::scientific, 196,
        "1."
        "8687756769780509540796454456451914010558732120109525969429256432096981087058077729801813168701880053639794"
        "426461545548245637628888359202843267363059694535371642753129197801704948550990687327223808e+196"},
    {0x1.fffffffffffffp+652, chars_format::scientific, 196,
        "3."
        "7375513539561019081592908912903828021117464240219051938858512864193962174116155459603626337403760107279588"
        "852923091096491275257776718405686534726119389070743285506258395603409897101981374654447616e+196"},
    {0x1.fffffffffffffp+653, chars_format::scientific, 196,
        "7."
        "4751027079122038163185817825807656042234928480438103877717025728387924348232310919207252674807520214559177"
        "705846182192982550515553436811373069452238778141486571012516791206819794203962749308895232e+196"},
    {0x1.fffffffffffffp+654, chars_format::scientific, 197,
        "1."
        "4950205415824407632637163565161531208446985696087620775543405145677584869646462183841450534961504042911835"
        "5411692364385965101031106873622746138904477556282973142025033582413639588407925498617790464e+197"},
    {0x1.fffffffffffffp+655, chars_format::scientific, 197,
        "2."
        "990041083164881526527432713032306241689397139217524155108681029135516973929292436768290106992300808582